/**
 * BSD 3-Clause License
 *
 * Copyright (c) 2018-2020, Virgil Security, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 * * Redistributions of source code must retain the above copyright notice, this
 * list of conditions and the following disclaimer.
 *
 * * Redistributions in binary form must reproduce the above copyright notice,
 * this list of conditions and the following disclaimer in the documentation
 * and/or other materials provided with the distribution.
 *
 * * Neither the name of the copyright holder nor the names of its
 * contributors may be used to endorse or promote products derived from
 * this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

(function (global, factory) {
            typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports) :
            typeof define === 'function' && define.amd ? define(['exports'], factory) :
            (global = global || self, factory(global.E3kit = {}));
}(this, (function (exports) { 'use strict';

            var global$1 = (typeof global !== "undefined" ? global :
                        typeof self !== "undefined" ? self :
                        typeof window !== "undefined" ? window : {});

            // shim for using process in browser
            // based off https://github.com/defunctzombie/node-process/blob/master/browser.js

            function defaultSetTimout() {
                throw new Error('setTimeout has not been defined');
            }
            function defaultClearTimeout () {
                throw new Error('clearTimeout has not been defined');
            }
            var cachedSetTimeout = defaultSetTimout;
            var cachedClearTimeout = defaultClearTimeout;
            if (typeof global$1.setTimeout === 'function') {
                cachedSetTimeout = setTimeout;
            }
            if (typeof global$1.clearTimeout === 'function') {
                cachedClearTimeout = clearTimeout;
            }

            function runTimeout(fun) {
                if (cachedSetTimeout === setTimeout) {
                    //normal enviroments in sane situations
                    return setTimeout(fun, 0);
                }
                // if setTimeout wasn't available but was latter defined
                if ((cachedSetTimeout === defaultSetTimout || !cachedSetTimeout) && setTimeout) {
                    cachedSetTimeout = setTimeout;
                    return setTimeout(fun, 0);
                }
                try {
                    // when when somebody has screwed with setTimeout but no I.E. maddness
                    return cachedSetTimeout(fun, 0);
                } catch(e){
                    try {
                        // When we are in I.E. but the script has been evaled so I.E. doesn't trust the global object when called normally
                        return cachedSetTimeout.call(null, fun, 0);
                    } catch(e){
                        // same as above but when it's a version of I.E. that must have the global object for 'this', hopfully our context correct otherwise it will throw a global error
                        return cachedSetTimeout.call(this, fun, 0);
                    }
                }


            }
            function runClearTimeout(marker) {
                if (cachedClearTimeout === clearTimeout) {
                    //normal enviroments in sane situations
                    return clearTimeout(marker);
                }
                // if clearTimeout wasn't available but was latter defined
                if ((cachedClearTimeout === defaultClearTimeout || !cachedClearTimeout) && clearTimeout) {
                    cachedClearTimeout = clearTimeout;
                    return clearTimeout(marker);
                }
                try {
                    // when when somebody has screwed with setTimeout but no I.E. maddness
                    return cachedClearTimeout(marker);
                } catch (e){
                    try {
                        // When we are in I.E. but the script has been evaled so I.E. doesn't  trust the global object when called normally
                        return cachedClearTimeout.call(null, marker);
                    } catch (e){
                        // same as above but when it's a version of I.E. that must have the global object for 'this', hopfully our context correct otherwise it will throw a global error.
                        // Some versions of I.E. have different rules for clearTimeout vs setTimeout
                        return cachedClearTimeout.call(this, marker);
                    }
                }



            }
            var queue = [];
            var draining = false;
            var currentQueue;
            var queueIndex = -1;

            function cleanUpNextTick() {
                if (!draining || !currentQueue) {
                    return;
                }
                draining = false;
                if (currentQueue.length) {
                    queue = currentQueue.concat(queue);
                } else {
                    queueIndex = -1;
                }
                if (queue.length) {
                    drainQueue();
                }
            }

            function drainQueue() {
                if (draining) {
                    return;
                }
                var timeout = runTimeout(cleanUpNextTick);
                draining = true;

                var len = queue.length;
                while(len) {
                    currentQueue = queue;
                    queue = [];
                    while (++queueIndex < len) {
                        if (currentQueue) {
                            currentQueue[queueIndex].run();
                        }
                    }
                    queueIndex = -1;
                    len = queue.length;
                }
                currentQueue = null;
                draining = false;
                runClearTimeout(timeout);
            }
            function nextTick(fun) {
                var args = new Array(arguments.length - 1);
                if (arguments.length > 1) {
                    for (var i = 1; i < arguments.length; i++) {
                        args[i - 1] = arguments[i];
                    }
                }
                queue.push(new Item(fun, args));
                if (queue.length === 1 && !draining) {
                    runTimeout(drainQueue);
                }
            }
            // v8 likes predictible objects
            function Item(fun, array) {
                this.fun = fun;
                this.array = array;
            }
            Item.prototype.run = function () {
                this.fun.apply(null, this.array);
            };
            var title = 'browser';
            var platform = 'browser';
            var browser = true;
            var env = {};
            var argv = [];
            var version = ''; // empty string to avoid regexp issues
            var versions = {};
            var release = {};
            var config = {};

            function noop() {}

            var on = noop;
            var addListener = noop;
            var once = noop;
            var off = noop;
            var removeListener = noop;
            var removeAllListeners = noop;
            var emit = noop;

            function binding(name) {
                throw new Error('process.binding is not supported');
            }

            function cwd () { return '/' }
            function chdir (dir) {
                throw new Error('process.chdir is not supported');
            }function umask() { return 0; }

            // from https://github.com/kumavis/browser-process-hrtime/blob/master/index.js
            var performance = global$1.performance || {};
            var performanceNow =
              performance.now        ||
              performance.mozNow     ||
              performance.msNow      ||
              performance.oNow       ||
              performance.webkitNow  ||
              function(){ return (new Date()).getTime() };

            // generate timestamp or delta
            // see http://nodejs.org/api/process.html#process_process_hrtime
            function hrtime(previousTimestamp){
              var clocktime = performanceNow.call(performance)*1e-3;
              var seconds = Math.floor(clocktime);
              var nanoseconds = Math.floor((clocktime%1)*1e9);
              if (previousTimestamp) {
                seconds = seconds - previousTimestamp[0];
                nanoseconds = nanoseconds - previousTimestamp[1];
                if (nanoseconds<0) {
                  seconds--;
                  nanoseconds += 1e9;
                }
              }
              return [seconds,nanoseconds]
            }

            var startTime = new Date();
            function uptime() {
              var currentTime = new Date();
              var dif = currentTime - startTime;
              return dif / 1000;
            }

            var process = {
              nextTick: nextTick,
              title: title,
              browser: browser,
              env: env,
              argv: argv,
              version: version,
              versions: versions,
              on: on,
              addListener: addListener,
              once: once,
              off: off,
              removeListener: removeListener,
              removeAllListeners: removeAllListeners,
              emit: emit,
              binding: binding,
              cwd: cwd,
              chdir: chdir,
              umask: umask,
              hrtime: hrtime,
              platform: platform,
              release: release,
              config: config,
              uptime: uptime
            };

            var commonjsGlobal = typeof globalThis !== 'undefined' ? globalThis : typeof window !== 'undefined' ? window : typeof global$1 !== 'undefined' ? global$1 : typeof self !== 'undefined' ? self : {};

            function createCommonjsModule(fn, module) {
            	return module = { exports: {} }, fn(module, module.exports), module.exports;
            }

            var base64 = createCommonjsModule(function (module, exports) {
            (function(root) {

            	// Detect free variables `exports`.
            	var freeExports =  exports;

            	// Detect free variable `module`.
            	var freeModule =  module &&
            		module.exports == freeExports && module;

            	// Detect free variable `global`, from Node.js or Browserified code, and use
            	// it as `root`.
            	var freeGlobal = typeof commonjsGlobal == 'object' && commonjsGlobal;
            	if (freeGlobal.global === freeGlobal || freeGlobal.window === freeGlobal) {
            		root = freeGlobal;
            	}

            	/*--------------------------------------------------------------------------*/

            	var InvalidCharacterError = function(message) {
            		this.message = message;
            	};
            	InvalidCharacterError.prototype = new Error;
            	InvalidCharacterError.prototype.name = 'InvalidCharacterError';

            	var error = function(message) {
            		// Note: the error messages used throughout this file match those used by
            		// the native `atob`/`btoa` implementation in Chromium.
            		throw new InvalidCharacterError(message);
            	};

            	var TABLE = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
            	// http://whatwg.org/html/common-microsyntaxes.html#space-character
            	var REGEX_SPACE_CHARACTERS = /[\t\n\f\r ]/g;

            	// `decode` is designed to be fully compatible with `atob` as described in the
            	// HTML Standard. http://whatwg.org/html/webappapis.html#dom-windowbase64-atob
            	// The optimized base64-decoding algorithm used is based on @atk’s excellent
            	// implementation. https://gist.github.com/atk/1020396
            	var decode = function(input) {
            		input = String(input)
            			.replace(REGEX_SPACE_CHARACTERS, '');
            		var length = input.length;
            		if (length % 4 == 0) {
            			input = input.replace(/==?$/, '');
            			length = input.length;
            		}
            		if (
            			length % 4 == 1 ||
            			// http://whatwg.org/C#alphanumeric-ascii-characters
            			/[^+a-zA-Z0-9/]/.test(input)
            		) {
            			error(
            				'Invalid character: the string to be decoded is not correctly encoded.'
            			);
            		}
            		var bitCounter = 0;
            		var bitStorage;
            		var buffer;
            		var output = '';
            		var position = -1;
            		while (++position < length) {
            			buffer = TABLE.indexOf(input.charAt(position));
            			bitStorage = bitCounter % 4 ? bitStorage * 64 + buffer : buffer;
            			// Unless this is the first of a group of 4 characters…
            			if (bitCounter++ % 4) {
            				// …convert the first 8 bits to a single ASCII character.
            				output += String.fromCharCode(
            					0xFF & bitStorage >> (-2 * bitCounter & 6)
            				);
            			}
            		}
            		return output;
            	};

            	// `encode` is designed to be fully compatible with `btoa` as described in the
            	// HTML Standard: http://whatwg.org/html/webappapis.html#dom-windowbase64-btoa
            	var encode = function(input) {
            		input = String(input);
            		if (/[^\0-\xFF]/.test(input)) {
            			// Note: no need to special-case astral symbols here, as surrogates are
            			// matched, and the input is supposed to only contain ASCII anyway.
            			error(
            				'The string to be encoded contains characters outside of the ' +
            				'Latin1 range.'
            			);
            		}
            		var padding = input.length % 3;
            		var output = '';
            		var position = -1;
            		var a;
            		var b;
            		var c;
            		var buffer;
            		// Make sure any padding is handled outside of the loop.
            		var length = input.length - padding;

            		while (++position < length) {
            			// Read three bytes, i.e. 24 bits.
            			a = input.charCodeAt(position) << 16;
            			b = input.charCodeAt(++position) << 8;
            			c = input.charCodeAt(++position);
            			buffer = a + b + c;
            			// Turn the 24 bits into four chunks of 6 bits each, and append the
            			// matching character for each of them to the output.
            			output += (
            				TABLE.charAt(buffer >> 18 & 0x3F) +
            				TABLE.charAt(buffer >> 12 & 0x3F) +
            				TABLE.charAt(buffer >> 6 & 0x3F) +
            				TABLE.charAt(buffer & 0x3F)
            			);
            		}

            		if (padding == 2) {
            			a = input.charCodeAt(position) << 8;
            			b = input.charCodeAt(++position);
            			buffer = a + b;
            			output += (
            				TABLE.charAt(buffer >> 10) +
            				TABLE.charAt((buffer >> 4) & 0x3F) +
            				TABLE.charAt((buffer << 2) & 0x3F) +
            				'='
            			);
            		} else if (padding == 1) {
            			buffer = input.charCodeAt(position);
            			output += (
            				TABLE.charAt(buffer >> 2) +
            				TABLE.charAt((buffer << 4) & 0x3F) +
            				'=='
            			);
            		}

            		return output;
            	};

            	var base64 = {
            		'encode': encode,
            		'decode': decode,
            		'version': '0.1.0'
            	};

            	// Some AMD build optimizers, like r.js, check for specific condition patterns
            	// like the following:
            	if (freeExports && !freeExports.nodeType) {
            		if (freeModule) { // in Node.js or RingoJS v0.8.0+
            			freeModule.exports = base64;
            		} else { // in Narwhal or RingoJS v0.7.0-
            			for (var key in base64) {
            				base64.hasOwnProperty(key) && (freeExports[key] = base64[key]);
            			}
            		}
            	} else { // in Rhino or a web browser
            		root.base64 = base64;
            	}

            }(commonjsGlobal));
            });

            /**
             * Decodes the base64 encoded string into a `string`.
             * @hidden
             * @param {string} input
             * @returns {string}
             */
            function base64Decode(input) {
                return base64.decode(input);
            }
            /**
             * Encodes the `input` string into a base64 `string`.
             * @hidden
             * @param {string} input
             * @returns {string}
             */
            function base64Encode(input) {
                return base64.encode(input);
            }
            /**
             * Converts regular base64 encoded string to URL-safe base64 encoded string.
             * @hidden
             * @param {string} input - Regular base64 encoded string.
             * @returns {string} - URL-safe base64 encoded string.
             */
            function base64UrlFromBase64(input) {
                input = input.split('=')[0];
                input = input.replace(/\+/g, '-').replace(/\//g, '_');
                return input;
            }
            /**
             * Converts URL-safe base64 encoded string to regular base64 encoded string.
             * @hidden
             * @param {string} input - URL-safe base64 encoded string.
             * @returns {string} - Regular base64 encoded string.
             */
            function base64UrlToBase64(input) {
                input = input.replace(/-/g, '+').replace(/_/g, '/');
                switch (input.length % 4) {
                    case 0: break; // no padding needed
                    case 2:
                        input = input + '==';
                        break;
                    case 3:
                        input = input + '=';
                        break;
                    default:
                        throw new Error('Invalid base64 string');
                }
                return input;
            }
            /**
             * * Encodes the `input` string into a string using URL-safe base64 encoding.
             *
             * @hidden
             *
             * @param {string} input - The input.
             * @returns {string}
             */
            function base64UrlEncode(input) {
                let output = base64Encode(input);
                return base64UrlFromBase64(output);
            }
            /**
             * Decodes the URL-safe base64-encoded `input` string into a `string`.
             *
             * @hidden
             *
             * @param {string} input
             * @returns {string}
             */
            function base64UrlDecode(input) {
                const str = base64UrlToBase64(input);
                return base64Decode(str);
            }

            /**
             * Converts javascript date object or timestamp in milliseconds
             * to Unix timestamp.
             *
             * @hidden
             *
             * @param {Date | number} date - The date or timestamp to convert.
             * @returns {number}
             */
            function getUnixTimestamp(date) {
                let time;
                if (typeof date === 'number') {
                    time = date;
                }
                else {
                    time = date.getTime();
                }
                return Math.floor(time / 1000);
            }
            /**
             * Adds the given number of seconds to the given date.
             *
             * @hidden
             *
             * @param {Date | number} date - The date to add seconds to.
             * If `date` is a `number` it is treated as a timestamp in milliseconds.
             * @param {number} seconds - The number of seconds to add.
             * @returns {Date} - The new date.
             */
            function addSeconds(date, seconds) {
                if (typeof date === 'number') {
                    return new Date(date + seconds * 1000);
                }
                return new Date(date.getTime() + seconds * 1000);
            }

            /**
             * JWT Subject.
             * @hidden
             */
            const SubjectPrefix = "identity-";
            /**
             * JWT Issuer.
             * @hidden
             */
            const IssuerPrefix = "virgil-";

            /**
             * Class representing the JWT providing access to the
             * Virgil Security APIs.
             * Implements {@link IAccessToken} interface.
             */
            class Jwt {
                constructor(header, body, signature) {
                    if (typeof header === 'string') {
                        const stringRepresentation = header;
                        const parts = stringRepresentation.split('.');
                        if (parts.length !== 3)
                            throw new Error('Wrong JWT format');
                        try {
                            this.header = JSON.parse(base64UrlDecode(parts[0]));
                            this.body = JSON.parse(base64UrlDecode(parts[1]));
                            this.signature = base64UrlToBase64(parts[2]);
                        }
                        catch (e) {
                            throw new Error('Wrong JWT format');
                        }
                        this.unsignedData = parts[0] + '.' + parts[1];
                        this.stringRepresentation = stringRepresentation;
                    }
                    else if (typeof header === 'object' && typeof body === 'object') {
                        this.header = header;
                        this.body = body;
                        this.signature = signature;
                        this.unsignedData = this.headerBase64() + '.' + this.bodyBase64();
                        this.stringRepresentation = this.signature == null
                            ? this.unsignedData
                            : this.unsignedData + '.' + this.signatureBase64();
                    }
                    else {
                        throw new TypeError('Invalid arguments for function Jwt. ' +
                            'Expected a string representation of a token, or header and body as objects');
                    }
                }
                /**
                 * Parses the string representation of the JWT into
                 * an object representation.
                 *
                 * @param {string} jwtStr - The JWT string. Must have the following format:
                 *
                 * `base64UrlEncode(Header) + "." + base64UrlEncode(Body) + "." + base64UrlEncode(Signature)`
                 *
                 * See the {@link https://jwt.io/introduction/ | Introduction to JWT} for more details.
                 *
                 * @returns {Jwt}
                 */
                static fromString(jwtStr) {
                    return new Jwt(jwtStr);
                }
                /**
                 * Returns the string representation of this JWT.
                 * @returns {string}
                 */
                toString() {
                    return this.stringRepresentation;
                }
                /**
                 * Retrieves the identity that is the subject of this JWT.
                 * @returns {string}
                 */
                identity() {
                    if (this.body.sub.indexOf(SubjectPrefix) !== 0) {
                        throw new Error('wrong sub format');
                    }
                    return this.body.sub.substr(SubjectPrefix.length);
                }
                /**
                 * Retrieves the application ID that is the issuer of this JWT.
                 * @returns {string}
                 */
                appId() {
                    if (this.body.iss.indexOf(IssuerPrefix) !== 0) {
                        throw new Error('wrong iss format');
                    }
                    return this.body.iss.substr(IssuerPrefix.length);
                }
                /**
                 * Returns a boolean indicating whether this JWT is (or will be)
                 * expired at the given date or not.
                 *
                 * @param {Date} at - The date to check. Defaults to `new Date()`.
                 * @returns {boolean} - `true` if token is expired, otherwise `false`.
                 */
                isExpired(at = new Date) {
                    const now = getUnixTimestamp(at);
                    return this.body.exp < now;
                }
                headerBase64() {
                    return base64UrlEncode(JSON.stringify(this.header));
                }
                bodyBase64() {
                    return base64UrlEncode(JSON.stringify(this.body));
                }
                signatureBase64() {
                    return base64UrlFromBase64(this.signature);
                }
            }

            /**
             * Test if `condition` is truthy. If it is not, an `Error` is thrown with a
             * `message` property equal to `message` parameter.
             * @hidden
             * @param {boolean} condition
             * @param {string} message
             */
            function assert(condition, message) {
                if (!condition) {
                    throw new Error(message);
                }
            }

            const TOKEN_EXPIRATION_MARGIN = 5;
            /**
             * Implementation of {@link IAccessTokenProvider} that caches the JWT
             * in memory while it's fresh (i.e. not expired) and uses the user-provided
             * callback function to get the JWT when requested by the clients.
             */
            class CachingJwtProvider {
                /**
                 * Creates a new instance of `CachingJwtProvider`.
                 * @param {GetJwtCallback} renewJwtFn - The function that will be called
                 * whenever the fresh JWT is needed. If the `renewJwtFn` returns the JWT
                 * as a string, it will be converted to {@link Jwt} instance automatically.
                 * @param {Jwt|string} [initialToken] - Optional initial JWT.
                 */
                constructor(renewJwtFn, initialToken) {
                    if (typeof renewJwtFn !== 'function') {
                        throw new TypeError('`renewJwtFn` must be a function');
                    }
                    if (initialToken) {
                        let jwt;
                        if (typeof initialToken === 'string') {
                            jwt = Jwt.fromString(initialToken);
                        }
                        else if (initialToken instanceof Jwt) {
                            jwt = initialToken;
                        }
                        else {
                            throw new Error(`Expected "initialToken" to be a string or an instance of Jwt, got ${typeof initialToken}`);
                        }
                        this.cachedJwt = jwt;
                    }
                    this.getJwt = (context) => {
                        if (this.cachedJwt && !this.cachedJwt.isExpired(addSeconds(new Date, TOKEN_EXPIRATION_MARGIN))) {
                            return Promise.resolve(this.cachedJwt);
                        }
                        if (this.jwtPromise) {
                            return this.jwtPromise;
                        }
                        this.jwtPromise = Promise.resolve(renewJwtFn(context))
                            .then(token => {
                            const jwt = typeof token === 'string' ? Jwt.fromString(token) : token;
                            this.cachedJwt = jwt;
                            this.jwtPromise = undefined;
                            return jwt;
                        }).catch(err => {
                            this.jwtPromise = undefined;
                            throw err;
                        });
                        return this.jwtPromise;
                    };
                }
                /**
                 * Returns a `Promise` resolved with the cached token if it's fresh, or the
                 * token obtained by the call to the `renewJwtCallback` otherwise. The token
                 * obtained from the `renewJwtCallback` is then cached. If the `renewJwtCallback`
                 * returns the JWT as a string, it is converted to {@link Jwt} instance before returning.
                 * @param {ITokenContext} context
                 * @returns {Promise<IAccessToken>}
                 */
                getToken(context) {
                    return this.getJwt(context);
                }
            }

            /*! *****************************************************************************
            Copyright (c) Microsoft Corporation. All rights reserved.
            Licensed under the Apache License, Version 2.0 (the "License"); you may not use
            this file except in compliance with the License. You may obtain a copy of the
            License at http://www.apache.org/licenses/LICENSE-2.0

            THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
            KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
            WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
            MERCHANTABLITY OR NON-INFRINGEMENT.

            See the Apache Version 2.0 License for specific language governing permissions
            and limitations under the License.
            ***************************************************************************** */

            function __rest(s, e) {
                var t = {};
                for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
                    t[p] = s[p];
                if (s != null && typeof Object.getOwnPropertySymbols === "function")
                    for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) if (e.indexOf(p[i]) < 0)
                        t[p[i]] = s[p[i]];
                return t;
            }

            function __awaiter(thisArg, _arguments, P, generator) {
                return new (P || (P = Promise))(function (resolve, reject) {
                    function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
                    function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
                    function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
                    step((generator = generator.apply(thisArg, _arguments || [])).next());
                });
            }

            /**
             * Intermediate representation of the Virgil Card with `contentSnapshot`
             * and `snapshot`s of the signatures in UTF-8.
             */
            class RawSignedModel {
                /**
                 * Initializes a new instance of `RawSignedModel`.
                 * @param {string} contentSnapshot - The content snapshot in UTF-8.
                 * @param {IRawSignature[]} signatures - The signatures. If signatures
                 * themselves have snapshots, those must also be in UTF-8.
                 */
                constructor(contentSnapshot, signatures) {
                    this.contentSnapshot = contentSnapshot;
                    this.signatures = signatures;
                }
                /**
                 * Converts the `str` in base64 encoding into a `RawSignedModel` object.
                 *
                 * @param {string} str - Base64 string representation of the card as
                 * returned by {@RawSignedModel.toString} method.
                 *
                 * @returns {RawSignedModel}
                 */
                static fromString(str) {
                    const jsonStr = base64Decode(str);
                    let obj;
                    try {
                        obj = JSON.parse(jsonStr);
                    }
                    catch (error) {
                        throw new Error('The string to be parsed is in invalid format');
                    }
                    return RawSignedModel.fromJson(obj);
                }
                /**
                 * Converts the `json` serializable object into a `RawSignedModel` object.
                 * @param {IRawSignedModelJson} json - JSON-serializable object returned by
                 * {@link RawSignedModel.toJson} method.
                 * @returns {RawSignedModel}
                 */
                static fromJson(json) {
                    const contentSnapshotUtf8 = base64Decode(json.content_snapshot);
                    const signaturesWithUtf8Snapshots = (json.signatures || []).map(({ signer, signature, snapshot }) => {
                        if (snapshot) {
                            return {
                                signer,
                                signature,
                                snapshot: base64Decode(snapshot)
                            };
                        }
                        return { signer, signature };
                    });
                    return new RawSignedModel(contentSnapshotUtf8, signaturesWithUtf8Snapshots);
                }
                /**
                 * This is to make it work with `JSON.stringify`, calls
                 * {@link RawSignedModel.toJson} under the hood.
                 * @returns {IRawSignedModelJson}
                 */
                toJSON() {
                    return this.toJson();
                }
                /**
                 * Returns a JSON-serializable representation of this model in the
                 * format it is stored in the Virgil Cards Service. (i.e. with
                 * `contentSnapshot` and `snapshot`s of the signatures as base64 encoded
                 * strings.
                 * @returns {IRawSignedModelJson}
                 */
                toJson() {
                    return {
                        content_snapshot: base64Encode(this.contentSnapshot),
                        signatures: this.signatures.map(({ signer, signature, snapshot }) => {
                            if (snapshot) {
                                return {
                                    signer,
                                    signature,
                                    snapshot: base64Encode(snapshot)
                                };
                            }
                            return { signer, signature };
                        })
                    };
                }
                /**
                 * Serializes this model to string in base64 encoding.
                 * @returns {string}
                 */
                toString() {
                    return base64Encode(JSON.stringify(this));
                }
                /**
                 * Same as {@link RawSignedModel.toJson}. Please use that instead.
                 * @returns {IRawSignedModelJson}
                 */
                exportAsJson() {
                    return this.toJson();
                }
                /**
                 * Same as {@link RawSignedModel.toString}. Please use that instead.
                 * @returns {string}
                 */
                exportAsString() {
                    return this.toString();
                }
            }

            var fetchBrowser = createCommonjsModule(function (module, exports) {
            (function (self) {

              function fetchPonyfill(options) {
                var Promise = options && options.Promise || self.Promise;
                var XMLHttpRequest = options && options.XMLHttpRequest || self.XMLHttpRequest;
                var global = self;

                return (function () {
                  var self = Object.create(global, {
                    fetch: {
                      value: undefined,
                      writable: true
                    }
                  });

                  (function(self) {

                    if (self.fetch) {
                      return
                    }

                    var support = {
                      searchParams: 'URLSearchParams' in self,
                      iterable: 'Symbol' in self && 'iterator' in Symbol,
                      blob: 'FileReader' in self && 'Blob' in self && (function() {
                        try {
                          new Blob();
                          return true
                        } catch(e) {
                          return false
                        }
                      })(),
                      formData: 'FormData' in self,
                      arrayBuffer: 'ArrayBuffer' in self
                    };

                    if (support.arrayBuffer) {
                      var viewClasses = [
                        '[object Int8Array]',
                        '[object Uint8Array]',
                        '[object Uint8ClampedArray]',
                        '[object Int16Array]',
                        '[object Uint16Array]',
                        '[object Int32Array]',
                        '[object Uint32Array]',
                        '[object Float32Array]',
                        '[object Float64Array]'
                      ];

                      var isDataView = function(obj) {
                        return obj && DataView.prototype.isPrototypeOf(obj)
                      };

                      var isArrayBufferView = ArrayBuffer.isView || function(obj) {
                        return obj && viewClasses.indexOf(Object.prototype.toString.call(obj)) > -1
                      };
                    }

                    function normalizeName(name) {
                      if (typeof name !== 'string') {
                        name = String(name);
                      }
                      if (/[^a-z0-9\-#$%&'*+.\^_`|~]/i.test(name)) {
                        throw new TypeError('Invalid character in header field name')
                      }
                      return name.toLowerCase()
                    }

                    function normalizeValue(value) {
                      if (typeof value !== 'string') {
                        value = String(value);
                      }
                      return value
                    }

                    // Build a destructive iterator for the value list
                    function iteratorFor(items) {
                      var iterator = {
                        next: function() {
                          var value = items.shift();
                          return {done: value === undefined, value: value}
                        }
                      };

                      if (support.iterable) {
                        iterator[Symbol.iterator] = function() {
                          return iterator
                        };
                      }

                      return iterator
                    }

                    function Headers(headers) {
                      this.map = {};

                      if (headers instanceof Headers) {
                        headers.forEach(function(value, name) {
                          this.append(name, value);
                        }, this);
                      } else if (Array.isArray(headers)) {
                        headers.forEach(function(header) {
                          this.append(header[0], header[1]);
                        }, this);
                      } else if (headers) {
                        Object.getOwnPropertyNames(headers).forEach(function(name) {
                          this.append(name, headers[name]);
                        }, this);
                      }
                    }

                    Headers.prototype.append = function(name, value) {
                      name = normalizeName(name);
                      value = normalizeValue(value);
                      var oldValue = this.map[name];
                      this.map[name] = oldValue ? oldValue+','+value : value;
                    };

                    Headers.prototype['delete'] = function(name) {
                      delete this.map[normalizeName(name)];
                    };

                    Headers.prototype.get = function(name) {
                      name = normalizeName(name);
                      return this.has(name) ? this.map[name] : null
                    };

                    Headers.prototype.has = function(name) {
                      return this.map.hasOwnProperty(normalizeName(name))
                    };

                    Headers.prototype.set = function(name, value) {
                      this.map[normalizeName(name)] = normalizeValue(value);
                    };

                    Headers.prototype.forEach = function(callback, thisArg) {
                      for (var name in this.map) {
                        if (this.map.hasOwnProperty(name)) {
                          callback.call(thisArg, this.map[name], name, this);
                        }
                      }
                    };

                    Headers.prototype.keys = function() {
                      var items = [];
                      this.forEach(function(value, name) { items.push(name); });
                      return iteratorFor(items)
                    };

                    Headers.prototype.values = function() {
                      var items = [];
                      this.forEach(function(value) { items.push(value); });
                      return iteratorFor(items)
                    };

                    Headers.prototype.entries = function() {
                      var items = [];
                      this.forEach(function(value, name) { items.push([name, value]); });
                      return iteratorFor(items)
                    };

                    if (support.iterable) {
                      Headers.prototype[Symbol.iterator] = Headers.prototype.entries;
                    }

                    function consumed(body) {
                      if (body.bodyUsed) {
                        return Promise.reject(new TypeError('Already read'))
                      }
                      body.bodyUsed = true;
                    }

                    function fileReaderReady(reader) {
                      return new Promise(function(resolve, reject) {
                        reader.onload = function() {
                          resolve(reader.result);
                        };
                        reader.onerror = function() {
                          reject(reader.error);
                        };
                      })
                    }

                    function readBlobAsArrayBuffer(blob) {
                      var reader = new FileReader();
                      var promise = fileReaderReady(reader);
                      reader.readAsArrayBuffer(blob);
                      return promise
                    }

                    function readBlobAsText(blob) {
                      var reader = new FileReader();
                      var promise = fileReaderReady(reader);
                      reader.readAsText(blob);
                      return promise
                    }

                    function readArrayBufferAsText(buf) {
                      var view = new Uint8Array(buf);
                      var chars = new Array(view.length);

                      for (var i = 0; i < view.length; i++) {
                        chars[i] = String.fromCharCode(view[i]);
                      }
                      return chars.join('')
                    }

                    function bufferClone(buf) {
                      if (buf.slice) {
                        return buf.slice(0)
                      } else {
                        var view = new Uint8Array(buf.byteLength);
                        view.set(new Uint8Array(buf));
                        return view.buffer
                      }
                    }

                    function Body() {
                      this.bodyUsed = false;

                      this._initBody = function(body) {
                        this._bodyInit = body;
                        if (!body) {
                          this._bodyText = '';
                        } else if (typeof body === 'string') {
                          this._bodyText = body;
                        } else if (support.blob && Blob.prototype.isPrototypeOf(body)) {
                          this._bodyBlob = body;
                        } else if (support.formData && FormData.prototype.isPrototypeOf(body)) {
                          this._bodyFormData = body;
                        } else if (support.searchParams && URLSearchParams.prototype.isPrototypeOf(body)) {
                          this._bodyText = body.toString();
                        } else if (support.arrayBuffer && support.blob && isDataView(body)) {
                          this._bodyArrayBuffer = bufferClone(body.buffer);
                          // IE 10-11 can't handle a DataView body.
                          this._bodyInit = new Blob([this._bodyArrayBuffer]);
                        } else if (support.arrayBuffer && (ArrayBuffer.prototype.isPrototypeOf(body) || isArrayBufferView(body))) {
                          this._bodyArrayBuffer = bufferClone(body);
                        } else {
                          throw new Error('unsupported BodyInit type')
                        }

                        if (!this.headers.get('content-type')) {
                          if (typeof body === 'string') {
                            this.headers.set('content-type', 'text/plain;charset=UTF-8');
                          } else if (this._bodyBlob && this._bodyBlob.type) {
                            this.headers.set('content-type', this._bodyBlob.type);
                          } else if (support.searchParams && URLSearchParams.prototype.isPrototypeOf(body)) {
                            this.headers.set('content-type', 'application/x-www-form-urlencoded;charset=UTF-8');
                          }
                        }
                      };

                      if (support.blob) {
                        this.blob = function() {
                          var rejected = consumed(this);
                          if (rejected) {
                            return rejected
                          }

                          if (this._bodyBlob) {
                            return Promise.resolve(this._bodyBlob)
                          } else if (this._bodyArrayBuffer) {
                            return Promise.resolve(new Blob([this._bodyArrayBuffer]))
                          } else if (this._bodyFormData) {
                            throw new Error('could not read FormData body as blob')
                          } else {
                            return Promise.resolve(new Blob([this._bodyText]))
                          }
                        };

                        this.arrayBuffer = function() {
                          if (this._bodyArrayBuffer) {
                            return consumed(this) || Promise.resolve(this._bodyArrayBuffer)
                          } else {
                            return this.blob().then(readBlobAsArrayBuffer)
                          }
                        };
                      }

                      this.text = function() {
                        var rejected = consumed(this);
                        if (rejected) {
                          return rejected
                        }

                        if (this._bodyBlob) {
                          return readBlobAsText(this._bodyBlob)
                        } else if (this._bodyArrayBuffer) {
                          return Promise.resolve(readArrayBufferAsText(this._bodyArrayBuffer))
                        } else if (this._bodyFormData) {
                          throw new Error('could not read FormData body as text')
                        } else {
                          return Promise.resolve(this._bodyText)
                        }
                      };

                      if (support.formData) {
                        this.formData = function() {
                          return this.text().then(decode)
                        };
                      }

                      this.json = function() {
                        return this.text().then(JSON.parse)
                      };

                      return this
                    }

                    // HTTP methods whose capitalization should be normalized
                    var methods = ['DELETE', 'GET', 'HEAD', 'OPTIONS', 'POST', 'PUT'];

                    function normalizeMethod(method) {
                      var upcased = method.toUpperCase();
                      return (methods.indexOf(upcased) > -1) ? upcased : method
                    }

                    function Request(input, options) {
                      options = options || {};
                      var body = options.body;

                      if (input instanceof Request) {
                        if (input.bodyUsed) {
                          throw new TypeError('Already read')
                        }
                        this.url = input.url;
                        this.credentials = input.credentials;
                        if (!options.headers) {
                          this.headers = new Headers(input.headers);
                        }
                        this.method = input.method;
                        this.mode = input.mode;
                        if (!body && input._bodyInit != null) {
                          body = input._bodyInit;
                          input.bodyUsed = true;
                        }
                      } else {
                        this.url = String(input);
                      }

                      this.credentials = options.credentials || this.credentials || 'omit';
                      if (options.headers || !this.headers) {
                        this.headers = new Headers(options.headers);
                      }
                      this.method = normalizeMethod(options.method || this.method || 'GET');
                      this.mode = options.mode || this.mode || null;
                      this.referrer = null;

                      if ((this.method === 'GET' || this.method === 'HEAD') && body) {
                        throw new TypeError('Body not allowed for GET or HEAD requests')
                      }
                      this._initBody(body);
                    }

                    Request.prototype.clone = function() {
                      return new Request(this, { body: this._bodyInit })
                    };

                    function decode(body) {
                      var form = new FormData();
                      body.trim().split('&').forEach(function(bytes) {
                        if (bytes) {
                          var split = bytes.split('=');
                          var name = split.shift().replace(/\+/g, ' ');
                          var value = split.join('=').replace(/\+/g, ' ');
                          form.append(decodeURIComponent(name), decodeURIComponent(value));
                        }
                      });
                      return form
                    }

                    function parseHeaders(rawHeaders) {
                      var headers = new Headers();
                      // Replace instances of \r\n and \n followed by at least one space or horizontal tab with a space
                      // https://tools.ietf.org/html/rfc7230#section-3.2
                      var preProcessedHeaders = rawHeaders.replace(/\r?\n[\t ]+/g, ' ');
                      preProcessedHeaders.split(/\r?\n/).forEach(function(line) {
                        var parts = line.split(':');
                        var key = parts.shift().trim();
                        if (key) {
                          var value = parts.join(':').trim();
                          headers.append(key, value);
                        }
                      });
                      return headers
                    }

                    Body.call(Request.prototype);

                    function Response(bodyInit, options) {
                      if (!options) {
                        options = {};
                      }

                      this.type = 'default';
                      this.status = options.status === undefined ? 200 : options.status;
                      this.ok = this.status >= 200 && this.status < 300;
                      this.statusText = 'statusText' in options ? options.statusText : 'OK';
                      this.headers = new Headers(options.headers);
                      this.url = options.url || '';
                      this._initBody(bodyInit);
                    }

                    Body.call(Response.prototype);

                    Response.prototype.clone = function() {
                      return new Response(this._bodyInit, {
                        status: this.status,
                        statusText: this.statusText,
                        headers: new Headers(this.headers),
                        url: this.url
                      })
                    };

                    Response.error = function() {
                      var response = new Response(null, {status: 0, statusText: ''});
                      response.type = 'error';
                      return response
                    };

                    var redirectStatuses = [301, 302, 303, 307, 308];

                    Response.redirect = function(url, status) {
                      if (redirectStatuses.indexOf(status) === -1) {
                        throw new RangeError('Invalid status code')
                      }

                      return new Response(null, {status: status, headers: {location: url}})
                    };

                    self.Headers = Headers;
                    self.Request = Request;
                    self.Response = Response;

                    self.fetch = function(input, init) {
                      return new Promise(function(resolve, reject) {
                        var request = new Request(input, init);
                        var xhr = new XMLHttpRequest();

                        xhr.onload = function() {
                          var options = {
                            status: xhr.status,
                            statusText: xhr.statusText,
                            headers: parseHeaders(xhr.getAllResponseHeaders() || '')
                          };
                          options.url = 'responseURL' in xhr ? xhr.responseURL : options.headers.get('X-Request-URL');
                          var body = 'response' in xhr ? xhr.response : xhr.responseText;
                          resolve(new Response(body, options));
                        };

                        xhr.onerror = function() {
                          reject(new TypeError('Network request failed'));
                        };

                        xhr.ontimeout = function() {
                          reject(new TypeError('Network request failed'));
                        };

                        xhr.open(request.method, request.url, true);

                        if (request.credentials === 'include') {
                          xhr.withCredentials = true;
                        } else if (request.credentials === 'omit') {
                          xhr.withCredentials = false;
                        }

                        if ('responseType' in xhr && support.blob) {
                          xhr.responseType = 'blob';
                        }

                        request.headers.forEach(function(value, name) {
                          xhr.setRequestHeader(name, value);
                        });

                        xhr.send(typeof request._bodyInit === 'undefined' ? null : request._bodyInit);
                      })
                    };
                    self.fetch.polyfill = true;
                  })(typeof self !== 'undefined' ? self : this);


                  return {
                    fetch: self.fetch,
                    Headers: self.Headers,
                    Request: self.Request,
                    Response: self.Response
                  };
                }());
              }

              {
                module.exports = fetchPonyfill;
              }
            }(typeof self !== 'undefined' ? self : typeof commonjsGlobal !== 'undefined' ? commonjsGlobal : commonjsGlobal));
            });

            const { fetch: fetch$1, Request, Response, Headers } = fetchBrowser();

            const OS_LIST = [
                /* Windows Phone */
                {
                    name: 'Windows Phone',
                    test: [/windows phone/i],
                },
                /* Windows */
                {
                    test: [/windows/i],
                    name: 'Windows'
                },
                /* macOS */
                {
                    test: [/macintosh/i],
                    name: 'macOS'
                },
                /* iOS */
                {
                    test: [/(ipod|iphone|ipad)/i],
                    name: 'iOS'
                },
                /* Android */
                {
                    test: [/android/i],
                    name: 'Android',
                },
                /* Linux */
                {
                    test: [/linux/i],
                    name: 'Linux',
                },
                /* Chrome OS */
                {
                    test: [/CrOS/],
                    name: 'Chrome OS'
                },
                /* Playstation 4 */
                {
                    test: [/PlayStation 4/],
                    name: 'PlayStation 4',
                },
            ];

            // Order of browsers matters! Edge, Opera and Chromium have Chrome in User Agent.
            const BROWSER_LIST = [
                {
                    test: [/googlebot/i],
                    name: 'Googlebot'
                },
                {
                    test: [/opera/i, /opr\/|opios/i],
                    name: 'Opera',
                },
                {
                    test: [/msie|trident/i],
                    name: 'Internet Explorer',
                },
                {
                    test: [/\sedg/i],
                    name: 'Microsoft Edge'
                },
                {
                    test: [/firefox|iceweasel|fxios/i],
                    name: 'Firefox',
                },
                {
                    test: [/chromium/i],
                    name: 'Chromium'
                },
                {
                    test: [/chrome|crios|crmo/i],
                    name: 'Chrome',
                },
                {
                    test: [/android/i],
                    name: 'Android Browser'
                },
                {
                    test: [/playstation 4/i],
                    name: 'PlayStation 4',
                },
                {
                    test: [/safari|applewebkit/i],
                    name: 'Safari',
                }
            ];

            /**
             * Class responsible for tracking which Virgil SDK is being used to make requests, its version,
             * browser and platform.
             */
            class VirgilAgent {
                /**
                 * Initializes a new instance of `VirgilAgent`.
                 * @param {string} product - name of product eg (sdk, brainkey, bpp, keyknox, ratchet, e3kit, purekit)
                 * argument of request methods.
                 * @param {string} version - version of the product.
                 * @param {string} [userAgent] - string with device user agent. Optional
                 */
                constructor(product, version, userAgent) {
                    /**
                     * Detect Cordova / PhoneGap / Ionic frameworks on a mobile device.
                     * @return {boolean} true if detects Ionic.
                     */
                    this.isIonic = () => typeof window !== "undefined" &&
                        !!("cordova" in window || "phonegap" in window || "PhoneGap" in window) &&
                        /android|ios|iphone|ipod|ipad|iemobile/i.test(this.userAgent);
                    this.userAgent = userAgent || this.getUserAgent();
                    this.value = `${product};js;${this.getHeaderValue()};${version}`;
                }
                /**
                 * Returns navigator.userAgent string or '' if it's not defined.
                 * @return {string} user agent string
                 */
                getUserAgent() {
                    if (typeof navigator !== "undefined" && typeof navigator.userAgent === "string") {
                        return navigator.userAgent;
                    }
                    else {
                        return "";
                    }
                }
                ;
                /**
                 * Detects device OS
                 * @returns {string} returns OS if detected or 'other'.
                 */
                getOsName() {
                    const os = OS_LIST.find((os) => os.test.some(condition => condition.test(this.userAgent)));
                    return os ? os.name : 'other';
                }
                /**
                 * Detects device browser
                 * @returns {string} returns browser if detected of 'other'.
                 */
                getBrowser() {
                    const browser = BROWSER_LIST.find((browser) => browser.test.some(condition => condition.test(this.userAgent)));
                    return browser ? browser.name : 'other';
                }
                /**
                 * Detect React Native.
                 * @return {boolean} true if detects ReactNative .
                 */
                isReactNative() {
                    return typeof navigator === "object" && navigator.product === "ReactNative";
                }
                /**
                 * Return information for `virgil-agent` header.
                 * @return {string} string in format: PRODUCT;FAMILY;PLATFORM;VERSION
                 */
                getHeaderValue() {
                    try {
                        if (this.isReactNative())
                            return "ReactNative";
                        if (this.isIonic())
                            return `Ionic/${this.getOsName()}`;
                        if (!true && typeof global$1 !== 'undefined') {
                            const majorVersion = process.version.replace(/\.\d+\.\d+$/, '').replace('v', '');
                            return `Node${majorVersion}/${process.platform}`;
                        }
                        return `${this.getBrowser()}/${this.getOsName()}`;
                    }
                    catch (e) {
                        return `Unknown`;
                    }
                }
            }

            /**
             * Class responsible for making HTTP requests.
             * @hidden
             */
            class Connection {
                /**
                 * Initializes a new instance of `Connection`.
                 * @param {string} prefix - `prefix` will be prepended to the `endpoint`
                 * argument of request methods.
                 * @param {VirgilAgentValue} [virgilAgentValue] - optional instance of VirgilAgent for products that wraps
                 * Virgil SDK
                 */
                constructor(prefix, info) {
                    this.prefix = prefix;
                    if (!info)
                        info = { product: 'sdk', version: "6.0.0-alpha.5" };
                    this.virgilAgentValue = new VirgilAgent(info.product, info.version).value;
                }
                /**
                 * Issues a GET request against the `endpoint`.
                 * @param {string} endpoint - Endpoint URL relative to the `prefix`.
                 * @param {string} accessToken - Token to authenticate the request.
                 * @returns {Promise<Response>}
                 */
                get(endpoint, accessToken) {
                    const headers = this.createHeaders(accessToken);
                    return this.send(endpoint, 'GET', { headers });
                }
                /**
                 * Issues a POST request against the `endpoint` sending the `data` as JSON.
                 * @param {string} endpoint - Endpoint URL relative to the `prefix`.
                 * @param {string} accessToken - Token to authenticate the request.
                 * @param {object} data - Response body.
                 * @returns {Promise<Response>}
                 */
                post(endpoint, accessToken, data = {}) {
                    const headers = this.createHeaders(accessToken);
                    headers.set('Content-Type', 'application/json');
                    return this.send(endpoint, 'POST', {
                        headers: headers,
                        body: JSON.stringify(data)
                    });
                }
                send(endpoint, method, params) {
                    return fetch$1(this.prefix + endpoint, Object.assign({ method }, params));
                }
                createHeaders(accessToken) {
                    const headers = new Headers();
                    headers.set('Authorization', `Virgil ${accessToken}`);
                    headers.set('Virgil-Agent', this.virgilAgentValue);
                    return headers;
                }
            }

            /**
             * Custom error class for errors specific to Virgil SDK.
             */
            class VirgilError extends Error {
                constructor(m, name = 'VirgilError', DerivedClass = VirgilError) {
                    super(m);
                    Object.setPrototypeOf(this, DerivedClass.prototype);
                    this.name = name;
                }
            }

            var ErrorCode;
            (function (ErrorCode) {
                ErrorCode[ErrorCode["AccessTokenExpired"] = 20304] = "AccessTokenExpired";
                ErrorCode[ErrorCode["Unknown"] = 0] = "Unknown";
            })(ErrorCode || (ErrorCode = {}));
            /**
             * Error thrown by {@link CardManager} when request to the Virgil Cards Service
             * fails.
             */
            class VirgilHttpError extends VirgilError {
                constructor(message, status, errorCode) {
                    super(message, 'VirgilHttpError', VirgilHttpError);
                    this.httpStatus = status;
                    this.errorCode = errorCode;
                }
            }
            /**
             * Generates error object from response object with HTTP status >= 400
             *
             * @hidden
             *
             * @param {Response} response
             * @returns {Promise<VirgilHttpError>}
             */
            function generateErrorFromResponse(response) {
                return __awaiter(this, void 0, void 0, function* () {
                    if (response.status >= 400 && response.status < 500) {
                        const reason = yield response.json();
                        return new VirgilHttpError(reason.message, response.status, reason.code);
                    }
                    else {
                        return new VirgilHttpError(response.statusText, response.status, 0);
                    }
                });
            }

            const PublishEndpoint = '/card/v5';
            const SearchEndpoint = '/card/v5/actions/search';
            const GetCardEndpoint = (cardId) => `/card/v5/${cardId}`;
            const RevokeCardEndpoint = (cardId) => `/card/v5/actions/revoke/${cardId}`;
            /**
             * Class responsible for sending requests to the Virgil Cards Service.
             *
             * @hidden
             */
            class CardClient {
                /**
                 * Initializes new instance of `CardClient`.
                 * @param {IConnection | string} connection - Object implementing the
                 * {@link IConnection} interface.
                 */
                constructor(connection, productInfo) {
                    if (typeof connection === 'string') {
                        this.connection = new Connection(connection, productInfo);
                    }
                    else if (connection) {
                        this.connection = connection;
                    }
                    else {
                        this.connection = new Connection('https://api.virgilsecurity.com', productInfo);
                    }
                }
                /**
                 * Issues a request to search cards by the `identity`.
                 * @param {string[]} identities - Array of identities to search for.
                 * @param {string} accessToken - A token to authenticate the request.
                 * @returns {Promise<RawSignedModel[]>}
                 */
                searchCards(identities, accessToken) {
                    return __awaiter(this, void 0, void 0, function* () {
                        const response = yield this.connection.post(SearchEndpoint, accessToken, { identities });
                        if (!response.ok)
                            throw yield generateErrorFromResponse(response);
                        const cardsJson = yield response.json();
                        if (cardsJson === null)
                            return [];
                        return cardsJson.map(RawSignedModel.fromJson);
                    });
                }
                /**
                 * Issues a request to get the card by id.
                 * @param {string} cardId - Id of the card to fetch.
                 * @param {string} accessToken - A token to authenticate the request.
                 * @returns {Promise<ICardResult>}
                 */
                getCard(cardId, accessToken) {
                    return __awaiter(this, void 0, void 0, function* () {
                        if (!cardId)
                            throw new TypeError('`cardId` should not be empty');
                        if (!accessToken)
                            throw new TypeError('`accessToken` should not be empty');
                        const response = yield this.connection.get(GetCardEndpoint(cardId), accessToken);
                        if (!response.ok) {
                            throw yield generateErrorFromResponse(response);
                        }
                        const isOutdated = response.headers.get('X-Virgil-Is-Superseeded') === 'true';
                        const cardJson = yield response.json();
                        const cardRaw = RawSignedModel.fromJson(cardJson);
                        return { cardRaw, isOutdated };
                    });
                }
                /**
                 * Issues a request to publish the card.
                 * @param {RawSignedModel} model - Card to publish.
                 * @param {string} accessToken - A token to authenticate the request.
                 * @returns {Promise<RawSignedModel>}
                 */
                publishCard(model, accessToken) {
                    return __awaiter(this, void 0, void 0, function* () {
                        if (!model)
                            throw new TypeError('`model` should not be empty');
                        if (!accessToken)
                            throw new TypeError('`accessToken` should not be empty');
                        const response = yield this.connection.post(PublishEndpoint, accessToken, model);
                        if (!response.ok) {
                            throw yield generateErrorFromResponse(response);
                        }
                        const cardJson = yield response.json();
                        return RawSignedModel.fromJson(cardJson);
                    });
                }
                revokeCard(cardId, accessToken) {
                    return __awaiter(this, void 0, void 0, function* () {
                        if (!cardId)
                            throw new TypeError('`cardId` should not be empty');
                        if (!accessToken)
                            throw new TypeError('`accessToken` should not be empty');
                        const response = yield this.connection.post(RevokeCardEndpoint(cardId), accessToken);
                        if (!response.ok) {
                            throw yield generateErrorFromResponse(response);
                        }
                    });
                }
            }

            /**
             * @hidden
             */
            const SelfSigner = "self";
            /**
             * @hidden
             */
            const VirgilSigner = "virgil";
            /**
             * @hidden
             */
            const CardVersion = '5.0';
            /**
             * @hidden
             */
            const CardIdByteLength = 32;

            /**
             * Class responsible for generating signatures of the cards.
             */
            class ModelSigner {
                /**
                 * Initializes a new instance of `ModelSigner`.
                 * @param {ICardCrypto} crypto - Object implementing the
                 * {@link ICardCrypto} interface.
                 */
                constructor(crypto) {
                    this.crypto = crypto;
                }
                /**
                 * Generates a new signature based on `rawParams`.
                 * @param {IRawSignParams} rawParams
                 */
                sign(rawParams) {
                    const { model, signerPrivateKey, signer, extraSnapshot } = this.prepareParams(rawParams);
                    const signedSnapshot = extraSnapshot != null
                        ? model.contentSnapshot + extraSnapshot
                        : model.contentSnapshot;
                    const signature = this.crypto.generateSignature({ value: signedSnapshot, encoding: 'utf8' }, signerPrivateKey);
                    model.signatures.push({
                        signer,
                        signature: signature.toString('base64'),
                        snapshot: extraSnapshot
                    });
                }
                prepareParams({ model, signerPrivateKey, extraFields, signer }) {
                    signer = signer || SelfSigner;
                    let extraSnapshot;
                    if (extraFields != null) {
                        extraSnapshot = JSON.stringify(extraFields);
                    }
                    const final = { model, signerPrivateKey, signer, extraSnapshot };
                    this.validate(final);
                    return final;
                }
                validate({ model, signerPrivateKey, signer }) {
                    if (model == null) {
                        throw new Error("Model is empty");
                    }
                    if (signerPrivateKey == null) {
                        throw new Error("`signerPrivateKey` property is mandatory");
                    }
                    if (model.signatures != null && model.signatures.some(s => s.signer == signer)) {
                        throw new Error("The model already has this signature.");
                    }
                }
            }

            /**
             * Converts an {@link ICard} to a {@link RawSignedModel}.
             *
             * @hidden
             *
             * @param {ICard} card - The {@link ICard} to convert.
             * @returns {RawSignedModel}
             */
            function cardToRawSignedModel(card) {
                return new RawSignedModel(card.contentSnapshot, card.signatures.slice());
            }
            /**
             * Generates a {@link RawSignedModel} from the given `params`.
             *
             * @hidden
             *
             * @param {ICardCrypto} crypto - Object implementing the {@link ICardCrypto}
             * interface.
             * @param {INewCardParams} params - New card parameters.
             * @returns {RawSignedModel}
             */
            function generateRawSigned(crypto, params) {
                const { identity, publicKey, previousCardId } = params;
                const now = getUnixTimestamp(new Date);
                const details = {
                    identity: identity,
                    previous_card_id: previousCardId,
                    created_at: now,
                    version: CardVersion,
                    public_key: crypto.exportPublicKey(publicKey).toString('base64'),
                };
                return new RawSignedModel(JSON.stringify(details), []);
            }
            /**
             * Converts the {@link RawSignedModel} into the {@link ICard}.
             *
             * @hidden
             *
             * @param {ICardCrypto} crypto - Object implementing the {@link ICardCrypto}
             * interface.
             * @param {RawSignedModel} model - The model to convert.
             * @param {boolean} isOutdated - Boolean indicating whether there is a newer
             * Virgil Card replacing the one that `model` represents.
             *
             * @returns {ICard}
             */
            function parseRawSignedModel(crypto, model, isOutdated = false) {
                const content = JSON.parse(model.contentSnapshot);
                const signatures = model.signatures.map(rawSignToCardSign);
                return {
                    id: generateCardId(crypto, model.contentSnapshot),
                    publicKey: crypto.importPublicKey({ value: content.public_key, encoding: 'base64' }),
                    contentSnapshot: model.contentSnapshot,
                    identity: content.identity,
                    version: content.version,
                    createdAt: new Date(content.created_at * 1000),
                    previousCardId: content.previous_card_id,
                    signatures,
                    isOutdated
                };
            }
            /**
             * Given the array of `cards`, returns another array with outdated cards
             * filtered out and the `previousCard` properties of the cards that replace
             * the outdated ones being populated with appropriate outdated cards.
             * i.e. turns this (A is for Actual, O is for Outdated):
             * ```
             * A -> O -> A -> A -> O
             * ```
             * into this
             * ```
             * A -> A -> A
             * |         |
             * O         O
             * ```
             *
             * @hidden
             *
             * @param {ICard[]} cards - The cards array to transform.
             * @returns {ICard[]} - Transformed array.
             */
            function linkedCardList(cards) {
                const unsorted = Object.create(null);
                for (const card of cards) {
                    unsorted[card.id] = card;
                }
                for (const card of cards) {
                    if (card.previousCardId == null)
                        continue;
                    if (unsorted[card.previousCardId] == null)
                        continue;
                    unsorted[card.previousCardId].isOutdated = true;
                    card.previousCard = unsorted[card.previousCardId];
                    delete unsorted[card.previousCardId];
                }
                return Object.keys(unsorted).map(key => unsorted[key]);
            }
            /**
             * Calculates ID for the VirgilCard from the `snapshot` of its contents.
             *
             * @hidden
             *
             * @param {ICardCrypto} crypto - Object implementing the {@link ICardCrypto}
             * interface.
             * @param {string} snapshot - The VirgilCard's contents snapshot.
             * @returns {string} - VirgilCard's ID encoded in HEX.
             */
            function generateCardId(crypto, snapshot) {
                const fingerprint = crypto
                    .generateSha512({ value: snapshot, encoding: 'utf8' })
                    .slice(0, CardIdByteLength);
                return fingerprint.toString('hex');
            }
            function rawSignToCardSign({ snapshot, signature, signer }) {
                return {
                    signer,
                    signature,
                    snapshot,
                    extraFields: tryParseExtraFields(snapshot)
                };
            }
            function tryParseExtraFields(snapshot) {
                if (snapshot) {
                    try {
                        return JSON.parse(snapshot);
                    }
                    catch (ignored) { }
                }
                return {};
            }

            /**
             * Error thrown by {@link CardManager} instances when the card received from
             * the network (or imported from string\json) fails verification.
             */
            class VirgilCardVerificationError extends VirgilError {
                constructor(m) {
                    super(m, 'CardVerificationError', VirgilCardVerificationError);
                }
            }

            const CARDS_SERVICE__NAME = 'cards';
            /**
             * @hidden
             */
            const throwingAccessTokenProvider = {
                getToken: () => {
                    throw new Error('Please set `CardManager.accessTokenProvider` to be able to make requests.');
                }
            };
            const getCardServiceTokenContext = (context) => (Object.assign(Object.assign({}, context), { service: CARDS_SERVICE__NAME }));
            /**
             * Class responsible for creating, publishing and retrieving Virgil Cards.
             */
            class CardManager {
                constructor(params) {
                    this.crypto = params.cardCrypto;
                    this.client = new CardClient(params.apiUrl, params.productInfo);
                    this.modelSigner = new ModelSigner(params.cardCrypto);
                    this.signCallback = params.signCallback;
                    this.retryOnUnauthorized = params.retryOnUnauthorized;
                    this.cardVerifier = params.cardVerifier;
                    this.accessTokenProvider = params.accessTokenProvider || throwingAccessTokenProvider;
                }
                /**
                 * Generates a {@link RawSignedModel} that represents a card from
                 * `cardParams`.
                 * Use this method if you don't need to publish the card right away, for
                 * example if you need to first send it to your backend server to apply
                 * additional signature.
                 *
                 * @param {INewCardParams} cardParams - New card parameters.
                 * @returns {RawSignedModel}
                 */
                generateRawCard(cardParams) {
                    const model = generateRawSigned(this.crypto, cardParams);
                    this.modelSigner.sign({
                        model,
                        signerPrivateKey: cardParams.privateKey,
                        signer: SelfSigner,
                        extraFields: cardParams.extraFields
                    });
                    return model;
                }
                /**
                 * Generates a card from `cardParams` and publishes it in the Virgil Cards
                 * Service.
                 * @param {INewCardParams} cardParams - New card parameters.
                 * @returns {Promise<ICard>}
                 */
                publishCard(cardParams) {
                    return __awaiter(this, void 0, void 0, function* () {
                        validateCardParams(cardParams);
                        const tokenContext = {
                            service: CARDS_SERVICE__NAME,
                            identity: cardParams.identity,
                            operation: 'publish'
                        };
                        const token = yield this.accessTokenProvider.getToken(tokenContext);
                        const rawSignedModel = this.generateRawCard(Object.assign({}, cardParams, { identity: token.identity() }));
                        return yield this.publishRawSignedModel(rawSignedModel, tokenContext, token);
                    });
                }
                /**
                 * Publishes a previously generated card in the form of
                 * {@link RawSignedModel} object.
                 *
                 * @param {RawSignedModel} rawCard - The card to publish.
                 * @returns {Promise<ICard>}
                 */
                publishRawCard(rawCard) {
                    return __awaiter(this, void 0, void 0, function* () {
                        assert(rawCard != null && rawCard.contentSnapshot != null, '`rawCard` should not be empty');
                        const cardDetails = JSON.parse(rawCard.contentSnapshot);
                        const tokenContext = getCardServiceTokenContext({ identity: cardDetails.identity, operation: 'publish' });
                        const token = yield this.accessTokenProvider.getToken(tokenContext);
                        return this.publishRawSignedModel(rawCard, tokenContext, token);
                    });
                }
                /**
                 * Fetches the card by `cardId` from the Virgil Card Service.
                 * @param {string} cardId - Id of the card to fetch.
                 * @returns {Promise<ICard>}
                 */
                getCard(cardId) {
                    return __awaiter(this, void 0, void 0, function* () {
                        const tokenContext = getCardServiceTokenContext({ operation: 'get' });
                        const accessToken = yield this.accessTokenProvider.getToken(tokenContext);
                        const cardWithStatus = yield this.tryDo(tokenContext, accessToken, (token) => __awaiter(this, void 0, void 0, function* () { return yield this.client.getCard(cardId, token.toString()); }));
                        const card = parseRawSignedModel(this.crypto, cardWithStatus.cardRaw, cardWithStatus.isOutdated);
                        if (card.id !== cardId) {
                            throw new VirgilCardVerificationError('Received invalid card');
                        }
                        this.validateCards([card]);
                        return card;
                    });
                }
                /**
                 * Fetches collection of cards with the given `identity` from the Virgil
                 * Cards Service.
                 * @param {string|string[]} identities - Identity or an array of identities of the cards to fetch.
                 * @returns {Promise<ICard[]>}
                 */
                searchCards(identities) {
                    return __awaiter(this, void 0, void 0, function* () {
                        if (!identities)
                            throw new TypeError('Argument `identities` is required');
                        const identitiesArr = Array.isArray(identities) ? identities : [identities];
                        if (identitiesArr.length === 0)
                            throw new TypeError('Identities array must not be empty');
                        const tokenContext = getCardServiceTokenContext({ operation: 'search' });
                        const accessToken = yield this.accessTokenProvider.getToken(tokenContext);
                        const rawCards = yield this.tryDo(tokenContext, accessToken, (token) => __awaiter(this, void 0, void 0, function* () { return yield this.client.searchCards(identitiesArr, token.toString()); }));
                        const cards = rawCards.map(raw => parseRawSignedModel(this.crypto, raw, false));
                        const identitiesSet = new Set(identitiesArr);
                        if (cards.some(c => !identitiesSet.has(c.identity))) {
                            throw new VirgilCardVerificationError('Received invalid cards');
                        }
                        this.validateCards(cards);
                        return linkedCardList(cards);
                    });
                }
                /**
                 * Marks the Virgil Card specified by `cardId` as revoked.  Revoked cards will have `isOutdated`
                 * property set to `true` when retrieved via {@link CardManager.getCard} method.
                 * Also revoked cards will be absent in the {@link CardManager.searchCards} result.
                 * @param {string} cardId - Id of the card to revoke.
                 * @returns {Promise}
                 */
                revokeCard(cardId) {
                    return __awaiter(this, void 0, void 0, function* () {
                        if (!cardId)
                            throw new TypeError('Argument `cardId` is required');
                        const tokenContext = getCardServiceTokenContext({ operation: 'revoke' });
                        const accessToken = yield this.accessTokenProvider.getToken(tokenContext);
                        yield this.tryDo(tokenContext, accessToken, (token) => __awaiter(this, void 0, void 0, function* () { return yield this.client.revokeCard(cardId, token.toString()); }));
                    });
                }
                /**
                 * Converts the card in the form of {@link RawSignedModel} object to the
                 * {@link ICard} object.
                 *
                 * @see {@link CardManager.exportCard}
                 *
                 * @param {RawSignedModel} rawCard - The card to convert.
                 * @returns {ICard}
                 */
                importCard(rawCard) {
                    const card = parseRawSignedModel(this.crypto, rawCard);
                    this.validateCards([card]);
                    return card;
                }
                /**
                 * Converts the card in the base64 string form to the {@link ICard} object.
                 *
                 * @see {@link CardManager.exportCardAsString}
                 *
                 * @param {string} str - The string in base64.
                 * @returns {ICard}
                 */
                importCardFromString(str) {
                    assert(Boolean(str), '`str` should not be empty');
                    return this.importCard(RawSignedModel.fromString(str));
                }
                /**
                 * Converts the card in the JSON-serializable object form to the
                 * {@link ICard} object.
                 *
                 * @see {@link CardManager.exportCardAsJson}
                 *
                 * @param {IRawSignedModelJson} json
                 * @returns {ICard}
                 */
                importCardFromJson(json) {
                    assert(Boolean(json), '`json` should not be empty');
                    return this.importCard(RawSignedModel.fromJson(json));
                }
                /**
                 * Converts the card in the form of {@link ICard} object to the
                 * {@link RawSignedModel} object.
                 *
                 * @see {@link CardManager.importCard}
                 *
                 * @param {ICard} card
                 * @returns {RawSignedModel}
                 */
                exportCard(card) {
                    return cardToRawSignedModel(card);
                }
                /**
                 * Converts the card in the form of {@link ICard} object to the string
                 * in base64 encoding.
                 *
                 * @see {@link CardManager.importCardFromString}
                 *
                 * @param {ICard} card
                 * @returns {string}
                 */
                exportCardAsString(card) {
                    return this.exportCard(card).toString();
                }
                /**
                 * Converts the card in the form of {@link ICard} object to the
                 * JSON-serializable object form.
                 *
                 * @see {@link CardManager.importCardFromJson}
                 *
                 * @param {ICard} card
                 * @returns {IRawSignedModelJson}
                 */
                exportCardAsJson(card) {
                    return this.exportCard(card).toJson();
                }
                /**
                 * @hidden
                 */
                publishRawSignedModel(rawCard, context, accessToken) {
                    return __awaiter(this, void 0, void 0, function* () {
                        if (this.signCallback != null) {
                            rawCard = yield this.signCallback(rawCard);
                        }
                        const publishedModel = yield this.tryDo(context, accessToken, (token) => __awaiter(this, void 0, void 0, function* () { return yield this.client.publishCard(rawCard, token.toString()); }));
                        if (rawCard.contentSnapshot !== publishedModel.contentSnapshot) {
                            throw new VirgilCardVerificationError('Received invalid card');
                        }
                        const card = parseRawSignedModel(this.crypto, publishedModel);
                        this.validateCards([card]);
                        return card;
                    });
                }
                /**
                 * @hidden
                 */
                tryDo(context, token, func) {
                    return __awaiter(this, void 0, void 0, function* () {
                        try {
                            return yield func(token);
                        }
                        catch (e) {
                            if (e instanceof VirgilHttpError &&
                                e.httpStatus === 401 &&
                                e.errorCode === ErrorCode.AccessTokenExpired &&
                                this.retryOnUnauthorized) {
                                token = yield this.accessTokenProvider.getToken(getCardServiceTokenContext({
                                    identity: context.identity,
                                    operation: context.operation,
                                    forceReload: true
                                }));
                                return yield func(token);
                            }
                            throw e;
                        }
                    });
                }
                /**
                 * Delegates to the {@link CardManager.cardVerifier} to verify the validity
                 * of the `cards`.
                 *
                 * @throws {@link VirgilCardVerificationError} if any of the cards is not
                 * valid.
                 *
                 * @param {ICard[]} cards
                 */
                validateCards(cards) {
                    if (this.cardVerifier == null)
                        return;
                    for (const card of cards) {
                        if (!this.cardVerifier.verifyCard(card)) {
                            throw new VirgilCardVerificationError('Validation errors have been detected');
                        }
                    }
                }
            }
            /**
             * @hidden
             */
            function validateCardParams(params, validateIdentity = false) {
                assert(params != null, 'Card parameters must be provided');
                assert(params.privateKey != null, 'Card\'s private key is required');
                assert(params.publicKey != null, 'Card\'s public key is required');
                if (validateIdentity) {
                    assert(typeof params.identity === 'string' && params.identity !== '', 'Card\'s identity is required');
                }
            }

            const DEFAULTS = {
                verifySelfSignature: true,
                verifyVirgilSignature: true,
                whitelists: []
            };
            const VIRGIL_CARDS_PUBKEY_BASE64 = 'MCowBQYDK2VwAyEAljOYGANYiVq1WbvVvoYIKtvZi2ji9bAhxyu6iV/LF8M=';
            /**
             * Class responsible for validating cards by verifying their digital
             * signatures.
             */
            class VirgilCardVerifier {
                /**
                 * Initializes a new instance of `VirgilCardVerifier`.
                 * @param {ICardCrypto} crypto - Object implementing the
                 * {@link ICardCrypto} interface.
                 * @param {IVirgilCardVerifierParams} options - Initialization options.
                 */
                constructor(crypto, options) {
                    this.crypto = crypto;
                    const params = Object.assign(Object.assign({}, DEFAULTS), (options || {}));
                    this.verifySelfSignature = params.verifySelfSignature;
                    this.verifyVirgilSignature = params.verifyVirgilSignature;
                    this.whitelists = params.whitelists;
                    this.virgilCardsPublicKey = crypto.importPublicKey({ value: VIRGIL_CARDS_PUBKEY_BASE64, encoding: 'base64' });
                }
                /**
                 * Verifies the signatures of the `card`.
                 * @param {ICard} card
                 * @returns {boolean} `true` if the signatures to be verified are present
                 * and valid, otherwise `false`.
                 */
                verifyCard(card) {
                    if (this.selfValidationFailed(card)) {
                        return false;
                    }
                    if (this.virgilValidationFailed(card)) {
                        return false;
                    }
                    if (!this.whitelists || this.whitelists.length === 0) {
                        return true;
                    }
                    const signers = card.signatures.map(s => s.signer);
                    for (const whitelist of this.whitelists) {
                        if (whitelist == null || whitelist.length === 0) {
                            return false;
                        }
                        const intersectedCreds = whitelist.filter(x => signers.indexOf(x.signer) !== -1);
                        if (intersectedCreds.length === 0) {
                            return false;
                        }
                        const isValidForSome = intersectedCreds.some(cred => this.validateSignerSignature(card, this.getPublicKey(cred.publicKeyBase64), cred.signer));
                        if (!isValidForSome) {
                            return false;
                        }
                    }
                    return true;
                }
                selfValidationFailed(card) {
                    return this.verifySelfSignature
                        && !this.validateSignerSignature(card, card.publicKey, SelfSigner);
                }
                virgilValidationFailed(card) {
                    return this.verifyVirgilSignature
                        && !this.validateSignerSignature(card, this.virgilCardsPublicKey, VirgilSigner);
                }
                getPublicKey(signerPublicKeyBase64) {
                    return this.crypto.importPublicKey({ value: signerPublicKeyBase64, encoding: 'base64' });
                }
                validateSignerSignature(card, signerPublicKey, signer) {
                    const signature = card.signatures.find(s => s.signer === signer);
                    if (signature == null)
                        return false;
                    const extendedSnapshot = signature.snapshot == null
                        ? card.contentSnapshot
                        : card.contentSnapshot + signature.snapshot;
                    return this.crypto.verifySignature({ value: extendedSnapshot, encoding: 'utf8' }, { value: signature.signature, encoding: 'base64' }, signerPublicKey);
                }
            }

            var utf8 = createCommonjsModule(function (module, exports) {
            (function(root) {

            	var stringFromCharCode = String.fromCharCode;

            	// Taken from https://mths.be/punycode
            	function ucs2decode(string) {
            		var output = [];
            		var counter = 0;
            		var length = string.length;
            		var value;
            		var extra;
            		while (counter < length) {
            			value = string.charCodeAt(counter++);
            			if (value >= 0xD800 && value <= 0xDBFF && counter < length) {
            				// high surrogate, and there is a next character
            				extra = string.charCodeAt(counter++);
            				if ((extra & 0xFC00) == 0xDC00) { // low surrogate
            					output.push(((value & 0x3FF) << 10) + (extra & 0x3FF) + 0x10000);
            				} else {
            					// unmatched surrogate; only append this code unit, in case the next
            					// code unit is the high surrogate of a surrogate pair
            					output.push(value);
            					counter--;
            				}
            			} else {
            				output.push(value);
            			}
            		}
            		return output;
            	}

            	// Taken from https://mths.be/punycode
            	function ucs2encode(array) {
            		var length = array.length;
            		var index = -1;
            		var value;
            		var output = '';
            		while (++index < length) {
            			value = array[index];
            			if (value > 0xFFFF) {
            				value -= 0x10000;
            				output += stringFromCharCode(value >>> 10 & 0x3FF | 0xD800);
            				value = 0xDC00 | value & 0x3FF;
            			}
            			output += stringFromCharCode(value);
            		}
            		return output;
            	}

            	function checkScalarValue(codePoint) {
            		if (codePoint >= 0xD800 && codePoint <= 0xDFFF) {
            			throw Error(
            				'Lone surrogate U+' + codePoint.toString(16).toUpperCase() +
            				' is not a scalar value'
            			);
            		}
            	}
            	/*--------------------------------------------------------------------------*/

            	function createByte(codePoint, shift) {
            		return stringFromCharCode(((codePoint >> shift) & 0x3F) | 0x80);
            	}

            	function encodeCodePoint(codePoint) {
            		if ((codePoint & 0xFFFFFF80) == 0) { // 1-byte sequence
            			return stringFromCharCode(codePoint);
            		}
            		var symbol = '';
            		if ((codePoint & 0xFFFFF800) == 0) { // 2-byte sequence
            			symbol = stringFromCharCode(((codePoint >> 6) & 0x1F) | 0xC0);
            		}
            		else if ((codePoint & 0xFFFF0000) == 0) { // 3-byte sequence
            			checkScalarValue(codePoint);
            			symbol = stringFromCharCode(((codePoint >> 12) & 0x0F) | 0xE0);
            			symbol += createByte(codePoint, 6);
            		}
            		else if ((codePoint & 0xFFE00000) == 0) { // 4-byte sequence
            			symbol = stringFromCharCode(((codePoint >> 18) & 0x07) | 0xF0);
            			symbol += createByte(codePoint, 12);
            			symbol += createByte(codePoint, 6);
            		}
            		symbol += stringFromCharCode((codePoint & 0x3F) | 0x80);
            		return symbol;
            	}

            	function utf8encode(string) {
            		var codePoints = ucs2decode(string);
            		var length = codePoints.length;
            		var index = -1;
            		var codePoint;
            		var byteString = '';
            		while (++index < length) {
            			codePoint = codePoints[index];
            			byteString += encodeCodePoint(codePoint);
            		}
            		return byteString;
            	}

            	/*--------------------------------------------------------------------------*/

            	function readContinuationByte() {
            		if (byteIndex >= byteCount) {
            			throw Error('Invalid byte index');
            		}

            		var continuationByte = byteArray[byteIndex] & 0xFF;
            		byteIndex++;

            		if ((continuationByte & 0xC0) == 0x80) {
            			return continuationByte & 0x3F;
            		}

            		// If we end up here, it’s not a continuation byte
            		throw Error('Invalid continuation byte');
            	}

            	function decodeSymbol() {
            		var byte1;
            		var byte2;
            		var byte3;
            		var byte4;
            		var codePoint;

            		if (byteIndex > byteCount) {
            			throw Error('Invalid byte index');
            		}

            		if (byteIndex == byteCount) {
            			return false;
            		}

            		// Read first byte
            		byte1 = byteArray[byteIndex] & 0xFF;
            		byteIndex++;

            		// 1-byte sequence (no continuation bytes)
            		if ((byte1 & 0x80) == 0) {
            			return byte1;
            		}

            		// 2-byte sequence
            		if ((byte1 & 0xE0) == 0xC0) {
            			byte2 = readContinuationByte();
            			codePoint = ((byte1 & 0x1F) << 6) | byte2;
            			if (codePoint >= 0x80) {
            				return codePoint;
            			} else {
            				throw Error('Invalid continuation byte');
            			}
            		}

            		// 3-byte sequence (may include unpaired surrogates)
            		if ((byte1 & 0xF0) == 0xE0) {
            			byte2 = readContinuationByte();
            			byte3 = readContinuationByte();
            			codePoint = ((byte1 & 0x0F) << 12) | (byte2 << 6) | byte3;
            			if (codePoint >= 0x0800) {
            				checkScalarValue(codePoint);
            				return codePoint;
            			} else {
            				throw Error('Invalid continuation byte');
            			}
            		}

            		// 4-byte sequence
            		if ((byte1 & 0xF8) == 0xF0) {
            			byte2 = readContinuationByte();
            			byte3 = readContinuationByte();
            			byte4 = readContinuationByte();
            			codePoint = ((byte1 & 0x07) << 0x12) | (byte2 << 0x0C) |
            				(byte3 << 0x06) | byte4;
            			if (codePoint >= 0x010000 && codePoint <= 0x10FFFF) {
            				return codePoint;
            			}
            		}

            		throw Error('Invalid UTF-8 detected');
            	}

            	var byteArray;
            	var byteCount;
            	var byteIndex;
            	function utf8decode(byteString) {
            		byteArray = ucs2decode(byteString);
            		byteCount = byteArray.length;
            		byteIndex = 0;
            		var codePoints = [];
            		var tmp;
            		while ((tmp = decodeSymbol()) !== false) {
            			codePoints.push(tmp);
            		}
            		return ucs2encode(codePoints);
            	}

            	/*--------------------------------------------------------------------------*/

            	root.version = '3.0.0';
            	root.encode = utf8encode;
            	root.decode = utf8decode;

            }( exports));
            });

            // Some code originally from localForage
            // See: https://github.com/localForage/localForage/blob/master/src/utils/isIndexedDBValid.js
            /**
             * @hidden
             * @returns {boolean}
             */
            function isIndexedDbValid() {
                // We mimic PouchDB here
                // Following #7085 (see https://github.com/pouchdb/pouchdb/issues/7085)
                // buggy idb versions (typically Safari < 10.1) are considered valid.
                // On Firefox SecurityError is thrown while referencing indexedDB if cookies
                // are not allowed. `typeof indexedDB` also triggers the error.
                try {
                    // some outdated implementations of IDB that appear on Samsung
                    // and HTC Android devices <4.4 are missing IDBKeyRange
                    return typeof indexedDB !== 'undefined' && typeof IDBKeyRange !== 'undefined';
                }
                catch (e) {
                    return false;
                }
            }

            /**
             * Error thrown by {@link IStorageAdapter.store} method when saving a value
             * with a key that already exists in store.
             */
            class StorageEntryAlreadyExistsError extends VirgilError {
                constructor(key) {
                    super(`Storage entry ${key ? 'with key ' + name : 'with the given key'}already exists`, 'StorageEntryAlreadyExistsError', StorageEntryAlreadyExistsError);
                }
            }

            // Some code originally from localForage in
            // [localForage](https://github.com/localForage/localForage).
            // Transaction Modes
            const READ_ONLY = 'readonly';
            const READ_WRITE = 'readwrite';
            const dbContexts = {};
            /**
             * Implementation of {@link IStorageAdapter} that uses IndexedDB for
             * persistence. For use in browsers.
             */
            class IndexedDbStorageAdapter {
                /**
                 * Initializes an instance of `IndexedDbStorageAdapter`.
                 * @param {IStorageAdapterConfig} config - Configuration options.
                 * Currently only `name` is supported and must be the name of the
                 * IndexedDB database where the data will be stored.
                 */
                constructor(config) {
                    // Open the IndexedDB database (automatically creates one if one didn't
                    // previously exist), using any options set in the config.
                    this._initStorage = () => {
                        const dbInfo = {
                            db: null,
                            name: this._defaultConfig.name,
                            storeName: this._defaultConfig.storeName,
                            version: this._defaultConfig.version
                        };
                        // Get the current context of the database;
                        let dbContext = dbContexts[dbInfo.name];
                        // ...or create a new context.
                        if (!dbContext) {
                            dbContext = createDbContext();
                            // Register the new context in the global container.
                            dbContexts[dbInfo.name] = dbContext;
                        }
                        // Initialize the connection process only when
                        // all the related storages aren't pending.
                        return Promise.resolve()
                            .then(() => {
                            dbInfo.db = dbContext.db;
                            // Get the connection or open a new one without upgrade.
                            return _getOriginalConnection(dbInfo);
                        })
                            .then(db => {
                            dbInfo.db = db;
                            if (_isUpgradeNeeded(dbInfo, this._defaultConfig.version)) {
                                // Reopen the database for upgrading.
                                return _getUpgradedConnection(dbInfo);
                            }
                            return db;
                        })
                            .then(db => {
                            dbInfo.db = dbContext.db = db;
                            this._dbInfo = dbInfo;
                        });
                    };
                    // Specialize the default `ready()` function by making it dependent
                    // on the current database operations. Thus, the driver will be actually
                    // ready when it's been initialized (default) *and* there are no pending
                    // operations on the database (initiated by some other instances).
                    this.ready = () => {
                        const promise = this._ready.then(() => {
                            const dbContext = dbContexts[this._dbInfo.name];
                            if (dbContext && dbContext.dbReady) {
                                return dbContext.dbReady;
                            }
                        });
                        return promise;
                    };
                    if (!isIndexedDbValid()) {
                        throw new Error('Cannot use IndexedDbStorageAdapter. indexedDb is not supported');
                    }
                    this._defaultConfig = {
                        name: config.name,
                        version: 1,
                        storeName: 'keyvaluepairs'
                    };
                    this._ready = this._initStorage();
                }
                /**
                 * @inheritDoc
                 */
                store(key, data) {
                    key = normalizeKey(key);
                    return new Promise((resolve, reject) => {
                        this.ready().then(() => {
                            createTransaction(this._dbInfo, READ_WRITE, (err, transaction) => {
                                if (err) {
                                    return reject(err);
                                }
                                try {
                                    const store = transaction.objectStore(this._dbInfo.storeName);
                                    const req = store.add(data, key);
                                    transaction.oncomplete = () => {
                                        resolve();
                                    };
                                    transaction.onabort = transaction.onerror = () => {
                                        let error = req.error
                                            ? req.error
                                            : req.transaction.error;
                                        if (error && error.name === 'ConstraintError') {
                                            reject(new StorageEntryAlreadyExistsError(key));
                                        }
                                        reject(error);
                                    };
                                }
                                catch (error) {
                                    reject(error);
                                }
                            });
                        }).catch(reject);
                    });
                }
                /**
                 * @inheritDoc
                 */
                load(key) {
                    key = normalizeKey(key);
                    return new Promise((resolve, reject) => {
                        this.ready().then(() => {
                            createTransaction(this._dbInfo, READ_ONLY, (err, transaction) => {
                                if (err) {
                                    return reject(err);
                                }
                                try {
                                    const store = transaction.objectStore(this._dbInfo.storeName);
                                    const req = store.get(key);
                                    req.onsuccess = function () {
                                        if (req.result == null) {
                                            return resolve(null);
                                        }
                                        resolve(convertDbValue(req.result));
                                    };
                                    req.onerror = function () {
                                        reject(req.error);
                                    };
                                }
                                catch (e) {
                                    reject(e);
                                }
                            });
                        }).catch(reject);
                    });
                }
                /**
                 * @inheritDoc
                 */
                exists(key) {
                    key = normalizeKey(key);
                    return new Promise((resolve, reject) => {
                        this.ready().then(() => {
                            createTransaction(this._dbInfo, READ_ONLY, (err, transaction) => {
                                if (err) {
                                    return reject(err);
                                }
                                try {
                                    const store = transaction.objectStore(this._dbInfo.storeName);
                                    const req = store.openCursor(key);
                                    req.onsuccess = () => {
                                        const cursor = req.result;
                                        resolve(cursor !== null);
                                    };
                                    req.onerror = () => {
                                        reject(req.error);
                                    };
                                }
                                catch (e) {
                                    reject(e);
                                }
                            });
                        }).catch(reject);
                    });
                }
                /**
                 * @inheritDoc
                 */
                remove(key) {
                    key = normalizeKey(key);
                    return new Promise((resolve, reject) => {
                        this.ready().then(() => {
                            createTransaction(this._dbInfo, READ_WRITE, (err, transaction) => {
                                if (err) {
                                    return reject(err);
                                }
                                try {
                                    const store = transaction.objectStore(this._dbInfo.storeName);
                                    const countReq = store.count(key);
                                    let delReq;
                                    countReq.onsuccess = () => {
                                        const count = countReq.result;
                                        if (count === 0) {
                                            return resolve(false);
                                        }
                                        // safe for IE and some versions of Android
                                        // (including those used by Cordova).
                                        // Normally IE won't like `.delete()` and will insist on
                                        // using `['delete']()`
                                        delReq = store['delete'](key);
                                        delReq.onsuccess = () => resolve(true);
                                    };
                                    // The request will be also be aborted if we've exceeded our storage
                                    // space.
                                    transaction.onabort = transaction.onerror = () => {
                                        const req = delReq || countReq;
                                        const err = req.error
                                            ? req.error
                                            : req.transaction.error;
                                        reject(err);
                                    };
                                }
                                catch (e) {
                                    reject(e);
                                }
                            });
                        }).catch(reject);
                    });
                }
                /**
                 * @inheritDoc
                 */
                update(key, data) {
                    key = normalizeKey(key);
                    return new Promise((resolve, reject) => {
                        this.ready().then(() => {
                            createTransaction(this._dbInfo, READ_WRITE, (err, transaction) => {
                                if (err) {
                                    return reject(err);
                                }
                                try {
                                    const store = transaction.objectStore(this._dbInfo.storeName);
                                    const req = store.put(data, key);
                                    req.onsuccess = () => {
                                        resolve();
                                    };
                                    req.onerror = () => {
                                        reject(req.error);
                                    };
                                }
                                catch (error) {
                                    reject(error);
                                }
                            });
                        }).catch(reject);
                    });
                }
                /**
                 * @inheritDoc
                 */
                clear() {
                    return new Promise((resolve, reject) => {
                        this.ready().then(() => {
                            createTransaction(this._dbInfo, READ_WRITE, (err, transaction) => {
                                if (err) {
                                    return reject(err);
                                }
                                try {
                                    const store = transaction.objectStore(this._dbInfo.storeName);
                                    const req = store.clear();
                                    transaction.oncomplete = () => resolve();
                                    transaction.onabort = transaction.onerror = () => {
                                        const err = req.error
                                            ? req.error
                                            : req.transaction.error;
                                        reject(err);
                                    };
                                }
                                catch (e) {
                                    reject(e);
                                }
                            });
                        }).catch(reject);
                    });
                }
                /**
                 * @inheritDoc
                 */
                list() {
                    return new Promise((resolve, reject) => {
                        this.ready().then(() => {
                            createTransaction(this._dbInfo, READ_ONLY, (err, transaction) => {
                                if (err) {
                                    return reject(err);
                                }
                                try {
                                    const store = transaction.objectStore(this._dbInfo.storeName);
                                    const req = store.openCursor();
                                    const entries = [];
                                    req.onsuccess = () => {
                                        const cursor = req.result;
                                        if (!cursor) {
                                            resolve(entries);
                                        }
                                        else {
                                            entries.push(convertDbValue(cursor.value));
                                            cursor.continue();
                                        }
                                    };
                                    req.onerror = () => {
                                        reject(req.error);
                                    };
                                }
                                catch (e) {
                                    reject(e);
                                }
                            });
                        }).catch(reject);
                    });
                }
            }
            function createDbContext() {
                return {
                    // Database.
                    db: null,
                    // Database readiness (promise).
                    dbReady: null,
                    // Deferred operations on the database.
                    deferredOperations: []
                };
            }
            function _deferReadiness(dbInfo) {
                const dbContext = dbContexts[dbInfo.name];
                // Create a deferred object representing the current database operation.
                const deferredOperation = {};
                deferredOperation.promise = new Promise((resolve, reject) => {
                    deferredOperation.resolve = resolve;
                    deferredOperation.reject = reject;
                });
                // Enqueue the deferred operation.
                dbContext.deferredOperations.push(deferredOperation);
                // Chain its promise to the database readiness.
                if (!dbContext.dbReady) {
                    dbContext.dbReady = deferredOperation.promise;
                }
                else {
                    dbContext.dbReady = dbContext.dbReady.then(() => deferredOperation.promise);
                }
            }
            function _advanceReadiness(dbInfo) {
                const dbContext = dbContexts[dbInfo.name];
                // Dequeue a deferred operation.
                const deferredOperation = dbContext.deferredOperations.pop();
                // Resolve its promise (which is part of the database readiness
                // chain of promises).
                if (deferredOperation) {
                    deferredOperation.resolve();
                    return deferredOperation.promise;
                }
            }
            function _rejectReadiness(dbInfo, err) {
                const dbContext = dbContexts[dbInfo.name];
                // Dequeue a deferred operation.
                const deferredOperation = dbContext.deferredOperations.pop();
                // Reject its promise (which is part of the database readiness
                // chain of promises).
                if (deferredOperation) {
                    deferredOperation.reject(err);
                    return deferredOperation.promise;
                }
            }
            function _getConnection(dbInfo, upgradeNeeded) {
                return new Promise(function (resolve, reject) {
                    dbContexts[dbInfo.name] = dbContexts[dbInfo.name] || createDbContext();
                    if (dbInfo.db) {
                        if (upgradeNeeded) {
                            _deferReadiness(dbInfo);
                            dbInfo.db.close();
                        }
                        else {
                            return resolve(dbInfo.db);
                        }
                    }
                    const dbArgs = [dbInfo.name];
                    if (upgradeNeeded) {
                        dbArgs.push(String(dbInfo.version));
                    }
                    const openReq = indexedDB.open.apply(indexedDB, dbArgs);
                    if (upgradeNeeded) {
                        openReq.onupgradeneeded = (e) => {
                            const db = openReq.result;
                            try {
                                db.createObjectStore(dbInfo.storeName);
                            }
                            catch (ex) {
                                if (ex.name === 'ConstraintError') {
                                    console.warn('The database "' +
                                        dbInfo.name +
                                        '"' +
                                        ' has been upgraded from version ' +
                                        e.oldVersion +
                                        ' to version ' +
                                        e.newVersion +
                                        ', but the storage "' +
                                        dbInfo.storeName +
                                        '" already exists.');
                                }
                                else {
                                    throw ex;
                                }
                            }
                        };
                    }
                    openReq.onerror = (e) => {
                        e.preventDefault();
                        reject(openReq.error);
                    };
                    openReq.onsuccess = () => {
                        resolve(openReq.result);
                        _advanceReadiness(dbInfo);
                    };
                });
            }
            function _getOriginalConnection(dbInfo) {
                return _getConnection(dbInfo, false);
            }
            function _getUpgradedConnection(dbInfo) {
                return _getConnection(dbInfo, true);
            }
            function _isUpgradeNeeded(dbInfo, defaultVersion) {
                if (!dbInfo.db) {
                    return true;
                }
                const isNewStore = !dbInfo.db.objectStoreNames.contains(dbInfo.storeName);
                const isDowngrade = dbInfo.version < dbInfo.db.version;
                const isUpgrade = dbInfo.version > dbInfo.db.version;
                if (isDowngrade) {
                    // If the version is not the default one
                    // then warn for impossible downgrade.
                    if (dbInfo.version !== defaultVersion) {
                        console.warn('The database "' +
                            dbInfo.name +
                            '"' +
                            " can't be downgraded from version " +
                            dbInfo.db.version +
                            ' to version ' +
                            dbInfo.version +
                            '.');
                    }
                    // Align the versions to prevent errors.
                    dbInfo.version = dbInfo.db.version;
                }
                if (isUpgrade || isNewStore) {
                    // If the store is new then increment the version (if needed).
                    // This will trigger an "upgradeneeded" event which is required
                    // for creating a store.
                    if (isNewStore) {
                        const incVersion = dbInfo.db.version + 1;
                        if (incVersion > dbInfo.version) {
                            dbInfo.version = incVersion;
                        }
                    }
                    return true;
                }
                return false;
            }
            // Try to establish a new db connection to replace the
            // current one which is broken (i.e. experiencing
            // InvalidStateError while creating a transaction).
            function _tryReconnect(dbInfo) {
                _deferReadiness(dbInfo);
                const dbContext = dbContexts[dbInfo.name];
                dbInfo.db = null;
                return _getOriginalConnection(dbInfo)
                    .then(db => {
                    dbInfo.db = db;
                    if (_isUpgradeNeeded(dbInfo)) {
                        // Reopen the database for upgrading.
                        return _getUpgradedConnection(dbInfo);
                    }
                    return db;
                })
                    .then(db => {
                    // store the latest db reference
                    // in case the db was upgraded
                    dbInfo.db = dbContext.db = db;
                })
                    .catch(err => {
                    _rejectReadiness(dbInfo, err);
                    throw err;
                });
            }
            // FF doesn't like Promises (micro-tasks) and IDDB store operations,
            // so we have to do it with callbacks
            function createTransaction(dbInfo, mode, callback, retries) {
                if (retries === undefined) {
                    retries = 1;
                }
                try {
                    const tx = dbInfo.db.transaction(dbInfo.storeName, mode);
                    callback(null, tx);
                }
                catch (err) {
                    if (retries > 0 &&
                        (!dbInfo.db ||
                            err.name === 'InvalidStateError' ||
                            err.name === 'NotFoundError')) {
                        Promise.resolve()
                            .then(() => {
                            if (!dbInfo.db ||
                                (err.name === 'NotFoundError' &&
                                    !dbInfo.db.objectStoreNames.contains(dbInfo.storeName) &&
                                    dbInfo.version <= dbInfo.db.version)) {
                                // increase the db version, to create the new ObjectStore
                                if (dbInfo.db) {
                                    dbInfo.version = dbInfo.db.version + 1;
                                }
                                // Reopen the database for upgrading.
                                return _getUpgradedConnection(dbInfo);
                            }
                        })
                            .then(() => {
                            return _tryReconnect(dbInfo).then(function () {
                                createTransaction(dbInfo, mode, callback, retries - 1);
                            });
                        })
                            .catch(callback);
                    }
                    callback(err);
                }
            }
            function normalizeKey(key) {
                // Cast the key to a string, as that's all we can set as a key.
                if (typeof key !== 'string') {
                    console.warn(`${key} used as a key, but it is not a string.`);
                    key = String(key);
                }
                return key;
            }
            function convertDbValue(value) {
                if (value instanceof ArrayBuffer) {
                    const uint8Array = new Uint8Array(value);
                    // @ts-ignore
                    return utf8.decode(String.fromCharCode.apply(null, uint8Array));
                }
                if (typeof value === 'string') {
                    return value;
                }
                throw new TypeError('Unknown value format');
            }

            /**
             * Error thrown when the value loaded from persistent storage cannot be
             * parsed as a {@link IKeyEntry} object.
             */
            class InvalidKeyEntryError extends VirgilError {
                constructor(message = 'Loaded key entry was in invalid format.') {
                    super(message, 'InvalidKeyEntryError', InvalidKeyEntryError);
                }
            }
            /**
             * Error thrown from {@link KeyEntryStorage.save} method when saving a
             * a key entry with the name that already exists in store.
             */
            class KeyEntryAlreadyExistsError extends VirgilError {
                constructor(name) {
                    super(`Key entry ${name ? 'named ' + name : 'with same name'}already exists`, 'KeyEntryAlreadyExistsError', KeyEntryAlreadyExistsError);
                }
            }
            /**
             * Error thrown from {@link KeyEntryStorage.update} method when updating
             * a key entry that doesn't exist in store.
             */
            class KeyEntryDoesNotExistError extends VirgilError {
                constructor(name) {
                    super(`Key entry ${name ? 'named ' + name : 'with the given name'} does not exist.`, 'KeyEntryDoesNotExistError', KeyEntryDoesNotExistError);
                }
            }

            const DEFAULTS$2 = {
                dir: '.virgil_key_entries',
                name: 'VirgilKeyEntries'
            };
            const CREATION_DATE_KEY = 'creationDate';
            const MODIFICATION_DATE_KEY = 'modificationDate';
            /**
             * Class responsible for persisting private key bytes with optional
             * user-defined metadata.
             */
            class KeyEntryStorage {
                /**
                 * Initializes a new instance of `KeyEntryStorage`.
                 *
                 * @param {IKeyEntryStorageConfig} config - Instance configuration.
                 */
                constructor(config = {}) {
                    this.adapter = resolveAdapter$1(config);
                }
                /**
                 * @inheritDoc
                 */
                exists(name) {
                    validateName$1(name);
                    return this.adapter.exists(name);
                }
                /**
                 * @inheritDoc
                 */
                load(name) {
                    validateName$1(name);
                    return this.adapter.load(name).then(data => {
                        if (data == null) {
                            return null;
                        }
                        return deserializeKeyEntry(data);
                    });
                }
                /**
                 * @inheritDoc
                 */
                remove(name) {
                    validateName$1(name);
                    return this.adapter.remove(name);
                }
                /**
                 * @inheritDoc
                 */
                save({ name, value, meta }) {
                    validateNameProperty(name);
                    validateValueProperty(value);
                    const keyEntry = {
                        name: name,
                        value: value,
                        meta: meta,
                        creationDate: new Date(),
                        modificationDate: new Date()
                    };
                    return this.adapter.store(name, serializeKeyEntry(keyEntry))
                        .then(() => keyEntry)
                        .catch(error => {
                        if (error && error.name === 'StorageEntryAlreadyExistsError') {
                            throw new KeyEntryAlreadyExistsError(name);
                        }
                        throw error;
                    });
                }
                /**
                 * @inheritDoc
                 */
                list() {
                    return this.adapter.list()
                        .then(entries => entries.map(entry => deserializeKeyEntry(entry)));
                }
                /**
                 * @inheritDoc
                 */
                update({ name, value, meta }) {
                    validateNameProperty(name);
                    if (!(value || meta)) {
                        throw new TypeError('Invalid argument. Either `value` or `meta` property is required.');
                    }
                    return this.adapter.load(name)
                        .then(data => {
                        if (data === null) {
                            throw new KeyEntryDoesNotExistError(name);
                        }
                        const entry = deserializeKeyEntry(data);
                        const updatedEntry = Object.assign(entry, {
                            value: value || entry.value,
                            meta: meta || entry.meta,
                            modificationDate: new Date()
                        });
                        return this.adapter.update(name, serializeKeyEntry(updatedEntry))
                            .then(() => updatedEntry);
                    });
                }
                /**
                 * @inheritDoc
                 */
                clear() {
                    return this.adapter.clear();
                }
            }
            function serializeKeyEntry(keyEntry) {
                return JSON.stringify(keyEntry);
            }
            function deserializeKeyEntry(data) {
                try {
                    return JSON.parse(data, (key, value) => {
                        if (key === CREATION_DATE_KEY || key === MODIFICATION_DATE_KEY) {
                            return new Date(value);
                        }
                        return value;
                    });
                }
                catch (error) {
                    throw new InvalidKeyEntryError();
                }
            }
            function resolveAdapter$1(config) {
                if (typeof config === 'string') {
                    return new IndexedDbStorageAdapter({ dir: config, name: config });
                }
                const { adapter } = config, rest = __rest(config, ["adapter"]);
                if (adapter != null) {
                    return adapter;
                }
                return new IndexedDbStorageAdapter(Object.assign(Object.assign({}, DEFAULTS$2), rest));
            }
            const requiredArg = (name) => (value) => {
                if (!value)
                    throw new TypeError(`Argument '${name}' is required.`);
            };
            const requiredProp = (name) => (value) => {
                if (!value)
                    throw new TypeError(`Invalid argument. Property ${name} is required`);
            };
            const validateName$1 = requiredArg('name');
            const validateNameProperty = requiredProp('name');
            const validateValueProperty = requiredProp('value');

            var bind = function bind(fn, thisArg) {
              return function wrap() {
                var args = new Array(arguments.length);
                for (var i = 0; i < args.length; i++) {
                  args[i] = arguments[i];
                }
                return fn.apply(thisArg, args);
              };
            };

            /*global toString:true*/

            // utils is a library of generic helper functions non-specific to axios

            var toString = Object.prototype.toString;

            /**
             * Determine if a value is an Array
             *
             * @param {Object} val The value to test
             * @returns {boolean} True if value is an Array, otherwise false
             */
            function isArray(val) {
              return toString.call(val) === '[object Array]';
            }

            /**
             * Determine if a value is undefined
             *
             * @param {Object} val The value to test
             * @returns {boolean} True if the value is undefined, otherwise false
             */
            function isUndefined(val) {
              return typeof val === 'undefined';
            }

            /**
             * Determine if a value is a Buffer
             *
             * @param {Object} val The value to test
             * @returns {boolean} True if value is a Buffer, otherwise false
             */
            function isBuffer(val) {
              return val !== null && !isUndefined(val) && val.constructor !== null && !isUndefined(val.constructor)
                && typeof val.constructor.isBuffer === 'function' && val.constructor.isBuffer(val);
            }

            /**
             * Determine if a value is an ArrayBuffer
             *
             * @param {Object} val The value to test
             * @returns {boolean} True if value is an ArrayBuffer, otherwise false
             */
            function isArrayBuffer(val) {
              return toString.call(val) === '[object ArrayBuffer]';
            }

            /**
             * Determine if a value is a FormData
             *
             * @param {Object} val The value to test
             * @returns {boolean} True if value is an FormData, otherwise false
             */
            function isFormData(val) {
              return (typeof FormData !== 'undefined') && (val instanceof FormData);
            }

            /**
             * Determine if a value is a view on an ArrayBuffer
             *
             * @param {Object} val The value to test
             * @returns {boolean} True if value is a view on an ArrayBuffer, otherwise false
             */
            function isArrayBufferView(val) {
              var result;
              if ((typeof ArrayBuffer !== 'undefined') && (ArrayBuffer.isView)) {
                result = ArrayBuffer.isView(val);
              } else {
                result = (val) && (val.buffer) && (val.buffer instanceof ArrayBuffer);
              }
              return result;
            }

            /**
             * Determine if a value is a String
             *
             * @param {Object} val The value to test
             * @returns {boolean} True if value is a String, otherwise false
             */
            function isString(val) {
              return typeof val === 'string';
            }

            /**
             * Determine if a value is a Number
             *
             * @param {Object} val The value to test
             * @returns {boolean} True if value is a Number, otherwise false
             */
            function isNumber(val) {
              return typeof val === 'number';
            }

            /**
             * Determine if a value is an Object
             *
             * @param {Object} val The value to test
             * @returns {boolean} True if value is an Object, otherwise false
             */
            function isObject(val) {
              return val !== null && typeof val === 'object';
            }

            /**
             * Determine if a value is a Date
             *
             * @param {Object} val The value to test
             * @returns {boolean} True if value is a Date, otherwise false
             */
            function isDate(val) {
              return toString.call(val) === '[object Date]';
            }

            /**
             * Determine if a value is a File
             *
             * @param {Object} val The value to test
             * @returns {boolean} True if value is a File, otherwise false
             */
            function isFile(val) {
              return toString.call(val) === '[object File]';
            }

            /**
             * Determine if a value is a Blob
             *
             * @param {Object} val The value to test
             * @returns {boolean} True if value is a Blob, otherwise false
             */
            function isBlob(val) {
              return toString.call(val) === '[object Blob]';
            }

            /**
             * Determine if a value is a Function
             *
             * @param {Object} val The value to test
             * @returns {boolean} True if value is a Function, otherwise false
             */
            function isFunction(val) {
              return toString.call(val) === '[object Function]';
            }

            /**
             * Determine if a value is a Stream
             *
             * @param {Object} val The value to test
             * @returns {boolean} True if value is a Stream, otherwise false
             */
            function isStream(val) {
              return isObject(val) && isFunction(val.pipe);
            }

            /**
             * Determine if a value is a URLSearchParams object
             *
             * @param {Object} val The value to test
             * @returns {boolean} True if value is a URLSearchParams object, otherwise false
             */
            function isURLSearchParams(val) {
              return typeof URLSearchParams !== 'undefined' && val instanceof URLSearchParams;
            }

            /**
             * Trim excess whitespace off the beginning and end of a string
             *
             * @param {String} str The String to trim
             * @returns {String} The String freed of excess whitespace
             */
            function trim(str) {
              return str.replace(/^\s*/, '').replace(/\s*$/, '');
            }

            /**
             * Determine if we're running in a standard browser environment
             *
             * This allows axios to run in a web worker, and react-native.
             * Both environments support XMLHttpRequest, but not fully standard globals.
             *
             * web workers:
             *  typeof window -> undefined
             *  typeof document -> undefined
             *
             * react-native:
             *  navigator.product -> 'ReactNative'
             * nativescript
             *  navigator.product -> 'NativeScript' or 'NS'
             */
            function isStandardBrowserEnv() {
              if (typeof navigator !== 'undefined' && (navigator.product === 'ReactNative' ||
                                                       navigator.product === 'NativeScript' ||
                                                       navigator.product === 'NS')) {
                return false;
              }
              return (
                typeof window !== 'undefined' &&
                typeof document !== 'undefined'
              );
            }

            /**
             * Iterate over an Array or an Object invoking a function for each item.
             *
             * If `obj` is an Array callback will be called passing
             * the value, index, and complete array for each item.
             *
             * If 'obj' is an Object callback will be called passing
             * the value, key, and complete object for each property.
             *
             * @param {Object|Array} obj The object to iterate
             * @param {Function} fn The callback to invoke for each item
             */
            function forEach(obj, fn) {
              // Don't bother if no value provided
              if (obj === null || typeof obj === 'undefined') {
                return;
              }

              // Force an array if not already something iterable
              if (typeof obj !== 'object') {
                /*eslint no-param-reassign:0*/
                obj = [obj];
              }

              if (isArray(obj)) {
                // Iterate over array values
                for (var i = 0, l = obj.length; i < l; i++) {
                  fn.call(null, obj[i], i, obj);
                }
              } else {
                // Iterate over object keys
                for (var key in obj) {
                  if (Object.prototype.hasOwnProperty.call(obj, key)) {
                    fn.call(null, obj[key], key, obj);
                  }
                }
              }
            }

            /**
             * Accepts varargs expecting each argument to be an object, then
             * immutably merges the properties of each object and returns result.
             *
             * When multiple objects contain the same key the later object in
             * the arguments list will take precedence.
             *
             * Example:
             *
             * ```js
             * var result = merge({foo: 123}, {foo: 456});
             * console.log(result.foo); // outputs 456
             * ```
             *
             * @param {Object} obj1 Object to merge
             * @returns {Object} Result of all merge properties
             */
            function merge(/* obj1, obj2, obj3, ... */) {
              var result = {};
              function assignValue(val, key) {
                if (typeof result[key] === 'object' && typeof val === 'object') {
                  result[key] = merge(result[key], val);
                } else {
                  result[key] = val;
                }
              }

              for (var i = 0, l = arguments.length; i < l; i++) {
                forEach(arguments[i], assignValue);
              }
              return result;
            }

            /**
             * Function equal to merge with the difference being that no reference
             * to original objects is kept.
             *
             * @see merge
             * @param {Object} obj1 Object to merge
             * @returns {Object} Result of all merge properties
             */
            function deepMerge(/* obj1, obj2, obj3, ... */) {
              var result = {};
              function assignValue(val, key) {
                if (typeof result[key] === 'object' && typeof val === 'object') {
                  result[key] = deepMerge(result[key], val);
                } else if (typeof val === 'object') {
                  result[key] = deepMerge({}, val);
                } else {
                  result[key] = val;
                }
              }

              for (var i = 0, l = arguments.length; i < l; i++) {
                forEach(arguments[i], assignValue);
              }
              return result;
            }

            /**
             * Extends object a by mutably adding to it the properties of object b.
             *
             * @param {Object} a The object to be extended
             * @param {Object} b The object to copy properties from
             * @param {Object} thisArg The object to bind function to
             * @return {Object} The resulting value of object a
             */
            function extend(a, b, thisArg) {
              forEach(b, function assignValue(val, key) {
                if (thisArg && typeof val === 'function') {
                  a[key] = bind(val, thisArg);
                } else {
                  a[key] = val;
                }
              });
              return a;
            }

            var utils = {
              isArray: isArray,
              isArrayBuffer: isArrayBuffer,
              isBuffer: isBuffer,
              isFormData: isFormData,
              isArrayBufferView: isArrayBufferView,
              isString: isString,
              isNumber: isNumber,
              isObject: isObject,
              isUndefined: isUndefined,
              isDate: isDate,
              isFile: isFile,
              isBlob: isBlob,
              isFunction: isFunction,
              isStream: isStream,
              isURLSearchParams: isURLSearchParams,
              isStandardBrowserEnv: isStandardBrowserEnv,
              forEach: forEach,
              merge: merge,
              deepMerge: deepMerge,
              extend: extend,
              trim: trim
            };

            function encode(val) {
              return encodeURIComponent(val).
                replace(/%40/gi, '@').
                replace(/%3A/gi, ':').
                replace(/%24/g, '$').
                replace(/%2C/gi, ',').
                replace(/%20/g, '+').
                replace(/%5B/gi, '[').
                replace(/%5D/gi, ']');
            }

            /**
             * Build a URL by appending params to the end
             *
             * @param {string} url The base of the url (e.g., http://www.google.com)
             * @param {object} [params] The params to be appended
             * @returns {string} The formatted url
             */
            var buildURL = function buildURL(url, params, paramsSerializer) {
              /*eslint no-param-reassign:0*/
              if (!params) {
                return url;
              }

              var serializedParams;
              if (paramsSerializer) {
                serializedParams = paramsSerializer(params);
              } else if (utils.isURLSearchParams(params)) {
                serializedParams = params.toString();
              } else {
                var parts = [];

                utils.forEach(params, function serialize(val, key) {
                  if (val === null || typeof val === 'undefined') {
                    return;
                  }

                  if (utils.isArray(val)) {
                    key = key + '[]';
                  } else {
                    val = [val];
                  }

                  utils.forEach(val, function parseValue(v) {
                    if (utils.isDate(v)) {
                      v = v.toISOString();
                    } else if (utils.isObject(v)) {
                      v = JSON.stringify(v);
                    }
                    parts.push(encode(key) + '=' + encode(v));
                  });
                });

                serializedParams = parts.join('&');
              }

              if (serializedParams) {
                var hashmarkIndex = url.indexOf('#');
                if (hashmarkIndex !== -1) {
                  url = url.slice(0, hashmarkIndex);
                }

                url += (url.indexOf('?') === -1 ? '?' : '&') + serializedParams;
              }

              return url;
            };

            function InterceptorManager() {
              this.handlers = [];
            }

            /**
             * Add a new interceptor to the stack
             *
             * @param {Function} fulfilled The function to handle `then` for a `Promise`
             * @param {Function} rejected The function to handle `reject` for a `Promise`
             *
             * @return {Number} An ID used to remove interceptor later
             */
            InterceptorManager.prototype.use = function use(fulfilled, rejected) {
              this.handlers.push({
                fulfilled: fulfilled,
                rejected: rejected
              });
              return this.handlers.length - 1;
            };

            /**
             * Remove an interceptor from the stack
             *
             * @param {Number} id The ID that was returned by `use`
             */
            InterceptorManager.prototype.eject = function eject(id) {
              if (this.handlers[id]) {
                this.handlers[id] = null;
              }
            };

            /**
             * Iterate over all the registered interceptors
             *
             * This method is particularly useful for skipping over any
             * interceptors that may have become `null` calling `eject`.
             *
             * @param {Function} fn The function to call for each interceptor
             */
            InterceptorManager.prototype.forEach = function forEach(fn) {
              utils.forEach(this.handlers, function forEachHandler(h) {
                if (h !== null) {
                  fn(h);
                }
              });
            };

            var InterceptorManager_1 = InterceptorManager;

            /**
             * Transform the data for a request or a response
             *
             * @param {Object|String} data The data to be transformed
             * @param {Array} headers The headers for the request or response
             * @param {Array|Function} fns A single function or Array of functions
             * @returns {*} The resulting transformed data
             */
            var transformData = function transformData(data, headers, fns) {
              /*eslint no-param-reassign:0*/
              utils.forEach(fns, function transform(fn) {
                data = fn(data, headers);
              });

              return data;
            };

            var isCancel = function isCancel(value) {
              return !!(value && value.__CANCEL__);
            };

            var normalizeHeaderName = function normalizeHeaderName(headers, normalizedName) {
              utils.forEach(headers, function processHeader(value, name) {
                if (name !== normalizedName && name.toUpperCase() === normalizedName.toUpperCase()) {
                  headers[normalizedName] = value;
                  delete headers[name];
                }
              });
            };

            /**
             * Update an Error with the specified config, error code, and response.
             *
             * @param {Error} error The error to update.
             * @param {Object} config The config.
             * @param {string} [code] The error code (for example, 'ECONNABORTED').
             * @param {Object} [request] The request.
             * @param {Object} [response] The response.
             * @returns {Error} The error.
             */
            var enhanceError = function enhanceError(error, config, code, request, response) {
              error.config = config;
              if (code) {
                error.code = code;
              }

              error.request = request;
              error.response = response;
              error.isAxiosError = true;

              error.toJSON = function() {
                return {
                  // Standard
                  message: this.message,
                  name: this.name,
                  // Microsoft
                  description: this.description,
                  number: this.number,
                  // Mozilla
                  fileName: this.fileName,
                  lineNumber: this.lineNumber,
                  columnNumber: this.columnNumber,
                  stack: this.stack,
                  // Axios
                  config: this.config,
                  code: this.code
                };
              };
              return error;
            };

            /**
             * Create an Error with the specified message, config, error code, request and response.
             *
             * @param {string} message The error message.
             * @param {Object} config The config.
             * @param {string} [code] The error code (for example, 'ECONNABORTED').
             * @param {Object} [request] The request.
             * @param {Object} [response] The response.
             * @returns {Error} The created error.
             */
            var createError = function createError(message, config, code, request, response) {
              var error = new Error(message);
              return enhanceError(error, config, code, request, response);
            };

            /**
             * Resolve or reject a Promise based on response status.
             *
             * @param {Function} resolve A function that resolves the promise.
             * @param {Function} reject A function that rejects the promise.
             * @param {object} response The response.
             */
            var settle = function settle(resolve, reject, response) {
              var validateStatus = response.config.validateStatus;
              if (!validateStatus || validateStatus(response.status)) {
                resolve(response);
              } else {
                reject(createError(
                  'Request failed with status code ' + response.status,
                  response.config,
                  null,
                  response.request,
                  response
                ));
              }
            };

            /**
             * Determines whether the specified URL is absolute
             *
             * @param {string} url The URL to test
             * @returns {boolean} True if the specified URL is absolute, otherwise false
             */
            var isAbsoluteURL = function isAbsoluteURL(url) {
              // A URL is considered absolute if it begins with "<scheme>://" or "//" (protocol-relative URL).
              // RFC 3986 defines scheme name as a sequence of characters beginning with a letter and followed
              // by any combination of letters, digits, plus, period, or hyphen.
              return /^([a-z][a-z\d\+\-\.]*:)?\/\//i.test(url);
            };

            /**
             * Creates a new URL by combining the specified URLs
             *
             * @param {string} baseURL The base URL
             * @param {string} relativeURL The relative URL
             * @returns {string} The combined URL
             */
            var combineURLs = function combineURLs(baseURL, relativeURL) {
              return relativeURL
                ? baseURL.replace(/\/+$/, '') + '/' + relativeURL.replace(/^\/+/, '')
                : baseURL;
            };

            /**
             * Creates a new URL by combining the baseURL with the requestedURL,
             * only when the requestedURL is not already an absolute URL.
             * If the requestURL is absolute, this function returns the requestedURL untouched.
             *
             * @param {string} baseURL The base URL
             * @param {string} requestedURL Absolute or relative URL to combine
             * @returns {string} The combined full path
             */
            var buildFullPath = function buildFullPath(baseURL, requestedURL) {
              if (baseURL && !isAbsoluteURL(requestedURL)) {
                return combineURLs(baseURL, requestedURL);
              }
              return requestedURL;
            };

            // Headers whose duplicates are ignored by node
            // c.f. https://nodejs.org/api/http.html#http_message_headers
            var ignoreDuplicateOf = [
              'age', 'authorization', 'content-length', 'content-type', 'etag',
              'expires', 'from', 'host', 'if-modified-since', 'if-unmodified-since',
              'last-modified', 'location', 'max-forwards', 'proxy-authorization',
              'referer', 'retry-after', 'user-agent'
            ];

            /**
             * Parse headers into an object
             *
             * ```
             * Date: Wed, 27 Aug 2014 08:58:49 GMT
             * Content-Type: application/json
             * Connection: keep-alive
             * Transfer-Encoding: chunked
             * ```
             *
             * @param {String} headers Headers needing to be parsed
             * @returns {Object} Headers parsed into an object
             */
            var parseHeaders = function parseHeaders(headers) {
              var parsed = {};
              var key;
              var val;
              var i;

              if (!headers) { return parsed; }

              utils.forEach(headers.split('\n'), function parser(line) {
                i = line.indexOf(':');
                key = utils.trim(line.substr(0, i)).toLowerCase();
                val = utils.trim(line.substr(i + 1));

                if (key) {
                  if (parsed[key] && ignoreDuplicateOf.indexOf(key) >= 0) {
                    return;
                  }
                  if (key === 'set-cookie') {
                    parsed[key] = (parsed[key] ? parsed[key] : []).concat([val]);
                  } else {
                    parsed[key] = parsed[key] ? parsed[key] + ', ' + val : val;
                  }
                }
              });

              return parsed;
            };

            var isURLSameOrigin = (
              utils.isStandardBrowserEnv() ?

              // Standard browser envs have full support of the APIs needed to test
              // whether the request URL is of the same origin as current location.
                (function standardBrowserEnv() {
                  var msie = /(msie|trident)/i.test(navigator.userAgent);
                  var urlParsingNode = document.createElement('a');
                  var originURL;

                  /**
                * Parse a URL to discover it's components
                *
                * @param {String} url The URL to be parsed
                * @returns {Object}
                */
                  function resolveURL(url) {
                    var href = url;

                    if (msie) {
                    // IE needs attribute set twice to normalize properties
                      urlParsingNode.setAttribute('href', href);
                      href = urlParsingNode.href;
                    }

                    urlParsingNode.setAttribute('href', href);

                    // urlParsingNode provides the UrlUtils interface - http://url.spec.whatwg.org/#urlutils
                    return {
                      href: urlParsingNode.href,
                      protocol: urlParsingNode.protocol ? urlParsingNode.protocol.replace(/:$/, '') : '',
                      host: urlParsingNode.host,
                      search: urlParsingNode.search ? urlParsingNode.search.replace(/^\?/, '') : '',
                      hash: urlParsingNode.hash ? urlParsingNode.hash.replace(/^#/, '') : '',
                      hostname: urlParsingNode.hostname,
                      port: urlParsingNode.port,
                      pathname: (urlParsingNode.pathname.charAt(0) === '/') ?
                        urlParsingNode.pathname :
                        '/' + urlParsingNode.pathname
                    };
                  }

                  originURL = resolveURL(window.location.href);

                  /**
                * Determine if a URL shares the same origin as the current location
                *
                * @param {String} requestURL The URL to test
                * @returns {boolean} True if URL shares the same origin, otherwise false
                */
                  return function isURLSameOrigin(requestURL) {
                    var parsed = (utils.isString(requestURL)) ? resolveURL(requestURL) : requestURL;
                    return (parsed.protocol === originURL.protocol &&
                        parsed.host === originURL.host);
                  };
                })() :

              // Non standard browser envs (web workers, react-native) lack needed support.
                (function nonStandardBrowserEnv() {
                  return function isURLSameOrigin() {
                    return true;
                  };
                })()
            );

            var cookies = (
              utils.isStandardBrowserEnv() ?

              // Standard browser envs support document.cookie
                (function standardBrowserEnv() {
                  return {
                    write: function write(name, value, expires, path, domain, secure) {
                      var cookie = [];
                      cookie.push(name + '=' + encodeURIComponent(value));

                      if (utils.isNumber(expires)) {
                        cookie.push('expires=' + new Date(expires).toGMTString());
                      }

                      if (utils.isString(path)) {
                        cookie.push('path=' + path);
                      }

                      if (utils.isString(domain)) {
                        cookie.push('domain=' + domain);
                      }

                      if (secure === true) {
                        cookie.push('secure');
                      }

                      document.cookie = cookie.join('; ');
                    },

                    read: function read(name) {
                      var match = document.cookie.match(new RegExp('(^|;\\s*)(' + name + ')=([^;]*)'));
                      return (match ? decodeURIComponent(match[3]) : null);
                    },

                    remove: function remove(name) {
                      this.write(name, '', Date.now() - 86400000);
                    }
                  };
                })() :

              // Non standard browser env (web workers, react-native) lack needed support.
                (function nonStandardBrowserEnv() {
                  return {
                    write: function write() {},
                    read: function read() { return null; },
                    remove: function remove() {}
                  };
                })()
            );

            var xhr = function xhrAdapter(config) {
              return new Promise(function dispatchXhrRequest(resolve, reject) {
                var requestData = config.data;
                var requestHeaders = config.headers;

                if (utils.isFormData(requestData)) {
                  delete requestHeaders['Content-Type']; // Let the browser set it
                }

                var request = new XMLHttpRequest();

                // HTTP basic authentication
                if (config.auth) {
                  var username = config.auth.username || '';
                  var password = config.auth.password || '';
                  requestHeaders.Authorization = 'Basic ' + btoa(username + ':' + password);
                }

                var fullPath = buildFullPath(config.baseURL, config.url);
                request.open(config.method.toUpperCase(), buildURL(fullPath, config.params, config.paramsSerializer), true);

                // Set the request timeout in MS
                request.timeout = config.timeout;

                // Listen for ready state
                request.onreadystatechange = function handleLoad() {
                  if (!request || request.readyState !== 4) {
                    return;
                  }

                  // The request errored out and we didn't get a response, this will be
                  // handled by onerror instead
                  // With one exception: request that using file: protocol, most browsers
                  // will return status as 0 even though it's a successful request
                  if (request.status === 0 && !(request.responseURL && request.responseURL.indexOf('file:') === 0)) {
                    return;
                  }

                  // Prepare the response
                  var responseHeaders = 'getAllResponseHeaders' in request ? parseHeaders(request.getAllResponseHeaders()) : null;
                  var responseData = !config.responseType || config.responseType === 'text' ? request.responseText : request.response;
                  var response = {
                    data: responseData,
                    status: request.status,
                    statusText: request.statusText,
                    headers: responseHeaders,
                    config: config,
                    request: request
                  };

                  settle(resolve, reject, response);

                  // Clean up request
                  request = null;
                };

                // Handle browser request cancellation (as opposed to a manual cancellation)
                request.onabort = function handleAbort() {
                  if (!request) {
                    return;
                  }

                  reject(createError('Request aborted', config, 'ECONNABORTED', request));

                  // Clean up request
                  request = null;
                };

                // Handle low level network errors
                request.onerror = function handleError() {
                  // Real errors are hidden from us by the browser
                  // onerror should only fire if it's a network error
                  reject(createError('Network Error', config, null, request));

                  // Clean up request
                  request = null;
                };

                // Handle timeout
                request.ontimeout = function handleTimeout() {
                  var timeoutErrorMessage = 'timeout of ' + config.timeout + 'ms exceeded';
                  if (config.timeoutErrorMessage) {
                    timeoutErrorMessage = config.timeoutErrorMessage;
                  }
                  reject(createError(timeoutErrorMessage, config, 'ECONNABORTED',
                    request));

                  // Clean up request
                  request = null;
                };

                // Add xsrf header
                // This is only done if running in a standard browser environment.
                // Specifically not if we're in a web worker, or react-native.
                if (utils.isStandardBrowserEnv()) {
                  var cookies$1 = cookies;

                  // Add xsrf header
                  var xsrfValue = (config.withCredentials || isURLSameOrigin(fullPath)) && config.xsrfCookieName ?
                    cookies$1.read(config.xsrfCookieName) :
                    undefined;

                  if (xsrfValue) {
                    requestHeaders[config.xsrfHeaderName] = xsrfValue;
                  }
                }

                // Add headers to the request
                if ('setRequestHeader' in request) {
                  utils.forEach(requestHeaders, function setRequestHeader(val, key) {
                    if (typeof requestData === 'undefined' && key.toLowerCase() === 'content-type') {
                      // Remove Content-Type if data is undefined
                      delete requestHeaders[key];
                    } else {
                      // Otherwise add header to the request
                      request.setRequestHeader(key, val);
                    }
                  });
                }

                // Add withCredentials to request if needed
                if (!utils.isUndefined(config.withCredentials)) {
                  request.withCredentials = !!config.withCredentials;
                }

                // Add responseType to request if needed
                if (config.responseType) {
                  try {
                    request.responseType = config.responseType;
                  } catch (e) {
                    // Expected DOMException thrown by browsers not compatible XMLHttpRequest Level 2.
                    // But, this can be suppressed for 'json' type as it can be parsed by default 'transformResponse' function.
                    if (config.responseType !== 'json') {
                      throw e;
                    }
                  }
                }

                // Handle progress if needed
                if (typeof config.onDownloadProgress === 'function') {
                  request.addEventListener('progress', config.onDownloadProgress);
                }

                // Not all browsers support upload events
                if (typeof config.onUploadProgress === 'function' && request.upload) {
                  request.upload.addEventListener('progress', config.onUploadProgress);
                }

                if (config.cancelToken) {
                  // Handle cancellation
                  config.cancelToken.promise.then(function onCanceled(cancel) {
                    if (!request) {
                      return;
                    }

                    request.abort();
                    reject(cancel);
                    // Clean up request
                    request = null;
                  });
                }

                if (requestData === undefined) {
                  requestData = null;
                }

                // Send the request
                request.send(requestData);
              });
            };

            var DEFAULT_CONTENT_TYPE = {
              'Content-Type': 'application/x-www-form-urlencoded'
            };

            function setContentTypeIfUnset(headers, value) {
              if (!utils.isUndefined(headers) && utils.isUndefined(headers['Content-Type'])) {
                headers['Content-Type'] = value;
              }
            }

            function getDefaultAdapter() {
              var adapter;
              if (typeof XMLHttpRequest !== 'undefined') {
                // For browsers use XHR adapter
                adapter = xhr;
              } else if (typeof process !== 'undefined' && Object.prototype.toString.call(process) === '[object process]') {
                // For node use HTTP adapter
                adapter = xhr;
              }
              return adapter;
            }

            var defaults = {
              adapter: getDefaultAdapter(),

              transformRequest: [function transformRequest(data, headers) {
                normalizeHeaderName(headers, 'Accept');
                normalizeHeaderName(headers, 'Content-Type');
                if (utils.isFormData(data) ||
                  utils.isArrayBuffer(data) ||
                  utils.isBuffer(data) ||
                  utils.isStream(data) ||
                  utils.isFile(data) ||
                  utils.isBlob(data)
                ) {
                  return data;
                }
                if (utils.isArrayBufferView(data)) {
                  return data.buffer;
                }
                if (utils.isURLSearchParams(data)) {
                  setContentTypeIfUnset(headers, 'application/x-www-form-urlencoded;charset=utf-8');
                  return data.toString();
                }
                if (utils.isObject(data)) {
                  setContentTypeIfUnset(headers, 'application/json;charset=utf-8');
                  return JSON.stringify(data);
                }
                return data;
              }],

              transformResponse: [function transformResponse(data) {
                /*eslint no-param-reassign:0*/
                if (typeof data === 'string') {
                  try {
                    data = JSON.parse(data);
                  } catch (e) { /* Ignore */ }
                }
                return data;
              }],

              /**
               * A timeout in milliseconds to abort a request. If set to 0 (default) a
               * timeout is not created.
               */
              timeout: 0,

              xsrfCookieName: 'XSRF-TOKEN',
              xsrfHeaderName: 'X-XSRF-TOKEN',

              maxContentLength: -1,

              validateStatus: function validateStatus(status) {
                return status >= 200 && status < 300;
              }
            };

            defaults.headers = {
              common: {
                'Accept': 'application/json, text/plain, */*'
              }
            };

            utils.forEach(['delete', 'get', 'head'], function forEachMethodNoData(method) {
              defaults.headers[method] = {};
            });

            utils.forEach(['post', 'put', 'patch'], function forEachMethodWithData(method) {
              defaults.headers[method] = utils.merge(DEFAULT_CONTENT_TYPE);
            });

            var defaults_1 = defaults;

            /**
             * Throws a `Cancel` if cancellation has been requested.
             */
            function throwIfCancellationRequested(config) {
              if (config.cancelToken) {
                config.cancelToken.throwIfRequested();
              }
            }

            /**
             * Dispatch a request to the server using the configured adapter.
             *
             * @param {object} config The config that is to be used for the request
             * @returns {Promise} The Promise to be fulfilled
             */
            var dispatchRequest = function dispatchRequest(config) {
              throwIfCancellationRequested(config);

              // Ensure headers exist
              config.headers = config.headers || {};

              // Transform request data
              config.data = transformData(
                config.data,
                config.headers,
                config.transformRequest
              );

              // Flatten headers
              config.headers = utils.merge(
                config.headers.common || {},
                config.headers[config.method] || {},
                config.headers
              );

              utils.forEach(
                ['delete', 'get', 'head', 'post', 'put', 'patch', 'common'],
                function cleanHeaderConfig(method) {
                  delete config.headers[method];
                }
              );

              var adapter = config.adapter || defaults_1.adapter;

              return adapter(config).then(function onAdapterResolution(response) {
                throwIfCancellationRequested(config);

                // Transform response data
                response.data = transformData(
                  response.data,
                  response.headers,
                  config.transformResponse
                );

                return response;
              }, function onAdapterRejection(reason) {
                if (!isCancel(reason)) {
                  throwIfCancellationRequested(config);

                  // Transform response data
                  if (reason && reason.response) {
                    reason.response.data = transformData(
                      reason.response.data,
                      reason.response.headers,
                      config.transformResponse
                    );
                  }
                }

                return Promise.reject(reason);
              });
            };

            /**
             * Config-specific merge-function which creates a new config-object
             * by merging two configuration objects together.
             *
             * @param {Object} config1
             * @param {Object} config2
             * @returns {Object} New object resulting from merging config2 to config1
             */
            var mergeConfig = function mergeConfig(config1, config2) {
              // eslint-disable-next-line no-param-reassign
              config2 = config2 || {};
              var config = {};

              var valueFromConfig2Keys = ['url', 'method', 'params', 'data'];
              var mergeDeepPropertiesKeys = ['headers', 'auth', 'proxy'];
              var defaultToConfig2Keys = [
                'baseURL', 'url', 'transformRequest', 'transformResponse', 'paramsSerializer',
                'timeout', 'withCredentials', 'adapter', 'responseType', 'xsrfCookieName',
                'xsrfHeaderName', 'onUploadProgress', 'onDownloadProgress',
                'maxContentLength', 'validateStatus', 'maxRedirects', 'httpAgent',
                'httpsAgent', 'cancelToken', 'socketPath'
              ];

              utils.forEach(valueFromConfig2Keys, function valueFromConfig2(prop) {
                if (typeof config2[prop] !== 'undefined') {
                  config[prop] = config2[prop];
                }
              });

              utils.forEach(mergeDeepPropertiesKeys, function mergeDeepProperties(prop) {
                if (utils.isObject(config2[prop])) {
                  config[prop] = utils.deepMerge(config1[prop], config2[prop]);
                } else if (typeof config2[prop] !== 'undefined') {
                  config[prop] = config2[prop];
                } else if (utils.isObject(config1[prop])) {
                  config[prop] = utils.deepMerge(config1[prop]);
                } else if (typeof config1[prop] !== 'undefined') {
                  config[prop] = config1[prop];
                }
              });

              utils.forEach(defaultToConfig2Keys, function defaultToConfig2(prop) {
                if (typeof config2[prop] !== 'undefined') {
                  config[prop] = config2[prop];
                } else if (typeof config1[prop] !== 'undefined') {
                  config[prop] = config1[prop];
                }
              });

              var axiosKeys = valueFromConfig2Keys
                .concat(mergeDeepPropertiesKeys)
                .concat(defaultToConfig2Keys);

              var otherKeys = Object
                .keys(config2)
                .filter(function filterAxiosKeys(key) {
                  return axiosKeys.indexOf(key) === -1;
                });

              utils.forEach(otherKeys, function otherKeysDefaultToConfig2(prop) {
                if (typeof config2[prop] !== 'undefined') {
                  config[prop] = config2[prop];
                } else if (typeof config1[prop] !== 'undefined') {
                  config[prop] = config1[prop];
                }
              });

              return config;
            };

            /**
             * Create a new instance of Axios
             *
             * @param {Object} instanceConfig The default config for the instance
             */
            function Axios(instanceConfig) {
              this.defaults = instanceConfig;
              this.interceptors = {
                request: new InterceptorManager_1(),
                response: new InterceptorManager_1()
              };
            }

            /**
             * Dispatch a request
             *
             * @param {Object} config The config specific for this request (merged with this.defaults)
             */
            Axios.prototype.request = function request(config) {
              /*eslint no-param-reassign:0*/
              // Allow for axios('example/url'[, config]) a la fetch API
              if (typeof config === 'string') {
                config = arguments[1] || {};
                config.url = arguments[0];
              } else {
                config = config || {};
              }

              config = mergeConfig(this.defaults, config);

              // Set config.method
              if (config.method) {
                config.method = config.method.toLowerCase();
              } else if (this.defaults.method) {
                config.method = this.defaults.method.toLowerCase();
              } else {
                config.method = 'get';
              }

              // Hook up interceptors middleware
              var chain = [dispatchRequest, undefined];
              var promise = Promise.resolve(config);

              this.interceptors.request.forEach(function unshiftRequestInterceptors(interceptor) {
                chain.unshift(interceptor.fulfilled, interceptor.rejected);
              });

              this.interceptors.response.forEach(function pushResponseInterceptors(interceptor) {
                chain.push(interceptor.fulfilled, interceptor.rejected);
              });

              while (chain.length) {
                promise = promise.then(chain.shift(), chain.shift());
              }

              return promise;
            };

            Axios.prototype.getUri = function getUri(config) {
              config = mergeConfig(this.defaults, config);
              return buildURL(config.url, config.params, config.paramsSerializer).replace(/^\?/, '');
            };

            // Provide aliases for supported request methods
            utils.forEach(['delete', 'get', 'head', 'options'], function forEachMethodNoData(method) {
              /*eslint func-names:0*/
              Axios.prototype[method] = function(url, config) {
                return this.request(utils.merge(config || {}, {
                  method: method,
                  url: url
                }));
              };
            });

            utils.forEach(['post', 'put', 'patch'], function forEachMethodWithData(method) {
              /*eslint func-names:0*/
              Axios.prototype[method] = function(url, data, config) {
                return this.request(utils.merge(config || {}, {
                  method: method,
                  url: url,
                  data: data
                }));
              };
            });

            var Axios_1 = Axios;

            /**
             * A `Cancel` is an object that is thrown when an operation is canceled.
             *
             * @class
             * @param {string=} message The message.
             */
            function Cancel(message) {
              this.message = message;
            }

            Cancel.prototype.toString = function toString() {
              return 'Cancel' + (this.message ? ': ' + this.message : '');
            };

            Cancel.prototype.__CANCEL__ = true;

            var Cancel_1 = Cancel;

            /**
             * A `CancelToken` is an object that can be used to request cancellation of an operation.
             *
             * @class
             * @param {Function} executor The executor function.
             */
            function CancelToken(executor) {
              if (typeof executor !== 'function') {
                throw new TypeError('executor must be a function.');
              }

              var resolvePromise;
              this.promise = new Promise(function promiseExecutor(resolve) {
                resolvePromise = resolve;
              });

              var token = this;
              executor(function cancel(message) {
                if (token.reason) {
                  // Cancellation has already been requested
                  return;
                }

                token.reason = new Cancel_1(message);
                resolvePromise(token.reason);
              });
            }

            /**
             * Throws a `Cancel` if cancellation has been requested.
             */
            CancelToken.prototype.throwIfRequested = function throwIfRequested() {
              if (this.reason) {
                throw this.reason;
              }
            };

            /**
             * Returns an object that contains a new `CancelToken` and a function that, when called,
             * cancels the `CancelToken`.
             */
            CancelToken.source = function source() {
              var cancel;
              var token = new CancelToken(function executor(c) {
                cancel = c;
              });
              return {
                token: token,
                cancel: cancel
              };
            };

            var CancelToken_1 = CancelToken;

            /**
             * Syntactic sugar for invoking a function and expanding an array for arguments.
             *
             * Common use case would be to use `Function.prototype.apply`.
             *
             *  ```js
             *  function f(x, y, z) {}
             *  var args = [1, 2, 3];
             *  f.apply(null, args);
             *  ```
             *
             * With `spread` this example can be re-written.
             *
             *  ```js
             *  spread(function(x, y, z) {})([1, 2, 3]);
             *  ```
             *
             * @param {Function} callback
             * @returns {Function}
             */
            var spread = function spread(callback) {
              return function wrap(arr) {
                return callback.apply(null, arr);
              };
            };

            /**
             * Create an instance of Axios
             *
             * @param {Object} defaultConfig The default config for the instance
             * @return {Axios} A new instance of Axios
             */
            function createInstance(defaultConfig) {
              var context = new Axios_1(defaultConfig);
              var instance = bind(Axios_1.prototype.request, context);

              // Copy axios.prototype to instance
              utils.extend(instance, Axios_1.prototype, context);

              // Copy context to instance
              utils.extend(instance, context);

              return instance;
            }

            // Create the default instance to be exported
            var axios = createInstance(defaults_1);

            // Expose Axios class to allow class inheritance
            axios.Axios = Axios_1;

            // Factory for creating new instances
            axios.create = function create(instanceConfig) {
              return createInstance(mergeConfig(axios.defaults, instanceConfig));
            };

            // Expose Cancel & CancelToken
            axios.Cancel = Cancel_1;
            axios.CancelToken = CancelToken_1;
            axios.isCancel = isCancel;

            // Expose all/spread
            axios.all = function all(promises) {
              return Promise.all(promises);
            };
            axios.spread = spread;

            var axios_1 = axios;

            // Allow use of default import syntax in TypeScript
            var default_1 = axios;
            axios_1.default = default_1;

            var axios$1 = axios_1;

            var commonjsGlobal$1 = typeof globalThis !== 'undefined' ? globalThis : typeof window !== 'undefined' ? window : typeof global !== 'undefined' ? global : typeof self !== 'undefined' ? self : {};

            function createCommonjsModule$1(fn, module) {
            	return module = { exports: {} }, fn(module, module.exports), module.exports;
            }

            function getCjsExportFromNamespace (n) {
            	return n && n['default'] || n;
            }

            var base64$1 = createCommonjsModule$1(function (module, exports) {
            (function(root) {

            	// Detect free variables `exports`.
            	var freeExports =  exports;

            	// Detect free variable `module`.
            	var freeModule =  module &&
            		module.exports == freeExports && module;

            	// Detect free variable `global`, from Node.js or Browserified code, and use
            	// it as `root`.
            	var freeGlobal = typeof commonjsGlobal$1 == 'object' && commonjsGlobal$1;
            	if (freeGlobal.global === freeGlobal || freeGlobal.window === freeGlobal) {
            		root = freeGlobal;
            	}

            	/*--------------------------------------------------------------------------*/

            	var InvalidCharacterError = function(message) {
            		this.message = message;
            	};
            	InvalidCharacterError.prototype = new Error;
            	InvalidCharacterError.prototype.name = 'InvalidCharacterError';

            	var error = function(message) {
            		// Note: the error messages used throughout this file match those used by
            		// the native `atob`/`btoa` implementation in Chromium.
            		throw new InvalidCharacterError(message);
            	};

            	var TABLE = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
            	// http://whatwg.org/html/common-microsyntaxes.html#space-character
            	var REGEX_SPACE_CHARACTERS = /[\t\n\f\r ]/g;

            	// `decode` is designed to be fully compatible with `atob` as described in the
            	// HTML Standard. http://whatwg.org/html/webappapis.html#dom-windowbase64-atob
            	// The optimized base64-decoding algorithm used is based on @atk’s excellent
            	// implementation. https://gist.github.com/atk/1020396
            	var decode = function(input) {
            		input = String(input)
            			.replace(REGEX_SPACE_CHARACTERS, '');
            		var length = input.length;
            		if (length % 4 == 0) {
            			input = input.replace(/==?$/, '');
            			length = input.length;
            		}
            		if (
            			length % 4 == 1 ||
            			// http://whatwg.org/C#alphanumeric-ascii-characters
            			/[^+a-zA-Z0-9/]/.test(input)
            		) {
            			error(
            				'Invalid character: the string to be decoded is not correctly encoded.'
            			);
            		}
            		var bitCounter = 0;
            		var bitStorage;
            		var buffer;
            		var output = '';
            		var position = -1;
            		while (++position < length) {
            			buffer = TABLE.indexOf(input.charAt(position));
            			bitStorage = bitCounter % 4 ? bitStorage * 64 + buffer : buffer;
            			// Unless this is the first of a group of 4 characters…
            			if (bitCounter++ % 4) {
            				// …convert the first 8 bits to a single ASCII character.
            				output += String.fromCharCode(
            					0xFF & bitStorage >> (-2 * bitCounter & 6)
            				);
            			}
            		}
            		return output;
            	};

            	// `encode` is designed to be fully compatible with `btoa` as described in the
            	// HTML Standard: http://whatwg.org/html/webappapis.html#dom-windowbase64-btoa
            	var encode = function(input) {
            		input = String(input);
            		if (/[^\0-\xFF]/.test(input)) {
            			// Note: no need to special-case astral symbols here, as surrogates are
            			// matched, and the input is supposed to only contain ASCII anyway.
            			error(
            				'The string to be encoded contains characters outside of the ' +
            				'Latin1 range.'
            			);
            		}
            		var padding = input.length % 3;
            		var output = '';
            		var position = -1;
            		var a;
            		var b;
            		var c;
            		var buffer;
            		// Make sure any padding is handled outside of the loop.
            		var length = input.length - padding;

            		while (++position < length) {
            			// Read three bytes, i.e. 24 bits.
            			a = input.charCodeAt(position) << 16;
            			b = input.charCodeAt(++position) << 8;
            			c = input.charCodeAt(++position);
            			buffer = a + b + c;
            			// Turn the 24 bits into four chunks of 6 bits each, and append the
            			// matching character for each of them to the output.
            			output += (
            				TABLE.charAt(buffer >> 18 & 0x3F) +
            				TABLE.charAt(buffer >> 12 & 0x3F) +
            				TABLE.charAt(buffer >> 6 & 0x3F) +
            				TABLE.charAt(buffer & 0x3F)
            			);
            		}

            		if (padding == 2) {
            			a = input.charCodeAt(position) << 8;
            			b = input.charCodeAt(++position);
            			buffer = a + b;
            			output += (
            				TABLE.charAt(buffer >> 10) +
            				TABLE.charAt((buffer >> 4) & 0x3F) +
            				TABLE.charAt((buffer << 2) & 0x3F) +
            				'='
            			);
            		} else if (padding == 1) {
            			buffer = input.charCodeAt(position);
            			output += (
            				TABLE.charAt(buffer >> 2) +
            				TABLE.charAt((buffer << 4) & 0x3F) +
            				'=='
            			);
            		}

            		return output;
            	};

            	var base64 = {
            		'encode': encode,
            		'decode': decode,
            		'version': '0.1.0'
            	};

            	// Some AMD build optimizers, like r.js, check for specific condition patterns
            	// like the following:
            	if (freeExports && !freeExports.nodeType) {
            		if (freeModule) { // in Node.js or RingoJS v0.8.0+
            			freeModule.exports = base64;
            		} else { // in Narwhal or RingoJS v0.7.0-
            			for (var key in base64) {
            				base64.hasOwnProperty(key) && (freeExports[key] = base64[key]);
            			}
            		}
            	} else { // in Rhino or a web browser
            		root.base64 = base64;
            	}

            }(commonjsGlobal$1));
            });

            /*! *****************************************************************************
            Copyright (c) Microsoft Corporation. All rights reserved.
            Licensed under the Apache License, Version 2.0 (the "License"); you may not use
            this file except in compliance with the License. You may obtain a copy of the
            License at http://www.apache.org/licenses/LICENSE-2.0

            THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
            KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
            WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
            MERCHANTABLITY OR NON-INFRINGEMENT.

            See the Apache Version 2.0 License for specific language governing permissions
            and limitations under the License.
            ***************************************************************************** */function r(e,t){var i={};for(var r in e)Object.prototype.hasOwnProperty.call(e,r)&&t.indexOf(r)<0&&(i[r]=e[r]);if(null!=e&&"function"==typeof Object.getOwnPropertySymbols){var n=0;for(r=Object.getOwnPropertySymbols(e);n<r.length;n++)t.indexOf(r[n])<0&&(i[r[n]]=e[r[n]]);}return i}function n(e,t,i,r){return new(i||(i=Promise))((function(n,s){function o(e){try{y(r.next(e));}catch(e){s(e);}}function a(e){try{y(r.throw(e));}catch(e){s(e);}}function y(e){e.done?n(e.value):new i((function(t){t(e.value);})).then(o,a);}y((r=r.apply(e,t||[])).next());}))}class s extends Error{constructor(e,t="KeyknoxError",i=s){super(e),Object.setPrototypeOf(this,i.prototype),this.name=t;}}class o extends s{constructor(e,t,i){super(e,"KeyknoxClientError",o),this.status=t,this.code=i;}}class a extends s{constructor(){super("CloudKeyStorage is out of sync","CloudKeyStorageOutOfSyncError",a);}}class y extends s{constructor(e){super(`Cloud entry '${e}' already exists`,"CloudEntryExistsError",y),this.cloudEntryName=e;}}class c extends s{constructor(e){super(`Cloud entry '${e}' doesn't exist`,"CloudEntryDoesntExistError",c),this.cloudEntryName=e;}}class u extends s{constructor(){super("GroupSessionMessageInfo already exist","GroupTicketAlreadyExistsError",u);}}class l extends s{constructor(){super("Group ticket doesn't exist","GroupTicketDoesntExistError",l);}}class v extends s{constructor(){super("Current user has no access to the group ticket","GroupTicketNoAccessError",v);}}class p{constructor(i,r,n,s){this.accessTokenProvider=i,this.axios=n||axios$1.create({baseURL:r||p.API_URL}),this.virgilAgent=s||new VirgilAgent("keyknox","0.4.0-next.3"),this.axios.interceptors.response.use(void 0,p.responseErrorHandler);}v1Push(e,t,i){return n(this,void 0,void 0,(function*(){const r={meta:e,value:t},n=yield this.accessTokenProvider.getToken({service:"keyknox",operation:"put"}),s={headers:p.getHeaders({accessToken:n,keyknoxHash:i,virgilAgent:this.virgilAgent})},o=yield this.axios.put("/keyknox/v1",r,s);return p.getKeyknoxValueV1(o)}))}v1Pull(){return n(this,void 0,void 0,(function*(){const e=yield this.accessTokenProvider.getToken({service:"keyknox",operation:"get"}),t={headers:p.getHeaders({accessToken:e,virgilAgent:this.virgilAgent})},i=yield this.axios.get("/keyknox/v1",t);return p.getKeyknoxValueV1(i)}))}v1Reset(){return n(this,void 0,void 0,(function*(){const e=yield this.accessTokenProvider.getToken({service:"keyknox",operation:"delete"}),t={headers:p.getHeaders({accessToken:e,virgilAgent:this.virgilAgent})},i=yield this.axios.post("/keyknox/v1/reset",void 0,t);return p.getKeyknoxValueV1(i)}))}v2Push(e){return n(this,void 0,void 0,(function*(){const{root:t,path:i,key:r,identities:n,meta:s,value:o,keyknoxHash:a}=e,y={root:t,path:i,key:r,identities:n,meta:s,value:o},c=yield this.accessTokenProvider.getToken({service:"keyknox",operation:"put"}),d={headers:p.getHeaders({accessToken:c,keyknoxHash:a,virgilAgent:this.virgilAgent})},h=yield this.axios.post("/keyknox/v2/push",y,d);return p.getKeyknoxValueV2(h)}))}v2Pull(e){return n(this,void 0,void 0,(function*(){const{root:t,path:i,key:r,identity:n}=e,s={root:t,path:i,key:r,identity:n},o=yield this.accessTokenProvider.getToken({service:"keyknox",operation:"get"}),a={headers:p.getHeaders({accessToken:o,virgilAgent:this.virgilAgent})},y=yield this.axios.post("/keyknox/v2/pull",s,a);return p.getKeyknoxValueV2(y)}))}v2GetKeys(e){return n(this,void 0,void 0,(function*(){const{root:t,path:i,identity:r}=e,n={root:t,path:i,identity:r},s=yield this.accessTokenProvider.getToken({service:"keyknox",operation:"get"}),o={headers:p.getHeaders({accessToken:s,virgilAgent:this.virgilAgent})};return (yield this.axios.post("/keyknox/v2/keys",n,o)).data}))}v2Reset(e){return n(this,void 0,void 0,(function*(){const{root:t,path:i,key:r,identity:n}=e,s={root:t,path:i,key:r,identity:n},o=yield this.accessTokenProvider.getToken({service:"keyknox",operation:"delete"}),a={headers:p.getHeaders({accessToken:o,virgilAgent:this.virgilAgent})},y=yield this.axios.post("/keyknox/v2/reset",s,a);return p.getKeyknoxValueV2(y)}))}static getKeyknoxValueV1(e){const{data:t,headers:i}=e;return {meta:t.meta,value:t.value,version:t.version,keyknoxHash:i["virgil-keyknox-hash"]}}static getKeyknoxValueV2(e){const{data:t,headers:i}=e;return {owner:t.owner,root:t.root,path:t.path,key:t.key,identities:t.identities,meta:t.meta,value:t.value,keyknoxHash:i["virgil-keyknox-hash"]}}static getHeaders(e){const{virgilAgent:t,accessToken:i,keyknoxHash:r}=e,n={"Virgil-Agent":t.value};return i&&(n.Authorization=`Virgil ${i.toString()}`),r&&(n["Virgil-Keyknox-Previous-Hash"]=r),n}static responseErrorHandler(e){const{response:t}=e;if(t){const{data:i}=t;return i&&i.code&&i.message?Promise.reject(new o(i.message,t.status,i.code)):Promise.reject(new o(e.message,t.status))}return Promise.reject(new o(e.message))}}p.API_URL="https://api.virgilsecurity.com";class k{constructor(e){this.crypto=e;}decrypt(e,t,i,r){if(!t||!e){if(t||e)throw new TypeError("'metadata' or 'encryptedData' is empty");return t}return this.crypto.decryptThenVerifyDetached({value:t,encoding:"base64"},{value:e,encoding:"base64"},i,r).toString("base64")}encrypt(e,t,i){const{metadata:r,encryptedData:n}=this.crypto.signThenEncryptDetached({value:e,encoding:"base64"},t,i);return {metadata:r.toString("base64"),encryptedData:n.toString("base64")}}}const g=50010;class m{constructor(e,t){this.myKeyknoxCrypto=e,this.keyknoxClient=t;}get keyknoxCrypto(){return this.myKeyknoxCrypto}static create(e,t){const i=new p(e);return new m(t,i)}v1Push(e,t,i,r){return n(this,void 0,void 0,(function*(){const{metadata:n,encryptedData:s}=this.myKeyknoxCrypto.encrypt(e,t,i),o=yield this.keyknoxClient.v1Push(n,s,r);return this.v1Decrypt(o,t,i)}))}v1Pull(e,t){return n(this,void 0,void 0,(function*(){const i=yield this.keyknoxClient.v1Pull();return this.v1Decrypt(i,e,t)}))}v1Reset(){return n(this,void 0,void 0,(function*(){return this.keyknoxClient.v1Reset()}))}v1Update(e){return n(this,void 0,void 0,(function*(){const{value:t,privateKey:i,publicKeys:r,keyknoxHash:n,newPrivateKey:s,newPublicKeys:o}=e;if(!s&&!o)return this.v1Push(t,i,r,n);const a=yield this.v1Pull(i,r),y=s||i,c=o||r,{metadata:d,encryptedData:h}=this.myKeyknoxCrypto.encrypt(a.value,y,c),u=yield this.keyknoxClient.v1Push(d,h,a.keyknoxHash);return this.v1Decrypt(u,y,c)}))}v1UpdateRecipients(e){return n(this,void 0,void 0,(function*(){const{privateKey:t,publicKeys:i,newPrivateKey:r,newPublicKeys:n}=e,s=yield this.v1Pull(t,i);if(!s.meta&&!s.value)return s;const o=r||t,a=n||i,{metadata:y,encryptedData:c}=this.myKeyknoxCrypto.encrypt(s.value,o,a),d=yield this.keyknoxClient.v1Push(y,c,s.keyknoxHash);return this.v1Decrypt(d,o,a)}))}v2Push(e){return n(this,void 0,void 0,(function*(){const{value:t,privateKey:i,publicKeys:n}=e,s=r(e,["value","privateKey","publicKeys"]),{metadata:o,encryptedData:a}=this.encrypt(t,i,n),y=yield this.keyknoxClient.v2Push(Object.assign(Object.assign({},s),{value:a,meta:o}));return this.v2Decrypt(y,i,n)}))}v2Pull(e){return n(this,void 0,void 0,(function*(){const{privateKey:t,publicKeys:i}=e,n=r(e,["privateKey","publicKeys"]),s=yield this.keyknoxClient.v2Pull(n);return this.v2Decrypt(s,t,i)}))}v2GetKeys(e){return n(this,void 0,void 0,(function*(){return this.keyknoxClient.v2GetKeys(e)}))}v2Reset(e){return n(this,void 0,void 0,(function*(){return this.keyknoxClient.v2Reset(e)}))}v1Decrypt(e,t,i){const{meta:n,value:s}=e,o=r(e,["meta","value"]),a=this.myKeyknoxCrypto.decrypt(n,s,t,i);return Object.assign(Object.assign({},o),{meta:n,value:a})}v2Decrypt(e,t,i){const{meta:n,value:s}=e,o=r(e,["meta","value"]),a=this.myKeyknoxCrypto.decrypt(n,s,t,i);return Object.assign(Object.assign({},o),{meta:n,value:a})}encrypt(e,t,i){return this.myKeyknoxCrypto.encrypt(e,t,i)}}class x{constructor(e){const{keyknoxManager:t,identity:i,privateKey:r,publicKey:n,root:s}=e;this.keyknoxManager=t,this.identity=i,this.privateKey=r,this.publicKey=n,this.root=s||x.DEFAULT_ROOT;}static create(e){const{accessTokenProvider:t,identity:i,privateKey:r,publicKey:n,virgilCrypto:s,root:o}=e,a=m.create(t,new k(s));return new x({keyknoxManager:a,identity:i,privateKey:r,publicKey:n,root:o})}store(e,t){return n(this,void 0,void 0,(function*(){const{epochNumber:i,sessionId:r,data:n}=e;let s=[this.identity],a=[this.publicKey];if(t){const e=Array.isArray(t)?t:[t];s=s.concat(e.map(e=>e.identity)),a=a.concat(e.map(e=>e.publicKey));}try{yield this.keyknoxManager.v2Push({identities:s,publicKeys:a,privateKey:this.privateKey,root:this.root,path:r,key:i.toString(),value:n});}catch(e){if(e instanceof o&&e.code===g)throw new u;throw e}}))}retrieve(e,t,i){return n(this,void 0,void 0,(function*(){let r=this.identity,n=this.publicKey;if(t&&i)r=t,n=i;else if(Boolean(t)!==Boolean(i))throw new Error("You need to provide both 'identity' and 'publicKey'");const s=yield this.keyknoxManager.v2GetKeys({root:this.root,path:e,identity:r});if(!s.length)throw new l;const o=s.map(t=>this.keyknoxManager.v2Pull({root:this.root,path:e,key:t,identity:r,privateKey:this.privateKey,publicKeys:n}));try{return (yield Promise.all(o)).map(({key:e,path:t,identities:i,value:r})=>({identities:i,groupSessionMessageInfo:{sessionId:t,epochNumber:Number(e),data:r}}))}catch(e){throw x.throwIfRecipientIsNotFound(e),e}}))}addRecipients(e,t){return n(this,void 0,void 0,(function*(){const i=(yield this.keyknoxManager.v2GetKeys({root:this.root,path:e,identity:this.identity})).map(i=>n(this,void 0,void 0,(function*(){const r=yield this.keyknoxManager.v2Pull({root:this.root,path:e,key:i,identity:this.identity,privateKey:this.privateKey,publicKeys:this.publicKey});yield this.keyknoxManager.v2Push(Object.assign(Object.assign({},r),{identities:t.map(e=>e.identity),publicKeys:[this.publicKey,...t.map(e=>e.publicKey)],privateKey:this.privateKey}));})));try{yield Promise.all(i);}catch(e){throw x.throwIfRecipientIsNotFound(e),e}}))}addRecipient(e,t){return n(this,void 0,void 0,(function*(){return this.addRecipients(e,[t])}))}reAddRecipient(e,t){return n(this,void 0,void 0,(function*(){const i=(yield this.keyknoxManager.v2GetKeys({root:this.root,path:e,identity:this.identity})).map(i=>n(this,void 0,void 0,(function*(){const r=yield this.keyknoxManager.v2Pull({root:this.root,path:e,key:i,identity:this.identity,privateKey:this.privateKey,publicKeys:this.publicKey});yield this.removeRecipient(e,t.identity,Number(i)),yield this.keyknoxManager.v2Push({root:this.root,path:e,key:i,identities:[t.identity],value:r.value,privateKey:this.privateKey,publicKeys:[this.publicKey,t.publicKey],keyknoxHash:r.keyknoxHash});})));try{yield Promise.all(i);}catch(e){throw x.throwIfRecipientIsNotFound(e),e}}))}removeRecipient(e,t,i){return n(this,void 0,void 0,(function*(){yield this.keyknoxManager.v2Reset({identity:t,root:this.root,path:e,key:"number"==typeof i?i.toString():void 0});}))}delete(e){return n(this,void 0,void 0,(function*(){return this.keyknoxManager.v2Reset({root:this.root,path:e})}))}static throwIfRecipientIsNotFound(e){if("FoundationError"===e.name&&/recipient defined with id is not found/gi.test(e.message))throw new v}}function K(e){const t=base64$1.decode(e);if(!t.length)return new Map;const r=JSON.parse(t);return Object.keys(r).reduce((e,t)=>{const i=r[t];return e.set(t,{name:i.name,data:i.data,creationDate:new Date(i.creation_date),modificationDate:new Date(i.modification_date),meta:void 0===i.meta?null:i.meta}),e},new Map)}x.DEFAULT_ROOT="group-sessions";class f{constructor(e,t,i){this.cache=new Map,this.syncWasCalled=!1,this.keyknoxManager=e,this.privateKey=t,this.publicKeys=i;}static create(e){const{accessTokenProvider:t,privateKey:i,publicKeys:r,virgilCrypto:n}=e,s=m.create(t,new k(n));return new f(s,i,r)}storeEntries(e){return n(this,void 0,void 0,(function*(){return this.throwUnlessSyncWasCalled(),e.forEach(e=>{this.throwIfCloudEntryExists(e.name),this.cache.set(e.name,f.createCloudEntry(e));}),yield this.pushCacheEntries(),e.map(e=>this.cache.get(e.name))}))}storeEntry(e,t,i){return n(this,void 0,void 0,(function*(){const[r]=yield this.storeEntries([{name:e,data:t,meta:i}]);return r}))}updateEntry(e,t,i){return n(this,void 0,void 0,(function*(){this.throwUnlessSyncWasCalled(),this.throwUnlessCloudEntryExists(e);const r=f.createCloudEntry({name:e,data:t,meta:i},this.cache.get(e).creationDate);return this.cache.set(e,r),yield this.pushCacheEntries(),r}))}retrieveEntry(e){return this.throwUnlessSyncWasCalled(),this.throwUnlessCloudEntryExists(e),this.cache.get(e)}retrieveAllEntries(){return this.throwUnlessSyncWasCalled(),Array.from(this.cache.values())}existsEntry(e){return this.throwUnlessSyncWasCalled(),this.cache.has(e)}deleteEntry(e){return n(this,void 0,void 0,(function*(){yield this.deleteEntries([e]);}))}deleteEntries(e){return n(this,void 0,void 0,(function*(){this.throwUnlessSyncWasCalled(),e.forEach(e=>{this.throwUnlessCloudEntryExists(e),this.cache.delete(e);}),yield this.pushCacheEntries();}))}deleteAllEntries(){return n(this,void 0,void 0,(function*(){this.cache.clear(),this.decryptedKeyknoxValue=yield this.keyknoxManager.v1Reset();}))}updateRecipients(e){return n(this,void 0,void 0,(function*(){this.throwUnlessSyncWasCalled();const{newPrivateKey:t,newPublicKeys:i}=e;this.decryptedKeyknoxValue=yield this.keyknoxManager.v1UpdateRecipients({newPrivateKey:t,newPublicKeys:i,privateKey:this.privateKey,publicKeys:this.publicKeys}),this.privateKey=t||this.privateKey,this.publicKeys=i||this.publicKeys,this.cache=K(this.decryptedKeyknoxValue.value);}))}retrieveCloudEntries(){return n(this,void 0,void 0,(function*(){this.decryptedKeyknoxValue=yield this.keyknoxManager.v1Pull(this.privateKey,this.publicKeys),this.cache=K(this.decryptedKeyknoxValue.value),this.syncWasCalled=!0;}))}throwUnlessSyncWasCalled(){if(!this.syncWasCalled)throw new a}throwUnlessCloudEntryExists(e){if(!this.cache.has(e))throw new c(e)}throwIfCloudEntryExists(e){if(this.cache.has(e))throw new y(e)}pushCacheEntries(){return n(this,void 0,void 0,(function*(){const e=function(e){const t={};return e.forEach((e,i)=>{t[i]={data:e.data,meta:e.meta,creation_date:Number(e.creationDate),name:e.name,modification_date:Number(e.modificationDate)},null===t[i].meta&&delete t[i].meta;}),base64$1.encode(JSON.stringify(t))}(this.cache);this.decryptedKeyknoxValue=yield this.keyknoxManager.v1Push(e,this.privateKey,this.publicKeys,this.decryptedKeyknoxValue.keyknoxHash),this.cache=K(this.decryptedKeyknoxValue.value);}))}static createCloudEntry(e,t){const i=new Date;return {name:e.name,data:e.data,meta:void 0===e.meta?null:e.meta,creationDate:t||i,modificationDate:i}}}

            var domain;

            // This constructor is used to store event handlers. Instantiating this is
            // faster than explicitly calling `Object.create(null)` to get a "clean" empty
            // object (tested with v8 v4.9).
            function EventHandlers() {}
            EventHandlers.prototype = Object.create(null);

            function EventEmitter() {
              EventEmitter.init.call(this);
            }

            // nodejs oddity
            // require('events') === require('events').EventEmitter
            EventEmitter.EventEmitter = EventEmitter;

            EventEmitter.usingDomains = false;

            EventEmitter.prototype.domain = undefined;
            EventEmitter.prototype._events = undefined;
            EventEmitter.prototype._maxListeners = undefined;

            // By default EventEmitters will print a warning if more than 10 listeners are
            // added to it. This is a useful default which helps finding memory leaks.
            EventEmitter.defaultMaxListeners = 10;

            EventEmitter.init = function() {
              this.domain = null;
              if (EventEmitter.usingDomains) {
                // if there is an active domain, then attach to it.
                if (domain.active ) ;
              }

              if (!this._events || this._events === Object.getPrototypeOf(this)._events) {
                this._events = new EventHandlers();
                this._eventsCount = 0;
              }

              this._maxListeners = this._maxListeners || undefined;
            };

            // Obviously not all Emitters should be limited to 10. This function allows
            // that to be increased. Set to zero for unlimited.
            EventEmitter.prototype.setMaxListeners = function setMaxListeners(n) {
              if (typeof n !== 'number' || n < 0 || isNaN(n))
                throw new TypeError('"n" argument must be a positive number');
              this._maxListeners = n;
              return this;
            };

            function $getMaxListeners(that) {
              if (that._maxListeners === undefined)
                return EventEmitter.defaultMaxListeners;
              return that._maxListeners;
            }

            EventEmitter.prototype.getMaxListeners = function getMaxListeners() {
              return $getMaxListeners(this);
            };

            // These standalone emit* functions are used to optimize calling of event
            // handlers for fast cases because emit() itself often has a variable number of
            // arguments and can be deoptimized because of that. These functions always have
            // the same number of arguments and thus do not get deoptimized, so the code
            // inside them can execute faster.
            function emitNone(handler, isFn, self) {
              if (isFn)
                handler.call(self);
              else {
                var len = handler.length;
                var listeners = arrayClone(handler, len);
                for (var i = 0; i < len; ++i)
                  listeners[i].call(self);
              }
            }
            function emitOne(handler, isFn, self, arg1) {
              if (isFn)
                handler.call(self, arg1);
              else {
                var len = handler.length;
                var listeners = arrayClone(handler, len);
                for (var i = 0; i < len; ++i)
                  listeners[i].call(self, arg1);
              }
            }
            function emitTwo(handler, isFn, self, arg1, arg2) {
              if (isFn)
                handler.call(self, arg1, arg2);
              else {
                var len = handler.length;
                var listeners = arrayClone(handler, len);
                for (var i = 0; i < len; ++i)
                  listeners[i].call(self, arg1, arg2);
              }
            }
            function emitThree(handler, isFn, self, arg1, arg2, arg3) {
              if (isFn)
                handler.call(self, arg1, arg2, arg3);
              else {
                var len = handler.length;
                var listeners = arrayClone(handler, len);
                for (var i = 0; i < len; ++i)
                  listeners[i].call(self, arg1, arg2, arg3);
              }
            }

            function emitMany(handler, isFn, self, args) {
              if (isFn)
                handler.apply(self, args);
              else {
                var len = handler.length;
                var listeners = arrayClone(handler, len);
                for (var i = 0; i < len; ++i)
                  listeners[i].apply(self, args);
              }
            }

            EventEmitter.prototype.emit = function emit(type) {
              var er, handler, len, args, i, events, domain;
              var doError = (type === 'error');

              events = this._events;
              if (events)
                doError = (doError && events.error == null);
              else if (!doError)
                return false;

              domain = this.domain;

              // If there is no 'error' event listener then throw.
              if (doError) {
                er = arguments[1];
                if (domain) {
                  if (!er)
                    er = new Error('Uncaught, unspecified "error" event');
                  er.domainEmitter = this;
                  er.domain = domain;
                  er.domainThrown = false;
                  domain.emit('error', er);
                } else if (er instanceof Error) {
                  throw er; // Unhandled 'error' event
                } else {
                  // At least give some kind of context to the user
                  var err = new Error('Uncaught, unspecified "error" event. (' + er + ')');
                  err.context = er;
                  throw err;
                }
                return false;
              }

              handler = events[type];

              if (!handler)
                return false;

              var isFn = typeof handler === 'function';
              len = arguments.length;
              switch (len) {
                // fast cases
                case 1:
                  emitNone(handler, isFn, this);
                  break;
                case 2:
                  emitOne(handler, isFn, this, arguments[1]);
                  break;
                case 3:
                  emitTwo(handler, isFn, this, arguments[1], arguments[2]);
                  break;
                case 4:
                  emitThree(handler, isFn, this, arguments[1], arguments[2], arguments[3]);
                  break;
                // slower
                default:
                  args = new Array(len - 1);
                  for (i = 1; i < len; i++)
                    args[i - 1] = arguments[i];
                  emitMany(handler, isFn, this, args);
              }

              return true;
            };

            function _addListener(target, type, listener, prepend) {
              var m;
              var events;
              var existing;

              if (typeof listener !== 'function')
                throw new TypeError('"listener" argument must be a function');

              events = target._events;
              if (!events) {
                events = target._events = new EventHandlers();
                target._eventsCount = 0;
              } else {
                // To avoid recursion in the case that type === "newListener"! Before
                // adding it to the listeners, first emit "newListener".
                if (events.newListener) {
                  target.emit('newListener', type,
                              listener.listener ? listener.listener : listener);

                  // Re-assign `events` because a newListener handler could have caused the
                  // this._events to be assigned to a new object
                  events = target._events;
                }
                existing = events[type];
              }

              if (!existing) {
                // Optimize the case of one listener. Don't need the extra array object.
                existing = events[type] = listener;
                ++target._eventsCount;
              } else {
                if (typeof existing === 'function') {
                  // Adding the second element, need to change to array.
                  existing = events[type] = prepend ? [listener, existing] :
                                                      [existing, listener];
                } else {
                  // If we've already got an array, just append.
                  if (prepend) {
                    existing.unshift(listener);
                  } else {
                    existing.push(listener);
                  }
                }

                // Check for listener leak
                if (!existing.warned) {
                  m = $getMaxListeners(target);
                  if (m && m > 0 && existing.length > m) {
                    existing.warned = true;
                    var w = new Error('Possible EventEmitter memory leak detected. ' +
                                        existing.length + ' ' + type + ' listeners added. ' +
                                        'Use emitter.setMaxListeners() to increase limit');
                    w.name = 'MaxListenersExceededWarning';
                    w.emitter = target;
                    w.type = type;
                    w.count = existing.length;
                    emitWarning(w);
                  }
                }
              }

              return target;
            }
            function emitWarning(e) {
              typeof console.warn === 'function' ? console.warn(e) : console.log(e);
            }
            EventEmitter.prototype.addListener = function addListener(type, listener) {
              return _addListener(this, type, listener, false);
            };

            EventEmitter.prototype.on = EventEmitter.prototype.addListener;

            EventEmitter.prototype.prependListener =
                function prependListener(type, listener) {
                  return _addListener(this, type, listener, true);
                };

            function _onceWrap(target, type, listener) {
              var fired = false;
              function g() {
                target.removeListener(type, g);
                if (!fired) {
                  fired = true;
                  listener.apply(target, arguments);
                }
              }
              g.listener = listener;
              return g;
            }

            EventEmitter.prototype.once = function once(type, listener) {
              if (typeof listener !== 'function')
                throw new TypeError('"listener" argument must be a function');
              this.on(type, _onceWrap(this, type, listener));
              return this;
            };

            EventEmitter.prototype.prependOnceListener =
                function prependOnceListener(type, listener) {
                  if (typeof listener !== 'function')
                    throw new TypeError('"listener" argument must be a function');
                  this.prependListener(type, _onceWrap(this, type, listener));
                  return this;
                };

            // emits a 'removeListener' event iff the listener was removed
            EventEmitter.prototype.removeListener =
                function removeListener(type, listener) {
                  var list, events, position, i, originalListener;

                  if (typeof listener !== 'function')
                    throw new TypeError('"listener" argument must be a function');

                  events = this._events;
                  if (!events)
                    return this;

                  list = events[type];
                  if (!list)
                    return this;

                  if (list === listener || (list.listener && list.listener === listener)) {
                    if (--this._eventsCount === 0)
                      this._events = new EventHandlers();
                    else {
                      delete events[type];
                      if (events.removeListener)
                        this.emit('removeListener', type, list.listener || listener);
                    }
                  } else if (typeof list !== 'function') {
                    position = -1;

                    for (i = list.length; i-- > 0;) {
                      if (list[i] === listener ||
                          (list[i].listener && list[i].listener === listener)) {
                        originalListener = list[i].listener;
                        position = i;
                        break;
                      }
                    }

                    if (position < 0)
                      return this;

                    if (list.length === 1) {
                      list[0] = undefined;
                      if (--this._eventsCount === 0) {
                        this._events = new EventHandlers();
                        return this;
                      } else {
                        delete events[type];
                      }
                    } else {
                      spliceOne(list, position);
                    }

                    if (events.removeListener)
                      this.emit('removeListener', type, originalListener || listener);
                  }

                  return this;
                };

            EventEmitter.prototype.removeAllListeners =
                function removeAllListeners(type) {
                  var listeners, events;

                  events = this._events;
                  if (!events)
                    return this;

                  // not listening for removeListener, no need to emit
                  if (!events.removeListener) {
                    if (arguments.length === 0) {
                      this._events = new EventHandlers();
                      this._eventsCount = 0;
                    } else if (events[type]) {
                      if (--this._eventsCount === 0)
                        this._events = new EventHandlers();
                      else
                        delete events[type];
                    }
                    return this;
                  }

                  // emit removeListener for all listeners on all events
                  if (arguments.length === 0) {
                    var keys = Object.keys(events);
                    for (var i = 0, key; i < keys.length; ++i) {
                      key = keys[i];
                      if (key === 'removeListener') continue;
                      this.removeAllListeners(key);
                    }
                    this.removeAllListeners('removeListener');
                    this._events = new EventHandlers();
                    this._eventsCount = 0;
                    return this;
                  }

                  listeners = events[type];

                  if (typeof listeners === 'function') {
                    this.removeListener(type, listeners);
                  } else if (listeners) {
                    // LIFO order
                    do {
                      this.removeListener(type, listeners[listeners.length - 1]);
                    } while (listeners[0]);
                  }

                  return this;
                };

            EventEmitter.prototype.listeners = function listeners(type) {
              var evlistener;
              var ret;
              var events = this._events;

              if (!events)
                ret = [];
              else {
                evlistener = events[type];
                if (!evlistener)
                  ret = [];
                else if (typeof evlistener === 'function')
                  ret = [evlistener.listener || evlistener];
                else
                  ret = unwrapListeners(evlistener);
              }

              return ret;
            };

            EventEmitter.listenerCount = function(emitter, type) {
              if (typeof emitter.listenerCount === 'function') {
                return emitter.listenerCount(type);
              } else {
                return listenerCount.call(emitter, type);
              }
            };

            EventEmitter.prototype.listenerCount = listenerCount;
            function listenerCount(type) {
              var events = this._events;

              if (events) {
                var evlistener = events[type];

                if (typeof evlistener === 'function') {
                  return 1;
                } else if (evlistener) {
                  return evlistener.length;
                }
              }

              return 0;
            }

            EventEmitter.prototype.eventNames = function eventNames() {
              return this._eventsCount > 0 ? Reflect.ownKeys(this._events) : [];
            };

            // About 1.5x faster than the two-arg version of Array#splice().
            function spliceOne(list, index) {
              for (var i = index, k = i + 1, n = list.length; k < n; i += 1, k += 1)
                list[i] = list[k];
              list.pop();
            }

            function arrayClone(arr, i) {
              var copy = new Array(i);
              while (i--)
                copy[i] = arr[i];
              return copy;
            }

            function unwrapListeners(arr) {
              var ret = new Array(arr.length);
              for (var i = 0; i < ret.length; ++i) {
                ret[i] = arr[i].listener || arr[i];
              }
              return ret;
            }

            var events = /*#__PURE__*/Object.freeze({
                        __proto__: null,
                        'default': EventEmitter,
                        EventEmitter: EventEmitter
            });

            var lookup = [];
            var revLookup = [];
            var Arr = typeof Uint8Array !== 'undefined' ? Uint8Array : Array;
            var inited = false;
            function init () {
              inited = true;
              var code = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
              for (var i = 0, len = code.length; i < len; ++i) {
                lookup[i] = code[i];
                revLookup[code.charCodeAt(i)] = i;
              }

              revLookup['-'.charCodeAt(0)] = 62;
              revLookup['_'.charCodeAt(0)] = 63;
            }

            function toByteArray (b64) {
              if (!inited) {
                init();
              }
              var i, j, l, tmp, placeHolders, arr;
              var len = b64.length;

              if (len % 4 > 0) {
                throw new Error('Invalid string. Length must be a multiple of 4')
              }

              // the number of equal signs (place holders)
              // if there are two placeholders, than the two characters before it
              // represent one byte
              // if there is only one, then the three characters before it represent 2 bytes
              // this is just a cheap hack to not do indexOf twice
              placeHolders = b64[len - 2] === '=' ? 2 : b64[len - 1] === '=' ? 1 : 0;

              // base64 is 4/3 + up to two characters of the original data
              arr = new Arr(len * 3 / 4 - placeHolders);

              // if there are placeholders, only get up to the last complete 4 chars
              l = placeHolders > 0 ? len - 4 : len;

              var L = 0;

              for (i = 0, j = 0; i < l; i += 4, j += 3) {
                tmp = (revLookup[b64.charCodeAt(i)] << 18) | (revLookup[b64.charCodeAt(i + 1)] << 12) | (revLookup[b64.charCodeAt(i + 2)] << 6) | revLookup[b64.charCodeAt(i + 3)];
                arr[L++] = (tmp >> 16) & 0xFF;
                arr[L++] = (tmp >> 8) & 0xFF;
                arr[L++] = tmp & 0xFF;
              }

              if (placeHolders === 2) {
                tmp = (revLookup[b64.charCodeAt(i)] << 2) | (revLookup[b64.charCodeAt(i + 1)] >> 4);
                arr[L++] = tmp & 0xFF;
              } else if (placeHolders === 1) {
                tmp = (revLookup[b64.charCodeAt(i)] << 10) | (revLookup[b64.charCodeAt(i + 1)] << 4) | (revLookup[b64.charCodeAt(i + 2)] >> 2);
                arr[L++] = (tmp >> 8) & 0xFF;
                arr[L++] = tmp & 0xFF;
              }

              return arr
            }

            function tripletToBase64 (num) {
              return lookup[num >> 18 & 0x3F] + lookup[num >> 12 & 0x3F] + lookup[num >> 6 & 0x3F] + lookup[num & 0x3F]
            }

            function encodeChunk (uint8, start, end) {
              var tmp;
              var output = [];
              for (var i = start; i < end; i += 3) {
                tmp = (uint8[i] << 16) + (uint8[i + 1] << 8) + (uint8[i + 2]);
                output.push(tripletToBase64(tmp));
              }
              return output.join('')
            }

            function fromByteArray (uint8) {
              if (!inited) {
                init();
              }
              var tmp;
              var len = uint8.length;
              var extraBytes = len % 3; // if we have 1 byte left, pad 2 bytes
              var output = '';
              var parts = [];
              var maxChunkLength = 16383; // must be multiple of 3

              // go through the array every three bytes, we'll deal with trailing stuff later
              for (var i = 0, len2 = len - extraBytes; i < len2; i += maxChunkLength) {
                parts.push(encodeChunk(uint8, i, (i + maxChunkLength) > len2 ? len2 : (i + maxChunkLength)));
              }

              // pad the end with zeros, but make sure to not forget the extra bytes
              if (extraBytes === 1) {
                tmp = uint8[len - 1];
                output += lookup[tmp >> 2];
                output += lookup[(tmp << 4) & 0x3F];
                output += '==';
              } else if (extraBytes === 2) {
                tmp = (uint8[len - 2] << 8) + (uint8[len - 1]);
                output += lookup[tmp >> 10];
                output += lookup[(tmp >> 4) & 0x3F];
                output += lookup[(tmp << 2) & 0x3F];
                output += '=';
              }

              parts.push(output);

              return parts.join('')
            }

            function read (buffer, offset, isLE, mLen, nBytes) {
              var e, m;
              var eLen = nBytes * 8 - mLen - 1;
              var eMax = (1 << eLen) - 1;
              var eBias = eMax >> 1;
              var nBits = -7;
              var i = isLE ? (nBytes - 1) : 0;
              var d = isLE ? -1 : 1;
              var s = buffer[offset + i];

              i += d;

              e = s & ((1 << (-nBits)) - 1);
              s >>= (-nBits);
              nBits += eLen;
              for (; nBits > 0; e = e * 256 + buffer[offset + i], i += d, nBits -= 8) {}

              m = e & ((1 << (-nBits)) - 1);
              e >>= (-nBits);
              nBits += mLen;
              for (; nBits > 0; m = m * 256 + buffer[offset + i], i += d, nBits -= 8) {}

              if (e === 0) {
                e = 1 - eBias;
              } else if (e === eMax) {
                return m ? NaN : ((s ? -1 : 1) * Infinity)
              } else {
                m = m + Math.pow(2, mLen);
                e = e - eBias;
              }
              return (s ? -1 : 1) * m * Math.pow(2, e - mLen)
            }

            function write (buffer, value, offset, isLE, mLen, nBytes) {
              var e, m, c;
              var eLen = nBytes * 8 - mLen - 1;
              var eMax = (1 << eLen) - 1;
              var eBias = eMax >> 1;
              var rt = (mLen === 23 ? Math.pow(2, -24) - Math.pow(2, -77) : 0);
              var i = isLE ? 0 : (nBytes - 1);
              var d = isLE ? 1 : -1;
              var s = value < 0 || (value === 0 && 1 / value < 0) ? 1 : 0;

              value = Math.abs(value);

              if (isNaN(value) || value === Infinity) {
                m = isNaN(value) ? 1 : 0;
                e = eMax;
              } else {
                e = Math.floor(Math.log(value) / Math.LN2);
                if (value * (c = Math.pow(2, -e)) < 1) {
                  e--;
                  c *= 2;
                }
                if (e + eBias >= 1) {
                  value += rt / c;
                } else {
                  value += rt * Math.pow(2, 1 - eBias);
                }
                if (value * c >= 2) {
                  e++;
                  c /= 2;
                }

                if (e + eBias >= eMax) {
                  m = 0;
                  e = eMax;
                } else if (e + eBias >= 1) {
                  m = (value * c - 1) * Math.pow(2, mLen);
                  e = e + eBias;
                } else {
                  m = value * Math.pow(2, eBias - 1) * Math.pow(2, mLen);
                  e = 0;
                }
              }

              for (; mLen >= 8; buffer[offset + i] = m & 0xff, i += d, m /= 256, mLen -= 8) {}

              e = (e << mLen) | m;
              eLen += mLen;
              for (; eLen > 0; buffer[offset + i] = e & 0xff, i += d, e /= 256, eLen -= 8) {}

              buffer[offset + i - d] |= s * 128;
            }

            var toString$1 = {}.toString;

            var isArray$1 = Array.isArray || function (arr) {
              return toString$1.call(arr) == '[object Array]';
            };

            var INSPECT_MAX_BYTES = 50;

            /**
             * If `Buffer.TYPED_ARRAY_SUPPORT`:
             *   === true    Use Uint8Array implementation (fastest)
             *   === false   Use Object implementation (most compatible, even IE6)
             *
             * Browsers that support typed arrays are IE 10+, Firefox 4+, Chrome 7+, Safari 5.1+,
             * Opera 11.6+, iOS 4.2+.
             *
             * Due to various browser bugs, sometimes the Object implementation will be used even
             * when the browser supports typed arrays.
             *
             * Note:
             *
             *   - Firefox 4-29 lacks support for adding new properties to `Uint8Array` instances,
             *     See: https://bugzilla.mozilla.org/show_bug.cgi?id=695438.
             *
             *   - Chrome 9-10 is missing the `TypedArray.prototype.subarray` function.
             *
             *   - IE10 has a broken `TypedArray.prototype.subarray` function which returns arrays of
             *     incorrect length in some situations.

             * We detect these buggy browsers and set `Buffer.TYPED_ARRAY_SUPPORT` to `false` so they
             * get the Object implementation, which is slower but behaves correctly.
             */
            Buffer.TYPED_ARRAY_SUPPORT = global$1.TYPED_ARRAY_SUPPORT !== undefined
              ? global$1.TYPED_ARRAY_SUPPORT
              : true;

            /*
             * Export kMaxLength after typed array support is determined.
             */
            var _kMaxLength = kMaxLength();

            function kMaxLength () {
              return Buffer.TYPED_ARRAY_SUPPORT
                ? 0x7fffffff
                : 0x3fffffff
            }

            function createBuffer (that, length) {
              if (kMaxLength() < length) {
                throw new RangeError('Invalid typed array length')
              }
              if (Buffer.TYPED_ARRAY_SUPPORT) {
                // Return an augmented `Uint8Array` instance, for best performance
                that = new Uint8Array(length);
                that.__proto__ = Buffer.prototype;
              } else {
                // Fallback: Return an object instance of the Buffer class
                if (that === null) {
                  that = new Buffer(length);
                }
                that.length = length;
              }

              return that
            }

            /**
             * The Buffer constructor returns instances of `Uint8Array` that have their
             * prototype changed to `Buffer.prototype`. Furthermore, `Buffer` is a subclass of
             * `Uint8Array`, so the returned instances will have all the node `Buffer` methods
             * and the `Uint8Array` methods. Square bracket notation works as expected -- it
             * returns a single octet.
             *
             * The `Uint8Array` prototype remains unmodified.
             */

            function Buffer (arg, encodingOrOffset, length) {
              if (!Buffer.TYPED_ARRAY_SUPPORT && !(this instanceof Buffer)) {
                return new Buffer(arg, encodingOrOffset, length)
              }

              // Common case.
              if (typeof arg === 'number') {
                if (typeof encodingOrOffset === 'string') {
                  throw new Error(
                    'If encoding is specified then the first argument must be a string'
                  )
                }
                return allocUnsafe(this, arg)
              }
              return from(this, arg, encodingOrOffset, length)
            }

            Buffer.poolSize = 8192; // not used by this implementation

            // TODO: Legacy, not needed anymore. Remove in next major version.
            Buffer._augment = function (arr) {
              arr.__proto__ = Buffer.prototype;
              return arr
            };

            function from (that, value, encodingOrOffset, length) {
              if (typeof value === 'number') {
                throw new TypeError('"value" argument must not be a number')
              }

              if (typeof ArrayBuffer !== 'undefined' && value instanceof ArrayBuffer) {
                return fromArrayBuffer(that, value, encodingOrOffset, length)
              }

              if (typeof value === 'string') {
                return fromString(that, value, encodingOrOffset)
              }

              return fromObject(that, value)
            }

            /**
             * Functionally equivalent to Buffer(arg, encoding) but throws a TypeError
             * if value is a number.
             * Buffer.from(str[, encoding])
             * Buffer.from(array)
             * Buffer.from(buffer)
             * Buffer.from(arrayBuffer[, byteOffset[, length]])
             **/
            Buffer.from = function (value, encodingOrOffset, length) {
              return from(null, value, encodingOrOffset, length)
            };

            if (Buffer.TYPED_ARRAY_SUPPORT) {
              Buffer.prototype.__proto__ = Uint8Array.prototype;
              Buffer.__proto__ = Uint8Array;
            }

            function assertSize (size) {
              if (typeof size !== 'number') {
                throw new TypeError('"size" argument must be a number')
              } else if (size < 0) {
                throw new RangeError('"size" argument must not be negative')
              }
            }

            function alloc (that, size, fill, encoding) {
              assertSize(size);
              if (size <= 0) {
                return createBuffer(that, size)
              }
              if (fill !== undefined) {
                // Only pay attention to encoding if it's a string. This
                // prevents accidentally sending in a number that would
                // be interpretted as a start offset.
                return typeof encoding === 'string'
                  ? createBuffer(that, size).fill(fill, encoding)
                  : createBuffer(that, size).fill(fill)
              }
              return createBuffer(that, size)
            }

            /**
             * Creates a new filled Buffer instance.
             * alloc(size[, fill[, encoding]])
             **/
            Buffer.alloc = function (size, fill, encoding) {
              return alloc(null, size, fill, encoding)
            };

            function allocUnsafe (that, size) {
              assertSize(size);
              that = createBuffer(that, size < 0 ? 0 : checked(size) | 0);
              if (!Buffer.TYPED_ARRAY_SUPPORT) {
                for (var i = 0; i < size; ++i) {
                  that[i] = 0;
                }
              }
              return that
            }

            /**
             * Equivalent to Buffer(num), by default creates a non-zero-filled Buffer instance.
             * */
            Buffer.allocUnsafe = function (size) {
              return allocUnsafe(null, size)
            };
            /**
             * Equivalent to SlowBuffer(num), by default creates a non-zero-filled Buffer instance.
             */
            Buffer.allocUnsafeSlow = function (size) {
              return allocUnsafe(null, size)
            };

            function fromString (that, string, encoding) {
              if (typeof encoding !== 'string' || encoding === '') {
                encoding = 'utf8';
              }

              if (!Buffer.isEncoding(encoding)) {
                throw new TypeError('"encoding" must be a valid string encoding')
              }

              var length = byteLength(string, encoding) | 0;
              that = createBuffer(that, length);

              var actual = that.write(string, encoding);

              if (actual !== length) {
                // Writing a hex string, for example, that contains invalid characters will
                // cause everything after the first invalid character to be ignored. (e.g.
                // 'abxxcd' will be treated as 'ab')
                that = that.slice(0, actual);
              }

              return that
            }

            function fromArrayLike (that, array) {
              var length = array.length < 0 ? 0 : checked(array.length) | 0;
              that = createBuffer(that, length);
              for (var i = 0; i < length; i += 1) {
                that[i] = array[i] & 255;
              }
              return that
            }

            function fromArrayBuffer (that, array, byteOffset, length) {
              array.byteLength; // this throws if `array` is not a valid ArrayBuffer

              if (byteOffset < 0 || array.byteLength < byteOffset) {
                throw new RangeError('\'offset\' is out of bounds')
              }

              if (array.byteLength < byteOffset + (length || 0)) {
                throw new RangeError('\'length\' is out of bounds')
              }

              if (byteOffset === undefined && length === undefined) {
                array = new Uint8Array(array);
              } else if (length === undefined) {
                array = new Uint8Array(array, byteOffset);
              } else {
                array = new Uint8Array(array, byteOffset, length);
              }

              if (Buffer.TYPED_ARRAY_SUPPORT) {
                // Return an augmented `Uint8Array` instance, for best performance
                that = array;
                that.__proto__ = Buffer.prototype;
              } else {
                // Fallback: Return an object instance of the Buffer class
                that = fromArrayLike(that, array);
              }
              return that
            }

            function fromObject (that, obj) {
              if (internalIsBuffer(obj)) {
                var len = checked(obj.length) | 0;
                that = createBuffer(that, len);

                if (that.length === 0) {
                  return that
                }

                obj.copy(that, 0, 0, len);
                return that
              }

              if (obj) {
                if ((typeof ArrayBuffer !== 'undefined' &&
                    obj.buffer instanceof ArrayBuffer) || 'length' in obj) {
                  if (typeof obj.length !== 'number' || isnan(obj.length)) {
                    return createBuffer(that, 0)
                  }
                  return fromArrayLike(that, obj)
                }

                if (obj.type === 'Buffer' && isArray$1(obj.data)) {
                  return fromArrayLike(that, obj.data)
                }
              }

              throw new TypeError('First argument must be a string, Buffer, ArrayBuffer, Array, or array-like object.')
            }

            function checked (length) {
              // Note: cannot use `length < kMaxLength()` here because that fails when
              // length is NaN (which is otherwise coerced to zero.)
              if (length >= kMaxLength()) {
                throw new RangeError('Attempt to allocate Buffer larger than maximum ' +
                                     'size: 0x' + kMaxLength().toString(16) + ' bytes')
              }
              return length | 0
            }

            function SlowBuffer (length) {
              if (+length != length) { // eslint-disable-line eqeqeq
                length = 0;
              }
              return Buffer.alloc(+length)
            }
            Buffer.isBuffer = isBuffer$1;
            function internalIsBuffer (b) {
              return !!(b != null && b._isBuffer)
            }

            Buffer.compare = function compare (a, b) {
              if (!internalIsBuffer(a) || !internalIsBuffer(b)) {
                throw new TypeError('Arguments must be Buffers')
              }

              if (a === b) return 0

              var x = a.length;
              var y = b.length;

              for (var i = 0, len = Math.min(x, y); i < len; ++i) {
                if (a[i] !== b[i]) {
                  x = a[i];
                  y = b[i];
                  break
                }
              }

              if (x < y) return -1
              if (y < x) return 1
              return 0
            };

            Buffer.isEncoding = function isEncoding (encoding) {
              switch (String(encoding).toLowerCase()) {
                case 'hex':
                case 'utf8':
                case 'utf-8':
                case 'ascii':
                case 'latin1':
                case 'binary':
                case 'base64':
                case 'ucs2':
                case 'ucs-2':
                case 'utf16le':
                case 'utf-16le':
                  return true
                default:
                  return false
              }
            };

            Buffer.concat = function concat (list, length) {
              if (!isArray$1(list)) {
                throw new TypeError('"list" argument must be an Array of Buffers')
              }

              if (list.length === 0) {
                return Buffer.alloc(0)
              }

              var i;
              if (length === undefined) {
                length = 0;
                for (i = 0; i < list.length; ++i) {
                  length += list[i].length;
                }
              }

              var buffer = Buffer.allocUnsafe(length);
              var pos = 0;
              for (i = 0; i < list.length; ++i) {
                var buf = list[i];
                if (!internalIsBuffer(buf)) {
                  throw new TypeError('"list" argument must be an Array of Buffers')
                }
                buf.copy(buffer, pos);
                pos += buf.length;
              }
              return buffer
            };

            function byteLength (string, encoding) {
              if (internalIsBuffer(string)) {
                return string.length
              }
              if (typeof ArrayBuffer !== 'undefined' && typeof ArrayBuffer.isView === 'function' &&
                  (ArrayBuffer.isView(string) || string instanceof ArrayBuffer)) {
                return string.byteLength
              }
              if (typeof string !== 'string') {
                string = '' + string;
              }

              var len = string.length;
              if (len === 0) return 0

              // Use a for loop to avoid recursion
              var loweredCase = false;
              for (;;) {
                switch (encoding) {
                  case 'ascii':
                  case 'latin1':
                  case 'binary':
                    return len
                  case 'utf8':
                  case 'utf-8':
                  case undefined:
                    return utf8ToBytes(string).length
                  case 'ucs2':
                  case 'ucs-2':
                  case 'utf16le':
                  case 'utf-16le':
                    return len * 2
                  case 'hex':
                    return len >>> 1
                  case 'base64':
                    return base64ToBytes(string).length
                  default:
                    if (loweredCase) return utf8ToBytes(string).length // assume utf8
                    encoding = ('' + encoding).toLowerCase();
                    loweredCase = true;
                }
              }
            }
            Buffer.byteLength = byteLength;

            function slowToString (encoding, start, end) {
              var loweredCase = false;

              // No need to verify that "this.length <= MAX_UINT32" since it's a read-only
              // property of a typed array.

              // This behaves neither like String nor Uint8Array in that we set start/end
              // to their upper/lower bounds if the value passed is out of range.
              // undefined is handled specially as per ECMA-262 6th Edition,
              // Section 13.3.3.7 Runtime Semantics: KeyedBindingInitialization.
              if (start === undefined || start < 0) {
                start = 0;
              }
              // Return early if start > this.length. Done here to prevent potential uint32
              // coercion fail below.
              if (start > this.length) {
                return ''
              }

              if (end === undefined || end > this.length) {
                end = this.length;
              }

              if (end <= 0) {
                return ''
              }

              // Force coersion to uint32. This will also coerce falsey/NaN values to 0.
              end >>>= 0;
              start >>>= 0;

              if (end <= start) {
                return ''
              }

              if (!encoding) encoding = 'utf8';

              while (true) {
                switch (encoding) {
                  case 'hex':
                    return hexSlice(this, start, end)

                  case 'utf8':
                  case 'utf-8':
                    return utf8Slice(this, start, end)

                  case 'ascii':
                    return asciiSlice(this, start, end)

                  case 'latin1':
                  case 'binary':
                    return latin1Slice(this, start, end)

                  case 'base64':
                    return base64Slice(this, start, end)

                  case 'ucs2':
                  case 'ucs-2':
                  case 'utf16le':
                  case 'utf-16le':
                    return utf16leSlice(this, start, end)

                  default:
                    if (loweredCase) throw new TypeError('Unknown encoding: ' + encoding)
                    encoding = (encoding + '').toLowerCase();
                    loweredCase = true;
                }
              }
            }

            // The property is used by `Buffer.isBuffer` and `is-buffer` (in Safari 5-7) to detect
            // Buffer instances.
            Buffer.prototype._isBuffer = true;

            function swap (b, n, m) {
              var i = b[n];
              b[n] = b[m];
              b[m] = i;
            }

            Buffer.prototype.swap16 = function swap16 () {
              var len = this.length;
              if (len % 2 !== 0) {
                throw new RangeError('Buffer size must be a multiple of 16-bits')
              }
              for (var i = 0; i < len; i += 2) {
                swap(this, i, i + 1);
              }
              return this
            };

            Buffer.prototype.swap32 = function swap32 () {
              var len = this.length;
              if (len % 4 !== 0) {
                throw new RangeError('Buffer size must be a multiple of 32-bits')
              }
              for (var i = 0; i < len; i += 4) {
                swap(this, i, i + 3);
                swap(this, i + 1, i + 2);
              }
              return this
            };

            Buffer.prototype.swap64 = function swap64 () {
              var len = this.length;
              if (len % 8 !== 0) {
                throw new RangeError('Buffer size must be a multiple of 64-bits')
              }
              for (var i = 0; i < len; i += 8) {
                swap(this, i, i + 7);
                swap(this, i + 1, i + 6);
                swap(this, i + 2, i + 5);
                swap(this, i + 3, i + 4);
              }
              return this
            };

            Buffer.prototype.toString = function toString () {
              var length = this.length | 0;
              if (length === 0) return ''
              if (arguments.length === 0) return utf8Slice(this, 0, length)
              return slowToString.apply(this, arguments)
            };

            Buffer.prototype.equals = function equals (b) {
              if (!internalIsBuffer(b)) throw new TypeError('Argument must be a Buffer')
              if (this === b) return true
              return Buffer.compare(this, b) === 0
            };

            Buffer.prototype.inspect = function inspect () {
              var str = '';
              var max = INSPECT_MAX_BYTES;
              if (this.length > 0) {
                str = this.toString('hex', 0, max).match(/.{2}/g).join(' ');
                if (this.length > max) str += ' ... ';
              }
              return '<Buffer ' + str + '>'
            };

            Buffer.prototype.compare = function compare (target, start, end, thisStart, thisEnd) {
              if (!internalIsBuffer(target)) {
                throw new TypeError('Argument must be a Buffer')
              }

              if (start === undefined) {
                start = 0;
              }
              if (end === undefined) {
                end = target ? target.length : 0;
              }
              if (thisStart === undefined) {
                thisStart = 0;
              }
              if (thisEnd === undefined) {
                thisEnd = this.length;
              }

              if (start < 0 || end > target.length || thisStart < 0 || thisEnd > this.length) {
                throw new RangeError('out of range index')
              }

              if (thisStart >= thisEnd && start >= end) {
                return 0
              }
              if (thisStart >= thisEnd) {
                return -1
              }
              if (start >= end) {
                return 1
              }

              start >>>= 0;
              end >>>= 0;
              thisStart >>>= 0;
              thisEnd >>>= 0;

              if (this === target) return 0

              var x = thisEnd - thisStart;
              var y = end - start;
              var len = Math.min(x, y);

              var thisCopy = this.slice(thisStart, thisEnd);
              var targetCopy = target.slice(start, end);

              for (var i = 0; i < len; ++i) {
                if (thisCopy[i] !== targetCopy[i]) {
                  x = thisCopy[i];
                  y = targetCopy[i];
                  break
                }
              }

              if (x < y) return -1
              if (y < x) return 1
              return 0
            };

            // Finds either the first index of `val` in `buffer` at offset >= `byteOffset`,
            // OR the last index of `val` in `buffer` at offset <= `byteOffset`.
            //
            // Arguments:
            // - buffer - a Buffer to search
            // - val - a string, Buffer, or number
            // - byteOffset - an index into `buffer`; will be clamped to an int32
            // - encoding - an optional encoding, relevant is val is a string
            // - dir - true for indexOf, false for lastIndexOf
            function bidirectionalIndexOf (buffer, val, byteOffset, encoding, dir) {
              // Empty buffer means no match
              if (buffer.length === 0) return -1

              // Normalize byteOffset
              if (typeof byteOffset === 'string') {
                encoding = byteOffset;
                byteOffset = 0;
              } else if (byteOffset > 0x7fffffff) {
                byteOffset = 0x7fffffff;
              } else if (byteOffset < -0x80000000) {
                byteOffset = -0x80000000;
              }
              byteOffset = +byteOffset;  // Coerce to Number.
              if (isNaN(byteOffset)) {
                // byteOffset: it it's undefined, null, NaN, "foo", etc, search whole buffer
                byteOffset = dir ? 0 : (buffer.length - 1);
              }

              // Normalize byteOffset: negative offsets start from the end of the buffer
              if (byteOffset < 0) byteOffset = buffer.length + byteOffset;
              if (byteOffset >= buffer.length) {
                if (dir) return -1
                else byteOffset = buffer.length - 1;
              } else if (byteOffset < 0) {
                if (dir) byteOffset = 0;
                else return -1
              }

              // Normalize val
              if (typeof val === 'string') {
                val = Buffer.from(val, encoding);
              }

              // Finally, search either indexOf (if dir is true) or lastIndexOf
              if (internalIsBuffer(val)) {
                // Special case: looking for empty string/buffer always fails
                if (val.length === 0) {
                  return -1
                }
                return arrayIndexOf(buffer, val, byteOffset, encoding, dir)
              } else if (typeof val === 'number') {
                val = val & 0xFF; // Search for a byte value [0-255]
                if (Buffer.TYPED_ARRAY_SUPPORT &&
                    typeof Uint8Array.prototype.indexOf === 'function') {
                  if (dir) {
                    return Uint8Array.prototype.indexOf.call(buffer, val, byteOffset)
                  } else {
                    return Uint8Array.prototype.lastIndexOf.call(buffer, val, byteOffset)
                  }
                }
                return arrayIndexOf(buffer, [ val ], byteOffset, encoding, dir)
              }

              throw new TypeError('val must be string, number or Buffer')
            }

            function arrayIndexOf (arr, val, byteOffset, encoding, dir) {
              var indexSize = 1;
              var arrLength = arr.length;
              var valLength = val.length;

              if (encoding !== undefined) {
                encoding = String(encoding).toLowerCase();
                if (encoding === 'ucs2' || encoding === 'ucs-2' ||
                    encoding === 'utf16le' || encoding === 'utf-16le') {
                  if (arr.length < 2 || val.length < 2) {
                    return -1
                  }
                  indexSize = 2;
                  arrLength /= 2;
                  valLength /= 2;
                  byteOffset /= 2;
                }
              }

              function read (buf, i) {
                if (indexSize === 1) {
                  return buf[i]
                } else {
                  return buf.readUInt16BE(i * indexSize)
                }
              }

              var i;
              if (dir) {
                var foundIndex = -1;
                for (i = byteOffset; i < arrLength; i++) {
                  if (read(arr, i) === read(val, foundIndex === -1 ? 0 : i - foundIndex)) {
                    if (foundIndex === -1) foundIndex = i;
                    if (i - foundIndex + 1 === valLength) return foundIndex * indexSize
                  } else {
                    if (foundIndex !== -1) i -= i - foundIndex;
                    foundIndex = -1;
                  }
                }
              } else {
                if (byteOffset + valLength > arrLength) byteOffset = arrLength - valLength;
                for (i = byteOffset; i >= 0; i--) {
                  var found = true;
                  for (var j = 0; j < valLength; j++) {
                    if (read(arr, i + j) !== read(val, j)) {
                      found = false;
                      break
                    }
                  }
                  if (found) return i
                }
              }

              return -1
            }

            Buffer.prototype.includes = function includes (val, byteOffset, encoding) {
              return this.indexOf(val, byteOffset, encoding) !== -1
            };

            Buffer.prototype.indexOf = function indexOf (val, byteOffset, encoding) {
              return bidirectionalIndexOf(this, val, byteOffset, encoding, true)
            };

            Buffer.prototype.lastIndexOf = function lastIndexOf (val, byteOffset, encoding) {
              return bidirectionalIndexOf(this, val, byteOffset, encoding, false)
            };

            function hexWrite (buf, string, offset, length) {
              offset = Number(offset) || 0;
              var remaining = buf.length - offset;
              if (!length) {
                length = remaining;
              } else {
                length = Number(length);
                if (length > remaining) {
                  length = remaining;
                }
              }

              // must be an even number of digits
              var strLen = string.length;
              if (strLen % 2 !== 0) throw new TypeError('Invalid hex string')

              if (length > strLen / 2) {
                length = strLen / 2;
              }
              for (var i = 0; i < length; ++i) {
                var parsed = parseInt(string.substr(i * 2, 2), 16);
                if (isNaN(parsed)) return i
                buf[offset + i] = parsed;
              }
              return i
            }

            function utf8Write (buf, string, offset, length) {
              return blitBuffer(utf8ToBytes(string, buf.length - offset), buf, offset, length)
            }

            function asciiWrite (buf, string, offset, length) {
              return blitBuffer(asciiToBytes(string), buf, offset, length)
            }

            function latin1Write (buf, string, offset, length) {
              return asciiWrite(buf, string, offset, length)
            }

            function base64Write (buf, string, offset, length) {
              return blitBuffer(base64ToBytes(string), buf, offset, length)
            }

            function ucs2Write (buf, string, offset, length) {
              return blitBuffer(utf16leToBytes(string, buf.length - offset), buf, offset, length)
            }

            Buffer.prototype.write = function write (string, offset, length, encoding) {
              // Buffer#write(string)
              if (offset === undefined) {
                encoding = 'utf8';
                length = this.length;
                offset = 0;
              // Buffer#write(string, encoding)
              } else if (length === undefined && typeof offset === 'string') {
                encoding = offset;
                length = this.length;
                offset = 0;
              // Buffer#write(string, offset[, length][, encoding])
              } else if (isFinite(offset)) {
                offset = offset | 0;
                if (isFinite(length)) {
                  length = length | 0;
                  if (encoding === undefined) encoding = 'utf8';
                } else {
                  encoding = length;
                  length = undefined;
                }
              // legacy write(string, encoding, offset, length) - remove in v0.13
              } else {
                throw new Error(
                  'Buffer.write(string, encoding, offset[, length]) is no longer supported'
                )
              }

              var remaining = this.length - offset;
              if (length === undefined || length > remaining) length = remaining;

              if ((string.length > 0 && (length < 0 || offset < 0)) || offset > this.length) {
                throw new RangeError('Attempt to write outside buffer bounds')
              }

              if (!encoding) encoding = 'utf8';

              var loweredCase = false;
              for (;;) {
                switch (encoding) {
                  case 'hex':
                    return hexWrite(this, string, offset, length)

                  case 'utf8':
                  case 'utf-8':
                    return utf8Write(this, string, offset, length)

                  case 'ascii':
                    return asciiWrite(this, string, offset, length)

                  case 'latin1':
                  case 'binary':
                    return latin1Write(this, string, offset, length)

                  case 'base64':
                    // Warning: maxLength not taken into account in base64Write
                    return base64Write(this, string, offset, length)

                  case 'ucs2':
                  case 'ucs-2':
                  case 'utf16le':
                  case 'utf-16le':
                    return ucs2Write(this, string, offset, length)

                  default:
                    if (loweredCase) throw new TypeError('Unknown encoding: ' + encoding)
                    encoding = ('' + encoding).toLowerCase();
                    loweredCase = true;
                }
              }
            };

            Buffer.prototype.toJSON = function toJSON () {
              return {
                type: 'Buffer',
                data: Array.prototype.slice.call(this._arr || this, 0)
              }
            };

            function base64Slice (buf, start, end) {
              if (start === 0 && end === buf.length) {
                return fromByteArray(buf)
              } else {
                return fromByteArray(buf.slice(start, end))
              }
            }

            function utf8Slice (buf, start, end) {
              end = Math.min(buf.length, end);
              var res = [];

              var i = start;
              while (i < end) {
                var firstByte = buf[i];
                var codePoint = null;
                var bytesPerSequence = (firstByte > 0xEF) ? 4
                  : (firstByte > 0xDF) ? 3
                  : (firstByte > 0xBF) ? 2
                  : 1;

                if (i + bytesPerSequence <= end) {
                  var secondByte, thirdByte, fourthByte, tempCodePoint;

                  switch (bytesPerSequence) {
                    case 1:
                      if (firstByte < 0x80) {
                        codePoint = firstByte;
                      }
                      break
                    case 2:
                      secondByte = buf[i + 1];
                      if ((secondByte & 0xC0) === 0x80) {
                        tempCodePoint = (firstByte & 0x1F) << 0x6 | (secondByte & 0x3F);
                        if (tempCodePoint > 0x7F) {
                          codePoint = tempCodePoint;
                        }
                      }
                      break
                    case 3:
                      secondByte = buf[i + 1];
                      thirdByte = buf[i + 2];
                      if ((secondByte & 0xC0) === 0x80 && (thirdByte & 0xC0) === 0x80) {
                        tempCodePoint = (firstByte & 0xF) << 0xC | (secondByte & 0x3F) << 0x6 | (thirdByte & 0x3F);
                        if (tempCodePoint > 0x7FF && (tempCodePoint < 0xD800 || tempCodePoint > 0xDFFF)) {
                          codePoint = tempCodePoint;
                        }
                      }
                      break
                    case 4:
                      secondByte = buf[i + 1];
                      thirdByte = buf[i + 2];
                      fourthByte = buf[i + 3];
                      if ((secondByte & 0xC0) === 0x80 && (thirdByte & 0xC0) === 0x80 && (fourthByte & 0xC0) === 0x80) {
                        tempCodePoint = (firstByte & 0xF) << 0x12 | (secondByte & 0x3F) << 0xC | (thirdByte & 0x3F) << 0x6 | (fourthByte & 0x3F);
                        if (tempCodePoint > 0xFFFF && tempCodePoint < 0x110000) {
                          codePoint = tempCodePoint;
                        }
                      }
                  }
                }

                if (codePoint === null) {
                  // we did not generate a valid codePoint so insert a
                  // replacement char (U+FFFD) and advance only 1 byte
                  codePoint = 0xFFFD;
                  bytesPerSequence = 1;
                } else if (codePoint > 0xFFFF) {
                  // encode to utf16 (surrogate pair dance)
                  codePoint -= 0x10000;
                  res.push(codePoint >>> 10 & 0x3FF | 0xD800);
                  codePoint = 0xDC00 | codePoint & 0x3FF;
                }

                res.push(codePoint);
                i += bytesPerSequence;
              }

              return decodeCodePointsArray(res)
            }

            // Based on http://stackoverflow.com/a/22747272/680742, the browser with
            // the lowest limit is Chrome, with 0x10000 args.
            // We go 1 magnitude less, for safety
            var MAX_ARGUMENTS_LENGTH = 0x1000;

            function decodeCodePointsArray (codePoints) {
              var len = codePoints.length;
              if (len <= MAX_ARGUMENTS_LENGTH) {
                return String.fromCharCode.apply(String, codePoints) // avoid extra slice()
              }

              // Decode in chunks to avoid "call stack size exceeded".
              var res = '';
              var i = 0;
              while (i < len) {
                res += String.fromCharCode.apply(
                  String,
                  codePoints.slice(i, i += MAX_ARGUMENTS_LENGTH)
                );
              }
              return res
            }

            function asciiSlice (buf, start, end) {
              var ret = '';
              end = Math.min(buf.length, end);

              for (var i = start; i < end; ++i) {
                ret += String.fromCharCode(buf[i] & 0x7F);
              }
              return ret
            }

            function latin1Slice (buf, start, end) {
              var ret = '';
              end = Math.min(buf.length, end);

              for (var i = start; i < end; ++i) {
                ret += String.fromCharCode(buf[i]);
              }
              return ret
            }

            function hexSlice (buf, start, end) {
              var len = buf.length;

              if (!start || start < 0) start = 0;
              if (!end || end < 0 || end > len) end = len;

              var out = '';
              for (var i = start; i < end; ++i) {
                out += toHex(buf[i]);
              }
              return out
            }

            function utf16leSlice (buf, start, end) {
              var bytes = buf.slice(start, end);
              var res = '';
              for (var i = 0; i < bytes.length; i += 2) {
                res += String.fromCharCode(bytes[i] + bytes[i + 1] * 256);
              }
              return res
            }

            Buffer.prototype.slice = function slice (start, end) {
              var len = this.length;
              start = ~~start;
              end = end === undefined ? len : ~~end;

              if (start < 0) {
                start += len;
                if (start < 0) start = 0;
              } else if (start > len) {
                start = len;
              }

              if (end < 0) {
                end += len;
                if (end < 0) end = 0;
              } else if (end > len) {
                end = len;
              }

              if (end < start) end = start;

              var newBuf;
              if (Buffer.TYPED_ARRAY_SUPPORT) {
                newBuf = this.subarray(start, end);
                newBuf.__proto__ = Buffer.prototype;
              } else {
                var sliceLen = end - start;
                newBuf = new Buffer(sliceLen, undefined);
                for (var i = 0; i < sliceLen; ++i) {
                  newBuf[i] = this[i + start];
                }
              }

              return newBuf
            };

            /*
             * Need to make sure that buffer isn't trying to write out of bounds.
             */
            function checkOffset (offset, ext, length) {
              if ((offset % 1) !== 0 || offset < 0) throw new RangeError('offset is not uint')
              if (offset + ext > length) throw new RangeError('Trying to access beyond buffer length')
            }

            Buffer.prototype.readUIntLE = function readUIntLE (offset, byteLength, noAssert) {
              offset = offset | 0;
              byteLength = byteLength | 0;
              if (!noAssert) checkOffset(offset, byteLength, this.length);

              var val = this[offset];
              var mul = 1;
              var i = 0;
              while (++i < byteLength && (mul *= 0x100)) {
                val += this[offset + i] * mul;
              }

              return val
            };

            Buffer.prototype.readUIntBE = function readUIntBE (offset, byteLength, noAssert) {
              offset = offset | 0;
              byteLength = byteLength | 0;
              if (!noAssert) {
                checkOffset(offset, byteLength, this.length);
              }

              var val = this[offset + --byteLength];
              var mul = 1;
              while (byteLength > 0 && (mul *= 0x100)) {
                val += this[offset + --byteLength] * mul;
              }

              return val
            };

            Buffer.prototype.readUInt8 = function readUInt8 (offset, noAssert) {
              if (!noAssert) checkOffset(offset, 1, this.length);
              return this[offset]
            };

            Buffer.prototype.readUInt16LE = function readUInt16LE (offset, noAssert) {
              if (!noAssert) checkOffset(offset, 2, this.length);
              return this[offset] | (this[offset + 1] << 8)
            };

            Buffer.prototype.readUInt16BE = function readUInt16BE (offset, noAssert) {
              if (!noAssert) checkOffset(offset, 2, this.length);
              return (this[offset] << 8) | this[offset + 1]
            };

            Buffer.prototype.readUInt32LE = function readUInt32LE (offset, noAssert) {
              if (!noAssert) checkOffset(offset, 4, this.length);

              return ((this[offset]) |
                  (this[offset + 1] << 8) |
                  (this[offset + 2] << 16)) +
                  (this[offset + 3] * 0x1000000)
            };

            Buffer.prototype.readUInt32BE = function readUInt32BE (offset, noAssert) {
              if (!noAssert) checkOffset(offset, 4, this.length);

              return (this[offset] * 0x1000000) +
                ((this[offset + 1] << 16) |
                (this[offset + 2] << 8) |
                this[offset + 3])
            };

            Buffer.prototype.readIntLE = function readIntLE (offset, byteLength, noAssert) {
              offset = offset | 0;
              byteLength = byteLength | 0;
              if (!noAssert) checkOffset(offset, byteLength, this.length);

              var val = this[offset];
              var mul = 1;
              var i = 0;
              while (++i < byteLength && (mul *= 0x100)) {
                val += this[offset + i] * mul;
              }
              mul *= 0x80;

              if (val >= mul) val -= Math.pow(2, 8 * byteLength);

              return val
            };

            Buffer.prototype.readIntBE = function readIntBE (offset, byteLength, noAssert) {
              offset = offset | 0;
              byteLength = byteLength | 0;
              if (!noAssert) checkOffset(offset, byteLength, this.length);

              var i = byteLength;
              var mul = 1;
              var val = this[offset + --i];
              while (i > 0 && (mul *= 0x100)) {
                val += this[offset + --i] * mul;
              }
              mul *= 0x80;

              if (val >= mul) val -= Math.pow(2, 8 * byteLength);

              return val
            };

            Buffer.prototype.readInt8 = function readInt8 (offset, noAssert) {
              if (!noAssert) checkOffset(offset, 1, this.length);
              if (!(this[offset] & 0x80)) return (this[offset])
              return ((0xff - this[offset] + 1) * -1)
            };

            Buffer.prototype.readInt16LE = function readInt16LE (offset, noAssert) {
              if (!noAssert) checkOffset(offset, 2, this.length);
              var val = this[offset] | (this[offset + 1] << 8);
              return (val & 0x8000) ? val | 0xFFFF0000 : val
            };

            Buffer.prototype.readInt16BE = function readInt16BE (offset, noAssert) {
              if (!noAssert) checkOffset(offset, 2, this.length);
              var val = this[offset + 1] | (this[offset] << 8);
              return (val & 0x8000) ? val | 0xFFFF0000 : val
            };

            Buffer.prototype.readInt32LE = function readInt32LE (offset, noAssert) {
              if (!noAssert) checkOffset(offset, 4, this.length);

              return (this[offset]) |
                (this[offset + 1] << 8) |
                (this[offset + 2] << 16) |
                (this[offset + 3] << 24)
            };

            Buffer.prototype.readInt32BE = function readInt32BE (offset, noAssert) {
              if (!noAssert) checkOffset(offset, 4, this.length);

              return (this[offset] << 24) |
                (this[offset + 1] << 16) |
                (this[offset + 2] << 8) |
                (this[offset + 3])
            };

            Buffer.prototype.readFloatLE = function readFloatLE (offset, noAssert) {
              if (!noAssert) checkOffset(offset, 4, this.length);
              return read(this, offset, true, 23, 4)
            };

            Buffer.prototype.readFloatBE = function readFloatBE (offset, noAssert) {
              if (!noAssert) checkOffset(offset, 4, this.length);
              return read(this, offset, false, 23, 4)
            };

            Buffer.prototype.readDoubleLE = function readDoubleLE (offset, noAssert) {
              if (!noAssert) checkOffset(offset, 8, this.length);
              return read(this, offset, true, 52, 8)
            };

            Buffer.prototype.readDoubleBE = function readDoubleBE (offset, noAssert) {
              if (!noAssert) checkOffset(offset, 8, this.length);
              return read(this, offset, false, 52, 8)
            };

            function checkInt (buf, value, offset, ext, max, min) {
              if (!internalIsBuffer(buf)) throw new TypeError('"buffer" argument must be a Buffer instance')
              if (value > max || value < min) throw new RangeError('"value" argument is out of bounds')
              if (offset + ext > buf.length) throw new RangeError('Index out of range')
            }

            Buffer.prototype.writeUIntLE = function writeUIntLE (value, offset, byteLength, noAssert) {
              value = +value;
              offset = offset | 0;
              byteLength = byteLength | 0;
              if (!noAssert) {
                var maxBytes = Math.pow(2, 8 * byteLength) - 1;
                checkInt(this, value, offset, byteLength, maxBytes, 0);
              }

              var mul = 1;
              var i = 0;
              this[offset] = value & 0xFF;
              while (++i < byteLength && (mul *= 0x100)) {
                this[offset + i] = (value / mul) & 0xFF;
              }

              return offset + byteLength
            };

            Buffer.prototype.writeUIntBE = function writeUIntBE (value, offset, byteLength, noAssert) {
              value = +value;
              offset = offset | 0;
              byteLength = byteLength | 0;
              if (!noAssert) {
                var maxBytes = Math.pow(2, 8 * byteLength) - 1;
                checkInt(this, value, offset, byteLength, maxBytes, 0);
              }

              var i = byteLength - 1;
              var mul = 1;
              this[offset + i] = value & 0xFF;
              while (--i >= 0 && (mul *= 0x100)) {
                this[offset + i] = (value / mul) & 0xFF;
              }

              return offset + byteLength
            };

            Buffer.prototype.writeUInt8 = function writeUInt8 (value, offset, noAssert) {
              value = +value;
              offset = offset | 0;
              if (!noAssert) checkInt(this, value, offset, 1, 0xff, 0);
              if (!Buffer.TYPED_ARRAY_SUPPORT) value = Math.floor(value);
              this[offset] = (value & 0xff);
              return offset + 1
            };

            function objectWriteUInt16 (buf, value, offset, littleEndian) {
              if (value < 0) value = 0xffff + value + 1;
              for (var i = 0, j = Math.min(buf.length - offset, 2); i < j; ++i) {
                buf[offset + i] = (value & (0xff << (8 * (littleEndian ? i : 1 - i)))) >>>
                  (littleEndian ? i : 1 - i) * 8;
              }
            }

            Buffer.prototype.writeUInt16LE = function writeUInt16LE (value, offset, noAssert) {
              value = +value;
              offset = offset | 0;
              if (!noAssert) checkInt(this, value, offset, 2, 0xffff, 0);
              if (Buffer.TYPED_ARRAY_SUPPORT) {
                this[offset] = (value & 0xff);
                this[offset + 1] = (value >>> 8);
              } else {
                objectWriteUInt16(this, value, offset, true);
              }
              return offset + 2
            };

            Buffer.prototype.writeUInt16BE = function writeUInt16BE (value, offset, noAssert) {
              value = +value;
              offset = offset | 0;
              if (!noAssert) checkInt(this, value, offset, 2, 0xffff, 0);
              if (Buffer.TYPED_ARRAY_SUPPORT) {
                this[offset] = (value >>> 8);
                this[offset + 1] = (value & 0xff);
              } else {
                objectWriteUInt16(this, value, offset, false);
              }
              return offset + 2
            };

            function objectWriteUInt32 (buf, value, offset, littleEndian) {
              if (value < 0) value = 0xffffffff + value + 1;
              for (var i = 0, j = Math.min(buf.length - offset, 4); i < j; ++i) {
                buf[offset + i] = (value >>> (littleEndian ? i : 3 - i) * 8) & 0xff;
              }
            }

            Buffer.prototype.writeUInt32LE = function writeUInt32LE (value, offset, noAssert) {
              value = +value;
              offset = offset | 0;
              if (!noAssert) checkInt(this, value, offset, 4, 0xffffffff, 0);
              if (Buffer.TYPED_ARRAY_SUPPORT) {
                this[offset + 3] = (value >>> 24);
                this[offset + 2] = (value >>> 16);
                this[offset + 1] = (value >>> 8);
                this[offset] = (value & 0xff);
              } else {
                objectWriteUInt32(this, value, offset, true);
              }
              return offset + 4
            };

            Buffer.prototype.writeUInt32BE = function writeUInt32BE (value, offset, noAssert) {
              value = +value;
              offset = offset | 0;
              if (!noAssert) checkInt(this, value, offset, 4, 0xffffffff, 0);
              if (Buffer.TYPED_ARRAY_SUPPORT) {
                this[offset] = (value >>> 24);
                this[offset + 1] = (value >>> 16);
                this[offset + 2] = (value >>> 8);
                this[offset + 3] = (value & 0xff);
              } else {
                objectWriteUInt32(this, value, offset, false);
              }
              return offset + 4
            };

            Buffer.prototype.writeIntLE = function writeIntLE (value, offset, byteLength, noAssert) {
              value = +value;
              offset = offset | 0;
              if (!noAssert) {
                var limit = Math.pow(2, 8 * byteLength - 1);

                checkInt(this, value, offset, byteLength, limit - 1, -limit);
              }

              var i = 0;
              var mul = 1;
              var sub = 0;
              this[offset] = value & 0xFF;
              while (++i < byteLength && (mul *= 0x100)) {
                if (value < 0 && sub === 0 && this[offset + i - 1] !== 0) {
                  sub = 1;
                }
                this[offset + i] = ((value / mul) >> 0) - sub & 0xFF;
              }

              return offset + byteLength
            };

            Buffer.prototype.writeIntBE = function writeIntBE (value, offset, byteLength, noAssert) {
              value = +value;
              offset = offset | 0;
              if (!noAssert) {
                var limit = Math.pow(2, 8 * byteLength - 1);

                checkInt(this, value, offset, byteLength, limit - 1, -limit);
              }

              var i = byteLength - 1;
              var mul = 1;
              var sub = 0;
              this[offset + i] = value & 0xFF;
              while (--i >= 0 && (mul *= 0x100)) {
                if (value < 0 && sub === 0 && this[offset + i + 1] !== 0) {
                  sub = 1;
                }
                this[offset + i] = ((value / mul) >> 0) - sub & 0xFF;
              }

              return offset + byteLength
            };

            Buffer.prototype.writeInt8 = function writeInt8 (value, offset, noAssert) {
              value = +value;
              offset = offset | 0;
              if (!noAssert) checkInt(this, value, offset, 1, 0x7f, -0x80);
              if (!Buffer.TYPED_ARRAY_SUPPORT) value = Math.floor(value);
              if (value < 0) value = 0xff + value + 1;
              this[offset] = (value & 0xff);
              return offset + 1
            };

            Buffer.prototype.writeInt16LE = function writeInt16LE (value, offset, noAssert) {
              value = +value;
              offset = offset | 0;
              if (!noAssert) checkInt(this, value, offset, 2, 0x7fff, -0x8000);
              if (Buffer.TYPED_ARRAY_SUPPORT) {
                this[offset] = (value & 0xff);
                this[offset + 1] = (value >>> 8);
              } else {
                objectWriteUInt16(this, value, offset, true);
              }
              return offset + 2
            };

            Buffer.prototype.writeInt16BE = function writeInt16BE (value, offset, noAssert) {
              value = +value;
              offset = offset | 0;
              if (!noAssert) checkInt(this, value, offset, 2, 0x7fff, -0x8000);
              if (Buffer.TYPED_ARRAY_SUPPORT) {
                this[offset] = (value >>> 8);
                this[offset + 1] = (value & 0xff);
              } else {
                objectWriteUInt16(this, value, offset, false);
              }
              return offset + 2
            };

            Buffer.prototype.writeInt32LE = function writeInt32LE (value, offset, noAssert) {
              value = +value;
              offset = offset | 0;
              if (!noAssert) checkInt(this, value, offset, 4, 0x7fffffff, -0x80000000);
              if (Buffer.TYPED_ARRAY_SUPPORT) {
                this[offset] = (value & 0xff);
                this[offset + 1] = (value >>> 8);
                this[offset + 2] = (value >>> 16);
                this[offset + 3] = (value >>> 24);
              } else {
                objectWriteUInt32(this, value, offset, true);
              }
              return offset + 4
            };

            Buffer.prototype.writeInt32BE = function writeInt32BE (value, offset, noAssert) {
              value = +value;
              offset = offset | 0;
              if (!noAssert) checkInt(this, value, offset, 4, 0x7fffffff, -0x80000000);
              if (value < 0) value = 0xffffffff + value + 1;
              if (Buffer.TYPED_ARRAY_SUPPORT) {
                this[offset] = (value >>> 24);
                this[offset + 1] = (value >>> 16);
                this[offset + 2] = (value >>> 8);
                this[offset + 3] = (value & 0xff);
              } else {
                objectWriteUInt32(this, value, offset, false);
              }
              return offset + 4
            };

            function checkIEEE754 (buf, value, offset, ext, max, min) {
              if (offset + ext > buf.length) throw new RangeError('Index out of range')
              if (offset < 0) throw new RangeError('Index out of range')
            }

            function writeFloat (buf, value, offset, littleEndian, noAssert) {
              if (!noAssert) {
                checkIEEE754(buf, value, offset, 4);
              }
              write(buf, value, offset, littleEndian, 23, 4);
              return offset + 4
            }

            Buffer.prototype.writeFloatLE = function writeFloatLE (value, offset, noAssert) {
              return writeFloat(this, value, offset, true, noAssert)
            };

            Buffer.prototype.writeFloatBE = function writeFloatBE (value, offset, noAssert) {
              return writeFloat(this, value, offset, false, noAssert)
            };

            function writeDouble (buf, value, offset, littleEndian, noAssert) {
              if (!noAssert) {
                checkIEEE754(buf, value, offset, 8);
              }
              write(buf, value, offset, littleEndian, 52, 8);
              return offset + 8
            }

            Buffer.prototype.writeDoubleLE = function writeDoubleLE (value, offset, noAssert) {
              return writeDouble(this, value, offset, true, noAssert)
            };

            Buffer.prototype.writeDoubleBE = function writeDoubleBE (value, offset, noAssert) {
              return writeDouble(this, value, offset, false, noAssert)
            };

            // copy(targetBuffer, targetStart=0, sourceStart=0, sourceEnd=buffer.length)
            Buffer.prototype.copy = function copy (target, targetStart, start, end) {
              if (!start) start = 0;
              if (!end && end !== 0) end = this.length;
              if (targetStart >= target.length) targetStart = target.length;
              if (!targetStart) targetStart = 0;
              if (end > 0 && end < start) end = start;

              // Copy 0 bytes; we're done
              if (end === start) return 0
              if (target.length === 0 || this.length === 0) return 0

              // Fatal error conditions
              if (targetStart < 0) {
                throw new RangeError('targetStart out of bounds')
              }
              if (start < 0 || start >= this.length) throw new RangeError('sourceStart out of bounds')
              if (end < 0) throw new RangeError('sourceEnd out of bounds')

              // Are we oob?
              if (end > this.length) end = this.length;
              if (target.length - targetStart < end - start) {
                end = target.length - targetStart + start;
              }

              var len = end - start;
              var i;

              if (this === target && start < targetStart && targetStart < end) {
                // descending copy from end
                for (i = len - 1; i >= 0; --i) {
                  target[i + targetStart] = this[i + start];
                }
              } else if (len < 1000 || !Buffer.TYPED_ARRAY_SUPPORT) {
                // ascending copy from start
                for (i = 0; i < len; ++i) {
                  target[i + targetStart] = this[i + start];
                }
              } else {
                Uint8Array.prototype.set.call(
                  target,
                  this.subarray(start, start + len),
                  targetStart
                );
              }

              return len
            };

            // Usage:
            //    buffer.fill(number[, offset[, end]])
            //    buffer.fill(buffer[, offset[, end]])
            //    buffer.fill(string[, offset[, end]][, encoding])
            Buffer.prototype.fill = function fill (val, start, end, encoding) {
              // Handle string cases:
              if (typeof val === 'string') {
                if (typeof start === 'string') {
                  encoding = start;
                  start = 0;
                  end = this.length;
                } else if (typeof end === 'string') {
                  encoding = end;
                  end = this.length;
                }
                if (val.length === 1) {
                  var code = val.charCodeAt(0);
                  if (code < 256) {
                    val = code;
                  }
                }
                if (encoding !== undefined && typeof encoding !== 'string') {
                  throw new TypeError('encoding must be a string')
                }
                if (typeof encoding === 'string' && !Buffer.isEncoding(encoding)) {
                  throw new TypeError('Unknown encoding: ' + encoding)
                }
              } else if (typeof val === 'number') {
                val = val & 255;
              }

              // Invalid ranges are not set to a default, so can range check early.
              if (start < 0 || this.length < start || this.length < end) {
                throw new RangeError('Out of range index')
              }

              if (end <= start) {
                return this
              }

              start = start >>> 0;
              end = end === undefined ? this.length : end >>> 0;

              if (!val) val = 0;

              var i;
              if (typeof val === 'number') {
                for (i = start; i < end; ++i) {
                  this[i] = val;
                }
              } else {
                var bytes = internalIsBuffer(val)
                  ? val
                  : utf8ToBytes(new Buffer(val, encoding).toString());
                var len = bytes.length;
                for (i = 0; i < end - start; ++i) {
                  this[i + start] = bytes[i % len];
                }
              }

              return this
            };

            // HELPER FUNCTIONS
            // ================

            var INVALID_BASE64_RE = /[^+\/0-9A-Za-z-_]/g;

            function base64clean (str) {
              // Node strips out invalid characters like \n and \t from the string, base64-js does not
              str = stringtrim(str).replace(INVALID_BASE64_RE, '');
              // Node converts strings with length < 2 to ''
              if (str.length < 2) return ''
              // Node allows for non-padded base64 strings (missing trailing ===), base64-js does not
              while (str.length % 4 !== 0) {
                str = str + '=';
              }
              return str
            }

            function stringtrim (str) {
              if (str.trim) return str.trim()
              return str.replace(/^\s+|\s+$/g, '')
            }

            function toHex (n) {
              if (n < 16) return '0' + n.toString(16)
              return n.toString(16)
            }

            function utf8ToBytes (string, units) {
              units = units || Infinity;
              var codePoint;
              var length = string.length;
              var leadSurrogate = null;
              var bytes = [];

              for (var i = 0; i < length; ++i) {
                codePoint = string.charCodeAt(i);

                // is surrogate component
                if (codePoint > 0xD7FF && codePoint < 0xE000) {
                  // last char was a lead
                  if (!leadSurrogate) {
                    // no lead yet
                    if (codePoint > 0xDBFF) {
                      // unexpected trail
                      if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD);
                      continue
                    } else if (i + 1 === length) {
                      // unpaired lead
                      if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD);
                      continue
                    }

                    // valid lead
                    leadSurrogate = codePoint;

                    continue
                  }

                  // 2 leads in a row
                  if (codePoint < 0xDC00) {
                    if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD);
                    leadSurrogate = codePoint;
                    continue
                  }

                  // valid surrogate pair
                  codePoint = (leadSurrogate - 0xD800 << 10 | codePoint - 0xDC00) + 0x10000;
                } else if (leadSurrogate) {
                  // valid bmp char, but last char was a lead
                  if ((units -= 3) > -1) bytes.push(0xEF, 0xBF, 0xBD);
                }

                leadSurrogate = null;

                // encode utf8
                if (codePoint < 0x80) {
                  if ((units -= 1) < 0) break
                  bytes.push(codePoint);
                } else if (codePoint < 0x800) {
                  if ((units -= 2) < 0) break
                  bytes.push(
                    codePoint >> 0x6 | 0xC0,
                    codePoint & 0x3F | 0x80
                  );
                } else if (codePoint < 0x10000) {
                  if ((units -= 3) < 0) break
                  bytes.push(
                    codePoint >> 0xC | 0xE0,
                    codePoint >> 0x6 & 0x3F | 0x80,
                    codePoint & 0x3F | 0x80
                  );
                } else if (codePoint < 0x110000) {
                  if ((units -= 4) < 0) break
                  bytes.push(
                    codePoint >> 0x12 | 0xF0,
                    codePoint >> 0xC & 0x3F | 0x80,
                    codePoint >> 0x6 & 0x3F | 0x80,
                    codePoint & 0x3F | 0x80
                  );
                } else {
                  throw new Error('Invalid code point')
                }
              }

              return bytes
            }

            function asciiToBytes (str) {
              var byteArray = [];
              for (var i = 0; i < str.length; ++i) {
                // Node's code seems to be doing this and not & 0x7F..
                byteArray.push(str.charCodeAt(i) & 0xFF);
              }
              return byteArray
            }

            function utf16leToBytes (str, units) {
              var c, hi, lo;
              var byteArray = [];
              for (var i = 0; i < str.length; ++i) {
                if ((units -= 2) < 0) break

                c = str.charCodeAt(i);
                hi = c >> 8;
                lo = c % 256;
                byteArray.push(lo);
                byteArray.push(hi);
              }

              return byteArray
            }


            function base64ToBytes (str) {
              return toByteArray(base64clean(str))
            }

            function blitBuffer (src, dst, offset, length) {
              for (var i = 0; i < length; ++i) {
                if ((i + offset >= dst.length) || (i >= src.length)) break
                dst[i + offset] = src[i];
              }
              return i
            }

            function isnan (val) {
              return val !== val // eslint-disable-line no-self-compare
            }


            // the following is from is-buffer, also by Feross Aboukhadijeh and with same lisence
            // The _isBuffer check is for Safari 5-7 support, because it's missing
            // Object.prototype.constructor. Remove this eventually
            function isBuffer$1(obj) {
              return obj != null && (!!obj._isBuffer || isFastBuffer(obj) || isSlowBuffer(obj))
            }

            function isFastBuffer (obj) {
              return !!obj.constructor && typeof obj.constructor.isBuffer === 'function' && obj.constructor.isBuffer(obj)
            }

            // For Node v0.10 support. Remove this eventually.
            function isSlowBuffer (obj) {
              return typeof obj.readFloatLE === 'function' && typeof obj.slice === 'function' && isFastBuffer(obj.slice(0, 0))
            }

            var bufferEs6 = /*#__PURE__*/Object.freeze({
                        __proto__: null,
                        INSPECT_MAX_BYTES: INSPECT_MAX_BYTES,
                        kMaxLength: _kMaxLength,
                        Buffer: Buffer,
                        SlowBuffer: SlowBuffer,
                        isBuffer: isBuffer$1
            });

            var inherits;
            if (typeof Object.create === 'function'){
              inherits = function inherits(ctor, superCtor) {
                // implementation from standard node.js 'util' module
                ctor.super_ = superCtor;
                ctor.prototype = Object.create(superCtor.prototype, {
                  constructor: {
                    value: ctor,
                    enumerable: false,
                    writable: true,
                    configurable: true
                  }
                });
              };
            } else {
              inherits = function inherits(ctor, superCtor) {
                ctor.super_ = superCtor;
                var TempCtor = function () {};
                TempCtor.prototype = superCtor.prototype;
                ctor.prototype = new TempCtor();
                ctor.prototype.constructor = ctor;
              };
            }
            var inherits$1 = inherits;

            var formatRegExp = /%[sdj%]/g;
            function format(f) {
              if (!isString$1(f)) {
                var objects = [];
                for (var i = 0; i < arguments.length; i++) {
                  objects.push(inspect(arguments[i]));
                }
                return objects.join(' ');
              }

              var i = 1;
              var args = arguments;
              var len = args.length;
              var str = String(f).replace(formatRegExp, function(x) {
                if (x === '%%') return '%';
                if (i >= len) return x;
                switch (x) {
                  case '%s': return String(args[i++]);
                  case '%d': return Number(args[i++]);
                  case '%j':
                    try {
                      return JSON.stringify(args[i++]);
                    } catch (_) {
                      return '[Circular]';
                    }
                  default:
                    return x;
                }
              });
              for (var x = args[i]; i < len; x = args[++i]) {
                if (isNull(x) || !isObject$1(x)) {
                  str += ' ' + x;
                } else {
                  str += ' ' + inspect(x);
                }
              }
              return str;
            }

            // Mark that a method should not be used.
            // Returns a modified function which warns once by default.
            // If --no-deprecation is set, then it is a no-op.
            function deprecate(fn, msg) {
              // Allow for deprecating things in the process of starting up.
              if (isUndefined$1(global$1.process)) {
                return function() {
                  return deprecate(fn, msg).apply(this, arguments);
                };
              }

              if (process.noDeprecation === true) {
                return fn;
              }

              var warned = false;
              function deprecated() {
                if (!warned) {
                  if (process.throwDeprecation) {
                    throw new Error(msg);
                  } else if (process.traceDeprecation) {
                    console.trace(msg);
                  } else {
                    console.error(msg);
                  }
                  warned = true;
                }
                return fn.apply(this, arguments);
              }

              return deprecated;
            }

            var debugs = {};
            var debugEnviron;
            function debuglog(set) {
              if (isUndefined$1(debugEnviron))
                debugEnviron = process.env.NODE_DEBUG || '';
              set = set.toUpperCase();
              if (!debugs[set]) {
                if (new RegExp('\\b' + set + '\\b', 'i').test(debugEnviron)) {
                  var pid = 0;
                  debugs[set] = function() {
                    var msg = format.apply(null, arguments);
                    console.error('%s %d: %s', set, pid, msg);
                  };
                } else {
                  debugs[set] = function() {};
                }
              }
              return debugs[set];
            }

            /**
             * Echos the value of a value. Trys to print the value out
             * in the best way possible given the different types.
             *
             * @param {Object} obj The object to print out.
             * @param {Object} opts Optional options object that alters the output.
             */
            /* legacy: obj, showHidden, depth, colors*/
            function inspect(obj, opts) {
              // default options
              var ctx = {
                seen: [],
                stylize: stylizeNoColor
              };
              // legacy...
              if (arguments.length >= 3) ctx.depth = arguments[2];
              if (arguments.length >= 4) ctx.colors = arguments[3];
              if (isBoolean(opts)) {
                // legacy...
                ctx.showHidden = opts;
              } else if (opts) {
                // got an "options" object
                _extend(ctx, opts);
              }
              // set default options
              if (isUndefined$1(ctx.showHidden)) ctx.showHidden = false;
              if (isUndefined$1(ctx.depth)) ctx.depth = 2;
              if (isUndefined$1(ctx.colors)) ctx.colors = false;
              if (isUndefined$1(ctx.customInspect)) ctx.customInspect = true;
              if (ctx.colors) ctx.stylize = stylizeWithColor;
              return formatValue(ctx, obj, ctx.depth);
            }

            // http://en.wikipedia.org/wiki/ANSI_escape_code#graphics
            inspect.colors = {
              'bold' : [1, 22],
              'italic' : [3, 23],
              'underline' : [4, 24],
              'inverse' : [7, 27],
              'white' : [37, 39],
              'grey' : [90, 39],
              'black' : [30, 39],
              'blue' : [34, 39],
              'cyan' : [36, 39],
              'green' : [32, 39],
              'magenta' : [35, 39],
              'red' : [31, 39],
              'yellow' : [33, 39]
            };

            // Don't use 'blue' not visible on cmd.exe
            inspect.styles = {
              'special': 'cyan',
              'number': 'yellow',
              'boolean': 'yellow',
              'undefined': 'grey',
              'null': 'bold',
              'string': 'green',
              'date': 'magenta',
              // "name": intentionally not styling
              'regexp': 'red'
            };


            function stylizeWithColor(str, styleType) {
              var style = inspect.styles[styleType];

              if (style) {
                return '\u001b[' + inspect.colors[style][0] + 'm' + str +
                       '\u001b[' + inspect.colors[style][1] + 'm';
              } else {
                return str;
              }
            }


            function stylizeNoColor(str, styleType) {
              return str;
            }


            function arrayToHash(array) {
              var hash = {};

              array.forEach(function(val, idx) {
                hash[val] = true;
              });

              return hash;
            }


            function formatValue(ctx, value, recurseTimes) {
              // Provide a hook for user-specified inspect functions.
              // Check that value is an object with an inspect function on it
              if (ctx.customInspect &&
                  value &&
                  isFunction$1(value.inspect) &&
                  // Filter out the util module, it's inspect function is special
                  value.inspect !== inspect &&
                  // Also filter out any prototype objects using the circular check.
                  !(value.constructor && value.constructor.prototype === value)) {
                var ret = value.inspect(recurseTimes, ctx);
                if (!isString$1(ret)) {
                  ret = formatValue(ctx, ret, recurseTimes);
                }
                return ret;
              }

              // Primitive types cannot have properties
              var primitive = formatPrimitive(ctx, value);
              if (primitive) {
                return primitive;
              }

              // Look up the keys of the object.
              var keys = Object.keys(value);
              var visibleKeys = arrayToHash(keys);

              if (ctx.showHidden) {
                keys = Object.getOwnPropertyNames(value);
              }

              // IE doesn't make error fields non-enumerable
              // http://msdn.microsoft.com/en-us/library/ie/dww52sbt(v=vs.94).aspx
              if (isError(value)
                  && (keys.indexOf('message') >= 0 || keys.indexOf('description') >= 0)) {
                return formatError(value);
              }

              // Some type of object without properties can be shortcutted.
              if (keys.length === 0) {
                if (isFunction$1(value)) {
                  var name = value.name ? ': ' + value.name : '';
                  return ctx.stylize('[Function' + name + ']', 'special');
                }
                if (isRegExp(value)) {
                  return ctx.stylize(RegExp.prototype.toString.call(value), 'regexp');
                }
                if (isDate$1(value)) {
                  return ctx.stylize(Date.prototype.toString.call(value), 'date');
                }
                if (isError(value)) {
                  return formatError(value);
                }
              }

              var base = '', array = false, braces = ['{', '}'];

              // Make Array say that they are Array
              if (isArray$2(value)) {
                array = true;
                braces = ['[', ']'];
              }

              // Make functions say that they are functions
              if (isFunction$1(value)) {
                var n = value.name ? ': ' + value.name : '';
                base = ' [Function' + n + ']';
              }

              // Make RegExps say that they are RegExps
              if (isRegExp(value)) {
                base = ' ' + RegExp.prototype.toString.call(value);
              }

              // Make dates with properties first say the date
              if (isDate$1(value)) {
                base = ' ' + Date.prototype.toUTCString.call(value);
              }

              // Make error with message first say the error
              if (isError(value)) {
                base = ' ' + formatError(value);
              }

              if (keys.length === 0 && (!array || value.length == 0)) {
                return braces[0] + base + braces[1];
              }

              if (recurseTimes < 0) {
                if (isRegExp(value)) {
                  return ctx.stylize(RegExp.prototype.toString.call(value), 'regexp');
                } else {
                  return ctx.stylize('[Object]', 'special');
                }
              }

              ctx.seen.push(value);

              var output;
              if (array) {
                output = formatArray(ctx, value, recurseTimes, visibleKeys, keys);
              } else {
                output = keys.map(function(key) {
                  return formatProperty(ctx, value, recurseTimes, visibleKeys, key, array);
                });
              }

              ctx.seen.pop();

              return reduceToSingleString(output, base, braces);
            }


            function formatPrimitive(ctx, value) {
              if (isUndefined$1(value))
                return ctx.stylize('undefined', 'undefined');
              if (isString$1(value)) {
                var simple = '\'' + JSON.stringify(value).replace(/^"|"$/g, '')
                                                         .replace(/'/g, "\\'")
                                                         .replace(/\\"/g, '"') + '\'';
                return ctx.stylize(simple, 'string');
              }
              if (isNumber$1(value))
                return ctx.stylize('' + value, 'number');
              if (isBoolean(value))
                return ctx.stylize('' + value, 'boolean');
              // For some reason typeof null is "object", so special case here.
              if (isNull(value))
                return ctx.stylize('null', 'null');
            }


            function formatError(value) {
              return '[' + Error.prototype.toString.call(value) + ']';
            }


            function formatArray(ctx, value, recurseTimes, visibleKeys, keys) {
              var output = [];
              for (var i = 0, l = value.length; i < l; ++i) {
                if (hasOwnProperty(value, String(i))) {
                  output.push(formatProperty(ctx, value, recurseTimes, visibleKeys,
                      String(i), true));
                } else {
                  output.push('');
                }
              }
              keys.forEach(function(key) {
                if (!key.match(/^\d+$/)) {
                  output.push(formatProperty(ctx, value, recurseTimes, visibleKeys,
                      key, true));
                }
              });
              return output;
            }


            function formatProperty(ctx, value, recurseTimes, visibleKeys, key, array) {
              var name, str, desc;
              desc = Object.getOwnPropertyDescriptor(value, key) || { value: value[key] };
              if (desc.get) {
                if (desc.set) {
                  str = ctx.stylize('[Getter/Setter]', 'special');
                } else {
                  str = ctx.stylize('[Getter]', 'special');
                }
              } else {
                if (desc.set) {
                  str = ctx.stylize('[Setter]', 'special');
                }
              }
              if (!hasOwnProperty(visibleKeys, key)) {
                name = '[' + key + ']';
              }
              if (!str) {
                if (ctx.seen.indexOf(desc.value) < 0) {
                  if (isNull(recurseTimes)) {
                    str = formatValue(ctx, desc.value, null);
                  } else {
                    str = formatValue(ctx, desc.value, recurseTimes - 1);
                  }
                  if (str.indexOf('\n') > -1) {
                    if (array) {
                      str = str.split('\n').map(function(line) {
                        return '  ' + line;
                      }).join('\n').substr(2);
                    } else {
                      str = '\n' + str.split('\n').map(function(line) {
                        return '   ' + line;
                      }).join('\n');
                    }
                  }
                } else {
                  str = ctx.stylize('[Circular]', 'special');
                }
              }
              if (isUndefined$1(name)) {
                if (array && key.match(/^\d+$/)) {
                  return str;
                }
                name = JSON.stringify('' + key);
                if (name.match(/^"([a-zA-Z_][a-zA-Z_0-9]*)"$/)) {
                  name = name.substr(1, name.length - 2);
                  name = ctx.stylize(name, 'name');
                } else {
                  name = name.replace(/'/g, "\\'")
                             .replace(/\\"/g, '"')
                             .replace(/(^"|"$)/g, "'");
                  name = ctx.stylize(name, 'string');
                }
              }

              return name + ': ' + str;
            }


            function reduceToSingleString(output, base, braces) {
              var length = output.reduce(function(prev, cur) {
                if (cur.indexOf('\n') >= 0) ;
                return prev + cur.replace(/\u001b\[\d\d?m/g, '').length + 1;
              }, 0);

              if (length > 60) {
                return braces[0] +
                       (base === '' ? '' : base + '\n ') +
                       ' ' +
                       output.join(',\n  ') +
                       ' ' +
                       braces[1];
              }

              return braces[0] + base + ' ' + output.join(', ') + ' ' + braces[1];
            }


            // NOTE: These type checking functions intentionally don't use `instanceof`
            // because it is fragile and can be easily faked with `Object.create()`.
            function isArray$2(ar) {
              return Array.isArray(ar);
            }

            function isBoolean(arg) {
              return typeof arg === 'boolean';
            }

            function isNull(arg) {
              return arg === null;
            }

            function isNullOrUndefined(arg) {
              return arg == null;
            }

            function isNumber$1(arg) {
              return typeof arg === 'number';
            }

            function isString$1(arg) {
              return typeof arg === 'string';
            }

            function isSymbol(arg) {
              return typeof arg === 'symbol';
            }

            function isUndefined$1(arg) {
              return arg === void 0;
            }

            function isRegExp(re) {
              return isObject$1(re) && objectToString(re) === '[object RegExp]';
            }

            function isObject$1(arg) {
              return typeof arg === 'object' && arg !== null;
            }

            function isDate$1(d) {
              return isObject$1(d) && objectToString(d) === '[object Date]';
            }

            function isError(e) {
              return isObject$1(e) &&
                  (objectToString(e) === '[object Error]' || e instanceof Error);
            }

            function isFunction$1(arg) {
              return typeof arg === 'function';
            }

            function isPrimitive(arg) {
              return arg === null ||
                     typeof arg === 'boolean' ||
                     typeof arg === 'number' ||
                     typeof arg === 'string' ||
                     typeof arg === 'symbol' ||  // ES6 symbol
                     typeof arg === 'undefined';
            }

            function isBuffer$2(maybeBuf) {
              return isBuffer$1(maybeBuf);
            }

            function objectToString(o) {
              return Object.prototype.toString.call(o);
            }


            function pad(n) {
              return n < 10 ? '0' + n.toString(10) : n.toString(10);
            }


            var months = ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep',
                          'Oct', 'Nov', 'Dec'];

            // 26 Feb 16:19:34
            function timestamp() {
              var d = new Date();
              var time = [pad(d.getHours()),
                          pad(d.getMinutes()),
                          pad(d.getSeconds())].join(':');
              return [d.getDate(), months[d.getMonth()], time].join(' ');
            }


            // log is just a thin wrapper to console.log that prepends a timestamp
            function log() {
              console.log('%s - %s', timestamp(), format.apply(null, arguments));
            }

            function _extend(origin, add) {
              // Don't do anything if add isn't an object
              if (!add || !isObject$1(add)) return origin;

              var keys = Object.keys(add);
              var i = keys.length;
              while (i--) {
                origin[keys[i]] = add[keys[i]];
              }
              return origin;
            }
            function hasOwnProperty(obj, prop) {
              return Object.prototype.hasOwnProperty.call(obj, prop);
            }

            var util = {
              inherits: inherits$1,
              _extend: _extend,
              log: log,
              isBuffer: isBuffer$2,
              isPrimitive: isPrimitive,
              isFunction: isFunction$1,
              isError: isError,
              isDate: isDate$1,
              isObject: isObject$1,
              isRegExp: isRegExp,
              isUndefined: isUndefined$1,
              isSymbol: isSymbol,
              isString: isString$1,
              isNumber: isNumber$1,
              isNullOrUndefined: isNullOrUndefined,
              isNull: isNull,
              isBoolean: isBoolean,
              isArray: isArray$2,
              inspect: inspect,
              deprecate: deprecate,
              format: format,
              debuglog: debuglog
            };

            var util$1 = /*#__PURE__*/Object.freeze({
                        __proto__: null,
                        format: format,
                        deprecate: deprecate,
                        debuglog: debuglog,
                        inspect: inspect,
                        isArray: isArray$2,
                        isBoolean: isBoolean,
                        isNull: isNull,
                        isNullOrUndefined: isNullOrUndefined,
                        isNumber: isNumber$1,
                        isString: isString$1,
                        isSymbol: isSymbol,
                        isUndefined: isUndefined$1,
                        isRegExp: isRegExp,
                        isObject: isObject$1,
                        isDate: isDate$1,
                        isError: isError,
                        isFunction: isFunction$1,
                        isPrimitive: isPrimitive,
                        isBuffer: isBuffer$2,
                        log: log,
                        inherits: inherits$1,
                        _extend: _extend,
                        'default': util
            });

            var immutable = extend$1;

            var hasOwnProperty$1 = Object.prototype.hasOwnProperty;

            function extend$1() {
                var target = {};

                for (var i = 0; i < arguments.length; i++) {
                    var source = arguments[i];

                    for (var key in source) {
                        if (hasOwnProperty$1.call(source, key)) {
                            target[key] = source[key];
                        }
                    }
                }

                return target
            }

            var mutable = extend$2;

            var hasOwnProperty$2 = Object.prototype.hasOwnProperty;

            function extend$2(target) {
                for (var i = 1; i < arguments.length; i++) {
                    var source = arguments[i];

                    for (var key in source) {
                        if (hasOwnProperty$2.call(source, key)) {
                            target[key] = source[key];
                        }
                    }
                }

                return target
            }

            // For (old) browser support



            var levelSupports = function supports () {
              var manifest = immutable.apply(null, arguments);

              return mutable(manifest, {
                // Features of abstract-leveldown
                bufferKeys: manifest.bufferKeys || false,
                snapshots: manifest.snapshots || false,
                permanence: manifest.permanence || false,
                seek: manifest.seek || false,
                clear: manifest.clear || false,

                // Features of abstract-leveldown that levelup doesn't have
                status: manifest.status || false,

                // Features of disk-based implementations
                createIfMissing: manifest.createIfMissing || false,
                errorIfExists: manifest.errorIfExists || false,

                // Features of level(up) that abstract-leveldown doesn't have yet
                deferredOpen: manifest.deferredOpen || false,
                openCallback: manifest.openCallback || false,
                promises: manifest.promises || false,
                streams: manifest.streams || false,
                encodings: manifest.encodings || false,

                // Methods that are not part of abstract-leveldown or levelup
                additionalMethods: immutable(manifest.additionalMethods)
              })
            };

            function AbstractIterator (db) {
              if (typeof db !== 'object' || db === null) {
                throw new TypeError('First argument must be an abstract-leveldown compliant store')
              }

              this.db = db;
              this._ended = false;
              this._nexting = false;
            }

            AbstractIterator.prototype.next = function (callback) {
              var self = this;

              if (typeof callback !== 'function') {
                throw new Error('next() requires a callback argument')
              }

              if (self._ended) {
                nextTick(callback, new Error('cannot call next() after end()'));
                return self
              }

              if (self._nexting) {
                nextTick(callback, new Error('cannot call next() before previous next() has completed'));
                return self
              }

              self._nexting = true;
              self._next(function () {
                self._nexting = false;
                callback.apply(null, arguments);
              });

              return self
            };

            AbstractIterator.prototype._next = function (callback) {
              nextTick(callback);
            };

            AbstractIterator.prototype.seek = function (target) {
              if (this._ended) {
                throw new Error('cannot call seek() after end()')
              }
              if (this._nexting) {
                throw new Error('cannot call seek() before next() has completed')
              }

              target = this.db._serializeKey(target);
              this._seek(target);
            };

            AbstractIterator.prototype._seek = function (target) {};

            AbstractIterator.prototype.end = function (callback) {
              if (typeof callback !== 'function') {
                throw new Error('end() requires a callback argument')
              }

              if (this._ended) {
                return nextTick(callback, new Error('end() already called on iterator'))
              }

              this._ended = true;
              this._end(callback);
            };

            AbstractIterator.prototype._end = function (callback) {
              nextTick(callback);
            };

            var abstractIterator = AbstractIterator;

            function AbstractChainedBatch (db) {
              if (typeof db !== 'object' || db === null) {
                throw new TypeError('First argument must be an abstract-leveldown compliant store')
              }

              this.db = db;
              this._operations = [];
              this._written = false;
            }

            AbstractChainedBatch.prototype._checkWritten = function () {
              if (this._written) {
                throw new Error('write() already called on this batch')
              }
            };

            AbstractChainedBatch.prototype.put = function (key, value) {
              this._checkWritten();

              var err = this.db._checkKey(key) || this.db._checkValue(value);
              if (err) throw err

              key = this.db._serializeKey(key);
              value = this.db._serializeValue(value);

              this._put(key, value);

              return this
            };

            AbstractChainedBatch.prototype._put = function (key, value) {
              this._operations.push({ type: 'put', key: key, value: value });
            };

            AbstractChainedBatch.prototype.del = function (key) {
              this._checkWritten();

              var err = this.db._checkKey(key);
              if (err) throw err

              key = this.db._serializeKey(key);
              this._del(key);

              return this
            };

            AbstractChainedBatch.prototype._del = function (key) {
              this._operations.push({ type: 'del', key: key });
            };

            AbstractChainedBatch.prototype.clear = function () {
              this._checkWritten();
              this._clear();

              return this
            };

            AbstractChainedBatch.prototype._clear = function () {
              this._operations = [];
            };

            AbstractChainedBatch.prototype.write = function (options, callback) {
              this._checkWritten();

              if (typeof options === 'function') { callback = options; }
              if (typeof callback !== 'function') {
                throw new Error('write() requires a callback argument')
              }
              if (typeof options !== 'object' || options === null) {
                options = {};
              }

              this._written = true;
              this._write(options, callback);
            };

            AbstractChainedBatch.prototype._write = function (options, callback) {
              this.db._batch(this._operations, options, callback);
            };

            var abstractChainedBatch = AbstractChainedBatch;

            var hasOwnProperty$3 = Object.prototype.hasOwnProperty;
            var rangeOptions = 'start end gt gte lt lte'.split(' ');

            function AbstractLevelDOWN (manifest) {
              this.status = 'new';

              // TODO (next major): make this mandatory
              this.supports = levelSupports(manifest, {
                status: true
              });
            }

            AbstractLevelDOWN.prototype.open = function (options, callback) {
              var self = this;
              var oldStatus = this.status;

              if (typeof options === 'function') callback = options;

              if (typeof callback !== 'function') {
                throw new Error('open() requires a callback argument')
              }

              if (typeof options !== 'object' || options === null) options = {};

              options.createIfMissing = options.createIfMissing !== false;
              options.errorIfExists = !!options.errorIfExists;

              this.status = 'opening';
              this._open(options, function (err) {
                if (err) {
                  self.status = oldStatus;
                  return callback(err)
                }
                self.status = 'open';
                callback();
              });
            };

            AbstractLevelDOWN.prototype._open = function (options, callback) {
              nextTick(callback);
            };

            AbstractLevelDOWN.prototype.close = function (callback) {
              var self = this;
              var oldStatus = this.status;

              if (typeof callback !== 'function') {
                throw new Error('close() requires a callback argument')
              }

              this.status = 'closing';
              this._close(function (err) {
                if (err) {
                  self.status = oldStatus;
                  return callback(err)
                }
                self.status = 'closed';
                callback();
              });
            };

            AbstractLevelDOWN.prototype._close = function (callback) {
              nextTick(callback);
            };

            AbstractLevelDOWN.prototype.get = function (key, options, callback) {
              if (typeof options === 'function') callback = options;

              if (typeof callback !== 'function') {
                throw new Error('get() requires a callback argument')
              }

              var err = this._checkKey(key);
              if (err) return nextTick(callback, err)

              key = this._serializeKey(key);

              if (typeof options !== 'object' || options === null) options = {};

              options.asBuffer = options.asBuffer !== false;

              this._get(key, options, callback);
            };

            AbstractLevelDOWN.prototype._get = function (key, options, callback) {
              nextTick(function () { callback(new Error('NotFound')); });
            };

            AbstractLevelDOWN.prototype.put = function (key, value, options, callback) {
              if (typeof options === 'function') callback = options;

              if (typeof callback !== 'function') {
                throw new Error('put() requires a callback argument')
              }

              var err = this._checkKey(key) || this._checkValue(value);
              if (err) return nextTick(callback, err)

              key = this._serializeKey(key);
              value = this._serializeValue(value);

              if (typeof options !== 'object' || options === null) options = {};

              this._put(key, value, options, callback);
            };

            AbstractLevelDOWN.prototype._put = function (key, value, options, callback) {
              nextTick(callback);
            };

            AbstractLevelDOWN.prototype.del = function (key, options, callback) {
              if (typeof options === 'function') callback = options;

              if (typeof callback !== 'function') {
                throw new Error('del() requires a callback argument')
              }

              var err = this._checkKey(key);
              if (err) return nextTick(callback, err)

              key = this._serializeKey(key);

              if (typeof options !== 'object' || options === null) options = {};

              this._del(key, options, callback);
            };

            AbstractLevelDOWN.prototype._del = function (key, options, callback) {
              nextTick(callback);
            };

            AbstractLevelDOWN.prototype.batch = function (array, options, callback) {
              if (!arguments.length) return this._chainedBatch()

              if (typeof options === 'function') callback = options;

              if (typeof array === 'function') callback = array;

              if (typeof callback !== 'function') {
                throw new Error('batch(array) requires a callback argument')
              }

              if (!Array.isArray(array)) {
                return nextTick(callback, new Error('batch(array) requires an array argument'))
              }

              if (array.length === 0) {
                return nextTick(callback)
              }

              if (typeof options !== 'object' || options === null) options = {};

              var serialized = new Array(array.length);

              for (var i = 0; i < array.length; i++) {
                if (typeof array[i] !== 'object' || array[i] === null) {
                  return nextTick(callback, new Error('batch(array) element must be an object and not `null`'))
                }

                var e = immutable(array[i]);

                if (e.type !== 'put' && e.type !== 'del') {
                  return nextTick(callback, new Error("`type` must be 'put' or 'del'"))
                }

                var err = this._checkKey(e.key);
                if (err) return nextTick(callback, err)

                e.key = this._serializeKey(e.key);

                if (e.type === 'put') {
                  var valueErr = this._checkValue(e.value);
                  if (valueErr) return nextTick(callback, valueErr)

                  e.value = this._serializeValue(e.value);
                }

                serialized[i] = e;
              }

              this._batch(serialized, options, callback);
            };

            AbstractLevelDOWN.prototype._batch = function (array, options, callback) {
              nextTick(callback);
            };

            AbstractLevelDOWN.prototype.clear = function (options, callback) {
              if (typeof options === 'function') {
                callback = options;
              } else if (typeof callback !== 'function') {
                throw new Error('clear() requires a callback argument')
              }

              options = cleanRangeOptions(this, options);
              options.reverse = !!options.reverse;
              options.limit = 'limit' in options ? options.limit : -1;

              this._clear(options, callback);
            };

            AbstractLevelDOWN.prototype._clear = function (options, callback) {
              // Avoid setupIteratorOptions, would serialize range options a second time.
              options.keys = true;
              options.values = false;
              options.keyAsBuffer = true;
              options.valueAsBuffer = true;

              var iterator = this._iterator(options);
              var emptyOptions = {};
              var self = this;

              var next = function (err) {
                if (err) {
                  return iterator.end(function () {
                    callback(err);
                  })
                }

                iterator.next(function (err, key) {
                  if (err) return next(err)
                  if (key === undefined) return iterator.end(callback)

                  // This could be optimized by using a batch, but the default _clear
                  // is not meant to be fast. Implementations have more room to optimize
                  // if they override _clear. Note: using _del bypasses key serialization.
                  self._del(key, emptyOptions, next);
                });
              };

              next();
            };

            AbstractLevelDOWN.prototype._setupIteratorOptions = function (options) {
              options = cleanRangeOptions(this, options);

              options.reverse = !!options.reverse;
              options.keys = options.keys !== false;
              options.values = options.values !== false;
              options.limit = 'limit' in options ? options.limit : -1;
              options.keyAsBuffer = options.keyAsBuffer !== false;
              options.valueAsBuffer = options.valueAsBuffer !== false;

              return options
            };

            function cleanRangeOptions (db, options) {
              var result = {};

              for (var k in options) {
                if (!hasOwnProperty$3.call(options, k)) continue

                var opt = options[k];

                if (isRangeOption(k)) {
                  // Note that we don't reject nullish and empty options here. While
                  // those types are invalid as keys, they are valid as range options.
                  opt = db._serializeKey(opt);
                }

                result[k] = opt;
              }

              return result
            }

            function isRangeOption (k) {
              return rangeOptions.indexOf(k) !== -1
            }

            AbstractLevelDOWN.prototype.iterator = function (options) {
              if (typeof options !== 'object' || options === null) options = {};
              options = this._setupIteratorOptions(options);
              return this._iterator(options)
            };

            AbstractLevelDOWN.prototype._iterator = function (options) {
              return new abstractIterator(this)
            };

            AbstractLevelDOWN.prototype._chainedBatch = function () {
              return new abstractChainedBatch(this)
            };

            AbstractLevelDOWN.prototype._serializeKey = function (key) {
              return key
            };

            AbstractLevelDOWN.prototype._serializeValue = function (value) {
              return value
            };

            AbstractLevelDOWN.prototype._checkKey = function (key) {
              if (key === null || key === undefined) {
                return new Error('key cannot be `null` or `undefined`')
              } else if (isBuffer$1(key) && key.length === 0) {
                return new Error('key cannot be an empty Buffer')
              } else if (key === '') {
                return new Error('key cannot be an empty String')
              } else if (Array.isArray(key) && key.length === 0) {
                return new Error('key cannot be an empty Array')
              }
            };

            AbstractLevelDOWN.prototype._checkValue = function (value) {
              if (value === null || value === undefined) {
                return new Error('value cannot be `null` or `undefined`')
              }
            };

            var abstractLeveldown = AbstractLevelDOWN;

            var AbstractLevelDOWN$1 = abstractLeveldown;
            var AbstractIterator$1 = abstractIterator;
            var AbstractChainedBatch$1 = abstractChainedBatch;

            var abstractLeveldown$1 = {
            	AbstractLevelDOWN: AbstractLevelDOWN$1,
            	AbstractIterator: AbstractIterator$1,
            	AbstractChainedBatch: AbstractChainedBatch$1
            };

            var inherits_browser = createCommonjsModule$1(function (module) {
            if (typeof Object.create === 'function') {
              // implementation from standard node.js 'util' module
              module.exports = function inherits(ctor, superCtor) {
                if (superCtor) {
                  ctor.super_ = superCtor;
                  ctor.prototype = Object.create(superCtor.prototype, {
                    constructor: {
                      value: ctor,
                      enumerable: false,
                      writable: true,
                      configurable: true
                    }
                  });
                }
              };
            } else {
              // old school shim for old browsers
              module.exports = function inherits(ctor, superCtor) {
                if (superCtor) {
                  ctor.super_ = superCtor;
                  var TempCtor = function () {};
                  TempCtor.prototype = superCtor.prototype;
                  ctor.prototype = new TempCtor();
                  ctor.prototype.constructor = ctor;
                }
              };
            }
            });

            var AbstractIterator$2 = abstractLeveldown$1.AbstractIterator;


            function DeferredIterator (db, options) {
              AbstractIterator$2.call(this, db);

              this._options = options;
              this._iterator = null;
              this._operations = [];
            }

            inherits_browser(DeferredIterator, AbstractIterator$2);

            DeferredIterator.prototype.setDb = function (db) {
              var it = this._iterator = db.iterator(this._options);
              this._operations.forEach(function (op) {
                it[op.method].apply(it, op.args);
              });
            };

            DeferredIterator.prototype._operation = function (method, args) {
              if (this._iterator) return this._iterator[method].apply(this._iterator, args)
              this._operations.push({ method: method, args: args });
            };

            'next end'.split(' ').forEach(function (m) {
              DeferredIterator.prototype['_' + m] = function () {
                this._operation(m, arguments);
              };
            });

            // Must defer seek() rather than _seek() because it requires db._serializeKey to be available
            DeferredIterator.prototype.seek = function () {
              this._operation('seek', arguments);
            };

            var deferredIterator = DeferredIterator;

            var AbstractLevelDOWN$2 = abstractLeveldown$1.AbstractLevelDOWN;


            var deferrables = 'put get del batch clear'.split(' ');
            var optionalDeferrables = 'approximateSize compactRange'.split(' ');

            function DeferredLevelDOWN (db) {
              AbstractLevelDOWN$2.call(this, db.supports || {});

              // TODO (future major): remove this fallback; db must have manifest that
              // declares approximateSize and compactRange in additionalMethods.
              optionalDeferrables.forEach(function (m) {
                if (typeof db[m] === 'function' && !this.supports.additionalMethods[m]) {
                  this.supports.additionalMethods[m] = true;
                }
              }, this);

              this._db = db;
              this._operations = [];
              closed(this);
            }

            inherits_browser(DeferredLevelDOWN, AbstractLevelDOWN$2);

            DeferredLevelDOWN.prototype.type = 'deferred-leveldown';

            DeferredLevelDOWN.prototype._open = function (options, callback) {
              var self = this;

              this._db.open(options, function (err) {
                if (err) return callback(err)

                self._operations.forEach(function (op) {
                  if (op.iterator) {
                    op.iterator.setDb(self._db);
                  } else {
                    self._db[op.method].apply(self._db, op.args);
                  }
                });
                self._operations = [];

                open(self);
                callback();
              });
            };

            DeferredLevelDOWN.prototype._close = function (callback) {
              var self = this;

              this._db.close(function (err) {
                if (err) return callback(err)
                closed(self);
                callback();
              });
            };

            function open (self) {
              deferrables.concat('iterator').forEach(function (m) {
                self['_' + m] = function () {
                  return this._db[m].apply(this._db, arguments)
                };
              });
              Object.keys(self.supports.additionalMethods).forEach(function (m) {
                self[m] = function () {
                  return this._db[m].apply(this._db, arguments)
                };
              });
            }

            function closed (self) {
              deferrables.forEach(function (m) {
                self['_' + m] = function () {
                  this._operations.push({ method: m, args: arguments });
                };
              });
              Object.keys(self.supports.additionalMethods).forEach(function (m) {
                self[m] = function () {
                  this._operations.push({ method: m, args: arguments });
                };
              });
              self._iterator = function (options) {
                var it = new deferredIterator(self, options);
                this._operations.push({ iterator: it });
                return it
              };
            }

            DeferredLevelDOWN.prototype._serializeKey = function (key) {
              return key
            };

            DeferredLevelDOWN.prototype._serializeValue = function (value) {
              return value
            };

            var deferredLeveldown = DeferredLevelDOWN;
            var DeferredIterator_1 = deferredIterator;
            deferredLeveldown.DeferredIterator = DeferredIterator_1;

            var require$$0 = getCjsExportFromNamespace(events);

            var streamBrowser = require$$0.EventEmitter;

            var _nodeResolve_empty = {};

            var _nodeResolve_empty$1 = /*#__PURE__*/Object.freeze({
                        __proto__: null,
                        'default': _nodeResolve_empty
            });

            var require$$0$1 = getCjsExportFromNamespace(_nodeResolve_empty$1);

            function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

            function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

            function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

            var Buffer$1 = bufferEs6.Buffer;

            var inspect$1 = require$$0$1.inspect;

            var custom = inspect$1 && inspect$1.custom || 'inspect';

            function copyBuffer(src, target, offset) {
              Buffer$1.prototype.copy.call(src, target, offset);
            }

            var buffer_list =
            /*#__PURE__*/
            function () {
              function BufferList() {
                this.head = null;
                this.tail = null;
                this.length = 0;
              }

              var _proto = BufferList.prototype;

              _proto.push = function push(v) {
                var entry = {
                  data: v,
                  next: null
                };
                if (this.length > 0) this.tail.next = entry;else this.head = entry;
                this.tail = entry;
                ++this.length;
              };

              _proto.unshift = function unshift(v) {
                var entry = {
                  data: v,
                  next: this.head
                };
                if (this.length === 0) this.tail = entry;
                this.head = entry;
                ++this.length;
              };

              _proto.shift = function shift() {
                if (this.length === 0) return;
                var ret = this.head.data;
                if (this.length === 1) this.head = this.tail = null;else this.head = this.head.next;
                --this.length;
                return ret;
              };

              _proto.clear = function clear() {
                this.head = this.tail = null;
                this.length = 0;
              };

              _proto.join = function join(s) {
                if (this.length === 0) return '';
                var p = this.head;
                var ret = '' + p.data;

                while (p = p.next) {
                  ret += s + p.data;
                }

                return ret;
              };

              _proto.concat = function concat(n) {
                if (this.length === 0) return Buffer$1.alloc(0);
                var ret = Buffer$1.allocUnsafe(n >>> 0);
                var p = this.head;
                var i = 0;

                while (p) {
                  copyBuffer(p.data, ret, i);
                  i += p.data.length;
                  p = p.next;
                }

                return ret;
              } // Consumes a specified amount of bytes or characters from the buffered data.
              ;

              _proto.consume = function consume(n, hasStrings) {
                var ret;

                if (n < this.head.data.length) {
                  // `slice` is the same for buffers and strings.
                  ret = this.head.data.slice(0, n);
                  this.head.data = this.head.data.slice(n);
                } else if (n === this.head.data.length) {
                  // First chunk is a perfect match.
                  ret = this.shift();
                } else {
                  // Result spans more than one buffer.
                  ret = hasStrings ? this._getString(n) : this._getBuffer(n);
                }

                return ret;
              };

              _proto.first = function first() {
                return this.head.data;
              } // Consumes a specified amount of characters from the buffered data.
              ;

              _proto._getString = function _getString(n) {
                var p = this.head;
                var c = 1;
                var ret = p.data;
                n -= ret.length;

                while (p = p.next) {
                  var str = p.data;
                  var nb = n > str.length ? str.length : n;
                  if (nb === str.length) ret += str;else ret += str.slice(0, n);
                  n -= nb;

                  if (n === 0) {
                    if (nb === str.length) {
                      ++c;
                      if (p.next) this.head = p.next;else this.head = this.tail = null;
                    } else {
                      this.head = p;
                      p.data = str.slice(nb);
                    }

                    break;
                  }

                  ++c;
                }

                this.length -= c;
                return ret;
              } // Consumes a specified amount of bytes from the buffered data.
              ;

              _proto._getBuffer = function _getBuffer(n) {
                var ret = Buffer$1.allocUnsafe(n);
                var p = this.head;
                var c = 1;
                p.data.copy(ret);
                n -= p.data.length;

                while (p = p.next) {
                  var buf = p.data;
                  var nb = n > buf.length ? buf.length : n;
                  buf.copy(ret, ret.length - n, 0, nb);
                  n -= nb;

                  if (n === 0) {
                    if (nb === buf.length) {
                      ++c;
                      if (p.next) this.head = p.next;else this.head = this.tail = null;
                    } else {
                      this.head = p;
                      p.data = buf.slice(nb);
                    }

                    break;
                  }

                  ++c;
                }

                this.length -= c;
                return ret;
              } // Make sure the linked list only shows the minimal necessary information.
              ;

              _proto[custom] = function (_, options) {
                return inspect$1(this, _objectSpread({}, options, {
                  // Only inspect one level.
                  depth: 0,
                  // It should not recurse.
                  customInspect: false
                }));
              };

              return BufferList;
            }();

            function destroy(err, cb) {
              var _this = this;

              var readableDestroyed = this._readableState && this._readableState.destroyed;
              var writableDestroyed = this._writableState && this._writableState.destroyed;

              if (readableDestroyed || writableDestroyed) {
                if (cb) {
                  cb(err);
                } else if (err) {
                  if (!this._writableState) {
                    nextTick(emitErrorNT, this, err);
                  } else if (!this._writableState.errorEmitted) {
                    this._writableState.errorEmitted = true;
                    nextTick(emitErrorNT, this, err);
                  }
                }

                return this;
              } // we set destroyed to true before firing error callbacks in order
              // to make it re-entrance safe in case destroy() is called within callbacks


              if (this._readableState) {
                this._readableState.destroyed = true;
              } // if this is a duplex stream mark the writable part as destroyed as well


              if (this._writableState) {
                this._writableState.destroyed = true;
              }

              this._destroy(err || null, function (err) {
                if (!cb && err) {
                  if (!_this._writableState) {
                    nextTick(emitErrorAndCloseNT, _this, err);
                  } else if (!_this._writableState.errorEmitted) {
                    _this._writableState.errorEmitted = true;
                    nextTick(emitErrorAndCloseNT, _this, err);
                  } else {
                    nextTick(emitCloseNT, _this);
                  }
                } else if (cb) {
                  nextTick(emitCloseNT, _this);
                  cb(err);
                } else {
                  nextTick(emitCloseNT, _this);
                }
              });

              return this;
            }

            function emitErrorAndCloseNT(self, err) {
              emitErrorNT(self, err);
              emitCloseNT(self);
            }

            function emitCloseNT(self) {
              if (self._writableState && !self._writableState.emitClose) return;
              if (self._readableState && !self._readableState.emitClose) return;
              self.emit('close');
            }

            function undestroy() {
              if (this._readableState) {
                this._readableState.destroyed = false;
                this._readableState.reading = false;
                this._readableState.ended = false;
                this._readableState.endEmitted = false;
              }

              if (this._writableState) {
                this._writableState.destroyed = false;
                this._writableState.ended = false;
                this._writableState.ending = false;
                this._writableState.finalCalled = false;
                this._writableState.prefinished = false;
                this._writableState.finished = false;
                this._writableState.errorEmitted = false;
              }
            }

            function emitErrorNT(self, err) {
              self.emit('error', err);
            }

            function errorOrDestroy(stream, err) {
              // We have tests that rely on errors being emitted
              // in the same tick, so changing this is semver major.
              // For now when you opt-in to autoDestroy we allow
              // the error to be emitted nextTick. In a future
              // semver major update we should change the default to this.
              var rState = stream._readableState;
              var wState = stream._writableState;
              if (rState && rState.autoDestroy || wState && wState.autoDestroy) stream.destroy(err);else stream.emit('error', err);
            }

            var destroy_1 = {
              destroy: destroy,
              undestroy: undestroy,
              errorOrDestroy: errorOrDestroy
            };

            function _inheritsLoose(subClass, superClass) { subClass.prototype = Object.create(superClass.prototype); subClass.prototype.constructor = subClass; subClass.__proto__ = superClass; }

            var codes = {};

            function createErrorType(code, message, Base) {
              if (!Base) {
                Base = Error;
              }

              function getMessage(arg1, arg2, arg3) {
                if (typeof message === 'string') {
                  return message;
                } else {
                  return message(arg1, arg2, arg3);
                }
              }

              var NodeError =
              /*#__PURE__*/
              function (_Base) {
                _inheritsLoose(NodeError, _Base);

                function NodeError(arg1, arg2, arg3) {
                  return _Base.call(this, getMessage(arg1, arg2, arg3)) || this;
                }

                return NodeError;
              }(Base);

              NodeError.prototype.name = Base.name;
              NodeError.prototype.code = code;
              codes[code] = NodeError;
            } // https://github.com/nodejs/node/blob/v10.8.0/lib/internal/errors.js


            function oneOf(expected, thing) {
              if (Array.isArray(expected)) {
                var len = expected.length;
                expected = expected.map(function (i) {
                  return String(i);
                });

                if (len > 2) {
                  return "one of ".concat(thing, " ").concat(expected.slice(0, len - 1).join(', '), ", or ") + expected[len - 1];
                } else if (len === 2) {
                  return "one of ".concat(thing, " ").concat(expected[0], " or ").concat(expected[1]);
                } else {
                  return "of ".concat(thing, " ").concat(expected[0]);
                }
              } else {
                return "of ".concat(thing, " ").concat(String(expected));
              }
            } // https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String/startsWith


            function startsWith(str, search, pos) {
              return str.substr(!pos || pos < 0 ? 0 : +pos, search.length) === search;
            } // https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String/endsWith


            function endsWith(str, search, this_len) {
              if (this_len === undefined || this_len > str.length) {
                this_len = str.length;
              }

              return str.substring(this_len - search.length, this_len) === search;
            } // https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/String/includes


            function includes(str, search, start) {
              if (typeof start !== 'number') {
                start = 0;
              }

              if (start + search.length > str.length) {
                return false;
              } else {
                return str.indexOf(search, start) !== -1;
              }
            }

            createErrorType('ERR_INVALID_OPT_VALUE', function (name, value) {
              return 'The value "' + value + '" is invalid for option "' + name + '"';
            }, TypeError);
            createErrorType('ERR_INVALID_ARG_TYPE', function (name, expected, actual) {
              // determiner: 'must be' or 'must not be'
              var determiner;

              if (typeof expected === 'string' && startsWith(expected, 'not ')) {
                determiner = 'must not be';
                expected = expected.replace(/^not /, '');
              } else {
                determiner = 'must be';
              }

              var msg;

              if (endsWith(name, ' argument')) {
                // For cases like 'first argument'
                msg = "The ".concat(name, " ").concat(determiner, " ").concat(oneOf(expected, 'type'));
              } else {
                var type = includes(name, '.') ? 'property' : 'argument';
                msg = "The \"".concat(name, "\" ").concat(type, " ").concat(determiner, " ").concat(oneOf(expected, 'type'));
              }

              msg += ". Received type ".concat(typeof actual);
              return msg;
            }, TypeError);
            createErrorType('ERR_STREAM_PUSH_AFTER_EOF', 'stream.push() after EOF');
            createErrorType('ERR_METHOD_NOT_IMPLEMENTED', function (name) {
              return 'The ' + name + ' method is not implemented';
            });
            createErrorType('ERR_STREAM_PREMATURE_CLOSE', 'Premature close');
            createErrorType('ERR_STREAM_DESTROYED', function (name) {
              return 'Cannot call ' + name + ' after a stream was destroyed';
            });
            createErrorType('ERR_MULTIPLE_CALLBACK', 'Callback called multiple times');
            createErrorType('ERR_STREAM_CANNOT_PIPE', 'Cannot pipe, not readable');
            createErrorType('ERR_STREAM_WRITE_AFTER_END', 'write after end');
            createErrorType('ERR_STREAM_NULL_VALUES', 'May not write null values to stream', TypeError);
            createErrorType('ERR_UNKNOWN_ENCODING', function (arg) {
              return 'Unknown encoding: ' + arg;
            }, TypeError);
            createErrorType('ERR_STREAM_UNSHIFT_AFTER_END_EVENT', 'stream.unshift() after end event');
            var codes_1 = codes;

            var errorsBrowser = {
            	codes: codes_1
            };

            var ERR_INVALID_OPT_VALUE = errorsBrowser.codes.ERR_INVALID_OPT_VALUE;

            function highWaterMarkFrom(options, isDuplex, duplexKey) {
              return options.highWaterMark != null ? options.highWaterMark : isDuplex ? options[duplexKey] : null;
            }

            function getHighWaterMark(state, options, duplexKey, isDuplex) {
              var hwm = highWaterMarkFrom(options, isDuplex, duplexKey);

              if (hwm != null) {
                if (!(isFinite(hwm) && Math.floor(hwm) === hwm) || hwm < 0) {
                  var name = isDuplex ? duplexKey : 'highWaterMark';
                  throw new ERR_INVALID_OPT_VALUE(name, hwm);
                }

                return Math.floor(hwm);
              } // Default value


              return state.objectMode ? 16 : 16 * 1024;
            }

            var state = {
              getHighWaterMark: getHighWaterMark
            };

            /**
             * Module exports.
             */

            var browser$1 = deprecate$1;

            /**
             * Mark that a method should not be used.
             * Returns a modified function which warns once by default.
             *
             * If `localStorage.noDeprecation = true` is set, then it is a no-op.
             *
             * If `localStorage.throwDeprecation = true` is set, then deprecated functions
             * will throw an Error when invoked.
             *
             * If `localStorage.traceDeprecation = true` is set, then deprecated functions
             * will invoke `console.trace()` instead of `console.error()`.
             *
             * @param {Function} fn - the function to deprecate
             * @param {String} msg - the string to print to the console when `fn` is invoked
             * @returns {Function} a new "deprecated" version of `fn`
             * @api public
             */

            function deprecate$1 (fn, msg) {
              if (config$1('noDeprecation')) {
                return fn;
              }

              var warned = false;
              function deprecated() {
                if (!warned) {
                  if (config$1('throwDeprecation')) {
                    throw new Error(msg);
                  } else if (config$1('traceDeprecation')) {
                    console.trace(msg);
                  } else {
                    console.warn(msg);
                  }
                  warned = true;
                }
                return fn.apply(this, arguments);
              }

              return deprecated;
            }

            /**
             * Checks `localStorage` for boolean values for the given `name`.
             *
             * @param {String} name
             * @returns {Boolean}
             * @api private
             */

            function config$1 (name) {
              // accessing global.localStorage can trigger a DOMException in sandboxed iframes
              try {
                if (!commonjsGlobal$1.localStorage) return false;
              } catch (_) {
                return false;
              }
              var val = commonjsGlobal$1.localStorage[name];
              if (null == val) return false;
              return String(val).toLowerCase() === 'true';
            }

            var _stream_writable = Writable;
            // there will be only 2 of these for each stream


            function CorkedRequest(state) {
              var _this = this;

              this.next = null;
              this.entry = null;

              this.finish = function () {
                onCorkedFinish(_this, state);
              };
            }
            /* </replacement> */

            /*<replacement>*/


            var Duplex;
            /*</replacement>*/

            Writable.WritableState = WritableState;
            /*<replacement>*/

            var internalUtil = {
              deprecate: browser$1
            };
            /*</replacement>*/

            /*<replacement>*/


            /*</replacement>*/


            var Buffer$2 = bufferEs6.Buffer;

            var OurUint8Array = commonjsGlobal$1.Uint8Array || function () {};

            function _uint8ArrayToBuffer(chunk) {
              return Buffer$2.from(chunk);
            }

            function _isUint8Array(obj) {
              return Buffer$2.isBuffer(obj) || obj instanceof OurUint8Array;
            }



            var getHighWaterMark$1 = state.getHighWaterMark;

            var _require$codes = errorsBrowser.codes,
                ERR_INVALID_ARG_TYPE = _require$codes.ERR_INVALID_ARG_TYPE,
                ERR_METHOD_NOT_IMPLEMENTED = _require$codes.ERR_METHOD_NOT_IMPLEMENTED,
                ERR_MULTIPLE_CALLBACK = _require$codes.ERR_MULTIPLE_CALLBACK,
                ERR_STREAM_CANNOT_PIPE = _require$codes.ERR_STREAM_CANNOT_PIPE,
                ERR_STREAM_DESTROYED = _require$codes.ERR_STREAM_DESTROYED,
                ERR_STREAM_NULL_VALUES = _require$codes.ERR_STREAM_NULL_VALUES,
                ERR_STREAM_WRITE_AFTER_END = _require$codes.ERR_STREAM_WRITE_AFTER_END,
                ERR_UNKNOWN_ENCODING = _require$codes.ERR_UNKNOWN_ENCODING;

            var errorOrDestroy$1 = destroy_1.errorOrDestroy;

            inherits_browser(Writable, streamBrowser);

            function nop() {}

            function WritableState(options, stream, isDuplex) {
              Duplex = Duplex || _stream_duplex;
              options = options || {}; // Duplex streams are both readable and writable, but share
              // the same options object.
              // However, some cases require setting options to different
              // values for the readable and the writable sides of the duplex stream,
              // e.g. options.readableObjectMode vs. options.writableObjectMode, etc.

              if (typeof isDuplex !== 'boolean') isDuplex = stream instanceof Duplex; // object stream flag to indicate whether or not this stream
              // contains buffers or objects.

              this.objectMode = !!options.objectMode;
              if (isDuplex) this.objectMode = this.objectMode || !!options.writableObjectMode; // the point at which write() starts returning false
              // Note: 0 is a valid value, means that we always return false if
              // the entire buffer is not flushed immediately on write()

              this.highWaterMark = getHighWaterMark$1(this, options, 'writableHighWaterMark', isDuplex); // if _final has been called

              this.finalCalled = false; // drain event flag.

              this.needDrain = false; // at the start of calling end()

              this.ending = false; // when end() has been called, and returned

              this.ended = false; // when 'finish' is emitted

              this.finished = false; // has it been destroyed

              this.destroyed = false; // should we decode strings into buffers before passing to _write?
              // this is here so that some node-core streams can optimize string
              // handling at a lower level.

              var noDecode = options.decodeStrings === false;
              this.decodeStrings = !noDecode; // Crypto is kind of old and crusty.  Historically, its default string
              // encoding is 'binary' so we have to make this configurable.
              // Everything else in the universe uses 'utf8', though.

              this.defaultEncoding = options.defaultEncoding || 'utf8'; // not an actual buffer we keep track of, but a measurement
              // of how much we're waiting to get pushed to some underlying
              // socket or file.

              this.length = 0; // a flag to see when we're in the middle of a write.

              this.writing = false; // when true all writes will be buffered until .uncork() call

              this.corked = 0; // a flag to be able to tell if the onwrite cb is called immediately,
              // or on a later tick.  We set this to true at first, because any
              // actions that shouldn't happen until "later" should generally also
              // not happen before the first write call.

              this.sync = true; // a flag to know if we're processing previously buffered items, which
              // may call the _write() callback in the same tick, so that we don't
              // end up in an overlapped onwrite situation.

              this.bufferProcessing = false; // the callback that's passed to _write(chunk,cb)

              this.onwrite = function (er) {
                onwrite(stream, er);
              }; // the callback that the user supplies to write(chunk,encoding,cb)


              this.writecb = null; // the amount that is being written when _write is called.

              this.writelen = 0;
              this.bufferedRequest = null;
              this.lastBufferedRequest = null; // number of pending user-supplied write callbacks
              // this must be 0 before 'finish' can be emitted

              this.pendingcb = 0; // emit prefinish if the only thing we're waiting for is _write cbs
              // This is relevant for synchronous Transform streams

              this.prefinished = false; // True if the error was already emitted and should not be thrown again

              this.errorEmitted = false; // Should close be emitted on destroy. Defaults to true.

              this.emitClose = options.emitClose !== false; // Should .destroy() be called after 'finish' (and potentially 'end')

              this.autoDestroy = !!options.autoDestroy; // count buffered requests

              this.bufferedRequestCount = 0; // allocate the first CorkedRequest, there is always
              // one allocated and free to use, and we maintain at most two

              this.corkedRequestsFree = new CorkedRequest(this);
            }

            WritableState.prototype.getBuffer = function getBuffer() {
              var current = this.bufferedRequest;
              var out = [];

              while (current) {
                out.push(current);
                current = current.next;
              }

              return out;
            };

            (function () {
              try {
                Object.defineProperty(WritableState.prototype, 'buffer', {
                  get: internalUtil.deprecate(function writableStateBufferGetter() {
                    return this.getBuffer();
                  }, '_writableState.buffer is deprecated. Use _writableState.getBuffer ' + 'instead.', 'DEP0003')
                });
              } catch (_) {}
            })(); // Test _writableState for inheritance to account for Duplex streams,
            // whose prototype chain only points to Readable.


            var realHasInstance;

            if (typeof Symbol === 'function' && Symbol.hasInstance && typeof Function.prototype[Symbol.hasInstance] === 'function') {
              realHasInstance = Function.prototype[Symbol.hasInstance];
              Object.defineProperty(Writable, Symbol.hasInstance, {
                value: function value(object) {
                  if (realHasInstance.call(this, object)) return true;
                  if (this !== Writable) return false;
                  return object && object._writableState instanceof WritableState;
                }
              });
            } else {
              realHasInstance = function realHasInstance(object) {
                return object instanceof this;
              };
            }

            function Writable(options) {
              Duplex = Duplex || _stream_duplex; // Writable ctor is applied to Duplexes, too.
              // `realHasInstance` is necessary because using plain `instanceof`
              // would return false, as no `_writableState` property is attached.
              // Trying to use the custom `instanceof` for Writable here will also break the
              // Node.js LazyTransform implementation, which has a non-trivial getter for
              // `_writableState` that would lead to infinite recursion.
              // Checking for a Stream.Duplex instance is faster here instead of inside
              // the WritableState constructor, at least with V8 6.5

              var isDuplex = this instanceof Duplex;
              if (!isDuplex && !realHasInstance.call(Writable, this)) return new Writable(options);
              this._writableState = new WritableState(options, this, isDuplex); // legacy.

              this.writable = true;

              if (options) {
                if (typeof options.write === 'function') this._write = options.write;
                if (typeof options.writev === 'function') this._writev = options.writev;
                if (typeof options.destroy === 'function') this._destroy = options.destroy;
                if (typeof options.final === 'function') this._final = options.final;
              }

              streamBrowser.call(this);
            } // Otherwise people can pipe Writable streams, which is just wrong.


            Writable.prototype.pipe = function () {
              errorOrDestroy$1(this, new ERR_STREAM_CANNOT_PIPE());
            };

            function writeAfterEnd(stream, cb) {
              var er = new ERR_STREAM_WRITE_AFTER_END(); // TODO: defer error events consistently everywhere, not just the cb

              errorOrDestroy$1(stream, er);
              nextTick(cb, er);
            } // Checks that a user-supplied chunk is valid, especially for the particular
            // mode the stream is in. Currently this means that `null` is never accepted
            // and undefined/non-string values are only allowed in object mode.


            function validChunk(stream, state, chunk, cb) {
              var er;

              if (chunk === null) {
                er = new ERR_STREAM_NULL_VALUES();
              } else if (typeof chunk !== 'string' && !state.objectMode) {
                er = new ERR_INVALID_ARG_TYPE('chunk', ['string', 'Buffer'], chunk);
              }

              if (er) {
                errorOrDestroy$1(stream, er);
                nextTick(cb, er);
                return false;
              }

              return true;
            }

            Writable.prototype.write = function (chunk, encoding, cb) {
              var state = this._writableState;
              var ret = false;

              var isBuf = !state.objectMode && _isUint8Array(chunk);

              if (isBuf && !Buffer$2.isBuffer(chunk)) {
                chunk = _uint8ArrayToBuffer(chunk);
              }

              if (typeof encoding === 'function') {
                cb = encoding;
                encoding = null;
              }

              if (isBuf) encoding = 'buffer';else if (!encoding) encoding = state.defaultEncoding;
              if (typeof cb !== 'function') cb = nop;
              if (state.ending) writeAfterEnd(this, cb);else if (isBuf || validChunk(this, state, chunk, cb)) {
                state.pendingcb++;
                ret = writeOrBuffer(this, state, isBuf, chunk, encoding, cb);
              }
              return ret;
            };

            Writable.prototype.cork = function () {
              this._writableState.corked++;
            };

            Writable.prototype.uncork = function () {
              var state = this._writableState;

              if (state.corked) {
                state.corked--;
                if (!state.writing && !state.corked && !state.bufferProcessing && state.bufferedRequest) clearBuffer(this, state);
              }
            };

            Writable.prototype.setDefaultEncoding = function setDefaultEncoding(encoding) {
              // node::ParseEncoding() requires lower case.
              if (typeof encoding === 'string') encoding = encoding.toLowerCase();
              if (!(['hex', 'utf8', 'utf-8', 'ascii', 'binary', 'base64', 'ucs2', 'ucs-2', 'utf16le', 'utf-16le', 'raw'].indexOf((encoding + '').toLowerCase()) > -1)) throw new ERR_UNKNOWN_ENCODING(encoding);
              this._writableState.defaultEncoding = encoding;
              return this;
            };

            Object.defineProperty(Writable.prototype, 'writableBuffer', {
              // making it explicit this property is not enumerable
              // because otherwise some prototype manipulation in
              // userland will fail
              enumerable: false,
              get: function get() {
                return this._writableState && this._writableState.getBuffer();
              }
            });

            function decodeChunk(state, chunk, encoding) {
              if (!state.objectMode && state.decodeStrings !== false && typeof chunk === 'string') {
                chunk = Buffer$2.from(chunk, encoding);
              }

              return chunk;
            }

            Object.defineProperty(Writable.prototype, 'writableHighWaterMark', {
              // making it explicit this property is not enumerable
              // because otherwise some prototype manipulation in
              // userland will fail
              enumerable: false,
              get: function get() {
                return this._writableState.highWaterMark;
              }
            }); // if we're already writing something, then just put this
            // in the queue, and wait our turn.  Otherwise, call _write
            // If we return false, then we need a drain event, so set that flag.

            function writeOrBuffer(stream, state, isBuf, chunk, encoding, cb) {
              if (!isBuf) {
                var newChunk = decodeChunk(state, chunk, encoding);

                if (chunk !== newChunk) {
                  isBuf = true;
                  encoding = 'buffer';
                  chunk = newChunk;
                }
              }

              var len = state.objectMode ? 1 : chunk.length;
              state.length += len;
              var ret = state.length < state.highWaterMark; // we must ensure that previous needDrain will not be reset to false.

              if (!ret) state.needDrain = true;

              if (state.writing || state.corked) {
                var last = state.lastBufferedRequest;
                state.lastBufferedRequest = {
                  chunk: chunk,
                  encoding: encoding,
                  isBuf: isBuf,
                  callback: cb,
                  next: null
                };

                if (last) {
                  last.next = state.lastBufferedRequest;
                } else {
                  state.bufferedRequest = state.lastBufferedRequest;
                }

                state.bufferedRequestCount += 1;
              } else {
                doWrite(stream, state, false, len, chunk, encoding, cb);
              }

              return ret;
            }

            function doWrite(stream, state, writev, len, chunk, encoding, cb) {
              state.writelen = len;
              state.writecb = cb;
              state.writing = true;
              state.sync = true;
              if (state.destroyed) state.onwrite(new ERR_STREAM_DESTROYED('write'));else if (writev) stream._writev(chunk, state.onwrite);else stream._write(chunk, encoding, state.onwrite);
              state.sync = false;
            }

            function onwriteError(stream, state, sync, er, cb) {
              --state.pendingcb;

              if (sync) {
                // defer the callback if we are being called synchronously
                // to avoid piling up things on the stack
                nextTick(cb, er); // this can emit finish, and it will always happen
                // after error

                nextTick(finishMaybe, stream, state);
                stream._writableState.errorEmitted = true;
                errorOrDestroy$1(stream, er);
              } else {
                // the caller expect this to happen before if
                // it is async
                cb(er);
                stream._writableState.errorEmitted = true;
                errorOrDestroy$1(stream, er); // this can emit finish, but finish must
                // always follow error

                finishMaybe(stream, state);
              }
            }

            function onwriteStateUpdate(state) {
              state.writing = false;
              state.writecb = null;
              state.length -= state.writelen;
              state.writelen = 0;
            }

            function onwrite(stream, er) {
              var state = stream._writableState;
              var sync = state.sync;
              var cb = state.writecb;
              if (typeof cb !== 'function') throw new ERR_MULTIPLE_CALLBACK();
              onwriteStateUpdate(state);
              if (er) onwriteError(stream, state, sync, er, cb);else {
                // Check if we're actually ready to finish, but don't emit yet
                var finished = needFinish(state) || stream.destroyed;

                if (!finished && !state.corked && !state.bufferProcessing && state.bufferedRequest) {
                  clearBuffer(stream, state);
                }

                if (sync) {
                  nextTick(afterWrite, stream, state, finished, cb);
                } else {
                  afterWrite(stream, state, finished, cb);
                }
              }
            }

            function afterWrite(stream, state, finished, cb) {
              if (!finished) onwriteDrain(stream, state);
              state.pendingcb--;
              cb();
              finishMaybe(stream, state);
            } // Must force callback to be called on nextTick, so that we don't
            // emit 'drain' before the write() consumer gets the 'false' return
            // value, and has a chance to attach a 'drain' listener.


            function onwriteDrain(stream, state) {
              if (state.length === 0 && state.needDrain) {
                state.needDrain = false;
                stream.emit('drain');
              }
            } // if there's something in the buffer waiting, then process it


            function clearBuffer(stream, state) {
              state.bufferProcessing = true;
              var entry = state.bufferedRequest;

              if (stream._writev && entry && entry.next) {
                // Fast case, write everything using _writev()
                var l = state.bufferedRequestCount;
                var buffer = new Array(l);
                var holder = state.corkedRequestsFree;
                holder.entry = entry;
                var count = 0;
                var allBuffers = true;

                while (entry) {
                  buffer[count] = entry;
                  if (!entry.isBuf) allBuffers = false;
                  entry = entry.next;
                  count += 1;
                }

                buffer.allBuffers = allBuffers;
                doWrite(stream, state, true, state.length, buffer, '', holder.finish); // doWrite is almost always async, defer these to save a bit of time
                // as the hot path ends with doWrite

                state.pendingcb++;
                state.lastBufferedRequest = null;

                if (holder.next) {
                  state.corkedRequestsFree = holder.next;
                  holder.next = null;
                } else {
                  state.corkedRequestsFree = new CorkedRequest(state);
                }

                state.bufferedRequestCount = 0;
              } else {
                // Slow case, write chunks one-by-one
                while (entry) {
                  var chunk = entry.chunk;
                  var encoding = entry.encoding;
                  var cb = entry.callback;
                  var len = state.objectMode ? 1 : chunk.length;
                  doWrite(stream, state, false, len, chunk, encoding, cb);
                  entry = entry.next;
                  state.bufferedRequestCount--; // if we didn't call the onwrite immediately, then
                  // it means that we need to wait until it does.
                  // also, that means that the chunk and cb are currently
                  // being processed, so move the buffer counter past them.

                  if (state.writing) {
                    break;
                  }
                }

                if (entry === null) state.lastBufferedRequest = null;
              }

              state.bufferedRequest = entry;
              state.bufferProcessing = false;
            }

            Writable.prototype._write = function (chunk, encoding, cb) {
              cb(new ERR_METHOD_NOT_IMPLEMENTED('_write()'));
            };

            Writable.prototype._writev = null;

            Writable.prototype.end = function (chunk, encoding, cb) {
              var state = this._writableState;

              if (typeof chunk === 'function') {
                cb = chunk;
                chunk = null;
                encoding = null;
              } else if (typeof encoding === 'function') {
                cb = encoding;
                encoding = null;
              }

              if (chunk !== null && chunk !== undefined) this.write(chunk, encoding); // .end() fully uncorks

              if (state.corked) {
                state.corked = 1;
                this.uncork();
              } // ignore unnecessary end() calls.


              if (!state.ending) endWritable(this, state, cb);
              return this;
            };

            Object.defineProperty(Writable.prototype, 'writableLength', {
              // making it explicit this property is not enumerable
              // because otherwise some prototype manipulation in
              // userland will fail
              enumerable: false,
              get: function get() {
                return this._writableState.length;
              }
            });

            function needFinish(state) {
              return state.ending && state.length === 0 && state.bufferedRequest === null && !state.finished && !state.writing;
            }

            function callFinal(stream, state) {
              stream._final(function (err) {
                state.pendingcb--;

                if (err) {
                  errorOrDestroy$1(stream, err);
                }

                state.prefinished = true;
                stream.emit('prefinish');
                finishMaybe(stream, state);
              });
            }

            function prefinish(stream, state) {
              if (!state.prefinished && !state.finalCalled) {
                if (typeof stream._final === 'function' && !state.destroyed) {
                  state.pendingcb++;
                  state.finalCalled = true;
                  nextTick(callFinal, stream, state);
                } else {
                  state.prefinished = true;
                  stream.emit('prefinish');
                }
              }
            }

            function finishMaybe(stream, state) {
              var need = needFinish(state);

              if (need) {
                prefinish(stream, state);

                if (state.pendingcb === 0) {
                  state.finished = true;
                  stream.emit('finish');

                  if (state.autoDestroy) {
                    // In case of duplex streams we need a way to detect
                    // if the readable side is ready for autoDestroy as well
                    var rState = stream._readableState;

                    if (!rState || rState.autoDestroy && rState.endEmitted) {
                      stream.destroy();
                    }
                  }
                }
              }

              return need;
            }

            function endWritable(stream, state, cb) {
              state.ending = true;
              finishMaybe(stream, state);

              if (cb) {
                if (state.finished) nextTick(cb);else stream.once('finish', cb);
              }

              state.ended = true;
              stream.writable = false;
            }

            function onCorkedFinish(corkReq, state, err) {
              var entry = corkReq.entry;
              corkReq.entry = null;

              while (entry) {
                var cb = entry.callback;
                state.pendingcb--;
                cb(err);
                entry = entry.next;
              } // reuse the free corkReq.


              state.corkedRequestsFree.next = corkReq;
            }

            Object.defineProperty(Writable.prototype, 'destroyed', {
              // making it explicit this property is not enumerable
              // because otherwise some prototype manipulation in
              // userland will fail
              enumerable: false,
              get: function get() {
                if (this._writableState === undefined) {
                  return false;
                }

                return this._writableState.destroyed;
              },
              set: function set(value) {
                // we ignore the value if the stream
                // has not been initialized yet
                if (!this._writableState) {
                  return;
                } // backward compatibility, the user is explicitly
                // managing destroyed


                this._writableState.destroyed = value;
              }
            });
            Writable.prototype.destroy = destroy_1.destroy;
            Writable.prototype._undestroy = destroy_1.undestroy;

            Writable.prototype._destroy = function (err, cb) {
              cb(err);
            };

            /*<replacement>*/

            var objectKeys = Object.keys || function (obj) {
              var keys = [];

              for (var key in obj) {
                keys.push(key);
              }

              return keys;
            };
            /*</replacement>*/


            var _stream_duplex = Duplex$1;





            inherits_browser(Duplex$1, _stream_readable);

            {
              // Allow the keys array to be GC'ed.
              var keys = objectKeys(_stream_writable.prototype);

              for (var v$1 = 0; v$1 < keys.length; v$1++) {
                var method = keys[v$1];
                if (!Duplex$1.prototype[method]) Duplex$1.prototype[method] = _stream_writable.prototype[method];
              }
            }

            function Duplex$1(options) {
              if (!(this instanceof Duplex$1)) return new Duplex$1(options);
              _stream_readable.call(this, options);
              _stream_writable.call(this, options);
              this.allowHalfOpen = true;

              if (options) {
                if (options.readable === false) this.readable = false;
                if (options.writable === false) this.writable = false;

                if (options.allowHalfOpen === false) {
                  this.allowHalfOpen = false;
                  this.once('end', onend);
                }
              }
            }

            Object.defineProperty(Duplex$1.prototype, 'writableHighWaterMark', {
              // making it explicit this property is not enumerable
              // because otherwise some prototype manipulation in
              // userland will fail
              enumerable: false,
              get: function get() {
                return this._writableState.highWaterMark;
              }
            });
            Object.defineProperty(Duplex$1.prototype, 'writableBuffer', {
              // making it explicit this property is not enumerable
              // because otherwise some prototype manipulation in
              // userland will fail
              enumerable: false,
              get: function get() {
                return this._writableState && this._writableState.getBuffer();
              }
            });
            Object.defineProperty(Duplex$1.prototype, 'writableLength', {
              // making it explicit this property is not enumerable
              // because otherwise some prototype manipulation in
              // userland will fail
              enumerable: false,
              get: function get() {
                return this._writableState.length;
              }
            }); // the no-half-open enforcer

            function onend() {
              // If the writable side ended, then we're ok.
              if (this._writableState.ended) return; // no more data can be written.
              // But allow more writes to happen in this tick.

              nextTick(onEndNT, this);
            }

            function onEndNT(self) {
              self.end();
            }

            Object.defineProperty(Duplex$1.prototype, 'destroyed', {
              // making it explicit this property is not enumerable
              // because otherwise some prototype manipulation in
              // userland will fail
              enumerable: false,
              get: function get() {
                if (this._readableState === undefined || this._writableState === undefined) {
                  return false;
                }

                return this._readableState.destroyed && this._writableState.destroyed;
              },
              set: function set(value) {
                // we ignore the value if the stream
                // has not been initialized yet
                if (this._readableState === undefined || this._writableState === undefined) {
                  return;
                } // backward compatibility, the user is explicitly
                // managing destroyed


                this._readableState.destroyed = value;
                this._writableState.destroyed = value;
              }
            });

            var safeBuffer = createCommonjsModule$1(function (module, exports) {
            /* eslint-disable node/no-deprecated-api */

            var Buffer = bufferEs6.Buffer;

            // alternative to using Object.keys for old browsers
            function copyProps (src, dst) {
              for (var key in src) {
                dst[key] = src[key];
              }
            }
            if (Buffer.from && Buffer.alloc && Buffer.allocUnsafe && Buffer.allocUnsafeSlow) {
              module.exports = bufferEs6;
            } else {
              // Copy properties from require('buffer')
              copyProps(bufferEs6, exports);
              exports.Buffer = SafeBuffer;
            }

            function SafeBuffer (arg, encodingOrOffset, length) {
              return Buffer(arg, encodingOrOffset, length)
            }

            SafeBuffer.prototype = Object.create(Buffer.prototype);

            // Copy static methods from Buffer
            copyProps(Buffer, SafeBuffer);

            SafeBuffer.from = function (arg, encodingOrOffset, length) {
              if (typeof arg === 'number') {
                throw new TypeError('Argument must not be a number')
              }
              return Buffer(arg, encodingOrOffset, length)
            };

            SafeBuffer.alloc = function (size, fill, encoding) {
              if (typeof size !== 'number') {
                throw new TypeError('Argument must be a number')
              }
              var buf = Buffer(size);
              if (fill !== undefined) {
                if (typeof encoding === 'string') {
                  buf.fill(fill, encoding);
                } else {
                  buf.fill(fill);
                }
              } else {
                buf.fill(0);
              }
              return buf
            };

            SafeBuffer.allocUnsafe = function (size) {
              if (typeof size !== 'number') {
                throw new TypeError('Argument must be a number')
              }
              return Buffer(size)
            };

            SafeBuffer.allocUnsafeSlow = function (size) {
              if (typeof size !== 'number') {
                throw new TypeError('Argument must be a number')
              }
              return bufferEs6.SlowBuffer(size)
            };
            });
            var safeBuffer_1 = safeBuffer.Buffer;

            /*<replacement>*/

            var Buffer$3 = safeBuffer.Buffer;
            /*</replacement>*/

            var isEncoding = Buffer$3.isEncoding || function (encoding) {
              encoding = '' + encoding;
              switch (encoding && encoding.toLowerCase()) {
                case 'hex':case 'utf8':case 'utf-8':case 'ascii':case 'binary':case 'base64':case 'ucs2':case 'ucs-2':case 'utf16le':case 'utf-16le':case 'raw':
                  return true;
                default:
                  return false;
              }
            };

            function _normalizeEncoding(enc) {
              if (!enc) return 'utf8';
              var retried;
              while (true) {
                switch (enc) {
                  case 'utf8':
                  case 'utf-8':
                    return 'utf8';
                  case 'ucs2':
                  case 'ucs-2':
                  case 'utf16le':
                  case 'utf-16le':
                    return 'utf16le';
                  case 'latin1':
                  case 'binary':
                    return 'latin1';
                  case 'base64':
                  case 'ascii':
                  case 'hex':
                    return enc;
                  default:
                    if (retried) return; // undefined
                    enc = ('' + enc).toLowerCase();
                    retried = true;
                }
              }
            }
            // Do not cache `Buffer.isEncoding` when checking encoding names as some
            // modules monkey-patch it to support additional encodings
            function normalizeEncoding(enc) {
              var nenc = _normalizeEncoding(enc);
              if (typeof nenc !== 'string' && (Buffer$3.isEncoding === isEncoding || !isEncoding(enc))) throw new Error('Unknown encoding: ' + enc);
              return nenc || enc;
            }

            // StringDecoder provides an interface for efficiently splitting a series of
            // buffers into a series of JS strings without breaking apart multi-byte
            // characters.
            var StringDecoder_1 = StringDecoder;
            function StringDecoder(encoding) {
              this.encoding = normalizeEncoding(encoding);
              var nb;
              switch (this.encoding) {
                case 'utf16le':
                  this.text = utf16Text;
                  this.end = utf16End;
                  nb = 4;
                  break;
                case 'utf8':
                  this.fillLast = utf8FillLast;
                  nb = 4;
                  break;
                case 'base64':
                  this.text = base64Text;
                  this.end = base64End;
                  nb = 3;
                  break;
                default:
                  this.write = simpleWrite;
                  this.end = simpleEnd;
                  return;
              }
              this.lastNeed = 0;
              this.lastTotal = 0;
              this.lastChar = Buffer$3.allocUnsafe(nb);
            }

            StringDecoder.prototype.write = function (buf) {
              if (buf.length === 0) return '';
              var r;
              var i;
              if (this.lastNeed) {
                r = this.fillLast(buf);
                if (r === undefined) return '';
                i = this.lastNeed;
                this.lastNeed = 0;
              } else {
                i = 0;
              }
              if (i < buf.length) return r ? r + this.text(buf, i) : this.text(buf, i);
              return r || '';
            };

            StringDecoder.prototype.end = utf8End;

            // Returns only complete characters in a Buffer
            StringDecoder.prototype.text = utf8Text;

            // Attempts to complete a partial non-UTF-8 character using bytes from a Buffer
            StringDecoder.prototype.fillLast = function (buf) {
              if (this.lastNeed <= buf.length) {
                buf.copy(this.lastChar, this.lastTotal - this.lastNeed, 0, this.lastNeed);
                return this.lastChar.toString(this.encoding, 0, this.lastTotal);
              }
              buf.copy(this.lastChar, this.lastTotal - this.lastNeed, 0, buf.length);
              this.lastNeed -= buf.length;
            };

            // Checks the type of a UTF-8 byte, whether it's ASCII, a leading byte, or a
            // continuation byte. If an invalid byte is detected, -2 is returned.
            function utf8CheckByte(byte) {
              if (byte <= 0x7F) return 0;else if (byte >> 5 === 0x06) return 2;else if (byte >> 4 === 0x0E) return 3;else if (byte >> 3 === 0x1E) return 4;
              return byte >> 6 === 0x02 ? -1 : -2;
            }

            // Checks at most 3 bytes at the end of a Buffer in order to detect an
            // incomplete multi-byte UTF-8 character. The total number of bytes (2, 3, or 4)
            // needed to complete the UTF-8 character (if applicable) are returned.
            function utf8CheckIncomplete(self, buf, i) {
              var j = buf.length - 1;
              if (j < i) return 0;
              var nb = utf8CheckByte(buf[j]);
              if (nb >= 0) {
                if (nb > 0) self.lastNeed = nb - 1;
                return nb;
              }
              if (--j < i || nb === -2) return 0;
              nb = utf8CheckByte(buf[j]);
              if (nb >= 0) {
                if (nb > 0) self.lastNeed = nb - 2;
                return nb;
              }
              if (--j < i || nb === -2) return 0;
              nb = utf8CheckByte(buf[j]);
              if (nb >= 0) {
                if (nb > 0) {
                  if (nb === 2) nb = 0;else self.lastNeed = nb - 3;
                }
                return nb;
              }
              return 0;
            }

            // Validates as many continuation bytes for a multi-byte UTF-8 character as
            // needed or are available. If we see a non-continuation byte where we expect
            // one, we "replace" the validated continuation bytes we've seen so far with
            // a single UTF-8 replacement character ('\ufffd'), to match v8's UTF-8 decoding
            // behavior. The continuation byte check is included three times in the case
            // where all of the continuation bytes for a character exist in the same buffer.
            // It is also done this way as a slight performance increase instead of using a
            // loop.
            function utf8CheckExtraBytes(self, buf, p) {
              if ((buf[0] & 0xC0) !== 0x80) {
                self.lastNeed = 0;
                return '\ufffd';
              }
              if (self.lastNeed > 1 && buf.length > 1) {
                if ((buf[1] & 0xC0) !== 0x80) {
                  self.lastNeed = 1;
                  return '\ufffd';
                }
                if (self.lastNeed > 2 && buf.length > 2) {
                  if ((buf[2] & 0xC0) !== 0x80) {
                    self.lastNeed = 2;
                    return '\ufffd';
                  }
                }
              }
            }

            // Attempts to complete a multi-byte UTF-8 character using bytes from a Buffer.
            function utf8FillLast(buf) {
              var p = this.lastTotal - this.lastNeed;
              var r = utf8CheckExtraBytes(this, buf);
              if (r !== undefined) return r;
              if (this.lastNeed <= buf.length) {
                buf.copy(this.lastChar, p, 0, this.lastNeed);
                return this.lastChar.toString(this.encoding, 0, this.lastTotal);
              }
              buf.copy(this.lastChar, p, 0, buf.length);
              this.lastNeed -= buf.length;
            }

            // Returns all complete UTF-8 characters in a Buffer. If the Buffer ended on a
            // partial character, the character's bytes are buffered until the required
            // number of bytes are available.
            function utf8Text(buf, i) {
              var total = utf8CheckIncomplete(this, buf, i);
              if (!this.lastNeed) return buf.toString('utf8', i);
              this.lastTotal = total;
              var end = buf.length - (total - this.lastNeed);
              buf.copy(this.lastChar, 0, end);
              return buf.toString('utf8', i, end);
            }

            // For UTF-8, a replacement character is added when ending on a partial
            // character.
            function utf8End(buf) {
              var r = buf && buf.length ? this.write(buf) : '';
              if (this.lastNeed) return r + '\ufffd';
              return r;
            }

            // UTF-16LE typically needs two bytes per character, but even if we have an even
            // number of bytes available, we need to check if we end on a leading/high
            // surrogate. In that case, we need to wait for the next two bytes in order to
            // decode the last character properly.
            function utf16Text(buf, i) {
              if ((buf.length - i) % 2 === 0) {
                var r = buf.toString('utf16le', i);
                if (r) {
                  var c = r.charCodeAt(r.length - 1);
                  if (c >= 0xD800 && c <= 0xDBFF) {
                    this.lastNeed = 2;
                    this.lastTotal = 4;
                    this.lastChar[0] = buf[buf.length - 2];
                    this.lastChar[1] = buf[buf.length - 1];
                    return r.slice(0, -1);
                  }
                }
                return r;
              }
              this.lastNeed = 1;
              this.lastTotal = 2;
              this.lastChar[0] = buf[buf.length - 1];
              return buf.toString('utf16le', i, buf.length - 1);
            }

            // For UTF-16LE we do not explicitly append special replacement characters if we
            // end on a partial character, we simply let v8 handle that.
            function utf16End(buf) {
              var r = buf && buf.length ? this.write(buf) : '';
              if (this.lastNeed) {
                var end = this.lastTotal - this.lastNeed;
                return r + this.lastChar.toString('utf16le', 0, end);
              }
              return r;
            }

            function base64Text(buf, i) {
              var n = (buf.length - i) % 3;
              if (n === 0) return buf.toString('base64', i);
              this.lastNeed = 3 - n;
              this.lastTotal = 3;
              if (n === 1) {
                this.lastChar[0] = buf[buf.length - 1];
              } else {
                this.lastChar[0] = buf[buf.length - 2];
                this.lastChar[1] = buf[buf.length - 1];
              }
              return buf.toString('base64', i, buf.length - n);
            }

            function base64End(buf) {
              var r = buf && buf.length ? this.write(buf) : '';
              if (this.lastNeed) return r + this.lastChar.toString('base64', 0, 3 - this.lastNeed);
              return r;
            }

            // Pass bytes on through for single-byte encodings (e.g. ascii, latin1, hex)
            function simpleWrite(buf) {
              return buf.toString(this.encoding);
            }

            function simpleEnd(buf) {
              return buf && buf.length ? this.write(buf) : '';
            }

            var string_decoder = {
            	StringDecoder: StringDecoder_1
            };

            var ERR_STREAM_PREMATURE_CLOSE = errorsBrowser.codes.ERR_STREAM_PREMATURE_CLOSE;

            function once$1(callback) {
              var called = false;
              return function () {
                if (called) return;
                called = true;

                for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
                  args[_key] = arguments[_key];
                }

                callback.apply(this, args);
              };
            }

            function noop$1() {}

            function isRequest(stream) {
              return stream.setHeader && typeof stream.abort === 'function';
            }

            function eos(stream, opts, callback) {
              if (typeof opts === 'function') return eos(stream, null, opts);
              if (!opts) opts = {};
              callback = once$1(callback || noop$1);
              var readable = opts.readable || opts.readable !== false && stream.readable;
              var writable = opts.writable || opts.writable !== false && stream.writable;

              var onlegacyfinish = function onlegacyfinish() {
                if (!stream.writable) onfinish();
              };

              var writableEnded = stream._writableState && stream._writableState.finished;

              var onfinish = function onfinish() {
                writable = false;
                writableEnded = true;
                if (!readable) callback.call(stream);
              };

              var readableEnded = stream._readableState && stream._readableState.endEmitted;

              var onend = function onend() {
                readable = false;
                readableEnded = true;
                if (!writable) callback.call(stream);
              };

              var onerror = function onerror(err) {
                callback.call(stream, err);
              };

              var onclose = function onclose() {
                var err;

                if (readable && !readableEnded) {
                  if (!stream._readableState || !stream._readableState.ended) err = new ERR_STREAM_PREMATURE_CLOSE();
                  return callback.call(stream, err);
                }

                if (writable && !writableEnded) {
                  if (!stream._writableState || !stream._writableState.ended) err = new ERR_STREAM_PREMATURE_CLOSE();
                  return callback.call(stream, err);
                }
              };

              var onrequest = function onrequest() {
                stream.req.on('finish', onfinish);
              };

              if (isRequest(stream)) {
                stream.on('complete', onfinish);
                stream.on('abort', onclose);
                if (stream.req) onrequest();else stream.on('request', onrequest);
              } else if (writable && !stream._writableState) {
                // legacy streams
                stream.on('end', onlegacyfinish);
                stream.on('close', onlegacyfinish);
              }

              stream.on('end', onend);
              stream.on('finish', onfinish);
              if (opts.error !== false) stream.on('error', onerror);
              stream.on('close', onclose);
              return function () {
                stream.removeListener('complete', onfinish);
                stream.removeListener('abort', onclose);
                stream.removeListener('request', onrequest);
                if (stream.req) stream.req.removeListener('finish', onfinish);
                stream.removeListener('end', onlegacyfinish);
                stream.removeListener('close', onlegacyfinish);
                stream.removeListener('finish', onfinish);
                stream.removeListener('end', onend);
                stream.removeListener('error', onerror);
                stream.removeListener('close', onclose);
              };
            }

            var endOfStream = eos;

            var _Object$setPrototypeO;

            function _defineProperty$1(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }



            var kLastResolve = Symbol('lastResolve');
            var kLastReject = Symbol('lastReject');
            var kError = Symbol('error');
            var kEnded = Symbol('ended');
            var kLastPromise = Symbol('lastPromise');
            var kHandlePromise = Symbol('handlePromise');
            var kStream = Symbol('stream');

            function createIterResult(value, done) {
              return {
                value: value,
                done: done
              };
            }

            function readAndResolve(iter) {
              var resolve = iter[kLastResolve];

              if (resolve !== null) {
                var data = iter[kStream].read(); // we defer if data is null
                // we can be expecting either 'end' or
                // 'error'

                if (data !== null) {
                  iter[kLastPromise] = null;
                  iter[kLastResolve] = null;
                  iter[kLastReject] = null;
                  resolve(createIterResult(data, false));
                }
              }
            }

            function onReadable(iter) {
              // we wait for the next tick, because it might
              // emit an error with process.nextTick
              nextTick(readAndResolve, iter);
            }

            function wrapForNext(lastPromise, iter) {
              return function (resolve, reject) {
                lastPromise.then(function () {
                  if (iter[kEnded]) {
                    resolve(createIterResult(undefined, true));
                    return;
                  }

                  iter[kHandlePromise](resolve, reject);
                }, reject);
              };
            }

            var AsyncIteratorPrototype = Object.getPrototypeOf(function () {});
            var ReadableStreamAsyncIteratorPrototype = Object.setPrototypeOf((_Object$setPrototypeO = {
              get stream() {
                return this[kStream];
              },

              next: function next() {
                var _this = this;

                // if we have detected an error in the meanwhile
                // reject straight away
                var error = this[kError];

                if (error !== null) {
                  return Promise.reject(error);
                }

                if (this[kEnded]) {
                  return Promise.resolve(createIterResult(undefined, true));
                }

                if (this[kStream].destroyed) {
                  // We need to defer via nextTick because if .destroy(err) is
                  // called, the error will be emitted via nextTick, and
                  // we cannot guarantee that there is no error lingering around
                  // waiting to be emitted.
                  return new Promise(function (resolve, reject) {
                    nextTick(function () {
                      if (_this[kError]) {
                        reject(_this[kError]);
                      } else {
                        resolve(createIterResult(undefined, true));
                      }
                    });
                  });
                } // if we have multiple next() calls
                // we will wait for the previous Promise to finish
                // this logic is optimized to support for await loops,
                // where next() is only called once at a time


                var lastPromise = this[kLastPromise];
                var promise;

                if (lastPromise) {
                  promise = new Promise(wrapForNext(lastPromise, this));
                } else {
                  // fast path needed to support multiple this.push()
                  // without triggering the next() queue
                  var data = this[kStream].read();

                  if (data !== null) {
                    return Promise.resolve(createIterResult(data, false));
                  }

                  promise = new Promise(this[kHandlePromise]);
                }

                this[kLastPromise] = promise;
                return promise;
              }
            }, _defineProperty$1(_Object$setPrototypeO, Symbol.asyncIterator, function () {
              return this;
            }), _defineProperty$1(_Object$setPrototypeO, "return", function _return() {
              var _this2 = this;

              // destroy(err, cb) is a private API
              // we can guarantee we have that here, because we control the
              // Readable class this is attached to
              return new Promise(function (resolve, reject) {
                _this2[kStream].destroy(null, function (err) {
                  if (err) {
                    reject(err);
                    return;
                  }

                  resolve(createIterResult(undefined, true));
                });
              });
            }), _Object$setPrototypeO), AsyncIteratorPrototype);

            var createReadableStreamAsyncIterator = function createReadableStreamAsyncIterator(stream) {
              var _Object$create;

              var iterator = Object.create(ReadableStreamAsyncIteratorPrototype, (_Object$create = {}, _defineProperty$1(_Object$create, kStream, {
                value: stream,
                writable: true
              }), _defineProperty$1(_Object$create, kLastResolve, {
                value: null,
                writable: true
              }), _defineProperty$1(_Object$create, kLastReject, {
                value: null,
                writable: true
              }), _defineProperty$1(_Object$create, kError, {
                value: null,
                writable: true
              }), _defineProperty$1(_Object$create, kEnded, {
                value: stream._readableState.endEmitted,
                writable: true
              }), _defineProperty$1(_Object$create, kHandlePromise, {
                value: function value(resolve, reject) {
                  var data = iterator[kStream].read();

                  if (data) {
                    iterator[kLastPromise] = null;
                    iterator[kLastResolve] = null;
                    iterator[kLastReject] = null;
                    resolve(createIterResult(data, false));
                  } else {
                    iterator[kLastResolve] = resolve;
                    iterator[kLastReject] = reject;
                  }
                },
                writable: true
              }), _Object$create));
              iterator[kLastPromise] = null;
              endOfStream(stream, function (err) {
                if (err && err.code !== 'ERR_STREAM_PREMATURE_CLOSE') {
                  var reject = iterator[kLastReject]; // reject if we are waiting for data in the Promise
                  // returned by next() and store the error

                  if (reject !== null) {
                    iterator[kLastPromise] = null;
                    iterator[kLastResolve] = null;
                    iterator[kLastReject] = null;
                    reject(err);
                  }

                  iterator[kError] = err;
                  return;
                }

                var resolve = iterator[kLastResolve];

                if (resolve !== null) {
                  iterator[kLastPromise] = null;
                  iterator[kLastResolve] = null;
                  iterator[kLastReject] = null;
                  resolve(createIterResult(undefined, true));
                }

                iterator[kEnded] = true;
              });
              stream.on('readable', onReadable.bind(null, iterator));
              return iterator;
            };

            var async_iterator = createReadableStreamAsyncIterator;

            var fromBrowser = function () {
              throw new Error('Readable.from is not available in the browser')
            };

            var _stream_readable = Readable;
            /*<replacement>*/

            var Duplex$2;
            /*</replacement>*/

            Readable.ReadableState = ReadableState;
            /*<replacement>*/

            var EE = require$$0.EventEmitter;

            var EElistenerCount = function EElistenerCount(emitter, type) {
              return emitter.listeners(type).length;
            };
            /*</replacement>*/

            /*<replacement>*/



            /*</replacement>*/


            var Buffer$4 = bufferEs6.Buffer;

            var OurUint8Array$1 = commonjsGlobal$1.Uint8Array || function () {};

            function _uint8ArrayToBuffer$1(chunk) {
              return Buffer$4.from(chunk);
            }

            function _isUint8Array$1(obj) {
              return Buffer$4.isBuffer(obj) || obj instanceof OurUint8Array$1;
            }
            /*<replacement>*/




            var debug;

            if (require$$0$1 && require$$0$1.debuglog) {
              debug = require$$0$1.debuglog('stream');
            } else {
              debug = function debug() {};
            }
            /*</replacement>*/






            var getHighWaterMark$2 = state.getHighWaterMark;

            var _require$codes$1 = errorsBrowser.codes,
                ERR_INVALID_ARG_TYPE$1 = _require$codes$1.ERR_INVALID_ARG_TYPE,
                ERR_STREAM_PUSH_AFTER_EOF = _require$codes$1.ERR_STREAM_PUSH_AFTER_EOF,
                ERR_METHOD_NOT_IMPLEMENTED$1 = _require$codes$1.ERR_METHOD_NOT_IMPLEMENTED,
                ERR_STREAM_UNSHIFT_AFTER_END_EVENT = _require$codes$1.ERR_STREAM_UNSHIFT_AFTER_END_EVENT; // Lazy loaded to improve the startup performance.


            var StringDecoder$1;
            var createReadableStreamAsyncIterator$1;
            var from$1;

            inherits_browser(Readable, streamBrowser);

            var errorOrDestroy$2 = destroy_1.errorOrDestroy;
            var kProxyEvents = ['error', 'close', 'destroy', 'pause', 'resume'];

            function prependListener(emitter, event, fn) {
              // Sadly this is not cacheable as some libraries bundle their own
              // event emitter implementation with them.
              if (typeof emitter.prependListener === 'function') return emitter.prependListener(event, fn); // This is a hack to make sure that our error handler is attached before any
              // userland ones.  NEVER DO THIS. This is here only because this code needs
              // to continue to work with older versions of Node.js that do not include
              // the prependListener() method. The goal is to eventually remove this hack.

              if (!emitter._events || !emitter._events[event]) emitter.on(event, fn);else if (Array.isArray(emitter._events[event])) emitter._events[event].unshift(fn);else emitter._events[event] = [fn, emitter._events[event]];
            }

            function ReadableState(options, stream, isDuplex) {
              Duplex$2 = Duplex$2 || _stream_duplex;
              options = options || {}; // Duplex streams are both readable and writable, but share
              // the same options object.
              // However, some cases require setting options to different
              // values for the readable and the writable sides of the duplex stream.
              // These options can be provided separately as readableXXX and writableXXX.

              if (typeof isDuplex !== 'boolean') isDuplex = stream instanceof Duplex$2; // object stream flag. Used to make read(n) ignore n and to
              // make all the buffer merging and length checks go away

              this.objectMode = !!options.objectMode;
              if (isDuplex) this.objectMode = this.objectMode || !!options.readableObjectMode; // the point at which it stops calling _read() to fill the buffer
              // Note: 0 is a valid value, means "don't call _read preemptively ever"

              this.highWaterMark = getHighWaterMark$2(this, options, 'readableHighWaterMark', isDuplex); // A linked list is used to store data chunks instead of an array because the
              // linked list can remove elements from the beginning faster than
              // array.shift()

              this.buffer = new buffer_list();
              this.length = 0;
              this.pipes = null;
              this.pipesCount = 0;
              this.flowing = null;
              this.ended = false;
              this.endEmitted = false;
              this.reading = false; // a flag to be able to tell if the event 'readable'/'data' is emitted
              // immediately, or on a later tick.  We set this to true at first, because
              // any actions that shouldn't happen until "later" should generally also
              // not happen before the first read call.

              this.sync = true; // whenever we return null, then we set a flag to say
              // that we're awaiting a 'readable' event emission.

              this.needReadable = false;
              this.emittedReadable = false;
              this.readableListening = false;
              this.resumeScheduled = false;
              this.paused = true; // Should close be emitted on destroy. Defaults to true.

              this.emitClose = options.emitClose !== false; // Should .destroy() be called after 'end' (and potentially 'finish')

              this.autoDestroy = !!options.autoDestroy; // has it been destroyed

              this.destroyed = false; // Crypto is kind of old and crusty.  Historically, its default string
              // encoding is 'binary' so we have to make this configurable.
              // Everything else in the universe uses 'utf8', though.

              this.defaultEncoding = options.defaultEncoding || 'utf8'; // the number of writers that are awaiting a drain event in .pipe()s

              this.awaitDrain = 0; // if true, a maybeReadMore has been scheduled

              this.readingMore = false;
              this.decoder = null;
              this.encoding = null;

              if (options.encoding) {
                if (!StringDecoder$1) StringDecoder$1 = string_decoder.StringDecoder;
                this.decoder = new StringDecoder$1(options.encoding);
                this.encoding = options.encoding;
              }
            }

            function Readable(options) {
              Duplex$2 = Duplex$2 || _stream_duplex;
              if (!(this instanceof Readable)) return new Readable(options); // Checking for a Stream.Duplex instance is faster here instead of inside
              // the ReadableState constructor, at least with V8 6.5

              var isDuplex = this instanceof Duplex$2;
              this._readableState = new ReadableState(options, this, isDuplex); // legacy

              this.readable = true;

              if (options) {
                if (typeof options.read === 'function') this._read = options.read;
                if (typeof options.destroy === 'function') this._destroy = options.destroy;
              }

              streamBrowser.call(this);
            }

            Object.defineProperty(Readable.prototype, 'destroyed', {
              // making it explicit this property is not enumerable
              // because otherwise some prototype manipulation in
              // userland will fail
              enumerable: false,
              get: function get() {
                if (this._readableState === undefined) {
                  return false;
                }

                return this._readableState.destroyed;
              },
              set: function set(value) {
                // we ignore the value if the stream
                // has not been initialized yet
                if (!this._readableState) {
                  return;
                } // backward compatibility, the user is explicitly
                // managing destroyed


                this._readableState.destroyed = value;
              }
            });
            Readable.prototype.destroy = destroy_1.destroy;
            Readable.prototype._undestroy = destroy_1.undestroy;

            Readable.prototype._destroy = function (err, cb) {
              cb(err);
            }; // Manually shove something into the read() buffer.
            // This returns true if the highWaterMark has not been hit yet,
            // similar to how Writable.write() returns true if you should
            // write() some more.


            Readable.prototype.push = function (chunk, encoding) {
              var state = this._readableState;
              var skipChunkCheck;

              if (!state.objectMode) {
                if (typeof chunk === 'string') {
                  encoding = encoding || state.defaultEncoding;

                  if (encoding !== state.encoding) {
                    chunk = Buffer$4.from(chunk, encoding);
                    encoding = '';
                  }

                  skipChunkCheck = true;
                }
              } else {
                skipChunkCheck = true;
              }

              return readableAddChunk(this, chunk, encoding, false, skipChunkCheck);
            }; // Unshift should *always* be something directly out of read()


            Readable.prototype.unshift = function (chunk) {
              return readableAddChunk(this, chunk, null, true, false);
            };

            function readableAddChunk(stream, chunk, encoding, addToFront, skipChunkCheck) {
              debug('readableAddChunk', chunk);
              var state = stream._readableState;

              if (chunk === null) {
                state.reading = false;
                onEofChunk(stream, state);
              } else {
                var er;
                if (!skipChunkCheck) er = chunkInvalid(state, chunk);

                if (er) {
                  errorOrDestroy$2(stream, er);
                } else if (state.objectMode || chunk && chunk.length > 0) {
                  if (typeof chunk !== 'string' && !state.objectMode && Object.getPrototypeOf(chunk) !== Buffer$4.prototype) {
                    chunk = _uint8ArrayToBuffer$1(chunk);
                  }

                  if (addToFront) {
                    if (state.endEmitted) errorOrDestroy$2(stream, new ERR_STREAM_UNSHIFT_AFTER_END_EVENT());else addChunk(stream, state, chunk, true);
                  } else if (state.ended) {
                    errorOrDestroy$2(stream, new ERR_STREAM_PUSH_AFTER_EOF());
                  } else if (state.destroyed) {
                    return false;
                  } else {
                    state.reading = false;

                    if (state.decoder && !encoding) {
                      chunk = state.decoder.write(chunk);
                      if (state.objectMode || chunk.length !== 0) addChunk(stream, state, chunk, false);else maybeReadMore(stream, state);
                    } else {
                      addChunk(stream, state, chunk, false);
                    }
                  }
                } else if (!addToFront) {
                  state.reading = false;
                  maybeReadMore(stream, state);
                }
              } // We can push more data if we are below the highWaterMark.
              // Also, if we have no data yet, we can stand some more bytes.
              // This is to work around cases where hwm=0, such as the repl.


              return !state.ended && (state.length < state.highWaterMark || state.length === 0);
            }

            function addChunk(stream, state, chunk, addToFront) {
              if (state.flowing && state.length === 0 && !state.sync) {
                state.awaitDrain = 0;
                stream.emit('data', chunk);
              } else {
                // update the buffer info.
                state.length += state.objectMode ? 1 : chunk.length;
                if (addToFront) state.buffer.unshift(chunk);else state.buffer.push(chunk);
                if (state.needReadable) emitReadable(stream);
              }

              maybeReadMore(stream, state);
            }

            function chunkInvalid(state, chunk) {
              var er;

              if (!_isUint8Array$1(chunk) && typeof chunk !== 'string' && chunk !== undefined && !state.objectMode) {
                er = new ERR_INVALID_ARG_TYPE$1('chunk', ['string', 'Buffer', 'Uint8Array'], chunk);
              }

              return er;
            }

            Readable.prototype.isPaused = function () {
              return this._readableState.flowing === false;
            }; // backwards compatibility.


            Readable.prototype.setEncoding = function (enc) {
              if (!StringDecoder$1) StringDecoder$1 = string_decoder.StringDecoder;
              var decoder = new StringDecoder$1(enc);
              this._readableState.decoder = decoder; // If setEncoding(null), decoder.encoding equals utf8

              this._readableState.encoding = this._readableState.decoder.encoding; // Iterate over current buffer to convert already stored Buffers:

              var p = this._readableState.buffer.head;
              var content = '';

              while (p !== null) {
                content += decoder.write(p.data);
                p = p.next;
              }

              this._readableState.buffer.clear();

              if (content !== '') this._readableState.buffer.push(content);
              this._readableState.length = content.length;
              return this;
            }; // Don't raise the hwm > 1GB


            var MAX_HWM = 0x40000000;

            function computeNewHighWaterMark(n) {
              if (n >= MAX_HWM) {
                // TODO(ronag): Throw ERR_VALUE_OUT_OF_RANGE.
                n = MAX_HWM;
              } else {
                // Get the next highest power of 2 to prevent increasing hwm excessively in
                // tiny amounts
                n--;
                n |= n >>> 1;
                n |= n >>> 2;
                n |= n >>> 4;
                n |= n >>> 8;
                n |= n >>> 16;
                n++;
              }

              return n;
            } // This function is designed to be inlinable, so please take care when making
            // changes to the function body.


            function howMuchToRead(n, state) {
              if (n <= 0 || state.length === 0 && state.ended) return 0;
              if (state.objectMode) return 1;

              if (n !== n) {
                // Only flow one buffer at a time
                if (state.flowing && state.length) return state.buffer.head.data.length;else return state.length;
              } // If we're asking for more than the current hwm, then raise the hwm.


              if (n > state.highWaterMark) state.highWaterMark = computeNewHighWaterMark(n);
              if (n <= state.length) return n; // Don't have enough

              if (!state.ended) {
                state.needReadable = true;
                return 0;
              }

              return state.length;
            } // you can override either this method, or the async _read(n) below.


            Readable.prototype.read = function (n) {
              debug('read', n);
              n = parseInt(n, 10);
              var state = this._readableState;
              var nOrig = n;
              if (n !== 0) state.emittedReadable = false; // if we're doing read(0) to trigger a readable event, but we
              // already have a bunch of data in the buffer, then just trigger
              // the 'readable' event and move on.

              if (n === 0 && state.needReadable && ((state.highWaterMark !== 0 ? state.length >= state.highWaterMark : state.length > 0) || state.ended)) {
                debug('read: emitReadable', state.length, state.ended);
                if (state.length === 0 && state.ended) endReadable(this);else emitReadable(this);
                return null;
              }

              n = howMuchToRead(n, state); // if we've ended, and we're now clear, then finish it up.

              if (n === 0 && state.ended) {
                if (state.length === 0) endReadable(this);
                return null;
              } // All the actual chunk generation logic needs to be
              // *below* the call to _read.  The reason is that in certain
              // synthetic stream cases, such as passthrough streams, _read
              // may be a completely synchronous operation which may change
              // the state of the read buffer, providing enough data when
              // before there was *not* enough.
              //
              // So, the steps are:
              // 1. Figure out what the state of things will be after we do
              // a read from the buffer.
              //
              // 2. If that resulting state will trigger a _read, then call _read.
              // Note that this may be asynchronous, or synchronous.  Yes, it is
              // deeply ugly to write APIs this way, but that still doesn't mean
              // that the Readable class should behave improperly, as streams are
              // designed to be sync/async agnostic.
              // Take note if the _read call is sync or async (ie, if the read call
              // has returned yet), so that we know whether or not it's safe to emit
              // 'readable' etc.
              //
              // 3. Actually pull the requested chunks out of the buffer and return.
              // if we need a readable event, then we need to do some reading.


              var doRead = state.needReadable;
              debug('need readable', doRead); // if we currently have less than the highWaterMark, then also read some

              if (state.length === 0 || state.length - n < state.highWaterMark) {
                doRead = true;
                debug('length less than watermark', doRead);
              } // however, if we've ended, then there's no point, and if we're already
              // reading, then it's unnecessary.


              if (state.ended || state.reading) {
                doRead = false;
                debug('reading or ended', doRead);
              } else if (doRead) {
                debug('do read');
                state.reading = true;
                state.sync = true; // if the length is currently zero, then we *need* a readable event.

                if (state.length === 0) state.needReadable = true; // call internal read method

                this._read(state.highWaterMark);

                state.sync = false; // If _read pushed data synchronously, then `reading` will be false,
                // and we need to re-evaluate how much data we can return to the user.

                if (!state.reading) n = howMuchToRead(nOrig, state);
              }

              var ret;
              if (n > 0) ret = fromList(n, state);else ret = null;

              if (ret === null) {
                state.needReadable = state.length <= state.highWaterMark;
                n = 0;
              } else {
                state.length -= n;
                state.awaitDrain = 0;
              }

              if (state.length === 0) {
                // If we have nothing in the buffer, then we want to know
                // as soon as we *do* get something into the buffer.
                if (!state.ended) state.needReadable = true; // If we tried to read() past the EOF, then emit end on the next tick.

                if (nOrig !== n && state.ended) endReadable(this);
              }

              if (ret !== null) this.emit('data', ret);
              return ret;
            };

            function onEofChunk(stream, state) {
              debug('onEofChunk');
              if (state.ended) return;

              if (state.decoder) {
                var chunk = state.decoder.end();

                if (chunk && chunk.length) {
                  state.buffer.push(chunk);
                  state.length += state.objectMode ? 1 : chunk.length;
                }
              }

              state.ended = true;

              if (state.sync) {
                // if we are sync, wait until next tick to emit the data.
                // Otherwise we risk emitting data in the flow()
                // the readable code triggers during a read() call
                emitReadable(stream);
              } else {
                // emit 'readable' now to make sure it gets picked up.
                state.needReadable = false;

                if (!state.emittedReadable) {
                  state.emittedReadable = true;
                  emitReadable_(stream);
                }
              }
            } // Don't emit readable right away in sync mode, because this can trigger
            // another read() call => stack overflow.  This way, it might trigger
            // a nextTick recursion warning, but that's not so bad.


            function emitReadable(stream) {
              var state = stream._readableState;
              debug('emitReadable', state.needReadable, state.emittedReadable);
              state.needReadable = false;

              if (!state.emittedReadable) {
                debug('emitReadable', state.flowing);
                state.emittedReadable = true;
                nextTick(emitReadable_, stream);
              }
            }

            function emitReadable_(stream) {
              var state = stream._readableState;
              debug('emitReadable_', state.destroyed, state.length, state.ended);

              if (!state.destroyed && (state.length || state.ended)) {
                stream.emit('readable');
                state.emittedReadable = false;
              } // The stream needs another readable event if
              // 1. It is not flowing, as the flow mechanism will take
              //    care of it.
              // 2. It is not ended.
              // 3. It is below the highWaterMark, so we can schedule
              //    another readable later.


              state.needReadable = !state.flowing && !state.ended && state.length <= state.highWaterMark;
              flow(stream);
            } // at this point, the user has presumably seen the 'readable' event,
            // and called read() to consume some data.  that may have triggered
            // in turn another _read(n) call, in which case reading = true if
            // it's in progress.
            // However, if we're not ended, or reading, and the length < hwm,
            // then go ahead and try to read some more preemptively.


            function maybeReadMore(stream, state) {
              if (!state.readingMore) {
                state.readingMore = true;
                nextTick(maybeReadMore_, stream, state);
              }
            }

            function maybeReadMore_(stream, state) {
              // Attempt to read more data if we should.
              //
              // The conditions for reading more data are (one of):
              // - Not enough data buffered (state.length < state.highWaterMark). The loop
              //   is responsible for filling the buffer with enough data if such data
              //   is available. If highWaterMark is 0 and we are not in the flowing mode
              //   we should _not_ attempt to buffer any extra data. We'll get more data
              //   when the stream consumer calls read() instead.
              // - No data in the buffer, and the stream is in flowing mode. In this mode
              //   the loop below is responsible for ensuring read() is called. Failing to
              //   call read here would abort the flow and there's no other mechanism for
              //   continuing the flow if the stream consumer has just subscribed to the
              //   'data' event.
              //
              // In addition to the above conditions to keep reading data, the following
              // conditions prevent the data from being read:
              // - The stream has ended (state.ended).
              // - There is already a pending 'read' operation (state.reading). This is a
              //   case where the the stream has called the implementation defined _read()
              //   method, but they are processing the call asynchronously and have _not_
              //   called push() with new data. In this case we skip performing more
              //   read()s. The execution ends in this method again after the _read() ends
              //   up calling push() with more data.
              while (!state.reading && !state.ended && (state.length < state.highWaterMark || state.flowing && state.length === 0)) {
                var len = state.length;
                debug('maybeReadMore read 0');
                stream.read(0);
                if (len === state.length) // didn't get any data, stop spinning.
                  break;
              }

              state.readingMore = false;
            } // abstract method.  to be overridden in specific implementation classes.
            // call cb(er, data) where data is <= n in length.
            // for virtual (non-string, non-buffer) streams, "length" is somewhat
            // arbitrary, and perhaps not very meaningful.


            Readable.prototype._read = function (n) {
              errorOrDestroy$2(this, new ERR_METHOD_NOT_IMPLEMENTED$1('_read()'));
            };

            Readable.prototype.pipe = function (dest, pipeOpts) {
              var src = this;
              var state = this._readableState;

              switch (state.pipesCount) {
                case 0:
                  state.pipes = dest;
                  break;

                case 1:
                  state.pipes = [state.pipes, dest];
                  break;

                default:
                  state.pipes.push(dest);
                  break;
              }

              state.pipesCount += 1;
              debug('pipe count=%d opts=%j', state.pipesCount, pipeOpts);
              var doEnd = (!pipeOpts || pipeOpts.end !== false) && dest !== process.stdout && dest !== process.stderr;
              var endFn = doEnd ? onend : unpipe;
              if (state.endEmitted) nextTick(endFn);else src.once('end', endFn);
              dest.on('unpipe', onunpipe);

              function onunpipe(readable, unpipeInfo) {
                debug('onunpipe');

                if (readable === src) {
                  if (unpipeInfo && unpipeInfo.hasUnpiped === false) {
                    unpipeInfo.hasUnpiped = true;
                    cleanup();
                  }
                }
              }

              function onend() {
                debug('onend');
                dest.end();
              } // when the dest drains, it reduces the awaitDrain counter
              // on the source.  This would be more elegant with a .once()
              // handler in flow(), but adding and removing repeatedly is
              // too slow.


              var ondrain = pipeOnDrain(src);
              dest.on('drain', ondrain);
              var cleanedUp = false;

              function cleanup() {
                debug('cleanup'); // cleanup event handlers once the pipe is broken

                dest.removeListener('close', onclose);
                dest.removeListener('finish', onfinish);
                dest.removeListener('drain', ondrain);
                dest.removeListener('error', onerror);
                dest.removeListener('unpipe', onunpipe);
                src.removeListener('end', onend);
                src.removeListener('end', unpipe);
                src.removeListener('data', ondata);
                cleanedUp = true; // if the reader is waiting for a drain event from this
                // specific writer, then it would cause it to never start
                // flowing again.
                // So, if this is awaiting a drain, then we just call it now.
                // If we don't know, then assume that we are waiting for one.

                if (state.awaitDrain && (!dest._writableState || dest._writableState.needDrain)) ondrain();
              }

              src.on('data', ondata);

              function ondata(chunk) {
                debug('ondata');
                var ret = dest.write(chunk);
                debug('dest.write', ret);

                if (ret === false) {
                  // If the user unpiped during `dest.write()`, it is possible
                  // to get stuck in a permanently paused state if that write
                  // also returned false.
                  // => Check whether `dest` is still a piping destination.
                  if ((state.pipesCount === 1 && state.pipes === dest || state.pipesCount > 1 && indexOf(state.pipes, dest) !== -1) && !cleanedUp) {
                    debug('false write response, pause', state.awaitDrain);
                    state.awaitDrain++;
                  }

                  src.pause();
                }
              } // if the dest has an error, then stop piping into it.
              // however, don't suppress the throwing behavior for this.


              function onerror(er) {
                debug('onerror', er);
                unpipe();
                dest.removeListener('error', onerror);
                if (EElistenerCount(dest, 'error') === 0) errorOrDestroy$2(dest, er);
              } // Make sure our error handler is attached before userland ones.


              prependListener(dest, 'error', onerror); // Both close and finish should trigger unpipe, but only once.

              function onclose() {
                dest.removeListener('finish', onfinish);
                unpipe();
              }

              dest.once('close', onclose);

              function onfinish() {
                debug('onfinish');
                dest.removeListener('close', onclose);
                unpipe();
              }

              dest.once('finish', onfinish);

              function unpipe() {
                debug('unpipe');
                src.unpipe(dest);
              } // tell the dest that it's being piped to


              dest.emit('pipe', src); // start the flow if it hasn't been started already.

              if (!state.flowing) {
                debug('pipe resume');
                src.resume();
              }

              return dest;
            };

            function pipeOnDrain(src) {
              return function pipeOnDrainFunctionResult() {
                var state = src._readableState;
                debug('pipeOnDrain', state.awaitDrain);
                if (state.awaitDrain) state.awaitDrain--;

                if (state.awaitDrain === 0 && EElistenerCount(src, 'data')) {
                  state.flowing = true;
                  flow(src);
                }
              };
            }

            Readable.prototype.unpipe = function (dest) {
              var state = this._readableState;
              var unpipeInfo = {
                hasUnpiped: false
              }; // if we're not piping anywhere, then do nothing.

              if (state.pipesCount === 0) return this; // just one destination.  most common case.

              if (state.pipesCount === 1) {
                // passed in one, but it's not the right one.
                if (dest && dest !== state.pipes) return this;
                if (!dest) dest = state.pipes; // got a match.

                state.pipes = null;
                state.pipesCount = 0;
                state.flowing = false;
                if (dest) dest.emit('unpipe', this, unpipeInfo);
                return this;
              } // slow case. multiple pipe destinations.


              if (!dest) {
                // remove all.
                var dests = state.pipes;
                var len = state.pipesCount;
                state.pipes = null;
                state.pipesCount = 0;
                state.flowing = false;

                for (var i = 0; i < len; i++) {
                  dests[i].emit('unpipe', this, {
                    hasUnpiped: false
                  });
                }

                return this;
              } // try to find the right one.


              var index = indexOf(state.pipes, dest);
              if (index === -1) return this;
              state.pipes.splice(index, 1);
              state.pipesCount -= 1;
              if (state.pipesCount === 1) state.pipes = state.pipes[0];
              dest.emit('unpipe', this, unpipeInfo);
              return this;
            }; // set up data events if they are asked for
            // Ensure readable listeners eventually get something


            Readable.prototype.on = function (ev, fn) {
              var res = streamBrowser.prototype.on.call(this, ev, fn);
              var state = this._readableState;

              if (ev === 'data') {
                // update readableListening so that resume() may be a no-op
                // a few lines down. This is needed to support once('readable').
                state.readableListening = this.listenerCount('readable') > 0; // Try start flowing on next tick if stream isn't explicitly paused

                if (state.flowing !== false) this.resume();
              } else if (ev === 'readable') {
                if (!state.endEmitted && !state.readableListening) {
                  state.readableListening = state.needReadable = true;
                  state.flowing = false;
                  state.emittedReadable = false;
                  debug('on readable', state.length, state.reading);

                  if (state.length) {
                    emitReadable(this);
                  } else if (!state.reading) {
                    nextTick(nReadingNextTick, this);
                  }
                }
              }

              return res;
            };

            Readable.prototype.addListener = Readable.prototype.on;

            Readable.prototype.removeListener = function (ev, fn) {
              var res = streamBrowser.prototype.removeListener.call(this, ev, fn);

              if (ev === 'readable') {
                // We need to check if there is someone still listening to
                // readable and reset the state. However this needs to happen
                // after readable has been emitted but before I/O (nextTick) to
                // support once('readable', fn) cycles. This means that calling
                // resume within the same tick will have no
                // effect.
                nextTick(updateReadableListening, this);
              }

              return res;
            };

            Readable.prototype.removeAllListeners = function (ev) {
              var res = streamBrowser.prototype.removeAllListeners.apply(this, arguments);

              if (ev === 'readable' || ev === undefined) {
                // We need to check if there is someone still listening to
                // readable and reset the state. However this needs to happen
                // after readable has been emitted but before I/O (nextTick) to
                // support once('readable', fn) cycles. This means that calling
                // resume within the same tick will have no
                // effect.
                nextTick(updateReadableListening, this);
              }

              return res;
            };

            function updateReadableListening(self) {
              var state = self._readableState;
              state.readableListening = self.listenerCount('readable') > 0;

              if (state.resumeScheduled && !state.paused) {
                // flowing needs to be set to true now, otherwise
                // the upcoming resume will not flow.
                state.flowing = true; // crude way to check if we should resume
              } else if (self.listenerCount('data') > 0) {
                self.resume();
              }
            }

            function nReadingNextTick(self) {
              debug('readable nexttick read 0');
              self.read(0);
            } // pause() and resume() are remnants of the legacy readable stream API
            // If the user uses them, then switch into old mode.


            Readable.prototype.resume = function () {
              var state = this._readableState;

              if (!state.flowing) {
                debug('resume'); // we flow only if there is no one listening
                // for readable, but we still have to call
                // resume()

                state.flowing = !state.readableListening;
                resume(this, state);
              }

              state.paused = false;
              return this;
            };

            function resume(stream, state) {
              if (!state.resumeScheduled) {
                state.resumeScheduled = true;
                nextTick(resume_, stream, state);
              }
            }

            function resume_(stream, state) {
              debug('resume', state.reading);

              if (!state.reading) {
                stream.read(0);
              }

              state.resumeScheduled = false;
              stream.emit('resume');
              flow(stream);
              if (state.flowing && !state.reading) stream.read(0);
            }

            Readable.prototype.pause = function () {
              debug('call pause flowing=%j', this._readableState.flowing);

              if (this._readableState.flowing !== false) {
                debug('pause');
                this._readableState.flowing = false;
                this.emit('pause');
              }

              this._readableState.paused = true;
              return this;
            };

            function flow(stream) {
              var state = stream._readableState;
              debug('flow', state.flowing);

              while (state.flowing && stream.read() !== null) {
              }
            } // wrap an old-style stream as the async data source.
            // This is *not* part of the readable stream interface.
            // It is an ugly unfortunate mess of history.


            Readable.prototype.wrap = function (stream) {
              var _this = this;

              var state = this._readableState;
              var paused = false;
              stream.on('end', function () {
                debug('wrapped end');

                if (state.decoder && !state.ended) {
                  var chunk = state.decoder.end();
                  if (chunk && chunk.length) _this.push(chunk);
                }

                _this.push(null);
              });
              stream.on('data', function (chunk) {
                debug('wrapped data');
                if (state.decoder) chunk = state.decoder.write(chunk); // don't skip over falsy values in objectMode

                if (state.objectMode && (chunk === null || chunk === undefined)) return;else if (!state.objectMode && (!chunk || !chunk.length)) return;

                var ret = _this.push(chunk);

                if (!ret) {
                  paused = true;
                  stream.pause();
                }
              }); // proxy all the other methods.
              // important when wrapping filters and duplexes.

              for (var i in stream) {
                if (this[i] === undefined && typeof stream[i] === 'function') {
                  this[i] = function methodWrap(method) {
                    return function methodWrapReturnFunction() {
                      return stream[method].apply(stream, arguments);
                    };
                  }(i);
                }
              } // proxy certain important events.


              for (var n = 0; n < kProxyEvents.length; n++) {
                stream.on(kProxyEvents[n], this.emit.bind(this, kProxyEvents[n]));
              } // when we try to consume some more bytes, simply unpause the
              // underlying stream.


              this._read = function (n) {
                debug('wrapped _read', n);

                if (paused) {
                  paused = false;
                  stream.resume();
                }
              };

              return this;
            };

            if (typeof Symbol === 'function') {
              Readable.prototype[Symbol.asyncIterator] = function () {
                if (createReadableStreamAsyncIterator$1 === undefined) {
                  createReadableStreamAsyncIterator$1 = async_iterator;
                }

                return createReadableStreamAsyncIterator$1(this);
              };
            }

            Object.defineProperty(Readable.prototype, 'readableHighWaterMark', {
              // making it explicit this property is not enumerable
              // because otherwise some prototype manipulation in
              // userland will fail
              enumerable: false,
              get: function get() {
                return this._readableState.highWaterMark;
              }
            });
            Object.defineProperty(Readable.prototype, 'readableBuffer', {
              // making it explicit this property is not enumerable
              // because otherwise some prototype manipulation in
              // userland will fail
              enumerable: false,
              get: function get() {
                return this._readableState && this._readableState.buffer;
              }
            });
            Object.defineProperty(Readable.prototype, 'readableFlowing', {
              // making it explicit this property is not enumerable
              // because otherwise some prototype manipulation in
              // userland will fail
              enumerable: false,
              get: function get() {
                return this._readableState.flowing;
              },
              set: function set(state) {
                if (this._readableState) {
                  this._readableState.flowing = state;
                }
              }
            }); // exposed for testing purposes only.

            Readable._fromList = fromList;
            Object.defineProperty(Readable.prototype, 'readableLength', {
              // making it explicit this property is not enumerable
              // because otherwise some prototype manipulation in
              // userland will fail
              enumerable: false,
              get: function get() {
                return this._readableState.length;
              }
            }); // Pluck off n bytes from an array of buffers.
            // Length is the combined lengths of all the buffers in the list.
            // This function is designed to be inlinable, so please take care when making
            // changes to the function body.

            function fromList(n, state) {
              // nothing buffered
              if (state.length === 0) return null;
              var ret;
              if (state.objectMode) ret = state.buffer.shift();else if (!n || n >= state.length) {
                // read it all, truncate the list
                if (state.decoder) ret = state.buffer.join('');else if (state.buffer.length === 1) ret = state.buffer.first();else ret = state.buffer.concat(state.length);
                state.buffer.clear();
              } else {
                // read part of list
                ret = state.buffer.consume(n, state.decoder);
              }
              return ret;
            }

            function endReadable(stream) {
              var state = stream._readableState;
              debug('endReadable', state.endEmitted);

              if (!state.endEmitted) {
                state.ended = true;
                nextTick(endReadableNT, state, stream);
              }
            }

            function endReadableNT(state, stream) {
              debug('endReadableNT', state.endEmitted, state.length); // Check that we didn't get one last unshift.

              if (!state.endEmitted && state.length === 0) {
                state.endEmitted = true;
                stream.readable = false;
                stream.emit('end');

                if (state.autoDestroy) {
                  // In case of duplex streams we need a way to detect
                  // if the writable side is ready for autoDestroy as well
                  var wState = stream._writableState;

                  if (!wState || wState.autoDestroy && wState.finished) {
                    stream.destroy();
                  }
                }
              }
            }

            if (typeof Symbol === 'function') {
              Readable.from = function (iterable, opts) {
                if (from$1 === undefined) {
                  from$1 = fromBrowser;
                }

                return from$1(Readable, iterable, opts);
              };
            }

            function indexOf(xs, x) {
              for (var i = 0, l = xs.length; i < l; i++) {
                if (xs[i] === x) return i;
              }

              return -1;
            }

            var _stream_transform = Transform;

            var _require$codes$2 = errorsBrowser.codes,
                ERR_METHOD_NOT_IMPLEMENTED$2 = _require$codes$2.ERR_METHOD_NOT_IMPLEMENTED,
                ERR_MULTIPLE_CALLBACK$1 = _require$codes$2.ERR_MULTIPLE_CALLBACK,
                ERR_TRANSFORM_ALREADY_TRANSFORMING = _require$codes$2.ERR_TRANSFORM_ALREADY_TRANSFORMING,
                ERR_TRANSFORM_WITH_LENGTH_0 = _require$codes$2.ERR_TRANSFORM_WITH_LENGTH_0;



            inherits_browser(Transform, _stream_duplex);

            function afterTransform(er, data) {
              var ts = this._transformState;
              ts.transforming = false;
              var cb = ts.writecb;

              if (cb === null) {
                return this.emit('error', new ERR_MULTIPLE_CALLBACK$1());
              }

              ts.writechunk = null;
              ts.writecb = null;
              if (data != null) // single equals check for both `null` and `undefined`
                this.push(data);
              cb(er);
              var rs = this._readableState;
              rs.reading = false;

              if (rs.needReadable || rs.length < rs.highWaterMark) {
                this._read(rs.highWaterMark);
              }
            }

            function Transform(options) {
              if (!(this instanceof Transform)) return new Transform(options);
              _stream_duplex.call(this, options);
              this._transformState = {
                afterTransform: afterTransform.bind(this),
                needTransform: false,
                transforming: false,
                writecb: null,
                writechunk: null,
                writeencoding: null
              }; // start out asking for a readable event once data is transformed.

              this._readableState.needReadable = true; // we have implemented the _read method, and done the other things
              // that Readable wants before the first _read call, so unset the
              // sync guard flag.

              this._readableState.sync = false;

              if (options) {
                if (typeof options.transform === 'function') this._transform = options.transform;
                if (typeof options.flush === 'function') this._flush = options.flush;
              } // When the writable side finishes, then flush out anything remaining.


              this.on('prefinish', prefinish$1);
            }

            function prefinish$1() {
              var _this = this;

              if (typeof this._flush === 'function' && !this._readableState.destroyed) {
                this._flush(function (er, data) {
                  done(_this, er, data);
                });
              } else {
                done(this, null, null);
              }
            }

            Transform.prototype.push = function (chunk, encoding) {
              this._transformState.needTransform = false;
              return _stream_duplex.prototype.push.call(this, chunk, encoding);
            }; // This is the part where you do stuff!
            // override this function in implementation classes.
            // 'chunk' is an input chunk.
            //
            // Call `push(newChunk)` to pass along transformed output
            // to the readable side.  You may call 'push' zero or more times.
            //
            // Call `cb(err)` when you are done with this chunk.  If you pass
            // an error, then that'll put the hurt on the whole operation.  If you
            // never call cb(), then you'll never get another chunk.


            Transform.prototype._transform = function (chunk, encoding, cb) {
              cb(new ERR_METHOD_NOT_IMPLEMENTED$2('_transform()'));
            };

            Transform.prototype._write = function (chunk, encoding, cb) {
              var ts = this._transformState;
              ts.writecb = cb;
              ts.writechunk = chunk;
              ts.writeencoding = encoding;

              if (!ts.transforming) {
                var rs = this._readableState;
                if (ts.needTransform || rs.needReadable || rs.length < rs.highWaterMark) this._read(rs.highWaterMark);
              }
            }; // Doesn't matter what the args are here.
            // _transform does all the work.
            // That we got here means that the readable side wants more data.


            Transform.prototype._read = function (n) {
              var ts = this._transformState;

              if (ts.writechunk !== null && !ts.transforming) {
                ts.transforming = true;

                this._transform(ts.writechunk, ts.writeencoding, ts.afterTransform);
              } else {
                // mark that we need a transform, so that any data that comes in
                // will get processed, now that we've asked for it.
                ts.needTransform = true;
              }
            };

            Transform.prototype._destroy = function (err, cb) {
              _stream_duplex.prototype._destroy.call(this, err, function (err2) {
                cb(err2);
              });
            };

            function done(stream, er, data) {
              if (er) return stream.emit('error', er);
              if (data != null) // single equals check for both `null` and `undefined`
                stream.push(data); // TODO(BridgeAR): Write a test for these two error cases
              // if there's nothing in the write buffer, then that means
              // that nothing more will ever be provided

              if (stream._writableState.length) throw new ERR_TRANSFORM_WITH_LENGTH_0();
              if (stream._transformState.transforming) throw new ERR_TRANSFORM_ALREADY_TRANSFORMING();
              return stream.push(null);
            }

            var _stream_passthrough = PassThrough;



            inherits_browser(PassThrough, _stream_transform);

            function PassThrough(options) {
              if (!(this instanceof PassThrough)) return new PassThrough(options);
              _stream_transform.call(this, options);
            }

            PassThrough.prototype._transform = function (chunk, encoding, cb) {
              cb(null, chunk);
            };

            var eos$1;

            function once$2(callback) {
              var called = false;
              return function () {
                if (called) return;
                called = true;
                callback.apply(void 0, arguments);
              };
            }

            var _require$codes$3 = errorsBrowser.codes,
                ERR_MISSING_ARGS = _require$codes$3.ERR_MISSING_ARGS,
                ERR_STREAM_DESTROYED$1 = _require$codes$3.ERR_STREAM_DESTROYED;

            function noop$2(err) {
              // Rethrow the error if it exists to avoid swallowing it
              if (err) throw err;
            }

            function isRequest$1(stream) {
              return stream.setHeader && typeof stream.abort === 'function';
            }

            function destroyer(stream, reading, writing, callback) {
              callback = once$2(callback);
              var closed = false;
              stream.on('close', function () {
                closed = true;
              });
              if (eos$1 === undefined) eos$1 = endOfStream;
              eos$1(stream, {
                readable: reading,
                writable: writing
              }, function (err) {
                if (err) return callback(err);
                closed = true;
                callback();
              });
              var destroyed = false;
              return function (err) {
                if (closed) return;
                if (destroyed) return;
                destroyed = true; // request.destroy just do .end - .abort is what we want

                if (isRequest$1(stream)) return stream.abort();
                if (typeof stream.destroy === 'function') return stream.destroy();
                callback(err || new ERR_STREAM_DESTROYED$1('pipe'));
              };
            }

            function call(fn) {
              fn();
            }

            function pipe(from, to) {
              return from.pipe(to);
            }

            function popCallback(streams) {
              if (!streams.length) return noop$2;
              if (typeof streams[streams.length - 1] !== 'function') return noop$2;
              return streams.pop();
            }

            function pipeline() {
              for (var _len = arguments.length, streams = new Array(_len), _key = 0; _key < _len; _key++) {
                streams[_key] = arguments[_key];
              }

              var callback = popCallback(streams);
              if (Array.isArray(streams[0])) streams = streams[0];

              if (streams.length < 2) {
                throw new ERR_MISSING_ARGS('streams');
              }

              var error;
              var destroys = streams.map(function (stream, i) {
                var reading = i < streams.length - 1;
                var writing = i > 0;
                return destroyer(stream, reading, writing, function (err) {
                  if (!error) error = err;
                  if (err) destroys.forEach(call);
                  if (reading) return;
                  destroys.forEach(call);
                  callback(error);
                });
              });
              return streams.reduce(pipe);
            }

            var pipeline_1 = pipeline;

            var readableBrowser = createCommonjsModule$1(function (module, exports) {
            exports = module.exports = _stream_readable;
            exports.Stream = exports;
            exports.Readable = exports;
            exports.Writable = _stream_writable;
            exports.Duplex = _stream_duplex;
            exports.Transform = _stream_transform;
            exports.PassThrough = _stream_passthrough;
            exports.finished = endOfStream;
            exports.pipeline = pipeline_1;
            });
            var readableBrowser_1 = readableBrowser.Stream;
            var readableBrowser_2 = readableBrowser.Readable;
            var readableBrowser_3 = readableBrowser.Writable;
            var readableBrowser_4 = readableBrowser.Duplex;
            var readableBrowser_5 = readableBrowser.Transform;
            var readableBrowser_6 = readableBrowser.PassThrough;
            var readableBrowser_7 = readableBrowser.finished;
            var readableBrowser_8 = readableBrowser.pipeline;

            var Readable$1 = readableBrowser.Readable;


            var levelIteratorStream = ReadStream;
            inherits_browser(ReadStream, Readable$1);

            function ReadStream (iterator, options) {
              if (!(this instanceof ReadStream)) return new ReadStream(iterator, options)
              options = options || {};
              Readable$1.call(this, immutable(options, {
                objectMode: true
              }));
              this._iterator = iterator;
              this._options = options;
              this.on('end', this.destroy.bind(this, null, null));
            }

            ReadStream.prototype._read = function () {
              var self = this;
              var options = this._options;
              if (this.destroyed) return

              this._iterator.next(function (err, key, value) {
                if (self.destroyed) return
                if (err) return self.destroy(err)

                if (key === undefined && value === undefined) {
                  self.push(null);
                } else if (options.keys !== false && options.values === false) {
                  self.push(key);
                } else if (options.keys === false && options.values !== false) {
                  self.push(value);
                } else {
                  self.push({ key: key, value: value });
                }
              });
            };

            ReadStream.prototype._destroy = function (err, callback) {
              this._iterator.end(function (err2) {
                callback(err || err2);
              });
            };

            var prr = createCommonjsModule$1(function (module) {
            /*!
              * prr
              * (c) 2013 Rod Vagg <rod@vagg.org>
              * https://github.com/rvagg/prr
              * License: MIT
              */

            (function (name, context, definition) {
              if ( module.exports)
                module.exports = definition();
              else
                context[name] = definition();
            })('prr', commonjsGlobal$1, function() {

              var setProperty = typeof Object.defineProperty == 'function'
                  ? function (obj, key, options) {
                      Object.defineProperty(obj, key, options);
                      return obj
                    }
                  : function (obj, key, options) { // < es5
                      obj[key] = options.value;
                      return obj
                    }

                , makeOptions = function (value, options) {
                    var oo = typeof options == 'object'
                      , os = !oo && typeof options == 'string'
                      , op = function (p) {
                          return oo
                            ? !!options[p]
                            : os
                              ? options.indexOf(p[0]) > -1
                              : false
                        };

                    return {
                        enumerable   : op('enumerable')
                      , configurable : op('configurable')
                      , writable     : op('writable')
                      , value        : value
                    }
                  }

                , prr = function (obj, key, value, options) {
                    var k;

                    options = makeOptions(value, options);

                    if (typeof key == 'object') {
                      for (k in key) {
                        if (Object.hasOwnProperty.call(key, k)) {
                          options.value = key[k];
                          setProperty(obj, k, options);
                        }
                      }
                      return obj
                    }

                    return setProperty(obj, key, options)
                  };

              return prr
            });
            });

            function init$1 (type, message, cause) {
              if (!!message && typeof message != 'string') {
                message = message.message || message.name;
              }
              prr(this, {
                  type    : type
                , name    : type
                  // can be passed just a 'cause'
                , cause   : typeof message != 'string' ? message : cause
                , message : message
              }, 'ewr');
            }

            // generic prototype, not intended to be actually used - helpful for `instanceof`
            function CustomError (message, cause) {
              Error.call(this);
              if (Error.captureStackTrace)
                Error.captureStackTrace(this, this.constructor);
              init$1.call(this, 'CustomError', message, cause);
            }

            CustomError.prototype = new Error();

            function createError$1 (errno, type, proto) {
              var err = function (message, cause) {
                init$1.call(this, type, message, cause);
                //TODO: the specificity here is stupid, errno should be available everywhere
                if (type == 'FilesystemError') {
                  this.code    = this.cause.code;
                  this.path    = this.cause.path;
                  this.errno   = this.cause.errno;
                  this.message =
                    (errno.errno[this.cause.errno]
                      ? errno.errno[this.cause.errno].description
                      : this.cause.message)
                    + (this.cause.path ? ' [' + this.cause.path + ']' : '');
                }
                Error.call(this);
                if (Error.captureStackTrace)
                  Error.captureStackTrace(this, err);
              };
              err.prototype = !!proto ? new proto() : new CustomError();
              return err
            }

            var custom$1 = function (errno) {
              var ce = function (type, proto) {
                return createError$1(errno, type, proto)
              };
              return {
                  CustomError     : CustomError
                , FilesystemError : ce('FilesystemError')
                , createError     : ce
              }
            };

            var errno = createCommonjsModule$1(function (module) {
            var all = module.exports.all = [
              {
                errno: -2,
                code: 'ENOENT',
                description: 'no such file or directory'
              },
              {
                errno: -1,
                code: 'UNKNOWN',
                description: 'unknown error'
              },
              {
                errno: 0,
                code: 'OK',
                description: 'success'
              },
              {
                errno: 1,
                code: 'EOF',
                description: 'end of file'
              },
              {
                errno: 2,
                code: 'EADDRINFO',
                description: 'getaddrinfo error'
              },
              {
                errno: 3,
                code: 'EACCES',
                description: 'permission denied'
              },
              {
                errno: 4,
                code: 'EAGAIN',
                description: 'resource temporarily unavailable'
              },
              {
                errno: 5,
                code: 'EADDRINUSE',
                description: 'address already in use'
              },
              {
                errno: 6,
                code: 'EADDRNOTAVAIL',
                description: 'address not available'
              },
              {
                errno: 7,
                code: 'EAFNOSUPPORT',
                description: 'address family not supported'
              },
              {
                errno: 8,
                code: 'EALREADY',
                description: 'connection already in progress'
              },
              {
                errno: 9,
                code: 'EBADF',
                description: 'bad file descriptor'
              },
              {
                errno: 10,
                code: 'EBUSY',
                description: 'resource busy or locked'
              },
              {
                errno: 11,
                code: 'ECONNABORTED',
                description: 'software caused connection abort'
              },
              {
                errno: 12,
                code: 'ECONNREFUSED',
                description: 'connection refused'
              },
              {
                errno: 13,
                code: 'ECONNRESET',
                description: 'connection reset by peer'
              },
              {
                errno: 14,
                code: 'EDESTADDRREQ',
                description: 'destination address required'
              },
              {
                errno: 15,
                code: 'EFAULT',
                description: 'bad address in system call argument'
              },
              {
                errno: 16,
                code: 'EHOSTUNREACH',
                description: 'host is unreachable'
              },
              {
                errno: 17,
                code: 'EINTR',
                description: 'interrupted system call'
              },
              {
                errno: 18,
                code: 'EINVAL',
                description: 'invalid argument'
              },
              {
                errno: 19,
                code: 'EISCONN',
                description: 'socket is already connected'
              },
              {
                errno: 20,
                code: 'EMFILE',
                description: 'too many open files'
              },
              {
                errno: 21,
                code: 'EMSGSIZE',
                description: 'message too long'
              },
              {
                errno: 22,
                code: 'ENETDOWN',
                description: 'network is down'
              },
              {
                errno: 23,
                code: 'ENETUNREACH',
                description: 'network is unreachable'
              },
              {
                errno: 24,
                code: 'ENFILE',
                description: 'file table overflow'
              },
              {
                errno: 25,
                code: 'ENOBUFS',
                description: 'no buffer space available'
              },
              {
                errno: 26,
                code: 'ENOMEM',
                description: 'not enough memory'
              },
              {
                errno: 27,
                code: 'ENOTDIR',
                description: 'not a directory'
              },
              {
                errno: 28,
                code: 'EISDIR',
                description: 'illegal operation on a directory'
              },
              {
                errno: 29,
                code: 'ENONET',
                description: 'machine is not on the network'
              },
              {
                errno: 31,
                code: 'ENOTCONN',
                description: 'socket is not connected'
              },
              {
                errno: 32,
                code: 'ENOTSOCK',
                description: 'socket operation on non-socket'
              },
              {
                errno: 33,
                code: 'ENOTSUP',
                description: 'operation not supported on socket'
              },
              {
                errno: 34,
                code: 'ENOENT',
                description: 'no such file or directory'
              },
              {
                errno: 35,
                code: 'ENOSYS',
                description: 'function not implemented'
              },
              {
                errno: 36,
                code: 'EPIPE',
                description: 'broken pipe'
              },
              {
                errno: 37,
                code: 'EPROTO',
                description: 'protocol error'
              },
              {
                errno: 38,
                code: 'EPROTONOSUPPORT',
                description: 'protocol not supported'
              },
              {
                errno: 39,
                code: 'EPROTOTYPE',
                description: 'protocol wrong type for socket'
              },
              {
                errno: 40,
                code: 'ETIMEDOUT',
                description: 'connection timed out'
              },
              {
                errno: 41,
                code: 'ECHARSET',
                description: 'invalid Unicode character'
              },
              {
                errno: 42,
                code: 'EAIFAMNOSUPPORT',
                description: 'address family for hostname not supported'
              },
              {
                errno: 44,
                code: 'EAISERVICE',
                description: 'servname not supported for ai_socktype'
              },
              {
                errno: 45,
                code: 'EAISOCKTYPE',
                description: 'ai_socktype not supported'
              },
              {
                errno: 46,
                code: 'ESHUTDOWN',
                description: 'cannot send after transport endpoint shutdown'
              },
              {
                errno: 47,
                code: 'EEXIST',
                description: 'file already exists'
              },
              {
                errno: 48,
                code: 'ESRCH',
                description: 'no such process'
              },
              {
                errno: 49,
                code: 'ENAMETOOLONG',
                description: 'name too long'
              },
              {
                errno: 50,
                code: 'EPERM',
                description: 'operation not permitted'
              },
              {
                errno: 51,
                code: 'ELOOP',
                description: 'too many symbolic links encountered'
              },
              {
                errno: 52,
                code: 'EXDEV',
                description: 'cross-device link not permitted'
              },
              {
                errno: 53,
                code: 'ENOTEMPTY',
                description: 'directory not empty'
              },
              {
                errno: 54,
                code: 'ENOSPC',
                description: 'no space left on device'
              },
              {
                errno: 55,
                code: 'EIO',
                description: 'i/o error'
              },
              {
                errno: 56,
                code: 'EROFS',
                description: 'read-only file system'
              },
              {
                errno: 57,
                code: 'ENODEV',
                description: 'no such device'
              },
              {
                errno: 58,
                code: 'ESPIPE',
                description: 'invalid seek'
              },
              {
                errno: 59,
                code: 'ECANCELED',
                description: 'operation canceled'
              }
            ];

            module.exports.errno = {};
            module.exports.code = {};

            all.forEach(function (error) {
              module.exports.errno[error.errno] = error;
              module.exports.code[error.code] = error;
            });

            module.exports.custom = custom$1(module.exports);
            module.exports.create = module.exports.custom.createError;
            });
            var errno_1 = errno.all;
            var errno_2 = errno.errno;
            var errno_3 = errno.code;
            var errno_4 = errno.custom;
            var errno_5 = errno.create;

            var createError$2 = errno.create;
            var LevelUPError = createError$2('LevelUPError');
            var NotFoundError = createError$2('NotFoundError', LevelUPError);

            NotFoundError.prototype.notFound = true;
            NotFoundError.prototype.status = 404;

            var errors = {
              LevelUPError: LevelUPError,
              InitializationError: createError$2('InitializationError', LevelUPError),
              OpenError: createError$2('OpenError', LevelUPError),
              ReadError: createError$2('ReadError', LevelUPError),
              WriteError: createError$2('WriteError', LevelUPError),
              NotFoundError: NotFoundError,
              EncodingError: createError$2('EncodingError', LevelUPError)
            };

            function promisify () {
              var callback;
              var promise = new Promise(function (resolve, reject) {
                callback = function callback (err, value) {
                  if (err) reject(err);
                  else resolve(value);
                };
              });
              callback.promise = promise;
              return callback
            }

            var promisify_1 = promisify;

            var getCallback = function (options, callback) {
              return typeof options === 'function' ? options : callback
            };

            var getOptions = function (options) {
              return typeof options === 'object' && options !== null ? options : {}
            };

            var common = {
            	getCallback: getCallback,
            	getOptions: getOptions
            };

            var WriteError = errors.WriteError;

            var getCallback$1 = common.getCallback;
            var getOptions$1 = common.getOptions;

            function Batch (levelup) {
              this._levelup = levelup;
              this.batch = levelup.db.batch();
              this.ops = [];
              this.length = 0;
            }

            Batch.prototype.put = function (key, value) {
              try {
                this.batch.put(key, value);
              } catch (e) {
                throw new WriteError(e)
              }

              this.ops.push({ type: 'put', key: key, value: value });
              this.length++;

              return this
            };

            Batch.prototype.del = function (key) {
              try {
                this.batch.del(key);
              } catch (err) {
                throw new WriteError(err)
              }

              this.ops.push({ type: 'del', key: key });
              this.length++;

              return this
            };

            Batch.prototype.clear = function () {
              try {
                this.batch.clear();
              } catch (err) {
                throw new WriteError(err)
              }

              this.ops = [];
              this.length = 0;

              return this
            };

            Batch.prototype.write = function (options, callback) {
              var levelup = this._levelup;
              var ops = this.ops;
              var promise;

              callback = getCallback$1(options, callback);

              if (!callback) {
                callback = promisify_1();
                promise = callback.promise;
              }

              options = getOptions$1(options);

              try {
                this.batch.write(options, function (err) {
                  if (err) { return callback(new WriteError(err)) }
                  levelup.emit('batch', ops);
                  callback();
                });
              } catch (err) {
                throw new WriteError(err)
              }

              return promise
            };

            var batch = Batch;

            function compare(a, b) {
              if (a === b) {
                return 0;
              }

              var x = a.length;
              var y = b.length;

              for (var i = 0, len = Math.min(x, y); i < len; ++i) {
                if (a[i] !== b[i]) {
                  x = a[i];
                  y = b[i];
                  break;
                }
              }

              if (x < y) {
                return -1;
              }
              if (y < x) {
                return 1;
              }
              return 0;
            }
            var hasOwn = Object.prototype.hasOwnProperty;

            var objectKeys$1 = Object.keys || function (obj) {
              var keys = [];
              for (var key in obj) {
                if (hasOwn.call(obj, key)) keys.push(key);
              }
              return keys;
            };
            var pSlice = Array.prototype.slice;
            var _functionsHaveNames;
            function functionsHaveNames() {
              if (typeof _functionsHaveNames !== 'undefined') {
                return _functionsHaveNames;
              }
              return _functionsHaveNames = (function () {
                return function foo() {}.name === 'foo';
              }());
            }
            function pToString (obj) {
              return Object.prototype.toString.call(obj);
            }
            function isView(arrbuf) {
              if (isBuffer$1(arrbuf)) {
                return false;
              }
              if (typeof global$1.ArrayBuffer !== 'function') {
                return false;
              }
              if (typeof ArrayBuffer.isView === 'function') {
                return ArrayBuffer.isView(arrbuf);
              }
              if (!arrbuf) {
                return false;
              }
              if (arrbuf instanceof DataView) {
                return true;
              }
              if (arrbuf.buffer && arrbuf.buffer instanceof ArrayBuffer) {
                return true;
              }
              return false;
            }
            // 1. The assert module provides functions that throw
            // AssertionError's when particular conditions are not met. The
            // assert module must conform to the following interface.

            function assert$1(value, message) {
              if (!value) fail(value, true, message, '==', ok);
            }

            // 2. The AssertionError is defined in assert.
            // new assert.AssertionError({ message: message,
            //                             actual: actual,
            //                             expected: expected })

            var regex = /\s*function\s+([^\(\s]*)\s*/;
            // based on https://github.com/ljharb/function.prototype.name/blob/adeeeec8bfcc6068b187d7d9fb3d5bb1d3a30899/implementation.js
            function getName(func) {
              if (!isFunction$1(func)) {
                return;
              }
              if (functionsHaveNames()) {
                return func.name;
              }
              var str = func.toString();
              var match = str.match(regex);
              return match && match[1];
            }
            assert$1.AssertionError = AssertionError;
            function AssertionError(options) {
              this.name = 'AssertionError';
              this.actual = options.actual;
              this.expected = options.expected;
              this.operator = options.operator;
              if (options.message) {
                this.message = options.message;
                this.generatedMessage = false;
              } else {
                this.message = getMessage(this);
                this.generatedMessage = true;
              }
              var stackStartFunction = options.stackStartFunction || fail;
              if (Error.captureStackTrace) {
                Error.captureStackTrace(this, stackStartFunction);
              } else {
                // non v8 browsers so we can have a stacktrace
                var err = new Error();
                if (err.stack) {
                  var out = err.stack;

                  // try to strip useless frames
                  var fn_name = getName(stackStartFunction);
                  var idx = out.indexOf('\n' + fn_name);
                  if (idx >= 0) {
                    // once we have located the function frame
                    // we need to strip out everything before it (and its line)
                    var next_line = out.indexOf('\n', idx + 1);
                    out = out.substring(next_line + 1);
                  }

                  this.stack = out;
                }
              }
            }

            // assert.AssertionError instanceof Error
            inherits$1(AssertionError, Error);

            function truncate(s, n) {
              if (typeof s === 'string') {
                return s.length < n ? s : s.slice(0, n);
              } else {
                return s;
              }
            }
            function inspect$2(something) {
              if (functionsHaveNames() || !isFunction$1(something)) {
                return inspect(something);
              }
              var rawname = getName(something);
              var name = rawname ? ': ' + rawname : '';
              return '[Function' +  name + ']';
            }
            function getMessage(self) {
              return truncate(inspect$2(self.actual), 128) + ' ' +
                     self.operator + ' ' +
                     truncate(inspect$2(self.expected), 128);
            }

            // At present only the three keys mentioned above are used and
            // understood by the spec. Implementations or sub modules can pass
            // other keys to the AssertionError's constructor - they will be
            // ignored.

            // 3. All of the following functions must throw an AssertionError
            // when a corresponding condition is not met, with a message that
            // may be undefined if not provided.  All assertion methods provide
            // both the actual and expected values to the assertion error for
            // display purposes.

            function fail(actual, expected, message, operator, stackStartFunction) {
              throw new AssertionError({
                message: message,
                actual: actual,
                expected: expected,
                operator: operator,
                stackStartFunction: stackStartFunction
              });
            }

            // EXTENSION! allows for well behaved errors defined elsewhere.
            assert$1.fail = fail;

            // 4. Pure assertion tests whether a value is truthy, as determined
            // by !!guard.
            // assert.ok(guard, message_opt);
            // This statement is equivalent to assert.equal(true, !!guard,
            // message_opt);. To test strictly for the value true, use
            // assert.strictEqual(true, guard, message_opt);.

            function ok(value, message) {
              if (!value) fail(value, true, message, '==', ok);
            }
            assert$1.ok = ok;

            // 5. The equality assertion tests shallow, coercive equality with
            // ==.
            // assert.equal(actual, expected, message_opt);
            assert$1.equal = equal;
            function equal(actual, expected, message) {
              if (actual != expected) fail(actual, expected, message, '==', equal);
            }

            // 6. The non-equality assertion tests for whether two objects are not equal
            // with != assert.notEqual(actual, expected, message_opt);
            assert$1.notEqual = notEqual;
            function notEqual(actual, expected, message) {
              if (actual == expected) {
                fail(actual, expected, message, '!=', notEqual);
              }
            }

            // 7. The equivalence assertion tests a deep equality relation.
            // assert.deepEqual(actual, expected, message_opt);
            assert$1.deepEqual = deepEqual;
            function deepEqual(actual, expected, message) {
              if (!_deepEqual(actual, expected, false)) {
                fail(actual, expected, message, 'deepEqual', deepEqual);
              }
            }
            assert$1.deepStrictEqual = deepStrictEqual;
            function deepStrictEqual(actual, expected, message) {
              if (!_deepEqual(actual, expected, true)) {
                fail(actual, expected, message, 'deepStrictEqual', deepStrictEqual);
              }
            }

            function _deepEqual(actual, expected, strict, memos) {
              // 7.1. All identical values are equivalent, as determined by ===.
              if (actual === expected) {
                return true;
              } else if (isBuffer$1(actual) && isBuffer$1(expected)) {
                return compare(actual, expected) === 0;

              // 7.2. If the expected value is a Date object, the actual value is
              // equivalent if it is also a Date object that refers to the same time.
              } else if (isDate$1(actual) && isDate$1(expected)) {
                return actual.getTime() === expected.getTime();

              // 7.3 If the expected value is a RegExp object, the actual value is
              // equivalent if it is also a RegExp object with the same source and
              // properties (`global`, `multiline`, `lastIndex`, `ignoreCase`).
              } else if (isRegExp(actual) && isRegExp(expected)) {
                return actual.source === expected.source &&
                       actual.global === expected.global &&
                       actual.multiline === expected.multiline &&
                       actual.lastIndex === expected.lastIndex &&
                       actual.ignoreCase === expected.ignoreCase;

              // 7.4. Other pairs that do not both pass typeof value == 'object',
              // equivalence is determined by ==.
              } else if ((actual === null || typeof actual !== 'object') &&
                         (expected === null || typeof expected !== 'object')) {
                return strict ? actual === expected : actual == expected;

              // If both values are instances of typed arrays, wrap their underlying
              // ArrayBuffers in a Buffer each to increase performance
              // This optimization requires the arrays to have the same type as checked by
              // Object.prototype.toString (aka pToString). Never perform binary
              // comparisons for Float*Arrays, though, since e.g. +0 === -0 but their
              // bit patterns are not identical.
              } else if (isView(actual) && isView(expected) &&
                         pToString(actual) === pToString(expected) &&
                         !(actual instanceof Float32Array ||
                           actual instanceof Float64Array)) {
                return compare(new Uint8Array(actual.buffer),
                               new Uint8Array(expected.buffer)) === 0;

              // 7.5 For all other Object pairs, including Array objects, equivalence is
              // determined by having the same number of owned properties (as verified
              // with Object.prototype.hasOwnProperty.call), the same set of keys
              // (although not necessarily the same order), equivalent values for every
              // corresponding key, and an identical 'prototype' property. Note: this
              // accounts for both named and indexed properties on Arrays.
              } else if (isBuffer$1(actual) !== isBuffer$1(expected)) {
                return false;
              } else {
                memos = memos || {actual: [], expected: []};

                var actualIndex = memos.actual.indexOf(actual);
                if (actualIndex !== -1) {
                  if (actualIndex === memos.expected.indexOf(expected)) {
                    return true;
                  }
                }

                memos.actual.push(actual);
                memos.expected.push(expected);

                return objEquiv(actual, expected, strict, memos);
              }
            }

            function isArguments(object) {
              return Object.prototype.toString.call(object) == '[object Arguments]';
            }

            function objEquiv(a, b, strict, actualVisitedObjects) {
              if (a === null || a === undefined || b === null || b === undefined)
                return false;
              // if one is a primitive, the other must be same
              if (isPrimitive(a) || isPrimitive(b))
                return a === b;
              if (strict && Object.getPrototypeOf(a) !== Object.getPrototypeOf(b))
                return false;
              var aIsArgs = isArguments(a);
              var bIsArgs = isArguments(b);
              if ((aIsArgs && !bIsArgs) || (!aIsArgs && bIsArgs))
                return false;
              if (aIsArgs) {
                a = pSlice.call(a);
                b = pSlice.call(b);
                return _deepEqual(a, b, strict);
              }
              var ka = objectKeys$1(a);
              var kb = objectKeys$1(b);
              var key, i;
              // having the same number of owned properties (keys incorporates
              // hasOwnProperty)
              if (ka.length !== kb.length)
                return false;
              //the same set of keys (although not necessarily the same order),
              ka.sort();
              kb.sort();
              //~~~cheap key test
              for (i = ka.length - 1; i >= 0; i--) {
                if (ka[i] !== kb[i])
                  return false;
              }
              //equivalent values for every corresponding key, and
              //~~~possibly expensive deep test
              for (i = ka.length - 1; i >= 0; i--) {
                key = ka[i];
                if (!_deepEqual(a[key], b[key], strict, actualVisitedObjects))
                  return false;
              }
              return true;
            }

            // 8. The non-equivalence assertion tests for any deep inequality.
            // assert.notDeepEqual(actual, expected, message_opt);
            assert$1.notDeepEqual = notDeepEqual;
            function notDeepEqual(actual, expected, message) {
              if (_deepEqual(actual, expected, false)) {
                fail(actual, expected, message, 'notDeepEqual', notDeepEqual);
              }
            }

            assert$1.notDeepStrictEqual = notDeepStrictEqual;
            function notDeepStrictEqual(actual, expected, message) {
              if (_deepEqual(actual, expected, true)) {
                fail(actual, expected, message, 'notDeepStrictEqual', notDeepStrictEqual);
              }
            }


            // 9. The strict equality assertion tests strict equality, as determined by ===.
            // assert.strictEqual(actual, expected, message_opt);
            assert$1.strictEqual = strictEqual;
            function strictEqual(actual, expected, message) {
              if (actual !== expected) {
                fail(actual, expected, message, '===', strictEqual);
              }
            }

            // 10. The strict non-equality assertion tests for strict inequality, as
            // determined by !==.  assert.notStrictEqual(actual, expected, message_opt);
            assert$1.notStrictEqual = notStrictEqual;
            function notStrictEqual(actual, expected, message) {
              if (actual === expected) {
                fail(actual, expected, message, '!==', notStrictEqual);
              }
            }

            function expectedException(actual, expected) {
              if (!actual || !expected) {
                return false;
              }

              if (Object.prototype.toString.call(expected) == '[object RegExp]') {
                return expected.test(actual);
              }

              try {
                if (actual instanceof expected) {
                  return true;
                }
              } catch (e) {
                // Ignore.  The instanceof check doesn't work for arrow functions.
              }

              if (Error.isPrototypeOf(expected)) {
                return false;
              }

              return expected.call({}, actual) === true;
            }

            function _tryBlock(block) {
              var error;
              try {
                block();
              } catch (e) {
                error = e;
              }
              return error;
            }

            function _throws(shouldThrow, block, expected, message) {
              var actual;

              if (typeof block !== 'function') {
                throw new TypeError('"block" argument must be a function');
              }

              if (typeof expected === 'string') {
                message = expected;
                expected = null;
              }

              actual = _tryBlock(block);

              message = (expected && expected.name ? ' (' + expected.name + ').' : '.') +
                        (message ? ' ' + message : '.');

              if (shouldThrow && !actual) {
                fail(actual, expected, 'Missing expected exception' + message);
              }

              var userProvidedMessage = typeof message === 'string';
              var isUnwantedException = !shouldThrow && isError(actual);
              var isUnexpectedException = !shouldThrow && actual && !expected;

              if ((isUnwantedException &&
                  userProvidedMessage &&
                  expectedException(actual, expected)) ||
                  isUnexpectedException) {
                fail(actual, expected, 'Got unwanted exception' + message);
              }

              if ((shouldThrow && actual && expected &&
                  !expectedException(actual, expected)) || (!shouldThrow && actual)) {
                throw actual;
              }
            }

            // 11. Expected to throw an error:
            // assert.throws(block, Error_opt, message_opt);
            assert$1.throws = throws;
            function throws(block, /*optional*/error, /*optional*/message) {
              _throws(true, block, error, message);
            }

            // EXTENSION! This is annoying to write outside this module.
            assert$1.doesNotThrow = doesNotThrow;
            function doesNotThrow(block, /*optional*/error, /*optional*/message) {
              _throws(false, block, error, message);
            }

            assert$1.ifError = ifError;
            function ifError(err) {
              if (err) throw err;
            }

            var assert$2 = /*#__PURE__*/Object.freeze({
                        __proto__: null,
                        'default': assert$1,
                        AssertionError: AssertionError,
                        fail: fail,
                        ok: ok,
                        assert: ok,
                        equal: equal,
                        notEqual: notEqual,
                        deepEqual: deepEqual,
                        deepStrictEqual: deepStrictEqual,
                        notDeepEqual: notDeepEqual,
                        notDeepStrictEqual: notDeepStrictEqual,
                        strictEqual: strictEqual,
                        notStrictEqual: notStrictEqual,
                        throws: throws,
                        doesNotThrow: doesNotThrow,
                        ifError: ifError
            });

            var require$$1 = getCjsExportFromNamespace(util$1);

            var assert$3 = getCjsExportFromNamespace(assert$2);

            var EventEmitter$1 = require$$0.EventEmitter;
            var inherits$2 = require$$1.inherits;








            var getCallback$2 = common.getCallback;
            var getOptions$2 = common.getOptions;

            var WriteError$1 = errors.WriteError;
            var ReadError = errors.ReadError;
            var NotFoundError$1 = errors.NotFoundError;
            var OpenError = errors.OpenError;
            var InitializationError = errors.InitializationError;

            // Possible AbstractLevelDOWN#status values:
            //  - 'new'     - newly created, not opened or closed
            //  - 'opening' - waiting for the database to be opened, post open()
            //  - 'open'    - successfully opened the database, available for use
            //  - 'closing' - waiting for the database to be closed, post close()
            //  - 'closed'  - database has been successfully closed, should not be
            //                 used except for another open() operation

            function LevelUP (db, options, callback) {
              if (!(this instanceof LevelUP)) {
                return new LevelUP(db, options, callback)
              }

              var error;
              var self = this;

              EventEmitter$1.call(this);
              this.setMaxListeners(Infinity);

              if (typeof options === 'function') {
                callback = options;
                options = {};
              }

              options = options || {};

              if (!db || typeof db !== 'object') {
                error = new InitializationError('First argument must be an abstract-leveldown compliant store');
                if (typeof callback === 'function') {
                  return nextTick(callback, error)
                }
                throw error
              }

              assert$3.strictEqual(typeof db.status, 'string', '.status required, old abstract-leveldown');

              this.options = getOptions$2(options);
              this._db = db;
              this.db = new deferredLeveldown(db);
              this.open(callback || function (err) {
                if (err) self.emit('error', err);
              });

              // Create manifest based on deferred-leveldown's
              this.supports = levelSupports(this.db.supports, {
                status: false,
                deferredOpen: true,
                openCallback: true,
                promises: true,
                streams: true
              });

              // Experimental: enrich levelup interface
              Object.keys(this.supports.additionalMethods).forEach(function (method) {
                if (this[method] != null) return

                // Don't do this.db[method].bind() because this.db is dynamic.
                this[method] = function () {
                  return this.db[method].apply(this.db, arguments)
                };
              }, this);
            }

            LevelUP.prototype.emit = EventEmitter$1.prototype.emit;
            LevelUP.prototype.once = EventEmitter$1.prototype.once;
            inherits$2(LevelUP, EventEmitter$1);

            LevelUP.prototype.open = function (opts, callback) {
              var self = this;
              var promise;

              if (typeof opts === 'function') {
                callback = opts;
                opts = null;
              }

              if (!callback) {
                callback = promisify_1();
                promise = callback.promise;
              }

              if (!opts) {
                opts = this.options;
              }

              if (this.isOpen()) {
                nextTick(callback, null, self);
                return promise
              }

              if (this._isOpening()) {
                this.once('open', function () { callback(null, self); });
                return promise
              }

              this.emit('opening');

              this.db.open(opts, function (err) {
                if (err) {
                  return callback(new OpenError(err))
                }
                self.db = self._db;
                callback(null, self);
                self.emit('open');
                self.emit('ready');
              });

              return promise
            };

            LevelUP.prototype.close = function (callback) {
              var self = this;
              var promise;

              if (!callback) {
                callback = promisify_1();
                promise = callback.promise;
              }

              if (this.isOpen()) {
                this.db.close(function () {
                  self.emit('closed');
                  callback.apply(null, arguments);
                });
                this.emit('closing');
                this.db = new deferredLeveldown(this._db);
              } else if (this.isClosed()) {
                nextTick(callback);
              } else if (this.db.status === 'closing') {
                this.once('closed', callback);
              } else if (this._isOpening()) {
                this.once('open', function () {
                  self.close(callback);
                });
              }

              return promise
            };

            LevelUP.prototype.isOpen = function () {
              return this.db.status === 'open'
            };

            LevelUP.prototype._isOpening = function () {
              return this.db.status === 'opening'
            };

            LevelUP.prototype.isClosed = function () {
              return (/^clos|new/).test(this.db.status)
            };

            LevelUP.prototype.get = function (key, options, callback) {
              if (key === null || key === undefined) {
                throw new ReadError('get() requires a key argument')
              }

              var promise;

              callback = getCallback$2(options, callback);

              if (!callback) {
                callback = promisify_1();
                promise = callback.promise;
              }

              if (maybeError(this, callback)) { return promise }

              options = getOptions$2(options);

              this.db.get(key, options, function (err, value) {
                if (err) {
                  if ((/notfound/i).test(err) || err.notFound) {
                    err = new NotFoundError$1('Key not found in database [' + key + ']', err);
                  } else {
                    err = new ReadError(err);
                  }
                  return callback(err)
                }
                callback(null, value);
              });

              return promise
            };

            LevelUP.prototype.put = function (key, value, options, callback) {
              if (key === null || key === undefined) {
                throw new WriteError$1('put() requires a key argument')
              }

              var self = this;
              var promise;

              callback = getCallback$2(options, callback);

              if (!callback) {
                callback = promisify_1();
                promise = callback.promise;
              }

              if (maybeError(this, callback)) { return promise }

              options = getOptions$2(options);

              this.db.put(key, value, options, function (err) {
                if (err) {
                  return callback(new WriteError$1(err))
                }
                self.emit('put', key, value);
                callback();
              });

              return promise
            };

            LevelUP.prototype.del = function (key, options, callback) {
              if (key === null || key === undefined) {
                throw new WriteError$1('del() requires a key argument')
              }

              var self = this;
              var promise;

              callback = getCallback$2(options, callback);

              if (!callback) {
                callback = promisify_1();
                promise = callback.promise;
              }

              if (maybeError(this, callback)) { return promise }

              options = getOptions$2(options);

              this.db.del(key, options, function (err) {
                if (err) {
                  return callback(new WriteError$1(err))
                }
                self.emit('del', key);
                callback();
              });

              return promise
            };

            LevelUP.prototype.batch = function (arr, options, callback) {
              if (!arguments.length) {
                return new batch(this)
              }

              if (!Array.isArray(arr)) {
                throw new WriteError$1('batch() requires an array argument')
              }

              var self = this;
              var promise;

              callback = getCallback$2(options, callback);

              if (!callback) {
                callback = promisify_1();
                promise = callback.promise;
              }

              if (maybeError(this, callback)) { return promise }

              options = getOptions$2(options);

              this.db.batch(arr, options, function (err) {
                if (err) {
                  return callback(new WriteError$1(err))
                }
                self.emit('batch', arr);
                callback();
              });

              return promise
            };

            LevelUP.prototype.iterator = function (options) {
              return this.db.iterator(options)
            };

            LevelUP.prototype.clear = function (options, callback) {
              var self = this;
              var promise;

              callback = getCallback$2(options, callback);
              options = getOptions$2(options);

              if (!callback) {
                callback = promisify_1();
                promise = callback.promise;
              }

              if (maybeError(this, callback)) {
                return promise
              }

              this.db.clear(options, function (err) {
                if (err) {
                  return callback(new WriteError$1(err))
                }
                self.emit('clear', options);
                callback();
              });

              return promise
            };

            LevelUP.prototype.readStream =
            LevelUP.prototype.createReadStream = function (options) {
              options = immutable({ keys: true, values: true }, options);
              if (typeof options.limit !== 'number') { options.limit = -1; }
              return new levelIteratorStream(this.db.iterator(options), options)
            };

            LevelUP.prototype.keyStream =
            LevelUP.prototype.createKeyStream = function (options) {
              return this.createReadStream(immutable(options, { keys: true, values: false }))
            };

            LevelUP.prototype.valueStream =
            LevelUP.prototype.createValueStream = function (options) {
              return this.createReadStream(immutable(options, { keys: false, values: true }))
            };

            LevelUP.prototype.toString = function () {
              return 'LevelUP'
            };

            LevelUP.prototype.type = 'levelup';

            function maybeError (db, callback) {
              if (!db._isOpening() && !db.isOpen()) {
                nextTick(callback, new ReadError('Database is not open'));
                return true
              }
            }

            LevelUP.errors = errors;
            var levelup = LevelUP.default = LevelUP;

            function AbstractIterator$3 (db) {
              if (typeof db !== 'object' || db === null) {
                throw new TypeError('First argument must be an abstract-leveldown compliant store')
              }

              this.db = db;
              this._ended = false;
              this._nexting = false;
            }

            AbstractIterator$3.prototype.next = function (callback) {
              var self = this;

              if (typeof callback !== 'function') {
                throw new Error('next() requires a callback argument')
              }

              if (self._ended) {
                nextTick(callback, new Error('cannot call next() after end()'));
                return self
              }

              if (self._nexting) {
                nextTick(callback, new Error('cannot call next() before previous next() has completed'));
                return self
              }

              self._nexting = true;
              self._next(function () {
                self._nexting = false;
                callback.apply(null, arguments);
              });

              return self
            };

            AbstractIterator$3.prototype._next = function (callback) {
              nextTick(callback);
            };

            AbstractIterator$3.prototype.seek = function (target) {
              if (this._ended) {
                throw new Error('cannot call seek() after end()')
              }
              if (this._nexting) {
                throw new Error('cannot call seek() before next() has completed')
              }

              target = this.db._serializeKey(target);
              this._seek(target);
            };

            AbstractIterator$3.prototype._seek = function (target) {};

            AbstractIterator$3.prototype.end = function (callback) {
              if (typeof callback !== 'function') {
                throw new Error('end() requires a callback argument')
              }

              if (this._ended) {
                return nextTick(callback, new Error('end() already called on iterator'))
              }

              this._ended = true;
              this._end(callback);
            };

            AbstractIterator$3.prototype._end = function (callback) {
              nextTick(callback);
            };

            var abstractIterator$1 = AbstractIterator$3;

            function AbstractChainedBatch$2 (db) {
              if (typeof db !== 'object' || db === null) {
                throw new TypeError('First argument must be an abstract-leveldown compliant store')
              }

              this.db = db;
              this._operations = [];
              this._written = false;
            }

            AbstractChainedBatch$2.prototype._checkWritten = function () {
              if (this._written) {
                throw new Error('write() already called on this batch')
              }
            };

            AbstractChainedBatch$2.prototype.put = function (key, value) {
              this._checkWritten();

              var err = this.db._checkKey(key) || this.db._checkValue(value);
              if (err) throw err

              key = this.db._serializeKey(key);
              value = this.db._serializeValue(value);

              this._put(key, value);

              return this
            };

            AbstractChainedBatch$2.prototype._put = function (key, value) {
              this._operations.push({ type: 'put', key: key, value: value });
            };

            AbstractChainedBatch$2.prototype.del = function (key) {
              this._checkWritten();

              var err = this.db._checkKey(key);
              if (err) throw err

              key = this.db._serializeKey(key);
              this._del(key);

              return this
            };

            AbstractChainedBatch$2.prototype._del = function (key) {
              this._operations.push({ type: 'del', key: key });
            };

            AbstractChainedBatch$2.prototype.clear = function () {
              this._checkWritten();
              this._clear();

              return this
            };

            AbstractChainedBatch$2.prototype._clear = function () {
              this._operations = [];
            };

            AbstractChainedBatch$2.prototype.write = function (options, callback) {
              this._checkWritten();

              if (typeof options === 'function') { callback = options; }
              if (typeof callback !== 'function') {
                throw new Error('write() requires a callback argument')
              }
              if (typeof options !== 'object' || options === null) {
                options = {};
              }

              this._written = true;
              this._write(options, callback);
            };

            AbstractChainedBatch$2.prototype._write = function (options, callback) {
              this.db._batch(this._operations, options, callback);
            };

            var abstractChainedBatch$1 = AbstractChainedBatch$2;

            var hasOwnProperty$4 = Object.prototype.hasOwnProperty;
            var rangeOptions$1 = 'start end gt gte lt lte'.split(' ');

            function AbstractLevelDOWN$3 (manifest) {
              this.status = 'new';

              // TODO (next major): make this mandatory
              this.supports = levelSupports(manifest, {
                status: true
              });
            }

            AbstractLevelDOWN$3.prototype.open = function (options, callback) {
              var self = this;
              var oldStatus = this.status;

              if (typeof options === 'function') callback = options;

              if (typeof callback !== 'function') {
                throw new Error('open() requires a callback argument')
              }

              if (typeof options !== 'object' || options === null) options = {};

              options.createIfMissing = options.createIfMissing !== false;
              options.errorIfExists = !!options.errorIfExists;

              this.status = 'opening';
              this._open(options, function (err) {
                if (err) {
                  self.status = oldStatus;
                  return callback(err)
                }
                self.status = 'open';
                callback();
              });
            };

            AbstractLevelDOWN$3.prototype._open = function (options, callback) {
              nextTick(callback);
            };

            AbstractLevelDOWN$3.prototype.close = function (callback) {
              var self = this;
              var oldStatus = this.status;

              if (typeof callback !== 'function') {
                throw new Error('close() requires a callback argument')
              }

              this.status = 'closing';
              this._close(function (err) {
                if (err) {
                  self.status = oldStatus;
                  return callback(err)
                }
                self.status = 'closed';
                callback();
              });
            };

            AbstractLevelDOWN$3.prototype._close = function (callback) {
              nextTick(callback);
            };

            AbstractLevelDOWN$3.prototype.get = function (key, options, callback) {
              if (typeof options === 'function') callback = options;

              if (typeof callback !== 'function') {
                throw new Error('get() requires a callback argument')
              }

              var err = this._checkKey(key);
              if (err) return nextTick(callback, err)

              key = this._serializeKey(key);

              if (typeof options !== 'object' || options === null) options = {};

              options.asBuffer = options.asBuffer !== false;

              this._get(key, options, callback);
            };

            AbstractLevelDOWN$3.prototype._get = function (key, options, callback) {
              nextTick(function () { callback(new Error('NotFound')); });
            };

            AbstractLevelDOWN$3.prototype.put = function (key, value, options, callback) {
              if (typeof options === 'function') callback = options;

              if (typeof callback !== 'function') {
                throw new Error('put() requires a callback argument')
              }

              var err = this._checkKey(key) || this._checkValue(value);
              if (err) return nextTick(callback, err)

              key = this._serializeKey(key);
              value = this._serializeValue(value);

              if (typeof options !== 'object' || options === null) options = {};

              this._put(key, value, options, callback);
            };

            AbstractLevelDOWN$3.prototype._put = function (key, value, options, callback) {
              nextTick(callback);
            };

            AbstractLevelDOWN$3.prototype.del = function (key, options, callback) {
              if (typeof options === 'function') callback = options;

              if (typeof callback !== 'function') {
                throw new Error('del() requires a callback argument')
              }

              var err = this._checkKey(key);
              if (err) return nextTick(callback, err)

              key = this._serializeKey(key);

              if (typeof options !== 'object' || options === null) options = {};

              this._del(key, options, callback);
            };

            AbstractLevelDOWN$3.prototype._del = function (key, options, callback) {
              nextTick(callback);
            };

            AbstractLevelDOWN$3.prototype.batch = function (array, options, callback) {
              if (!arguments.length) return this._chainedBatch()

              if (typeof options === 'function') callback = options;

              if (typeof array === 'function') callback = array;

              if (typeof callback !== 'function') {
                throw new Error('batch(array) requires a callback argument')
              }

              if (!Array.isArray(array)) {
                return nextTick(callback, new Error('batch(array) requires an array argument'))
              }

              if (array.length === 0) {
                return nextTick(callback)
              }

              if (typeof options !== 'object' || options === null) options = {};

              var serialized = new Array(array.length);

              for (var i = 0; i < array.length; i++) {
                if (typeof array[i] !== 'object' || array[i] === null) {
                  return nextTick(callback, new Error('batch(array) element must be an object and not `null`'))
                }

                var e = immutable(array[i]);

                if (e.type !== 'put' && e.type !== 'del') {
                  return nextTick(callback, new Error("`type` must be 'put' or 'del'"))
                }

                var err = this._checkKey(e.key);
                if (err) return nextTick(callback, err)

                e.key = this._serializeKey(e.key);

                if (e.type === 'put') {
                  var valueErr = this._checkValue(e.value);
                  if (valueErr) return nextTick(callback, valueErr)

                  e.value = this._serializeValue(e.value);
                }

                serialized[i] = e;
              }

              this._batch(serialized, options, callback);
            };

            AbstractLevelDOWN$3.prototype._batch = function (array, options, callback) {
              nextTick(callback);
            };

            AbstractLevelDOWN$3.prototype.clear = function (options, callback) {
              if (typeof options === 'function') {
                callback = options;
              } else if (typeof callback !== 'function') {
                throw new Error('clear() requires a callback argument')
              }

              options = cleanRangeOptions$1(this, options);
              options.reverse = !!options.reverse;
              options.limit = 'limit' in options ? options.limit : -1;

              this._clear(options, callback);
            };

            AbstractLevelDOWN$3.prototype._clear = function (options, callback) {
              // Avoid setupIteratorOptions, would serialize range options a second time.
              options.keys = true;
              options.values = false;
              options.keyAsBuffer = true;
              options.valueAsBuffer = true;

              var iterator = this._iterator(options);
              var emptyOptions = {};
              var self = this;

              var next = function (err) {
                if (err) {
                  return iterator.end(function () {
                    callback(err);
                  })
                }

                iterator.next(function (err, key) {
                  if (err) return next(err)
                  if (key === undefined) return iterator.end(callback)

                  // This could be optimized by using a batch, but the default _clear
                  // is not meant to be fast. Implementations have more room to optimize
                  // if they override _clear. Note: using _del bypasses key serialization.
                  self._del(key, emptyOptions, next);
                });
              };

              next();
            };

            AbstractLevelDOWN$3.prototype._setupIteratorOptions = function (options) {
              options = cleanRangeOptions$1(this, options);

              options.reverse = !!options.reverse;
              options.keys = options.keys !== false;
              options.values = options.values !== false;
              options.limit = 'limit' in options ? options.limit : -1;
              options.keyAsBuffer = options.keyAsBuffer !== false;
              options.valueAsBuffer = options.valueAsBuffer !== false;

              return options
            };

            function cleanRangeOptions$1 (db, options) {
              var result = {};

              for (var k in options) {
                if (!hasOwnProperty$4.call(options, k)) continue

                var opt = options[k];

                if (isRangeOption$1(k)) {
                  // Note that we don't reject nullish and empty options here. While
                  // those types are invalid as keys, they are valid as range options.
                  opt = db._serializeKey(opt);
                }

                result[k] = opt;
              }

              return result
            }

            function isRangeOption$1 (k) {
              return rangeOptions$1.indexOf(k) !== -1
            }

            AbstractLevelDOWN$3.prototype.iterator = function (options) {
              if (typeof options !== 'object' || options === null) options = {};
              options = this._setupIteratorOptions(options);
              return this._iterator(options)
            };

            AbstractLevelDOWN$3.prototype._iterator = function (options) {
              return new abstractIterator$1(this)
            };

            AbstractLevelDOWN$3.prototype._chainedBatch = function () {
              return new abstractChainedBatch$1(this)
            };

            AbstractLevelDOWN$3.prototype._serializeKey = function (key) {
              return key
            };

            AbstractLevelDOWN$3.prototype._serializeValue = function (value) {
              return value
            };

            AbstractLevelDOWN$3.prototype._checkKey = function (key) {
              if (key === null || key === undefined) {
                return new Error('key cannot be `null` or `undefined`')
              } else if (isBuffer$1(key) && key.length === 0) {
                return new Error('key cannot be an empty Buffer')
              } else if (key === '') {
                return new Error('key cannot be an empty String')
              } else if (Array.isArray(key) && key.length === 0) {
                return new Error('key cannot be an empty Array')
              }
            };

            AbstractLevelDOWN$3.prototype._checkValue = function (value) {
              if (value === null || value === undefined) {
                return new Error('value cannot be `null` or `undefined`')
              }
            };

            var abstractLeveldown$2 = AbstractLevelDOWN$3;

            var AbstractLevelDOWN$4 = abstractLeveldown$2;
            var AbstractIterator$4 = abstractIterator$1;
            var AbstractChainedBatch$3 = abstractChainedBatch$1;

            var abstractLeveldown$3 = {
            	AbstractLevelDOWN: AbstractLevelDOWN$4,
            	AbstractIterator: AbstractIterator$4,
            	AbstractChainedBatch: AbstractChainedBatch$3
            };

            var defined = function () {
                for (var i = 0; i < arguments.length; i++) {
                    if (arguments[i] !== undefined) return arguments[i];
                }
            };

            var levelOptionWrap = function (opts, prefix) {
                if (!opts) opts = {};
                if (!prefix) prefix = {};
                var xopts = {};
                var gte = defined(prefix.gte, prefix.ge, prefix.start);
                var lte = defined(prefix.lte, prefix.le, prefix.end);
                var ogte = defined(opts.gte, opts.ge, opts.start);
                var olte = defined(opts.lte, opts.le, opts.end);
                
                if (prefix.gt) {
                    if (ogte !== undefined) {
                        xopts.gte = prefix.gt(ogte);
                    }
                    else xopts.gt = prefix.gt(opts.gt);
                }
                else if (gte) {
                    if (ogte !== undefined) {
                        xopts.gte = gte(ogte);
                    }
                    else xopts.gt = gte(opts.gt);
                }
                
                if (prefix.lt) {
                    if (olte !== undefined) {
                        xopts.lte = prefix.lt(olte);
                    }
                    else xopts.lt = prefix.lt(opts.lt);
                }
                else if (lte) {
                    if (olte !== undefined) {
                        xopts.lte = lte(olte);
                    }
                    else xopts.lt = lte(opts.lt);
                }
                
                if (prefix.limit !== undefined) {
                    xopts.limit = prefix.limit(opts.limit);
                }
                else if (opts.limit !== undefined) {
                    xopts.limit = opts.limit;
                }
                return xopts;
            };

            var reachdown = function reachdown (db, visit, strict) {
              if (visit && typeof visit !== 'function') visit = typeVisitor(visit);
              return walk(db, visit, strict !== false)
            };

            function walk (db, visit, strict, nested) {
              // TBD
              // if (nested && typeof db.down === 'function') return db.down(visit, strict)

              if (visit && visit(db, type(db))) return db
              if (isAbstract(db.db)) return walk(db.db, visit, strict)
              if (isAbstract(db._db)) return walk(db._db, visit, strict)
              if (isLevelup(db.db)) return walk(db.db, visit, strict)
              if (visit && strict) return null

              return db
            }

            function isAbstract (db) {
              if (!db || typeof db !== 'object') return false

              // Loose by design, for when node_modules contains multiple versions of abstract-leveldown.
              return typeof db._batch === 'function' && typeof db._iterator === 'function'
            }

            function typeVisitor (wanted) {
              return function (db, type) {
                return type ? type === wanted : false
              }
            }

            function type (db) {
              if (db.type) return db.type

              // Fragile, but unavoidable at this time
              // TODO: add .type to abstract-leveldown implementations and levelup
              if (isLevelup(db)) return 'levelup'
              if (isEncdown(db)) return 'encoding-down'
              if (isDeferred(db)) return 'deferred-leveldown'
            }

            function isLevelup (db) {
              return isObject$2(db) && /^levelup$/i.test(db)
            }

            function isEncdown (db) {
              return isObject$2(db) && isObject$2(db.codec) && isObject$2(db.codec.encodings)
            }

            function isDeferred (db) {
              return isObject$2(db) && Array.isArray(db._operations) && Array.isArray(db._iterators)
            }

            function isObject$2 (o) {
              return typeof o === 'object' && o !== null
            }

            var matchdown = function matchdown (db, type) {
              // Skip layers that we handle ourselves
              if (type === 'levelup') return false
              if (type === 'encoding-down') return false
              if (type === 'deferred-leveldown') return false

              return true
            };

            var rangeOptions$2 = 'start end gt gte lt lte'.split(' ');
            var defaultClear = abstractLeveldown$3.AbstractLevelDOWN.prototype._clear;
            var hasOwnProperty$5 = Object.prototype.hasOwnProperty;
            var END = Buffer.from([0xff]);

            function concat (prefix, key, force) {
              if (typeof key === 'string' && (force || key.length)) return prefix + key
              if (isBuffer$1(key) && (force || key.length)) {
                return Buffer.concat([Buffer.from(prefix), key])
              }
              return key
            }

            function SubIterator (db, ite, prefix) {
              this.iterator = ite;
              this.prefix = prefix;

              abstractLeveldown$3.AbstractIterator.call(this, db);
            }

            inherits_browser(SubIterator, abstractLeveldown$3.AbstractIterator);

            SubIterator.prototype._next = function (cb) {
              var self = this;
              this.iterator.next(function (err, key, value) {
                if (err) return cb(err)
                if (key) key = key.slice(self.prefix.length);
                cb.apply(null, arguments);
              });
            };

            SubIterator.prototype._seek = function (key) {
              this.iterator.seek(concat(this.prefix, key));
            };

            SubIterator.prototype._end = function (cb) {
              this.iterator.end(cb);
            };

            function SubDown (db, prefix, opts) {
              if (!(this instanceof SubDown)) return new SubDown(db, prefix, opts)
              if (typeof opts === 'string') opts = { separator: opts };
              if (!opts) opts = {};

              var separator = opts.separator;

              if (!prefix) prefix = '';
              if (!separator) separator = '!';
              if (prefix[0] === separator) prefix = prefix.slice(1);
              if (prefix[prefix.length - 1] === separator) prefix = prefix.slice(0, -1);

              this.db = db;
              this.leveldown = null;
              this.ownPrefix = separator + prefix + separator;
              this.prefix = this.ownPrefix;
              this._beforeOpen = opts.open;

              var self = this;

              this._wrap = {
                gt: function (x) {
                  return concat(self.prefix, x || '', true)
                },
                lt: function (x) {
                  if (isBuffer$1(x) && !x.length) x = END;
                  return concat(self.prefix, x || '\xff')
                }
              };

              abstractLeveldown$3.AbstractLevelDOWN.call(this);
            }

            inherits_browser(SubDown, abstractLeveldown$3.AbstractLevelDOWN);

            SubDown.prototype.type = 'subleveldown';

            SubDown.prototype._open = function (opts, cb) {
              var self = this;

              this.db.open(function (err) {
                if (err) return cb(err)

                var subdb = reachdown(self.db, 'subleveldown');

                if (subdb && subdb.prefix) {
                  self.prefix = subdb.prefix + self.ownPrefix;
                  self.leveldown = subdb.leveldown;
                } else {
                  self.leveldown = reachdown(self.db, matchdown, false);
                }

                if (self._beforeOpen) self._beforeOpen(cb);
                else cb();
              });
            };

            SubDown.prototype._close = function (cb) {
              this.leveldown.close(cb);
            };

            SubDown.prototype._serializeKey = function (key) {
              return isBuffer$1(key) ? key : String(key)
            };

            SubDown.prototype._put = function (key, value, opts, cb) {
              this.leveldown.put(concat(this.prefix, key), value, opts, cb);
            };

            SubDown.prototype._get = function (key, opts, cb) {
              this.leveldown.get(concat(this.prefix, key), opts, cb);
            };

            SubDown.prototype._del = function (key, opts, cb) {
              this.leveldown.del(concat(this.prefix, key), opts, cb);
            };

            SubDown.prototype._batch = function (operations, opts, cb) {
              // No need to make a copy of the array, abstract-leveldown does that
              for (var i = 0; i < operations.length; i++) {
                operations[i].key = concat(this.prefix, operations[i].key);
              }

              this.leveldown.batch(operations, opts, cb);
            };

            SubDown.prototype._clear = function (opts, cb) {
              if (typeof this.leveldown.clear === 'function') {
                // Prefer optimized implementation of clear()
                opts = addRestOptions(levelOptionWrap(opts, this._wrap), opts);
                this.leveldown.clear(opts, cb);
              } else {
                // Fall back to iterator-based implementation
                defaultClear.call(this, opts, cb);
              }
            };

            function addRestOptions (target, opts) {
              for (var k in opts) {
                if (hasOwnProperty$5.call(opts, k) && !isRangeOption$2(k)) {
                  target[k] = opts[k];
                }
              }

              return target
            }

            function isRangeOption$2 (k) {
              return rangeOptions$2.indexOf(k) !== -1
            }

            // TODO (refactor): use addRestOptions instead
            function extend$3 (xopts, opts) {
              xopts.keys = opts.keys;
              xopts.values = opts.values;
              xopts.createIfMissing = opts.createIfMissing;
              xopts.errorIfExists = opts.errorIfExists;
              xopts.keyEncoding = opts.keyEncoding;
              xopts.valueEncoding = opts.valueEncoding;
              xopts.compression = opts.compression;
              xopts.db = opts.db;
              xopts.limit = opts.limit;
              xopts.keyAsBuffer = opts.keyAsBuffer;
              xopts.valueAsBuffer = opts.valueAsBuffer;
              xopts.reverse = opts.reverse;
              xopts.fillCache = opts.fillCache;
              return xopts
            }

            function fixRange (opts) {
              return (!opts.reverse || (!opts.end && !opts.start)) ? opts : { start: opts.end, end: opts.start }
            }

            SubDown.prototype._iterator = function (opts) {
              var xopts = extend$3(levelOptionWrap(fixRange(opts), this._wrap), opts);
              return new SubIterator(this, this.leveldown.iterator(xopts), this.prefix)
            };

            var leveldown = SubDown;

            function AbstractIterator$5 (db) {
              if (typeof db !== 'object' || db === null) {
                throw new TypeError('First argument must be an abstract-leveldown compliant store')
              }

              this.db = db;
              this._ended = false;
              this._nexting = false;
            }

            AbstractIterator$5.prototype.next = function (callback) {
              var self = this;

              if (typeof callback !== 'function') {
                throw new Error('next() requires a callback argument')
              }

              if (self._ended) {
                nextTick(callback, new Error('cannot call next() after end()'));
                return self
              }

              if (self._nexting) {
                nextTick(callback, new Error('cannot call next() before previous next() has completed'));
                return self
              }

              self._nexting = true;
              self._next(function () {
                self._nexting = false;
                callback.apply(null, arguments);
              });

              return self
            };

            AbstractIterator$5.prototype._next = function (callback) {
              nextTick(callback);
            };

            AbstractIterator$5.prototype.seek = function (target) {
              if (this._ended) {
                throw new Error('cannot call seek() after end()')
              }
              if (this._nexting) {
                throw new Error('cannot call seek() before next() has completed')
              }

              target = this.db._serializeKey(target);
              this._seek(target);
            };

            AbstractIterator$5.prototype._seek = function (target) {};

            AbstractIterator$5.prototype.end = function (callback) {
              if (typeof callback !== 'function') {
                throw new Error('end() requires a callback argument')
              }

              if (this._ended) {
                return nextTick(callback, new Error('end() already called on iterator'))
              }

              this._ended = true;
              this._end(callback);
            };

            AbstractIterator$5.prototype._end = function (callback) {
              nextTick(callback);
            };

            var abstractIterator$2 = AbstractIterator$5;

            function AbstractChainedBatch$4 (db) {
              if (typeof db !== 'object' || db === null) {
                throw new TypeError('First argument must be an abstract-leveldown compliant store')
              }

              this.db = db;
              this._operations = [];
              this._written = false;
            }

            AbstractChainedBatch$4.prototype._checkWritten = function () {
              if (this._written) {
                throw new Error('write() already called on this batch')
              }
            };

            AbstractChainedBatch$4.prototype.put = function (key, value) {
              this._checkWritten();

              var err = this.db._checkKey(key) || this.db._checkValue(value);
              if (err) throw err

              key = this.db._serializeKey(key);
              value = this.db._serializeValue(value);

              this._put(key, value);

              return this
            };

            AbstractChainedBatch$4.prototype._put = function (key, value) {
              this._operations.push({ type: 'put', key: key, value: value });
            };

            AbstractChainedBatch$4.prototype.del = function (key) {
              this._checkWritten();

              var err = this.db._checkKey(key);
              if (err) throw err

              key = this.db._serializeKey(key);
              this._del(key);

              return this
            };

            AbstractChainedBatch$4.prototype._del = function (key) {
              this._operations.push({ type: 'del', key: key });
            };

            AbstractChainedBatch$4.prototype.clear = function () {
              this._checkWritten();
              this._clear();

              return this
            };

            AbstractChainedBatch$4.prototype._clear = function () {
              this._operations = [];
            };

            AbstractChainedBatch$4.prototype.write = function (options, callback) {
              this._checkWritten();

              if (typeof options === 'function') { callback = options; }
              if (typeof callback !== 'function') {
                throw new Error('write() requires a callback argument')
              }
              if (typeof options !== 'object' || options === null) {
                options = {};
              }

              this._written = true;
              this._write(options, callback);
            };

            AbstractChainedBatch$4.prototype._write = function (options, callback) {
              this.db._batch(this._operations, options, callback);
            };

            var abstractChainedBatch$2 = AbstractChainedBatch$4;

            var hasOwnProperty$6 = Object.prototype.hasOwnProperty;
            var rangeOptions$3 = 'start end gt gte lt lte'.split(' ');

            function AbstractLevelDOWN$5 (manifest) {
              this.status = 'new';

              // TODO (next major): make this mandatory
              this.supports = levelSupports(manifest, {
                status: true
              });
            }

            AbstractLevelDOWN$5.prototype.open = function (options, callback) {
              var self = this;
              var oldStatus = this.status;

              if (typeof options === 'function') callback = options;

              if (typeof callback !== 'function') {
                throw new Error('open() requires a callback argument')
              }

              if (typeof options !== 'object' || options === null) options = {};

              options.createIfMissing = options.createIfMissing !== false;
              options.errorIfExists = !!options.errorIfExists;

              this.status = 'opening';
              this._open(options, function (err) {
                if (err) {
                  self.status = oldStatus;
                  return callback(err)
                }
                self.status = 'open';
                callback();
              });
            };

            AbstractLevelDOWN$5.prototype._open = function (options, callback) {
              nextTick(callback);
            };

            AbstractLevelDOWN$5.prototype.close = function (callback) {
              var self = this;
              var oldStatus = this.status;

              if (typeof callback !== 'function') {
                throw new Error('close() requires a callback argument')
              }

              this.status = 'closing';
              this._close(function (err) {
                if (err) {
                  self.status = oldStatus;
                  return callback(err)
                }
                self.status = 'closed';
                callback();
              });
            };

            AbstractLevelDOWN$5.prototype._close = function (callback) {
              nextTick(callback);
            };

            AbstractLevelDOWN$5.prototype.get = function (key, options, callback) {
              if (typeof options === 'function') callback = options;

              if (typeof callback !== 'function') {
                throw new Error('get() requires a callback argument')
              }

              var err = this._checkKey(key);
              if (err) return nextTick(callback, err)

              key = this._serializeKey(key);

              if (typeof options !== 'object' || options === null) options = {};

              options.asBuffer = options.asBuffer !== false;

              this._get(key, options, callback);
            };

            AbstractLevelDOWN$5.prototype._get = function (key, options, callback) {
              nextTick(function () { callback(new Error('NotFound')); });
            };

            AbstractLevelDOWN$5.prototype.put = function (key, value, options, callback) {
              if (typeof options === 'function') callback = options;

              if (typeof callback !== 'function') {
                throw new Error('put() requires a callback argument')
              }

              var err = this._checkKey(key) || this._checkValue(value);
              if (err) return nextTick(callback, err)

              key = this._serializeKey(key);
              value = this._serializeValue(value);

              if (typeof options !== 'object' || options === null) options = {};

              this._put(key, value, options, callback);
            };

            AbstractLevelDOWN$5.prototype._put = function (key, value, options, callback) {
              nextTick(callback);
            };

            AbstractLevelDOWN$5.prototype.del = function (key, options, callback) {
              if (typeof options === 'function') callback = options;

              if (typeof callback !== 'function') {
                throw new Error('del() requires a callback argument')
              }

              var err = this._checkKey(key);
              if (err) return nextTick(callback, err)

              key = this._serializeKey(key);

              if (typeof options !== 'object' || options === null) options = {};

              this._del(key, options, callback);
            };

            AbstractLevelDOWN$5.prototype._del = function (key, options, callback) {
              nextTick(callback);
            };

            AbstractLevelDOWN$5.prototype.batch = function (array, options, callback) {
              if (!arguments.length) return this._chainedBatch()

              if (typeof options === 'function') callback = options;

              if (typeof array === 'function') callback = array;

              if (typeof callback !== 'function') {
                throw new Error('batch(array) requires a callback argument')
              }

              if (!Array.isArray(array)) {
                return nextTick(callback, new Error('batch(array) requires an array argument'))
              }

              if (array.length === 0) {
                return nextTick(callback)
              }

              if (typeof options !== 'object' || options === null) options = {};

              var serialized = new Array(array.length);

              for (var i = 0; i < array.length; i++) {
                if (typeof array[i] !== 'object' || array[i] === null) {
                  return nextTick(callback, new Error('batch(array) element must be an object and not `null`'))
                }

                var e = immutable(array[i]);

                if (e.type !== 'put' && e.type !== 'del') {
                  return nextTick(callback, new Error("`type` must be 'put' or 'del'"))
                }

                var err = this._checkKey(e.key);
                if (err) return nextTick(callback, err)

                e.key = this._serializeKey(e.key);

                if (e.type === 'put') {
                  var valueErr = this._checkValue(e.value);
                  if (valueErr) return nextTick(callback, valueErr)

                  e.value = this._serializeValue(e.value);
                }

                serialized[i] = e;
              }

              this._batch(serialized, options, callback);
            };

            AbstractLevelDOWN$5.prototype._batch = function (array, options, callback) {
              nextTick(callback);
            };

            AbstractLevelDOWN$5.prototype.clear = function (options, callback) {
              if (typeof options === 'function') {
                callback = options;
              } else if (typeof callback !== 'function') {
                throw new Error('clear() requires a callback argument')
              }

              options = cleanRangeOptions$2(this, options);
              options.reverse = !!options.reverse;
              options.limit = 'limit' in options ? options.limit : -1;

              this._clear(options, callback);
            };

            AbstractLevelDOWN$5.prototype._clear = function (options, callback) {
              // Avoid setupIteratorOptions, would serialize range options a second time.
              options.keys = true;
              options.values = false;
              options.keyAsBuffer = true;
              options.valueAsBuffer = true;

              var iterator = this._iterator(options);
              var emptyOptions = {};
              var self = this;

              var next = function (err) {
                if (err) {
                  return iterator.end(function () {
                    callback(err);
                  })
                }

                iterator.next(function (err, key) {
                  if (err) return next(err)
                  if (key === undefined) return iterator.end(callback)

                  // This could be optimized by using a batch, but the default _clear
                  // is not meant to be fast. Implementations have more room to optimize
                  // if they override _clear. Note: using _del bypasses key serialization.
                  self._del(key, emptyOptions, next);
                });
              };

              next();
            };

            AbstractLevelDOWN$5.prototype._setupIteratorOptions = function (options) {
              options = cleanRangeOptions$2(this, options);

              options.reverse = !!options.reverse;
              options.keys = options.keys !== false;
              options.values = options.values !== false;
              options.limit = 'limit' in options ? options.limit : -1;
              options.keyAsBuffer = options.keyAsBuffer !== false;
              options.valueAsBuffer = options.valueAsBuffer !== false;

              return options
            };

            function cleanRangeOptions$2 (db, options) {
              var result = {};

              for (var k in options) {
                if (!hasOwnProperty$6.call(options, k)) continue

                var opt = options[k];

                if (isRangeOption$3(k)) {
                  // Note that we don't reject nullish and empty options here. While
                  // those types are invalid as keys, they are valid as range options.
                  opt = db._serializeKey(opt);
                }

                result[k] = opt;
              }

              return result
            }

            function isRangeOption$3 (k) {
              return rangeOptions$3.indexOf(k) !== -1
            }

            AbstractLevelDOWN$5.prototype.iterator = function (options) {
              if (typeof options !== 'object' || options === null) options = {};
              options = this._setupIteratorOptions(options);
              return this._iterator(options)
            };

            AbstractLevelDOWN$5.prototype._iterator = function (options) {
              return new abstractIterator$2(this)
            };

            AbstractLevelDOWN$5.prototype._chainedBatch = function () {
              return new abstractChainedBatch$2(this)
            };

            AbstractLevelDOWN$5.prototype._serializeKey = function (key) {
              return key
            };

            AbstractLevelDOWN$5.prototype._serializeValue = function (value) {
              return value
            };

            AbstractLevelDOWN$5.prototype._checkKey = function (key) {
              if (key === null || key === undefined) {
                return new Error('key cannot be `null` or `undefined`')
              } else if (isBuffer$1(key) && key.length === 0) {
                return new Error('key cannot be an empty Buffer')
              } else if (key === '') {
                return new Error('key cannot be an empty String')
              } else if (Array.isArray(key) && key.length === 0) {
                return new Error('key cannot be an empty Array')
              }
            };

            AbstractLevelDOWN$5.prototype._checkValue = function (value) {
              if (value === null || value === undefined) {
                return new Error('value cannot be `null` or `undefined`')
              }
            };

            var abstractLeveldown$4 = AbstractLevelDOWN$5;

            var AbstractLevelDOWN$6 = abstractLeveldown$4;
            var AbstractIterator$6 = abstractIterator$2;
            var AbstractChainedBatch$5 = abstractChainedBatch$2;

            var abstractLeveldown$5 = {
            	AbstractLevelDOWN: AbstractLevelDOWN$6,
            	AbstractIterator: AbstractIterator$6,
            	AbstractChainedBatch: AbstractChainedBatch$5
            };

            var encodings = createCommonjsModule$1(function (module, exports) {
            exports.utf8 = exports['utf-8'] = {
              encode: function (data) {
                return isBinary(data) ? data : String(data)
              },
              decode: identity,
              buffer: false,
              type: 'utf8'
            };

            exports.json = {
              encode: JSON.stringify,
              decode: JSON.parse,
              buffer: false,
              type: 'json'
            };

            exports.binary = {
              encode: function (data) {
                return isBinary(data) ? data : Buffer.from(data)
              },
              decode: identity,
              buffer: true,
              type: 'binary'
            };

            exports.none = {
              encode: identity,
              decode: identity,
              buffer: false,
              type: 'id'
            };

            exports.id = exports.none;

            var bufferEncodings = [
              'hex',
              'ascii',
              'base64',
              'ucs2',
              'ucs-2',
              'utf16le',
              'utf-16le'
            ];

            bufferEncodings.forEach(function (type) {
              exports[type] = {
                encode: function (data) {
                  return isBinary(data) ? data : Buffer.from(data, type)
                },
                decode: function (buffer) {
                  return buffer.toString(type)
                },
                buffer: true,
                type: type
              };
            });

            function identity (value) {
              return value
            }

            function isBinary (data) {
              return data === undefined || data === null || isBuffer$1(data)
            }
            });
            var encodings_1 = encodings.utf8;
            var encodings_2 = encodings.json;
            var encodings_3 = encodings.binary;
            var encodings_4 = encodings.none;
            var encodings_5 = encodings.id;

            var levelCodec = Codec;

            function Codec (opts) {
              if (!(this instanceof Codec)) {
                return new Codec(opts)
              }
              this.opts = opts || {};
              this.encodings = encodings;
            }

            Codec.prototype._encoding = function (encoding) {
              if (typeof encoding === 'string') encoding = encodings[encoding];
              if (!encoding) encoding = encodings.id;
              return encoding
            };

            Codec.prototype._keyEncoding = function (opts, batchOpts) {
              return this._encoding((batchOpts && batchOpts.keyEncoding) ||
                                    (opts && opts.keyEncoding) ||
                                    this.opts.keyEncoding)
            };

            Codec.prototype._valueEncoding = function (opts, batchOpts) {
              return this._encoding((batchOpts && (batchOpts.valueEncoding || batchOpts.encoding)) ||
                                    (opts && (opts.valueEncoding || opts.encoding)) ||
                                    (this.opts.valueEncoding || this.opts.encoding))
            };

            Codec.prototype.encodeKey = function (key, opts, batchOpts) {
              return this._keyEncoding(opts, batchOpts).encode(key)
            };

            Codec.prototype.encodeValue = function (value, opts, batchOpts) {
              return this._valueEncoding(opts, batchOpts).encode(value)
            };

            Codec.prototype.decodeKey = function (key, opts) {
              return this._keyEncoding(opts).decode(key)
            };

            Codec.prototype.decodeValue = function (value, opts) {
              return this._valueEncoding(opts).decode(value)
            };

            Codec.prototype.encodeBatch = function (ops, opts) {
              var self = this;

              return ops.map(function (_op) {
                var op = {
                  type: _op.type,
                  key: self.encodeKey(_op.key, opts, _op)
                };
                if (self.keyAsBuffer(opts, _op)) op.keyEncoding = 'binary';
                if (_op.prefix) op.prefix = _op.prefix;
                if ('value' in _op) {
                  op.value = self.encodeValue(_op.value, opts, _op);
                  if (self.valueAsBuffer(opts, _op)) op.valueEncoding = 'binary';
                }
                return op
              })
            };

            var ltgtKeys = ['lt', 'gt', 'lte', 'gte', 'start', 'end'];

            Codec.prototype.encodeLtgt = function (ltgt) {
              var self = this;
              var ret = {};
              Object.keys(ltgt).forEach(function (key) {
                ret[key] = ltgtKeys.indexOf(key) > -1
                  ? self.encodeKey(ltgt[key], ltgt)
                  : ltgt[key];
              });
              return ret
            };

            Codec.prototype.createStreamDecoder = function (opts) {
              var self = this;

              if (opts.keys && opts.values) {
                return function (key, value) {
                  return {
                    key: self.decodeKey(key, opts),
                    value: self.decodeValue(value, opts)
                  }
                }
              } else if (opts.keys) {
                return function (key) {
                  return self.decodeKey(key, opts)
                }
              } else if (opts.values) {
                return function (_, value) {
                  return self.decodeValue(value, opts)
                }
              } else {
                return function () {}
              }
            };

            Codec.prototype.keyAsBuffer = function (opts) {
              return this._keyEncoding(opts).buffer
            };

            Codec.prototype.valueAsBuffer = function (opts) {
              return this._valueEncoding(opts).buffer
            };

            var AbstractLevelDOWN$7 = abstractLeveldown$5.AbstractLevelDOWN;
            var AbstractChainedBatch$6 = abstractLeveldown$5.AbstractChainedBatch;
            var AbstractIterator$7 = abstractLeveldown$5.AbstractIterator;


            var EncodingError = errors.EncodingError;
            var rangeMethods = ['approximateSize', 'compactRange'];

            var encodingDown = DB.default = DB;

            function DB (db, opts) {
              if (!(this instanceof DB)) return new DB(db, opts)

              var manifest = db.supports || {};
              var additionalMethods = manifest.additionalMethods || {};

              AbstractLevelDOWN$7.call(this, manifest);

              this.supports.encodings = true;
              this.supports.additionalMethods = {};

              rangeMethods.forEach(function (m) {
                // TODO (future major): remove this fallback
                var fallback = typeof db[m] === 'function';

                if (additionalMethods[m] || fallback) {
                  this.supports.additionalMethods[m] = true;

                  this[m] = function (start, end, opts, cb) {
                    start = this.codec.encodeKey(start, opts);
                    end = this.codec.encodeKey(end, opts);
                    return this.db[m](start, end, opts, cb)
                  };
                }
              }, this);

              opts = opts || {};
              if (typeof opts.keyEncoding === 'undefined') opts.keyEncoding = 'utf8';
              if (typeof opts.valueEncoding === 'undefined') opts.valueEncoding = 'utf8';

              this.db = db;
              this.codec = new levelCodec(opts);
            }

            inherits_browser(DB, AbstractLevelDOWN$7);

            DB.prototype.type = 'encoding-down';

            DB.prototype._serializeKey =
            DB.prototype._serializeValue = function (datum) {
              return datum
            };

            DB.prototype._open = function (opts, cb) {
              this.db.open(opts, cb);
            };

            DB.prototype._close = function (cb) {
              this.db.close(cb);
            };

            DB.prototype._put = function (key, value, opts, cb) {
              key = this.codec.encodeKey(key, opts);
              value = this.codec.encodeValue(value, opts);
              this.db.put(key, value, opts, cb);
            };

            DB.prototype._get = function (key, opts, cb) {
              var self = this;
              key = this.codec.encodeKey(key, opts);
              opts.asBuffer = this.codec.valueAsBuffer(opts);
              this.db.get(key, opts, function (err, value) {
                if (err) return cb(err)
                try {
                  value = self.codec.decodeValue(value, opts);
                } catch (err) {
                  return cb(new EncodingError(err))
                }
                cb(null, value);
              });
            };

            DB.prototype._del = function (key, opts, cb) {
              key = this.codec.encodeKey(key, opts);
              this.db.del(key, opts, cb);
            };

            DB.prototype._chainedBatch = function () {
              return new Batch$1(this)
            };

            DB.prototype._batch = function (ops, opts, cb) {
              ops = this.codec.encodeBatch(ops, opts);
              this.db.batch(ops, opts, cb);
            };

            DB.prototype._iterator = function (opts) {
              opts.keyAsBuffer = this.codec.keyAsBuffer(opts);
              opts.valueAsBuffer = this.codec.valueAsBuffer(opts);
              return new Iterator(this, opts)
            };

            DB.prototype._clear = function (opts, callback) {
              opts = this.codec.encodeLtgt(opts);
              this.db.clear(opts, callback);
            };

            function Iterator (db, opts) {
              AbstractIterator$7.call(this, db);
              this.codec = db.codec;
              this.keys = opts.keys;
              this.values = opts.values;
              this.opts = this.codec.encodeLtgt(opts);
              this.it = db.db.iterator(this.opts);
            }

            inherits_browser(Iterator, AbstractIterator$7);

            Iterator.prototype._next = function (cb) {
              var self = this;
              this.it.next(function (err, key, value) {
                if (err) return cb(err)
                try {
                  if (self.keys && typeof key !== 'undefined') {
                    key = self.codec.decodeKey(key, self.opts);
                  } else {
                    key = undefined;
                  }

                  if (self.values && typeof value !== 'undefined') {
                    value = self.codec.decodeValue(value, self.opts);
                  } else {
                    value = undefined;
                  }
                } catch (err) {
                  return cb(new EncodingError(err))
                }
                cb(null, key, value);
              });
            };

            Iterator.prototype._seek = function (key) {
              key = this.codec.encodeKey(key, this.opts);
              this.it.seek(key);
            };

            Iterator.prototype._end = function (cb) {
              this.it.end(cb);
            };

            function Batch$1 (db, codec) {
              AbstractChainedBatch$6.call(this, db);
              this.codec = db.codec;
              this.batch = db.db.batch();
            }

            inherits_browser(Batch$1, AbstractChainedBatch$6);

            Batch$1.prototype._put = function (key, value) {
              key = this.codec.encodeKey(key);
              value = this.codec.encodeValue(value);
              this.batch.put(key, value);
            };

            Batch$1.prototype._del = function (key) {
              key = this.codec.encodeKey(key);
              this.batch.del(key);
            };

            Batch$1.prototype._clear = function () {
              this.batch.clear();
            };

            Batch$1.prototype._write = function (opts, cb) {
              this.batch.write(opts, cb);
            };

            var subleveldown = createCommonjsModule$1(function (module) {
            module.exports = function (db, prefix, opts) {
              if (typeof prefix === 'object' && !opts) return module.exports(db, null, prefix)
              if (!opts) opts = {};

              return levelup(encodingDown(leveldown(db, prefix, opts), opts), opts)
            };
            });

            function AbstractIterator$8 (db) {
              if (typeof db !== 'object' || db === null) {
                throw new TypeError('First argument must be an abstract-leveldown compliant store')
              }

              this.db = db;
              this._ended = false;
              this._nexting = false;
            }

            AbstractIterator$8.prototype.next = function (callback) {
              var self = this;

              if (typeof callback !== 'function') {
                throw new Error('next() requires a callback argument')
              }

              if (self._ended) {
                nextTick(callback, new Error('cannot call next() after end()'));
                return self
              }

              if (self._nexting) {
                nextTick(callback, new Error('cannot call next() before previous next() has completed'));
                return self
              }

              self._nexting = true;
              self._next(function () {
                self._nexting = false;
                callback.apply(null, arguments);
              });

              return self
            };

            AbstractIterator$8.prototype._next = function (callback) {
              nextTick(callback);
            };

            AbstractIterator$8.prototype.seek = function (target) {
              if (this._ended) {
                throw new Error('cannot call seek() after end()')
              }
              if (this._nexting) {
                throw new Error('cannot call seek() before next() has completed')
              }

              target = this.db._serializeKey(target);
              this._seek(target);
            };

            AbstractIterator$8.prototype._seek = function (target) {};

            AbstractIterator$8.prototype.end = function (callback) {
              if (typeof callback !== 'function') {
                throw new Error('end() requires a callback argument')
              }

              if (this._ended) {
                return nextTick(callback, new Error('end() already called on iterator'))
              }

              this._ended = true;
              this._end(callback);
            };

            AbstractIterator$8.prototype._end = function (callback) {
              nextTick(callback);
            };

            var abstractIterator$3 = AbstractIterator$8;

            function AbstractChainedBatch$7 (db) {
              if (typeof db !== 'object' || db === null) {
                throw new TypeError('First argument must be an abstract-leveldown compliant store')
              }

              this.db = db;
              this._operations = [];
              this._written = false;
            }

            AbstractChainedBatch$7.prototype._checkWritten = function () {
              if (this._written) {
                throw new Error('write() already called on this batch')
              }
            };

            AbstractChainedBatch$7.prototype.put = function (key, value) {
              this._checkWritten();

              var err = this.db._checkKey(key) || this.db._checkValue(value);
              if (err) throw err

              key = this.db._serializeKey(key);
              value = this.db._serializeValue(value);

              this._put(key, value);

              return this
            };

            AbstractChainedBatch$7.prototype._put = function (key, value) {
              this._operations.push({ type: 'put', key: key, value: value });
            };

            AbstractChainedBatch$7.prototype.del = function (key) {
              this._checkWritten();

              var err = this.db._checkKey(key);
              if (err) throw err

              key = this.db._serializeKey(key);
              this._del(key);

              return this
            };

            AbstractChainedBatch$7.prototype._del = function (key) {
              this._operations.push({ type: 'del', key: key });
            };

            AbstractChainedBatch$7.prototype.clear = function () {
              this._checkWritten();
              this._clear();

              return this
            };

            AbstractChainedBatch$7.prototype._clear = function () {
              this._operations = [];
            };

            AbstractChainedBatch$7.prototype.write = function (options, callback) {
              this._checkWritten();

              if (typeof options === 'function') { callback = options; }
              if (typeof callback !== 'function') {
                throw new Error('write() requires a callback argument')
              }
              if (typeof options !== 'object' || options === null) {
                options = {};
              }

              this._written = true;
              this._write(options, callback);
            };

            AbstractChainedBatch$7.prototype._write = function (options, callback) {
              this.db._batch(this._operations, options, callback);
            };

            var abstractChainedBatch$3 = AbstractChainedBatch$7;

            var hasOwnProperty$7 = Object.prototype.hasOwnProperty;
            var rangeOptions$4 = 'start end gt gte lt lte'.split(' ');

            function AbstractLevelDOWN$8 (manifest) {
              this.status = 'new';

              // TODO (next major): make this mandatory
              this.supports = levelSupports(manifest, {
                status: true
              });
            }

            AbstractLevelDOWN$8.prototype.open = function (options, callback) {
              var self = this;
              var oldStatus = this.status;

              if (typeof options === 'function') callback = options;

              if (typeof callback !== 'function') {
                throw new Error('open() requires a callback argument')
              }

              if (typeof options !== 'object' || options === null) options = {};

              options.createIfMissing = options.createIfMissing !== false;
              options.errorIfExists = !!options.errorIfExists;

              this.status = 'opening';
              this._open(options, function (err) {
                if (err) {
                  self.status = oldStatus;
                  return callback(err)
                }
                self.status = 'open';
                callback();
              });
            };

            AbstractLevelDOWN$8.prototype._open = function (options, callback) {
              nextTick(callback);
            };

            AbstractLevelDOWN$8.prototype.close = function (callback) {
              var self = this;
              var oldStatus = this.status;

              if (typeof callback !== 'function') {
                throw new Error('close() requires a callback argument')
              }

              this.status = 'closing';
              this._close(function (err) {
                if (err) {
                  self.status = oldStatus;
                  return callback(err)
                }
                self.status = 'closed';
                callback();
              });
            };

            AbstractLevelDOWN$8.prototype._close = function (callback) {
              nextTick(callback);
            };

            AbstractLevelDOWN$8.prototype.get = function (key, options, callback) {
              if (typeof options === 'function') callback = options;

              if (typeof callback !== 'function') {
                throw new Error('get() requires a callback argument')
              }

              var err = this._checkKey(key);
              if (err) return nextTick(callback, err)

              key = this._serializeKey(key);

              if (typeof options !== 'object' || options === null) options = {};

              options.asBuffer = options.asBuffer !== false;

              this._get(key, options, callback);
            };

            AbstractLevelDOWN$8.prototype._get = function (key, options, callback) {
              nextTick(function () { callback(new Error('NotFound')); });
            };

            AbstractLevelDOWN$8.prototype.put = function (key, value, options, callback) {
              if (typeof options === 'function') callback = options;

              if (typeof callback !== 'function') {
                throw new Error('put() requires a callback argument')
              }

              var err = this._checkKey(key) || this._checkValue(value);
              if (err) return nextTick(callback, err)

              key = this._serializeKey(key);
              value = this._serializeValue(value);

              if (typeof options !== 'object' || options === null) options = {};

              this._put(key, value, options, callback);
            };

            AbstractLevelDOWN$8.prototype._put = function (key, value, options, callback) {
              nextTick(callback);
            };

            AbstractLevelDOWN$8.prototype.del = function (key, options, callback) {
              if (typeof options === 'function') callback = options;

              if (typeof callback !== 'function') {
                throw new Error('del() requires a callback argument')
              }

              var err = this._checkKey(key);
              if (err) return nextTick(callback, err)

              key = this._serializeKey(key);

              if (typeof options !== 'object' || options === null) options = {};

              this._del(key, options, callback);
            };

            AbstractLevelDOWN$8.prototype._del = function (key, options, callback) {
              nextTick(callback);
            };

            AbstractLevelDOWN$8.prototype.batch = function (array, options, callback) {
              if (!arguments.length) return this._chainedBatch()

              if (typeof options === 'function') callback = options;

              if (typeof array === 'function') callback = array;

              if (typeof callback !== 'function') {
                throw new Error('batch(array) requires a callback argument')
              }

              if (!Array.isArray(array)) {
                return nextTick(callback, new Error('batch(array) requires an array argument'))
              }

              if (array.length === 0) {
                return nextTick(callback)
              }

              if (typeof options !== 'object' || options === null) options = {};

              var serialized = new Array(array.length);

              for (var i = 0; i < array.length; i++) {
                if (typeof array[i] !== 'object' || array[i] === null) {
                  return nextTick(callback, new Error('batch(array) element must be an object and not `null`'))
                }

                var e = immutable(array[i]);

                if (e.type !== 'put' && e.type !== 'del') {
                  return nextTick(callback, new Error("`type` must be 'put' or 'del'"))
                }

                var err = this._checkKey(e.key);
                if (err) return nextTick(callback, err)

                e.key = this._serializeKey(e.key);

                if (e.type === 'put') {
                  var valueErr = this._checkValue(e.value);
                  if (valueErr) return nextTick(callback, valueErr)

                  e.value = this._serializeValue(e.value);
                }

                serialized[i] = e;
              }

              this._batch(serialized, options, callback);
            };

            AbstractLevelDOWN$8.prototype._batch = function (array, options, callback) {
              nextTick(callback);
            };

            AbstractLevelDOWN$8.prototype.clear = function (options, callback) {
              if (typeof options === 'function') {
                callback = options;
              } else if (typeof callback !== 'function') {
                throw new Error('clear() requires a callback argument')
              }

              options = cleanRangeOptions$3(this, options);
              options.reverse = !!options.reverse;
              options.limit = 'limit' in options ? options.limit : -1;

              this._clear(options, callback);
            };

            AbstractLevelDOWN$8.prototype._clear = function (options, callback) {
              // Avoid setupIteratorOptions, would serialize range options a second time.
              options.keys = true;
              options.values = false;
              options.keyAsBuffer = true;
              options.valueAsBuffer = true;

              var iterator = this._iterator(options);
              var emptyOptions = {};
              var self = this;

              var next = function (err) {
                if (err) {
                  return iterator.end(function () {
                    callback(err);
                  })
                }

                iterator.next(function (err, key) {
                  if (err) return next(err)
                  if (key === undefined) return iterator.end(callback)

                  // This could be optimized by using a batch, but the default _clear
                  // is not meant to be fast. Implementations have more room to optimize
                  // if they override _clear. Note: using _del bypasses key serialization.
                  self._del(key, emptyOptions, next);
                });
              };

              next();
            };

            AbstractLevelDOWN$8.prototype._setupIteratorOptions = function (options) {
              options = cleanRangeOptions$3(this, options);

              options.reverse = !!options.reverse;
              options.keys = options.keys !== false;
              options.values = options.values !== false;
              options.limit = 'limit' in options ? options.limit : -1;
              options.keyAsBuffer = options.keyAsBuffer !== false;
              options.valueAsBuffer = options.valueAsBuffer !== false;

              return options
            };

            function cleanRangeOptions$3 (db, options) {
              var result = {};

              for (var k in options) {
                if (!hasOwnProperty$7.call(options, k)) continue

                var opt = options[k];

                if (isRangeOption$4(k)) {
                  // Note that we don't reject nullish and empty options here. While
                  // those types are invalid as keys, they are valid as range options.
                  opt = db._serializeKey(opt);
                }

                result[k] = opt;
              }

              return result
            }

            function isRangeOption$4 (k) {
              return rangeOptions$4.indexOf(k) !== -1
            }

            AbstractLevelDOWN$8.prototype.iterator = function (options) {
              if (typeof options !== 'object' || options === null) options = {};
              options = this._setupIteratorOptions(options);
              return this._iterator(options)
            };

            AbstractLevelDOWN$8.prototype._iterator = function (options) {
              return new abstractIterator$3(this)
            };

            AbstractLevelDOWN$8.prototype._chainedBatch = function () {
              return new abstractChainedBatch$3(this)
            };

            AbstractLevelDOWN$8.prototype._serializeKey = function (key) {
              return key
            };

            AbstractLevelDOWN$8.prototype._serializeValue = function (value) {
              return value
            };

            AbstractLevelDOWN$8.prototype._checkKey = function (key) {
              if (key === null || key === undefined) {
                return new Error('key cannot be `null` or `undefined`')
              } else if (isBuffer$1(key) && key.length === 0) {
                return new Error('key cannot be an empty Buffer')
              } else if (key === '') {
                return new Error('key cannot be an empty String')
              } else if (Array.isArray(key) && key.length === 0) {
                return new Error('key cannot be an empty Array')
              }
            };

            AbstractLevelDOWN$8.prototype._checkValue = function (value) {
              if (value === null || value === undefined) {
                return new Error('value cannot be `null` or `undefined`')
              }
            };

            var abstractLeveldown$6 = AbstractLevelDOWN$8;

            var AbstractLevelDOWN$9 = abstractLeveldown$6;
            var AbstractIterator$9 = abstractIterator$3;

            /*! *****************************************************************************
            Copyright (c) Microsoft Corporation. All rights reserved.
            Licensed under the Apache License, Version 2.0 (the "License"); you may not use
            this file except in compliance with the License. You may obtain a copy of the
            License at http://www.apache.org/licenses/LICENSE-2.0

            THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
            KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
            WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
            MERCHANTABLITY OR NON-INFRINGEMENT.

            See the Apache Version 2.0 License for specific language governing permissions
            and limitations under the License.
            ***************************************************************************** */

            function __awaiter$1(thisArg, _arguments, P, generator) {
                return new (P || (P = Promise))(function (resolve, reject) {
                    function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
                    function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
                    function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
                    step((generator = generator.apply(thisArg, _arguments || [])).next());
                });
            }

            class BrainKey {
                constructor(options) {
                    this.crypto = options.crypto;
                    this.brainKeyCrypto = options.brainKeyCrypto;
                    this.pythiaClient = options.pythiaClient;
                    this.keyPairType = options.keyPairType;
                }
                generateKeyPair(password, brainKeyId) {
                    return __awaiter$1(this, void 0, void 0, function* () {
                        const { blindedPassword, blindingSecret } = this.brainKeyCrypto.blind(password);
                        const seed = yield this.pythiaClient.generateSeed(blindedPassword.toString('base64'), brainKeyId);
                        const deblindedPassword = this.brainKeyCrypto.deblind({
                            blindingSecret,
                            transformedPassword: seed,
                        });
                        return this.crypto.generateKeysFromKeyMaterial(deblindedPassword, this.keyPairType);
                    });
                }
            }

            class PythiaError extends Error {
                // eslint-disable-next-line @typescript-eslint/no-explicit-any
                constructor(message, name = 'PythiaError', DerivedClass = PythiaError) {
                    super(message);
                    Object.setPrototypeOf(this, DerivedClass.prototype);
                    this.name = name;
                }
            }
            class PythiaClientError extends PythiaError {
                constructor(message, code, httpStatus) {
                    super(message, 'PythiaClientError', PythiaClientError);
                    this.code = code;
                    this.httpStatus = httpStatus;
                }
            }

            class PythiaClient {
                constructor(accessTokenProvider, apiUrl, virgilAgent) {
                    if (accessTokenProvider == null) {
                        throw new Error('`accessTokenProvider` is required');
                    }
                    this.accessTokenProvider = accessTokenProvider;
                    this.axios = axios$1.create({ baseURL: apiUrl || PythiaClient.DEFAULT_URL });
                    this.virgilAgent =
                        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                        virgilAgent || new VirgilAgent("pythia", "0.3.4");
                    this.axios.interceptors.response.use(undefined, PythiaClient.onBadResponse);
                }
                generateSeed(blindedPassword, brainKeyId) {
                    return __awaiter$1(this, void 0, void 0, function* () {
                        const body = {
                            // eslint-disable-next-line @typescript-eslint/camelcase
                            blinded_password: blindedPassword,
                        };
                        if (brainKeyId) {
                            // eslint-disable-next-line @typescript-eslint/camelcase
                            body.brainkey_id = brainKeyId;
                        }
                        const accessToken = yield this.accessTokenProvider.getToken({
                            service: 'pythia',
                            operation: 'seed',
                        });
                        const { data: { seed }, } = yield this.axios.post('/pythia/v1/brainkey', body, {
                            headers: PythiaClient.getHeaders(this.virgilAgent, accessToken),
                        });
                        return seed;
                    });
                }
                transformPassword(options) {
                    return __awaiter$1(this, void 0, void 0, function* () {
                        const body = {
                            // eslint-disable-next-line @typescript-eslint/camelcase
                            blinded_password: options.blindedPassword,
                            // eslint-disable-next-line @typescript-eslint/camelcase
                            user_id: options.salt,
                        };
                        if (typeof options.version === 'number' && !Number.isNaN(options.version)) {
                            body.version = options.version;
                        }
                        if (typeof options.includeProof === 'boolean') {
                            // eslint-disable-next-line @typescript-eslint/camelcase
                            body.include_proof = options.includeProof;
                        }
                        const accessToken = yield this.accessTokenProvider.getToken({
                            service: 'pythia',
                            operation: 'password',
                        });
                        const { 
                        // eslint-disable-next-line @typescript-eslint/camelcase
                        data: { transformed_password, proof }, } = yield this.axios.post('/pythia/v1/password', body, {
                            headers: PythiaClient.getHeaders(this.virgilAgent, accessToken),
                        });
                        const result = {
                            // eslint-disable-next-line @typescript-eslint/camelcase
                            transformedPassword: transformed_password,
                        };
                        if (body.include_proof) {
                            result.proof = {
                                valueC: proof.value_c,
                                valueU: proof.value_u,
                            };
                        }
                        return result;
                    });
                }
                static getHeaders(virgilAgent, accessToken) {
                    return {
                        Authorization: `Virgil ${accessToken.toString()}`,
                        'Virgil-Agent': virgilAgent.value,
                    };
                }
                static onBadResponse(error) {
                    if (error.response) {
                        if (error.response.data) {
                            const message = error.response.data.message || error.response.statusText;
                            throw new PythiaClientError(message, error.response.data.code, error.response.status);
                        }
                        throw new PythiaClientError(error.response.statusText, undefined, error.response.status);
                    }
                    throw new PythiaError('Something bad happened. Please try again later.');
                }
            }
            PythiaClient.DEFAULT_URL = 'https://api.virgilsecurity.com';

            /**
             * BSD 3-Clause License
             *
             * Copyright (c) 2018-2020, Virgil Security, Inc.
             * All rights reserved.
             *
             * Redistribution and use in source and binary forms, with or without
             * modification, are permitted provided that the following conditions are met:
             *
             * * Redistributions of source code must retain the above copyright notice, this
             * list of conditions and the following disclaimer.
             *
             * * Redistributions in binary form must reproduce the above copyright notice,
             * this list of conditions and the following disclaimer in the documentation
             * and/or other materials provided with the distribution.
             *
             * * Neither the name of the copyright holder nor the names of its
             * contributors may be used to endorse or promote products derived from
             * this software without specific prior written permission.
             *
             * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
             * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
             * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
             * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
             * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
             * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
             * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
             * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
             * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
             * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
             */

            /*! *****************************************************************************
            Copyright (c) Microsoft Corporation. All rights reserved.
            Licensed under the Apache License, Version 2.0 (the "License"); you may not use
            this file except in compliance with the License. You may obtain a copy of the
            License at http://www.apache.org/licenses/LICENSE-2.0

            THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
            KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
            WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
            MERCHANTABLITY OR NON-INFRINGEMENT.

            See the Apache Version 2.0 License for specific language governing permissions
            and limitations under the License.
            ***************************************************************************** */

            function __awaiter$2(thisArg, _arguments, P, generator) {
                return new (P || (P = Promise))(function (resolve, reject) {
                    function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
                    function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
                    function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
                    step((generator = generator.apply(thisArg, _arguments || [])).next());
                });
            }

            /**
             * @hidden
             */
            function hasDuplicates(array) {
                return new Set(array).size !== array.length;
            }
            /**
             * @hidden
             */
            function getObjectValues(obj) {
                if (Object.values)
                    return Object.values(obj);
                return Object.keys(obj).map(function (e) {
                    return obj[e];
                });
            }
            /**
             * @hidden
             *
             * Splits the `array` into separate chunks of the specified `size`
             *
             * @param array
             * @param size
             */
            function chunkArray(array, size) {
                size = Math.max(size, 0);
                const length = array == null ? 0 : array.length;
                if (!length || size < 1) {
                    return [];
                }
                let index = 0;
                let resIndex = 0;
                const result = Array(Math.ceil(length / size));
                while (index < length) {
                    result[resIndex++] = array.slice(index, (index += size));
                }
                return result;
            }

            /**
             * Custom error class for errors specific to Virgil E3kit.
             */
            class SdkError extends Error {
                constructor(m, name = 'SdkError', DerivedClass = SdkError) {
                    super(m);
                    Object.setPrototypeOf(this, DerivedClass.prototype);
                    this.name = name;
                }
            }
            /**
             * Error thrown by {@link EThree.register} when identity is already registered on Virgil Cloud.
             * To load private key use EThree.restorePrivateKey or EThree.rotatePrivateKey.
             */
            class IdentityAlreadyExistsError extends SdkError {
                constructor() {
                    super('This identity is already registered on Virgil Cloud. To load private key use EThree.restorePrivateKey or EThree.rotatePrivateKey', 'IdentityAlreadyExistsError', IdentityAlreadyExistsError);
                }
            }
            /**
             * Error thrown by  {@link Ethree.unregister} and {@link EThree.rotatePrivateKey}
             * when current identity of E3kit instance is not registered (i.e. there is
             * no Virgil Card for the current identity in Virgil Cloud).
             */
            class RegisterRequiredError extends SdkError {
                constructor() {
                    super('This identity is not registered', 'RegisterRequiredError', RegisterRequiredError);
                }
            }
            /**
             * Error thrown by {@link EThree.backupPrivateKey},  {@link EThree.changePassword} and
             * {@link EThree.resetPrivateKeyBackup} when user enters wrong password.
             */
            class WrongKeyknoxPasswordError extends SdkError {
                constructor() {
                    super('Password from remote private key storage is invalid', 'WrongKeyknoxPasswordError', WrongKeyknoxPasswordError);
                }
            }
            /**
             * Error thrown by {@link EThree.rotatePrivateKey} and {@link EThree.restorePrivateKey}
             */
            class PrivateKeyAlreadyExistsError extends SdkError {
                constructor() {
                    super('You already have a private key. Use EThree.cleanup() to delete it. If you delete the last copy of the private key, you will not be able to decrypt any information encrypted for this private key', 'PrivateKeyAlreadyExistsError', PrivateKeyAlreadyExistsError);
                }
            }
            /**
             * Error thrown by {@link EThree.resetPrivateKeyBackup} when backup copy of private key doesn't exist
             */
            class PrivateKeyNoBackupError extends SdkError {
                constructor() {
                    super("Backup copy of private key doesn't exist", 'PrivateKeyNoBackupError', PrivateKeyNoBackupError);
                }
            }
            /**
             * Error thrown by {@link EThree.register}, {@link EThree.rotatePrivateKey} and {@link EThree.lookupPublicKeys}
             * when one user has more then one card.
             */
            class MultipleCardsError extends SdkError {
                constructor(identity) {
                    super(`There are several public keys registered with ${identity}, which is not supported.`, 'MultipleCardsError', MultipleCardsError);
                    this.identity = identity;
                }
            }
            /**
             * Error thrown by {@link EThree.lookupPublicKeys} in case if some identity missing or has multiple cards.
             *
             * @deprecated since version 0.7.0
             * Will be removed in version 0.8.0
             */
            class LookupError extends SdkError {
                constructor(lookupResult) {
                    super('Failed some public keys lookups. You can see the results by calling error.lookupResult property of this error instance', 'LookupError', LookupError);
                    this.lookupResult = lookupResult;
                }
            }
            /**
             * Error thrown by {@link EThree.lookupPublicKeys} in case if sought identity is not registered.
             *
             * @deprecated since version 0.7.0
             * Will be removed in version 0.8.0
             */
            class LookupNotFoundError extends SdkError {
                constructor(identity) {
                    super(`${identity} not found`, 'LookupNotFoundError', LookupNotFoundError);
                    this.identity = identity;
                }
            }
            /**
             * Error thrown by {@link EThree.decryptFile} in case if signature of the file is not valid.
             */
            class IntegrityCheckFailedError extends SdkError {
                constructor(message) {
                    super(message, 'IntegrityCheckFailedError', IntegrityCheckFailedError);
                }
            }
            /**
             * Error thrown by {@link EThree.decryptFile} or {@link EThree.encryptFile} if user aborts an operation.
             */
            class AbortError extends SdkError {
                constructor() {
                    super('Operation aborted by user', 'AbortError', AbortError);
                }
            }
            /**
             * Error thrown by {@link EThree.findUsers} when some of the users's Virgil Cards weren't found.
             */
            class UsersNotFoundError extends SdkError {
                constructor(identities) {
                    super("Virgil Cards of some of the users weren't found in Virgil Cloud.\n" +
                        'Check the "identities" property of this error to see their identites', 'UsersNotFoundError', UsersNotFoundError);
                    this.identities = identities;
                }
            }
            /**
             * Error thrown by {@link EThree.findUsers} when some of the users found have more than one Virgil Card,
             * which is not allowed.
             */
            class UsersFoundWithMultipleCardsError extends SdkError {
                constructor(identities) {
                    super('Some of the users have multiple Virgil Cards in Virgil Cloud, which is not allowed.' +
                        'Check the "identities" property of this error to see their identities', 'UsersFoundWithMultipleCardsError', UsersFoundWithMultipleCardsError);
                    this.identities = identities;
                }
            }

            (function (GroupErrorCode) {
                GroupErrorCode[GroupErrorCode["LocalGroupNotFound"] = 1] = "LocalGroupNotFound";
                GroupErrorCode[GroupErrorCode["PermissionDenied"] = 2] = "PermissionDenied";
                GroupErrorCode[GroupErrorCode["RemoteGroupNotFound"] = 3] = "RemoteGroupNotFound";
                GroupErrorCode[GroupErrorCode["InvalidGroup"] = 4] = "InvalidGroup";
                GroupErrorCode[GroupErrorCode["InvalidChangeParticipants"] = 5] = "InvalidChangeParticipants";
                GroupErrorCode[GroupErrorCode["InvalidParticipantsCount"] = 6] = "InvalidParticipantsCount";
                GroupErrorCode[GroupErrorCode["DataVerificationFailed"] = 7] = "DataVerificationFailed";
                GroupErrorCode[GroupErrorCode["GroupIdTooShort"] = 8] = "GroupIdTooShort";
                GroupErrorCode[GroupErrorCode["MessageNotFromThisGroup"] = 9] = "MessageNotFromThisGroup";
                GroupErrorCode[GroupErrorCode["GroupIsOutdated"] = 10] = "GroupIsOutdated";
                GroupErrorCode[GroupErrorCode["NoAccess"] = 11] = "NoAccess";
            })(exports.GroupErrorCode || (exports.GroupErrorCode = {}));
            class GroupError extends SdkError {
                constructor(errorCode, message) {
                    super(message, 'GroupError', GroupError);
                    this.errorCode = errorCode;
                }
            }
            /**
             * Error thrown when an attempt is made to retrieve the private key from the
             * device's persistent storage, but no private key exists.
             *
             * Thrown by {@link EThree.encrypt}, {@link EThree.decrypt}, {@link EThree.backupPrivateKey},
             * {@link EThree.createGroup}, {@link EThree.loadGroup}, {@link EThree.getGroup},
             * {@link Group.encrypt}, {@link Group.decrypt}, {@link Group.update}, {@link Group.add},
             * {@link Group.remove} and {@link Group.reAdd}.
             */
            class MissingPrivateKeyError extends SdkError {
                constructor() {
                    super('No private key found on the device. You should call "register()" of "restorePrivateKey()"', 'MissingPrivateKeyError', MissingPrivateKeyError);
                }
            }

            /**
             * @hidden
             */
            const isArray$3 = (val) => {
                return Array.isArray(val);
            };
            /**
             * @hidden
             */
            const isString$2 = (val) => {
                return typeof val === 'string';
            };
            /**
             * @hidden
             */
            function isObject$3(obj) {
                return typeof obj === 'object' && obj !== null;
            }
            /**
             * @hidden
             */
            function isVirgilCard(obj) {
                return isObject$3(obj) && 'identity' in obj && 'publicKey' in obj;
            }
            /**
             * @hidden
             */
            function isFindUsersResult(obj) {
                if (!isObject$3(obj))
                    return false;
                const values = getObjectValues(obj);
                if (values.length === 0)
                    return false;
                return values.every(val => isVirgilCard(val));
            }
            /**
             * @hidden
             */
            function isLookupResult(obj, isPublicKeyFn) {
                if (!isObject$3(obj))
                    return false;
                const values = getObjectValues(obj);
                if (values.length === 0)
                    return false;
                return values.every(val => isPublicKeyFn(val));
            }

            /**
             * @hidden
             */
            const DEFAULT_STORAGE_NAME = '.virgil-local-storage';
            /**
             * @hidden
             */
            const DEFAULT_GROUP_STORAGE_NAME = '.virgil-group-storage';
            /**
             * @hidden
             */
            const DEFAULT_API_URL = 'https://api.virgilsecurity.com';
            /**
             * @hidden
             */
            const MAX_IDENTITIES_TO_SEARCH = 50;
            /**
             * @hidden
             */
            const CLOUD_GROUP_SESSIONS_ROOT = 'group-sessions';
            /**
             * @hidden
             */
            const VALID_GROUP_PARTICIPANT_COUNT_RANGE = [1, 100];
            /**
             * @hidden
             */
            const MAX_EPOCHS_IN_GROUP_SESSION = 50;

            function warn(message) {
                if (typeof console !== 'undefined' && typeof console.warn === 'function') {
                    console.warn(message);
                }
            }

            const DATE_TAG = '[object Date]';
            const toString$2 = Object.prototype.toString;
            /**
             * @hidden
             */
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            function isValidDate(date) {
                return date && toString$2.call(date) === DATE_TAG && !isNaN(date);
            }

            /**
             * @hidden
             */
            function getCardActiveAtMoment(card, activeAt) {
                if (!activeAt) {
                    return card;
                }
                const activeAtDate = new Date(activeAt);
                if (!isValidDate(activeAtDate)) {
                    throw new TypeError('Cannot get active card. Second argument, if provided, must be a Date or a timestamp');
                }
                let actualCard = card;
                while (actualCard && actualCard.createdAt > activeAt) {
                    actualCard = actualCard.previousCard;
                }
                if (!actualCard) {
                    throw new Error('The given sender Virgil Card is newer than the encrypted data.' +
                        'This may happen if they un-registered and registered again with the same identity.' +
                        'Try loading their Virgil Card by its ID.');
                }
                return actualCard;
            }
            /**
             * @hidden
             */
            const getCardsArray = (cardOrFindUsersResult) => {
                if (isVirgilCard(cardOrFindUsersResult)) {
                    return [cardOrFindUsersResult];
                }
                if (isFindUsersResult(cardOrFindUsersResult)) {
                    return getObjectValues(cardOrFindUsersResult);
                }
                return [];
            };

            /**
             * @hidden
             */
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            const isInteger = (val) => {
                if (Number.isInteger)
                    return Number.isInteger(val);
                return typeof val === 'number' && isFinite(val) && Math.floor(val) === val;
            };
            /**
             * @hidden
             */
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            const isSafeInteger = (val) => {
                if (Number.isSafeInteger)
                    return Number.isSafeInteger(val);
                return isInteger(val) && Math.abs(val) <= Number.MAX_SAFE_INTEGER;
            };
            /**
             * @hidden
             */
            const isNumberInRange = (num, range) => {
                return typeof num === 'number' && num >= range[0] && num <= range[1];
            };

            /**
             * @hidden
             */
            const setDifference = (a, b) => {
                return new Set([...a].filter(it => !b.has(it)));
            };

            const isValidParticipantCount = (count) => {
                return isNumberInRange(count, VALID_GROUP_PARTICIPANT_COUNT_RANGE);
            };
            class Group {
                constructor(options) {
                    const sortedTickets = options.tickets
                        .slice()
                        .sort((a, b) => a.groupSessionMessage.epochNumber - b.groupSessionMessage.epochNumber);
                    const lastTicket = sortedTickets[sortedTickets.length - 1];
                    if (!lastTicket) {
                        throw new GroupError(exports.GroupErrorCode.InvalidGroup, 'Failed to construct Group. Group must have at least one ticket.');
                    }
                    if (!isValidParticipantCount(lastTicket.participants.length)) {
                        throw new GroupError(exports.GroupErrorCode.InvalidParticipantsCount, `Cannot initialize group with ${lastTicket.participants.length} participant(s). Group can have ${VALID_GROUP_PARTICIPANT_COUNT_RANGE[0]} to ${VALID_GROUP_PARTICIPANT_COUNT_RANGE[1]} participants.`);
                    }
                    this.selfIdentity = options.privateKeyLoader.identity;
                    this.initiator = options.initiator;
                    this.participants = lastTicket.participants;
                    this._virgilCrypto = options.privateKeyLoader.options.virgilCrypto;
                    this._privateKeyLoader = options.privateKeyLoader;
                    this._session = this._virgilCrypto.importGroupSession(sortedTickets.map(t => t.groupSessionMessage.data));
                    this._cardManager = options.cardManager;
                    this._groupManager = options.groupManager;
                }
                encrypt(data) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const shouldReturnString = isString$2(data);
                        const privateKey = yield this._privateKeyLoader.loadLocalPrivateKey();
                        if (!privateKey) {
                            throw new MissingPrivateKeyError();
                        }
                        const encrypted = this._session.encrypt(data, privateKey);
                        return shouldReturnString ? encrypted.toString('base64') : encrypted;
                    });
                }
                decrypt(encryptedData, senderCard, encryptedAt) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const { sessionId: messageSessionId, epochNumber: messageEpochNumber, data: messageData, } = this._session.parseMessage(encryptedData);
                        if (!isVirgilCard(senderCard)) {
                            throw new TypeError('Cannot decrypt data. Second argument must be a Virgil Card object.');
                        }
                        const shouldReturnString = isString$2(encryptedData);
                        const actualCard = encryptedAt
                            ? getCardActiveAtMoment(senderCard, encryptedAt)
                            : senderCard;
                        if (messageSessionId !== this._session.getSessionId()) {
                            throw new GroupError(exports.GroupErrorCode.MessageNotFromThisGroup, 'The given message was encrypted for different group');
                        }
                        if (messageEpochNumber > this._session.getCurrentEpochNumber()) {
                            throw new GroupError(exports.GroupErrorCode.GroupIsOutdated, 'This group is out of date. Call "group.update()" or "e3kitInstance.loadGroup()" to be able to decrypt this message');
                        }
                        try {
                            let decrypted;
                            if (this._session.getCurrentEpochNumber() - messageEpochNumber <
                                MAX_EPOCHS_IN_GROUP_SESSION) {
                                decrypted = this._session.decrypt(messageData, actualCard.publicKey);
                            }
                            else {
                                const tempGroup = yield this._groupManager.retrieve(messageSessionId, messageEpochNumber);
                                if (!tempGroup) {
                                    throw new GroupError(exports.GroupErrorCode.LocalGroupNotFound, `Group with given id was not found in local storage. Try to load it first.`);
                                }
                                decrypted = tempGroup.decrypt(encryptedData, actualCard);
                            }
                            return shouldReturnString ? decrypted.toString('utf8') : decrypted;
                        }
                        catch (err) {
                            if (err.name === 'FoundationError' && /Invalid signature/.test(err.message)) {
                                throw new GroupError(exports.GroupErrorCode.DataVerificationFailed, "Verification of message integrity failed. This may be caused by the sender's public key rotation." +
                                    'Try looking it up again with "e3kitInstance.findUsers()"');
                            }
                            throw err;
                        }
                    });
                }
                update() {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const sessionId = this._session.getSessionId();
                        const initiatorCards = yield this._cardManager.searchCards(this.initiator);
                        if (initiatorCards.length === 0) {
                            throw new UsersNotFoundError([this.initiator]);
                        }
                        const group = yield this._groupManager.pull(sessionId, initiatorCards[0]);
                        this._session = group._session;
                        this.participants = group.participants;
                    });
                }
                add(cardOrFindUsersResult) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const cardsToAdd = getCardsArray(cardOrFindUsersResult);
                        if (cardsToAdd.length === 0) {
                            throw new TypeError('Failed to add participants. First argument must be the result of "eThree.findUsers" method');
                        }
                        if (!this.isEditable()) {
                            throw new GroupError(exports.GroupErrorCode.PermissionDenied, 'Only group initiator can add participants to the group');
                        }
                        const missingIdentities = setDifference(new Set(cardsToAdd.map(c => c.identity)), new Set(this.participants));
                        const newParticipantCount = missingIdentities.size + this.participants.length;
                        if (!isValidParticipantCount(newParticipantCount)) {
                            throw new GroupError(exports.GroupErrorCode.InvalidChangeParticipants, `Cannot add ${missingIdentities.size} participant(s) to the group that has ${this.participants.length} participants. Group can have ${VALID_GROUP_PARTICIPANT_COUNT_RANGE[0]} to ${VALID_GROUP_PARTICIPANT_COUNT_RANGE[1]} participants.`);
                        }
                        const missingCards = cardsToAdd.filter(c => missingIdentities.has(c.identity));
                        yield this._groupManager.addAccess(this._session.getSessionId(), missingCards);
                        this.participants = [...this.participants, ...missingIdentities];
                    });
                }
                remove(cardOrFindUsersResult) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const cardsToRemove = getCardsArray(cardOrFindUsersResult);
                        if (cardsToRemove.length === 0) {
                            throw new TypeError('Failed to remove participants. First argument must be the result of "eThree.findUsers" method');
                        }
                        if (!this.isEditable()) {
                            throw new GroupError(exports.GroupErrorCode.PermissionDenied, 'Only group initiator can remove participants from the group');
                        }
                        const oldIdentities = new Set(this.participants);
                        const newIdentities = setDifference(new Set(this.participants), new Set(cardsToRemove.map(c => c.identity)));
                        if (!isValidParticipantCount(newIdentities.size)) {
                            throw new GroupError(exports.GroupErrorCode.InvalidChangeParticipants, `Cannot remove ${oldIdentities.size -
                    newIdentities.size} participant(s) from the group that has ${oldIdentities.size} participants. Group can have ${VALID_GROUP_PARTICIPANT_COUNT_RANGE[0]} to ${VALID_GROUP_PARTICIPANT_COUNT_RANGE[1]} participants.`);
                        }
                        if (newIdentities.size === oldIdentities.size) {
                            // none of the identities to remove is in the existing participants set
                            throw new GroupError(exports.GroupErrorCode.InvalidChangeParticipants, 'Attempted to remove non-existent group participants');
                        }
                        const newCards = yield this._cardManager.searchCards([...newIdentities]);
                        const epochMessage = this._session.addNewEpoch();
                        const ticket = { groupSessionMessage: epochMessage, participants: [...newIdentities] };
                        yield this._groupManager.store(ticket, newCards);
                        newIdentities.add(this.initiator);
                        this.participants = [...newIdentities];
                        const removedIdentities = setDifference(oldIdentities, newIdentities);
                        yield this._groupManager.removeAccess(this._session.getSessionId(), [...removedIdentities]);
                    });
                }
                reAdd(participantCard) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        if (!isVirgilCard(participantCard)) {
                            throw new TypeError('Failed to re-add participant. First argument must be a Virgil Card object');
                        }
                        if (!this.isEditable()) {
                            throw new GroupError(exports.GroupErrorCode.PermissionDenied, 'Only group initiator can add or remove participants from the group');
                        }
                        yield this._groupManager.reAddAccess(this._session.getSessionId(), participantCard);
                    });
                }
                isEditable() {
                    return this.initiator === this.selfIdentity;
                }
            }

            class GroupManager {
                constructor({ identity, privateKeyLoader, cardManager, groupLocalStorage, }) {
                    this._selfIdentity = identity;
                    this._privateKeyLoader = privateKeyLoader;
                    this._cardManager = cardManager;
                    this._localGroupStorage = groupLocalStorage;
                }
                store(ticket, cards) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const cloudTicketStorage = yield this.getCloudTicketStorage();
                        yield cloudTicketStorage.store(ticket.groupSessionMessage, cards);
                        const group = new Group({
                            initiator: this.selfIdentity,
                            tickets: [ticket],
                            privateKeyLoader: this._privateKeyLoader,
                            cardManager: this._cardManager,
                            groupManager: this,
                        });
                        const localGroupStorage = yield this.getLocalGroupStorage();
                        localGroupStorage.store({
                            info: { initiator: this.selfIdentity },
                            tickets: [ticket],
                        });
                        return group;
                    });
                }
                pull(sessionId, initiatorCard) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const localGroupStorage = yield this.getLocalGroupStorage();
                        let cloudTickets;
                        try {
                            const cloudTicketStorage = yield this.getCloudTicketStorage();
                            cloudTickets = yield cloudTicketStorage.retrieve(sessionId, initiatorCard.identity, initiatorCard.publicKey);
                        }
                        catch (err) {
                            if (err.name === 'GroupTicketDoesntExistError' ||
                                err.name === 'GroupTicketNoAccessError') {
                                yield localGroupStorage.delete(sessionId);
                            }
                            switch (err.name) {
                                case 'GroupTicketDoesntExistError':
                                    throw new GroupError(exports.GroupErrorCode.NoAccess, 'Current user has no access to the group ticket');
                                case 'GroupTicketNoAccessError':
                                    throw new GroupError(exports.GroupErrorCode.RemoteGroupNotFound, 'Group with given id and initiator could not be found');
                                default:
                                    throw err;
                            }
                        }
                        const initiator = initiatorCard.identity;
                        const tickets = cloudTickets.map(ct => ({
                            groupSessionMessage: ct.groupSessionMessageInfo,
                            participants: ct.identities,
                        }));
                        const group = new Group({
                            initiator,
                            tickets,
                            privateKeyLoader: this._privateKeyLoader,
                            cardManager: this._cardManager,
                            groupManager: this,
                        });
                        localGroupStorage.store({ info: { initiator }, tickets });
                        return group;
                    });
                }
                retrieve(sessionId, epochNumber) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const options = isSafeInteger(epochNumber)
                            ? { epochNumber }
                            : { ticketCount: MAX_EPOCHS_IN_GROUP_SESSION };
                        const localGroupStorage = yield this.getLocalGroupStorage();
                        try {
                            const rawGroup = yield localGroupStorage.retrieve(sessionId, options);
                            if (!rawGroup)
                                return null;
                            return new Group({
                                initiator: rawGroup.info.initiator,
                                tickets: rawGroup.tickets,
                                privateKeyLoader: this._privateKeyLoader,
                                cardManager: this._cardManager,
                                groupManager: this,
                            });
                        }
                        catch (error) {
                            if (error.name === 'GroupTicketNoAccessError') {
                                throw new GroupError(exports.GroupErrorCode.NoAccess, 'Current user has no access to the group ticket');
                            }
                            throw error;
                        }
                    });
                }
                addAccess(sessionId, allowedCards) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const cloudTicketStorage = yield this.getCloudTicketStorage();
                        const localGroupStorage = yield this.getLocalGroupStorage();
                        try {
                            yield cloudTicketStorage.addRecipients(sessionId, allowedCards);
                            yield localGroupStorage.addParticipants(sessionId, allowedCards.map(card => card.identity));
                        }
                        catch (error) {
                            if (error.name === 'GroupTicketNoAccessError') {
                                throw new GroupError(exports.GroupErrorCode.NoAccess, 'Current user has no access to the group ticket');
                            }
                            throw error;
                        }
                    });
                }
                removeAccess(sessionId, forbiddenIdentities) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const cloudTicketStorage = yield this.getCloudTicketStorage();
                        yield Promise.all(forbiddenIdentities.map(identity => cloudTicketStorage.removeRecipient(sessionId, identity)));
                    });
                }
                delete(sessionId) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const cloudTicketStorage = yield this.getCloudTicketStorage();
                        yield cloudTicketStorage.delete(sessionId);
                        const localGroupStorage = yield this.getLocalGroupStorage();
                        yield localGroupStorage.delete(sessionId);
                    });
                }
                reAddAccess(sessionId, allowedCard) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const cloudTicketStorage = yield this.getCloudTicketStorage();
                        try {
                            yield cloudTicketStorage.reAddRecipient(sessionId, allowedCard);
                        }
                        catch (error) {
                            if (error.name === 'GroupTicketNoAccessError') {
                                throw new GroupError(exports.GroupErrorCode.NoAccess, 'Current user has no access to the group ticket');
                            }
                            throw error;
                        }
                    });
                }
                cleanup() {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const localGroupStorage = yield this.getLocalGroupStorage();
                        yield localGroupStorage.reset();
                    });
                }
                get selfIdentity() {
                    return this._selfIdentity;
                }
                getLocalGroupStorage() {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const keyPair = yield this._privateKeyLoader.loadLocalKeyPair();
                        if (keyPair) {
                            this._localGroupStorage.setEncryptionKeyPair(keyPair);
                        }
                        return this._localGroupStorage;
                    });
                }
                getCloudTicketStorage() {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const keyPair = yield this._privateKeyLoader.loadLocalKeyPair();
                        if (!keyPair) {
                            throw new MissingPrivateKeyError();
                        }
                        const { virgilCrypto, accessTokenProvider, apiUrl } = this._privateKeyLoader.options;
                        const keyknoxManager = new m(new k(virgilCrypto), new p(accessTokenProvider, apiUrl, undefined, 
                        // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                        new VirgilAgent("e3kit", "0.7.1")));
                        return new x(Object.assign({ root: CLOUD_GROUP_SESSIONS_ROOT, identity: this.selfIdentity, keyknoxManager }, keyPair));
                    });
                }
            }

            class VirgilEncryptDownIterator extends AbstractIterator$9 {
                constructor(db, options) {
                    super(db);
                    this.options = options;
                    this.it = db.db.iterator(Object.assign(Object.assign({}, options), { valueAsBuffer: true }));
                }
                _next(callback) {
                    this.it.next((err, key, encrypted) => {
                        if (err) {
                            return callback(err, undefined, undefined);
                        }
                        if (key === undefined && encrypted === undefined) {
                            return callback(undefined, undefined, undefined);
                        }
                        try {
                            const decrypted = this.db.decrypt(encrypted);
                            callback(undefined, key, this.options.valueAsBuffer ? decrypted : decrypted.toString('utf8'));
                        }
                        catch (err) {
                            callback(err, undefined, undefined);
                        }
                    });
                }
                _end(callback) {
                    this.it.end(callback);
                }
            }
            class VirgilEncryptDown extends AbstractLevelDOWN$9 {
                constructor(db, options) {
                    super('ignored');
                    this.db = db;
                    this.crypto = options.virgilCrypto;
                    this.keyPair = options.keyPair;
                }
                _open(options, callback) {
                    this.db.open(options, callback);
                }
                _close(callback) {
                    this.db.close(callback);
                }
                _get(key, options, callback) {
                    this.db.get(key, Object.assign(Object.assign({}, options), { asBuffer: true }), (err, encrypted) => {
                        if (err) {
                            return callback(err, undefined);
                        }
                        try {
                            const decrypted = this.decrypt(encrypted);
                            callback(undefined, options.asBuffer ? decrypted : decrypted.toString('utf8'));
                        }
                        catch (error) {
                            callback(error, undefined);
                        }
                    });
                }
                _put(key, value, options, callback) {
                    let encrypted;
                    try {
                        encrypted = this.encrypt(value);
                    }
                    catch (err) {
                        return setTimeout(() => callback(err));
                    }
                    this._db.put(key, encrypted, options, callback);
                }
                _del(key, options, callback) {
                    this.db.del(key, options, callback);
                }
                _batch(ops, options, callback) {
                    let operations;
                    try {
                        operations = ops.map(op => {
                            if (op.type === 'put') {
                                return Object.assign(Object.assign({}, op), { value: this.encrypt(op.value) });
                            }
                            return op;
                        });
                    }
                    catch (err) {
                        return setTimeout(() => callback(err));
                    }
                    this.db.batch(operations, options, callback);
                }
                _clear(options, callback) {
                    this.db.clear(options, callback);
                }
                _iterator(options) {
                    return new VirgilEncryptDownIterator(this, options);
                }
                setKeyPair(keyPair) {
                    this.keyPair = keyPair;
                }
                encrypt(value) {
                    if (!this.keyPair) {
                        throw new Error('Cannot encrypt value. Key pair is not set. Call "setKeyPair" first.');
                    }
                    return this.crypto.signThenEncrypt(value, this.keyPair.privateKey, this.keyPair.publicKey);
                }
                decrypt(encryptedValue) {
                    if (!this.keyPair) {
                        throw new Error('Cannot decrypt value. Key pair is not set. Call "setKeyPair" first.');
                    }
                    return this.crypto.decryptThenVerify(encryptedValue, this.keyPair.privateKey, this.keyPair.publicKey);
                }
            }

            /// <reference path="../declarations.d.ts" />
            class GroupLocalStorage {
                constructor({ identity, virgilCrypto, leveldown }) {
                    this._encryptionLevel = new VirgilEncryptDown(leveldown, { virgilCrypto });
                    const rootLevel = levelup(this._encryptionLevel);
                    const identityLevel = subleveldown(rootLevel, identity);
                    this._db = subleveldown(identityLevel, 'GROUPS', { valueEncoding: 'json' });
                }
                store(rawGroup) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const lastTicket = rawGroup.tickets[rawGroup.tickets.length - 1];
                        if (!lastTicket) {
                            throw new Error('Attempted to store group without tickets.');
                        }
                        const { sessionId } = lastTicket.groupSessionMessage;
                        const insertInfo = {
                            type: 'put',
                            key: sessionId,
                            value: rawGroup.info,
                        };
                        const insertTickets = rawGroup.tickets.map(ticket => ({
                            type: 'put',
                            key: this.getTicketKey(sessionId, ticket.groupSessionMessage.epochNumber),
                            value: ticket,
                        }));
                        yield this._db.batch([insertInfo, ...insertTickets]);
                    });
                }
                retrieve(sessionId, options) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const hasTicketCount = typeof options.ticketCount === 'number';
                        const hasEpochNumber = typeof options.epochNumber === 'number';
                        if (hasTicketCount === hasEpochNumber) {
                            throw new Error('Either "ticketCount" or "epochNumber" option must be provided');
                        }
                        const [info, tickets] = yield Promise.all([
                            this.retrieveGroupInfo(sessionId),
                            options.ticketCount
                                ? this.retrieveNLastTickets(sessionId, options.ticketCount)
                                : // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                                    this.retrieveTicketByEpochNumber(sessionId, options.epochNumber),
                        ]);
                        if (!info || tickets.length === 0)
                            return null;
                        return { info, tickets };
                    });
                }
                delete(sessionId) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const prefix = sessionId;
                        yield this._db.clear({
                            gt: prefix,
                            lte: prefix + '\xff',
                        });
                    });
                }
                reset() {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        yield this._db.clear();
                    });
                }
                addParticipants(sessionId, participants) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const [ticket] = yield this.retrieveNLastTickets(sessionId, 1);
                        const newTicket = {
                            participants: ticket.participants.concat(participants),
                            groupSessionMessage: ticket.groupSessionMessage,
                        };
                        const key = this.getTicketKey(sessionId, ticket.groupSessionMessage.epochNumber);
                        // TODO: figure out why 'this._db.put' doesn't work
                        // await this._db.put(key, newTicket);
                        yield this._db.batch([{ type: 'put', key, value: newTicket }]);
                    });
                }
                setEncryptionKeyPair(keyPair) {
                    this._encryptionLevel.setKeyPair(keyPair);
                }
                retrieveGroupInfo(sessionId) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        try {
                            return yield this._db.get(sessionId);
                        }
                        catch (err) {
                            if (err.notFound) {
                                return null;
                            }
                            throw err;
                        }
                    });
                }
                retrieveNLastTickets(sessionId, ticketCount) {
                    return new Promise((resolve, reject) => {
                        const tickets = [];
                        let error = undefined;
                        const prefix = sessionId + '!';
                        this._db
                            .createReadStream({
                            gt: prefix,
                            lte: prefix + '\xff',
                            reverse: true,
                            limit: ticketCount,
                        })
                            .on('data', data => tickets.unshift(data.value))
                            .on('error', err => (error = err))
                            .on('end', () => (error ? reject(error) : resolve(tickets)));
                    });
                }
                retrieveTicketByEpochNumber(sessionId, epochNumber) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const key = this.getTicketKey(sessionId, epochNumber);
                        try {
                            const ticket = yield this._db.get(key);
                            return [ticket];
                        }
                        catch (err) {
                            if (err.notFound) {
                                return [];
                            }
                            throw err;
                        }
                    });
                }
                getTicketKey(sessionId, epochNumber) {
                    // The structure of the ticket key:
                    // `<session_id>!<number_of_digits_in_epoch_number_encoded_as_single_char>!<epoch_number>`
                    // The reasoning:
                    // keys in LevelDB are stored in alphabetical (lexicographic) order,
                    // which means that if we just put the epoch number in the key we'll
                    // start getting wrong results when reading a stream of tickets because
                    // '11' is less than '2', for example.
                    // Storing the number of digits in the key allows us to only compare
                    // epochs with the same number of digits to each other and have tickets
                    // with larger number of digits always be greater than the ones with fewer digits.
                    // Since number of digits is also a number and hence susceptible to the
                    // same problem, we encode it in base 36 to get a single character so we
                    // can handle epoch numbers with up to 35 digits in them (which is more than
                    // necessary since epoch number is uint32 in the virgil crypto library)
                    const epochNumberStr = String(epochNumber);
                    const epochNumberEncodedLength = epochNumberStr.length.toString(36);
                    return `${sessionId}!${epochNumberEncodedLength}!${epochNumberStr}`;
                }
            }

            class AbstractEThree {
                /**
                 * @hidden
                 */
                constructor(options) {
                    this.inProcess = false;
                    this.identity = options.identity;
                    this.virgilCrypto = options.virgilCrypto;
                    this.cardManager = options.cardManager;
                    this.accessTokenProvider = options.accessTokenProvider;
                    this.keyEntryStorage = options.keyEntryStorage;
                    this.keyLoader = options.keyLoader;
                    this.groupManager = new GroupManager({
                        identity: options.identity,
                        privateKeyLoader: options.keyLoader,
                        cardManager: options.cardManager,
                        groupLocalStorage: new GroupLocalStorage({
                            identity: options.identity,
                            leveldown: options.groupStorageLeveldown,
                            virgilCrypto: options.virgilCrypto,
                        }),
                    });
                }
                /**
                 * Registers current user in Virgil Cloud. Saves private key locally and uploads public key to the cloud.
                 */
                register(keyPair) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        if (this.inProcess) {
                            this.throwIllegalInvocationError('register');
                        }
                        this.inProcess = true;
                        try {
                            const [cards, privateKey] = yield Promise.all([
                                this.cardManager.searchCards(this.identity),
                                this.keyLoader.loadLocalPrivateKey(),
                            ]);
                            if (cards.length > 1)
                                throw new MultipleCardsError(this.identity);
                            if (cards.length > 0)
                                throw new IdentityAlreadyExistsError();
                            if (privateKey)
                                yield this.keyLoader.resetLocalPrivateKey();
                            yield this.publishCardThenSavePrivateKeyLocal({ keyPair });
                        }
                        finally {
                            this.inProcess = false;
                        }
                    });
                }
                /**
                 * Generates a new private key and saves locally. Replaces old public key with new one in Cloud.
                 * Used in case if old private key is lost.
                 */
                rotatePrivateKey() {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        if (this.inProcess) {
                            this.throwIllegalInvocationError('rotatePrivateKey');
                        }
                        this.inProcess = true;
                        try {
                            const [cards, privateKey] = yield Promise.all([
                                this.cardManager.searchCards(this.identity),
                                this.keyLoader.loadLocalPrivateKey(),
                            ]);
                            if (cards.length === 0)
                                throw new RegisterRequiredError();
                            if (cards.length > 1)
                                throw new MultipleCardsError(this.identity);
                            if (privateKey)
                                throw new PrivateKeyAlreadyExistsError();
                            yield this.publishCardThenSavePrivateKeyLocal({ previousCard: cards[0] });
                        }
                        finally {
                            this.inProcess = false;
                        }
                    });
                }
                /**
                 * Downloads private key from Virgil Cloud. Use [[backupPrivateKey]] to upload the key first.
                 * @param pwd User password for access to Virgil Keyknox Storage.
                 */
                restorePrivateKey(pwd) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        try {
                            yield this.keyLoader.restorePrivateKey(pwd);
                        }
                        catch (e) {
                            if (e instanceof KeyEntryAlreadyExistsError) {
                                throw new PrivateKeyAlreadyExistsError();
                            }
                            throw e;
                        }
                    });
                }
                /**
                 * Deletes local private key from key storage. Make sure [[backupPrivateKey]] method was called
                 * first.
                 */
                cleanup() {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        yield this.keyLoader.resetLocalPrivateKey();
                        yield this.onPrivateKeyDeleted();
                    });
                }
                resetPrivateKeyBackup(pwd) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        if (!pwd) {
                            return yield this.keyLoader.resetAll();
                        }
                        warn(`'resetPrivateKeyBackup(pwd: string)' was deprecated. Please use 'resetPrivateKeyBackup()' instead.`);
                        return this.keyLoader.resetPrivateKeyBackup(pwd);
                    });
                }
                encrypt(message, recipients) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const shouldReturnString = isString$2(message);
                        const privateKey = yield this.keyLoader.loadLocalPrivateKey();
                        if (!privateKey) {
                            throw new MissingPrivateKeyError();
                        }
                        const publicKeys = this.getPublicKeysForEncryption(privateKey, recipients);
                        if (!publicKeys) {
                            throw new TypeError('Could not get public keys from the second argument.\n' +
                                'Make sure you pass the resolved value of "EThree.findUsers" or "EThree.lookupPublicKeys" methods ' +
                                'when encrypting for other users, or nothing when encrypting for the current user only.');
                        }
                        const res = this.virgilCrypto.signThenEncrypt(message, privateKey, publicKeys);
                        if (shouldReturnString) {
                            return res.toString('base64');
                        }
                        return res;
                    });
                }
                decrypt(message, senderCardOrPublicKey, encryptedAt) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const shouldReturnString = isString$2(message);
                        const privateKey = yield this.keyLoader.loadLocalPrivateKey();
                        if (!privateKey) {
                            throw new MissingPrivateKeyError();
                        }
                        const senderPublicKey = this.getPublicKeyForVerification(privateKey, senderCardOrPublicKey, encryptedAt);
                        if (!senderPublicKey) {
                            throw new TypeError('Could not get public key from the second argument.' +
                                'Expected a Virgil Card or a Public Key object. Got ' +
                                typeof senderCardOrPublicKey);
                        }
                        const res = this.virgilCrypto.decryptThenVerify(message, privateKey, senderPublicKey);
                        if (shouldReturnString) {
                            return res.toString('utf8');
                        }
                        return res;
                    });
                }
                findUsers(identities) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        if (!identities) {
                            throw new TypeError('Argument "identities" is required');
                        }
                        let identitySet;
                        if (typeof identities === 'string') {
                            identitySet = new Set([identities]);
                        }
                        else if (isArray$3(identities)) {
                            identitySet = new Set(identities);
                        }
                        else {
                            throw new TypeError(`Expected "identities" to be a string or an array of strings. Got: "${typeof identities}"`);
                        }
                        if (identitySet.size === 0) {
                            throw new TypeError('"identities" array must not be empty');
                        }
                        const result = Object.create({});
                        const identitiesWithMultipleCards = new Set();
                        const identityChunks = chunkArray(Array.from(identitySet), MAX_IDENTITIES_TO_SEARCH);
                        for (const identityChunk of identityChunks) {
                            const cards = yield this.cardManager.searchCards(identityChunk);
                            for (const card of cards) {
                                if (result[card.identity]) {
                                    identitiesWithMultipleCards.add(card.identity);
                                }
                                result[card.identity] = card;
                            }
                        }
                        const identitiesFound = new Set(Object.keys(result));
                        const identitiesNotFound = new Set([...identitySet].filter(i => !identitiesFound.has(i)));
                        if (identitiesNotFound.size > 0) {
                            throw new UsersNotFoundError([...identitiesNotFound]);
                        }
                        if (identitiesWithMultipleCards.size > 0) {
                            throw new UsersFoundWithMultipleCardsError([...identitiesWithMultipleCards]);
                        }
                        if (isArray$3(identities)) {
                            return result;
                        }
                        return result[identities];
                    });
                }
                lookupPublicKeys(identities) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        warn('Warning! Method "lookupPublicKeys" has been deprecated, use "findUsers" instead');
                        const argument = isArray$3(identities) ? identities : [identities];
                        if (argument.length === 0) {
                            throw new Error('Array should be non empty');
                        }
                        if (hasDuplicates(argument)) {
                            throw new Error('Identities in array should be unique');
                        }
                        const cards = yield this.cardManager.searchCards(argument);
                        const result = {};
                        const resultWithErrors = {};
                        for (const identity of argument) {
                            const filteredCards = cards.filter(card => card.identity === identity);
                            if (filteredCards.length === 0) {
                                resultWithErrors[identity] = new LookupNotFoundError(identity);
                            }
                            else if (filteredCards.length > 1) {
                                resultWithErrors[identity] = new MultipleCardsError(identity);
                            }
                            else {
                                result[identity] = filteredCards[0].publicKey;
                            }
                        }
                        if (getObjectValues(resultWithErrors).length !== 0) {
                            throw new LookupError(Object.assign(Object.assign({}, resultWithErrors), result));
                        }
                        if (Array.isArray(identities)) {
                            return result;
                        }
                        return result[identities];
                    });
                }
                /**
                 * Changes password for access to current user private key backup.
                 * @param oldPwd users old password
                 * @param newPwd users new password
                 */
                changePassword(oldPwd, newPwd) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        return yield this.keyLoader.changePassword(oldPwd, newPwd);
                    });
                }
                /**
                 * Uploads current user private key to Virgil Keyknox Storage.
                 */
                backupPrivateKey(pwd) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const privateKey = yield this.keyLoader.loadLocalPrivateKey();
                        if (!privateKey) {
                            throw new MissingPrivateKeyError();
                        }
                        yield this.keyLoader.savePrivateKeyRemote(privateKey, pwd);
                        return;
                    });
                }
                /**
                 * Checks if current user has private key saved locally.
                 */
                hasLocalPrivateKey() {
                    return this.keyLoader.hasPrivateKey();
                }
                /**
                 * Unregister current user. Revokes public key in Virgil Cloud and deletes local private key.
                 *
                 * @throws {RegisterRequiredError} If current user is not registered (i.e.
                 *                                 there is no Virgil Card for this identity)
                 * @throws {MultipleCardsError} If there is more than one Virgil Card for this identity
                 */
                unregister() {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        if (this.inProcess) {
                            this.throwIllegalInvocationError('unregister');
                        }
                        this.inProcess = true;
                        try {
                            const cards = yield this.cardManager.searchCards(this.identity);
                            if (cards.length > 1) {
                                throw new MultipleCardsError(this.identity);
                            }
                            if (cards.length === 0) {
                                throw new RegisterRequiredError();
                            }
                            yield this.cardManager.revokeCard(cards[0].id);
                            yield this.keyLoader.resetLocalPrivateKey();
                            yield this.onPrivateKeyDeleted();
                        }
                        finally {
                            this.inProcess = false;
                        }
                    });
                }
                createGroup(groupId, participants) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        let participantIdentities = new Set();
                        let participantCards = [];
                        if (isVirgilCard(participants)) {
                            participantIdentities = new Set([participants.identity]);
                            participantCards = [participants];
                        }
                        else if (isFindUsersResult(participants)) {
                            participantIdentities = new Set(Object.keys(participants));
                            participantCards = getObjectValues(participants);
                        }
                        else if (typeof participants !== 'undefined') {
                            throw new TypeError('Expected participants to be the result of "findUsers" method call or to be "typeof undefined"');
                        }
                        participantIdentities.add(this.identity);
                        if (!isValidParticipantCount(participantIdentities.size)) {
                            throw new GroupError(exports.GroupErrorCode.InvalidParticipantsCount, `Cannot create group with ${participantIdentities.size} participant(s). Group can have ${VALID_GROUP_PARTICIPANT_COUNT_RANGE[0]} to ${VALID_GROUP_PARTICIPANT_COUNT_RANGE[1]} participants.`);
                        }
                        const groupSession = this.virgilCrypto.generateGroupSession(groupId);
                        const ticket = {
                            groupSessionMessage: {
                                epochNumber: groupSession.getCurrentEpochNumber(),
                                sessionId: groupSession.getSessionId(),
                                data: groupSession.export()[0].toString('base64'),
                            },
                            participants: [...participantIdentities],
                        };
                        return yield this.groupManager.store(ticket, participantCards);
                    });
                }
                loadGroup(groupId, initiatorCard) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const sessionId = this.virgilCrypto.calculateGroupSessionId(groupId);
                        return yield this.groupManager.pull(sessionId, initiatorCard);
                    });
                }
                getGroup(groupId) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const sessionId = this.virgilCrypto.calculateGroupSessionId(groupId);
                        return yield this.groupManager.retrieve(sessionId);
                    });
                }
                deleteGroup(groupId) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const sessionId = this.virgilCrypto.calculateGroupSessionId(groupId);
                        yield this.groupManager.delete(sessionId);
                    });
                }
                /**
                 * @hidden
                 */
                publishCardThenSavePrivateKeyLocal(options) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const { keyPair, previousCard } = options;
                        const myKeyPair = keyPair || this.virgilCrypto.generateKeys();
                        const card = yield this.cardManager.publishCard({
                            privateKey: myKeyPair.privateKey,
                            publicKey: myKeyPair.publicKey,
                            previousCardId: previousCard ? previousCard.id : undefined,
                        });
                        yield this.keyLoader.savePrivateKeyLocal(myKeyPair.privateKey);
                        return {
                            card,
                            keyPair: myKeyPair,
                        };
                    });
                }
                /**
                 * @hidden
                 */
                isOwnPublicKeyIncluded(ownPublicKey, publicKeys) {
                    const selfPublicKey = this.virgilCrypto.exportPublicKey(ownPublicKey).toString('base64');
                    const stringKeys = publicKeys.map(key => this.virgilCrypto.exportPublicKey(key).toString('base64'));
                    return stringKeys.some(key => key === selfPublicKey);
                }
                throwIllegalInvocationError(method) {
                    throw new Error(`Calling ${method} two or more times in a row is not allowed.`);
                }
                /**
                 * @hidden
                 */
                addOwnPublicKey(privateKey, publicKeys) {
                    const ownPublicKey = this.virgilCrypto.extractPublicKey(privateKey);
                    if (!this.isOwnPublicKeyIncluded(ownPublicKey, publicKeys)) {
                        publicKeys.push(ownPublicKey);
                    }
                }
                /**
                 * @hidden
                 */
                onPrivateKeyDeleted() {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        yield this.groupManager.cleanup();
                    });
                }
                /**
                 * @hidden
                 */
                getPublicKeysForEncryption(ownPrivateKey, recipients) {
                    let publicKeys;
                    if (recipients == null) {
                        publicKeys = [];
                    }
                    else if (isVirgilCard(recipients)) {
                        publicKeys = [recipients.publicKey];
                    }
                    else if (isFindUsersResult(recipients)) {
                        publicKeys = getObjectValues(recipients).map((card) => card.publicKey);
                    }
                    else if (this.isPublicKey(recipients)) {
                        warn('Warning! Calling `encrypt` with the result of `lookupPublicKeys` method has been deprecated. ' +
                            'Please use the result of `findUsers` call instead');
                        publicKeys = [recipients];
                    }
                    else if (isLookupResult(recipients, this.isPublicKey.bind(this))) {
                        warn('Warning! Calling `encrypt` with the result of `lookupPublicKeys` method has been deprecated. ' +
                            'Please use the result of `findUsers` call instead');
                        publicKeys = getObjectValues(recipients).map((publicKey) => publicKey);
                    }
                    else {
                        return null;
                    }
                    this.addOwnPublicKey(ownPrivateKey, publicKeys);
                    return publicKeys;
                }
                /**
                 * @hidden
                 */
                getPublicKeyForVerification(ownPrivateKey, senderCardOrPublicKey, encryptedAt) {
                    if (senderCardOrPublicKey == null) {
                        return this.virgilCrypto.extractPublicKey(ownPrivateKey);
                    }
                    if (isVirgilCard(senderCardOrPublicKey)) {
                        return encryptedAt
                            ? getCardActiveAtMoment(senderCardOrPublicKey, encryptedAt).publicKey
                            : senderCardOrPublicKey.publicKey;
                    }
                    if (this.isPublicKey(senderCardOrPublicKey)) {
                        return senderCardOrPublicKey;
                    }
                    return null;
                }
            }

            const BRAIN_KEY_RATE_LIMIT_DELAY = 2000;
            const BRAIN_KEY_THROTTLING_ERROR_CODE = 60007;
            /**
             * @hidden
             */
            function generateBrainPair(pwd, options) {
                return __awaiter$2(this, void 0, void 0, function* () {
                    const pythiaClient = new PythiaClient(options.accessTokenProvider, options.apiUrl, 
                    // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                    new VirgilAgent("e3kit", "0.7.1"));
                    const brainKey = new BrainKey({
                        pythiaClient,
                        crypto: options.virgilCrypto,
                        brainKeyCrypto: options.pythiaCrypto,
                    });
                    return yield brainKey.generateKeyPair(pwd).catch((e) => {
                        if (typeof e === 'object' && e.code === BRAIN_KEY_THROTTLING_ERROR_CODE) {
                            const promise = new Promise((resolve, reject) => {
                                const repeat = () => brainKey
                                    .generateKeyPair(pwd)
                                    .then(resolve)
                                    .catch(reject);
                                setTimeout(repeat, BRAIN_KEY_RATE_LIMIT_DELAY);
                            });
                            return promise;
                        }
                        throw e;
                    });
                });
            }

            /**
             * @hidden
             */
            class PrivateKeyLoader {
                constructor(identity, options) {
                    this.identity = identity;
                    this.options = options;
                    this.keyknoxClient = new p(this.options.accessTokenProvider, this.options.apiUrl, undefined, 
                    // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                    new VirgilAgent("e3kit", "0.7.1"));
                    this.keyknoxCrypto = new k(this.options.virgilCrypto);
                    this.cachedPrivateKey = null;
                    this.handleResetError = (e) => {
                        if (e instanceof c) {
                            throw new PrivateKeyNoBackupError();
                        }
                        throw e;
                    };
                    this.localStorage = options.keyEntryStorage;
                }
                savePrivateKeyRemote(privateKey, password) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const storage = yield this.getStorage(password);
                        return yield storage.storeEntry(this.identity, this.options.virgilCrypto.exportPrivateKey(privateKey).toString('base64'));
                    });
                }
                savePrivateKeyLocal(privateKey) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        this.cachedPrivateKey = privateKey;
                        return yield this.localStorage.save({
                            name: this.identity,
                            value: this.options.virgilCrypto.exportPrivateKey(privateKey).toString('base64'),
                        });
                    });
                }
                loadLocalPrivateKey() {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        if (this.cachedPrivateKey)
                            return this.cachedPrivateKey;
                        const privateKeyData = yield this.localStorage.load(this.identity);
                        if (!privateKeyData)
                            return null;
                        return this.importAndCachePrivateKey(privateKeyData.value);
                    });
                }
                loadLocalKeyPair() {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const privateKey = yield this.loadLocalPrivateKey();
                        if (!privateKey)
                            return null;
                        const publicKey = this.options.virgilCrypto.extractPublicKey(privateKey);
                        return { privateKey, publicKey };
                    });
                }
                resetLocalPrivateKey() {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        yield this.localStorage.remove(this.identity);
                        this.cachedPrivateKey = null;
                    });
                }
                resetPrivateKeyBackup(password) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const storage = yield this.getStorage(password);
                        yield storage.deleteEntry(this.identity).catch(this.handleResetError);
                    });
                }
                resetAll() {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        yield this.keyknoxClient.v1Reset();
                    });
                }
                restorePrivateKey(password) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const storage = yield this.getStorage(password);
                        try {
                            const rawKey = storage.retrieveEntry(this.identity);
                            yield this.localStorage.save({ name: this.identity, value: rawKey.data });
                            return this.importAndCachePrivateKey(rawKey.data);
                        }
                        catch (e) {
                            if (e instanceof c) {
                                throw new PrivateKeyNoBackupError();
                            }
                            throw e;
                        }
                    });
                }
                changePassword(oldPwd, newPwd) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const storage = yield this.getStorage(oldPwd);
                        const keyPair = yield this.generateBrainPair(newPwd);
                        const update = yield storage.updateRecipients({
                            newPrivateKey: keyPair.privateKey,
                            newPublicKeys: [keyPair.publicKey],
                        });
                        return update;
                    });
                }
                hasPrivateKey() {
                    return this.localStorage.exists(this.identity);
                }
                generateBrainPair(pwd) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        return generateBrainPair(pwd, {
                            virgilCrypto: this.options.virgilCrypto,
                            pythiaCrypto: this.options.brainKeyCrypto,
                            accessTokenProvider: this.options.accessTokenProvider,
                            apiUrl: this.options.apiUrl,
                        });
                    });
                }
                getStorage(pwd) {
                    return __awaiter$2(this, void 0, void 0, function* () {
                        const keyPair = yield this.generateBrainPair(pwd);
                        const storage = new f(new m(this.keyknoxCrypto, this.keyknoxClient), keyPair.privateKey, keyPair.publicKey);
                        try {
                            yield storage.retrieveCloudEntries();
                        }
                        catch (e) {
                            if (e.name === 'FoundationError' || e.name === 'RNVirgilCryptoError') {
                                throw new WrongKeyknoxPasswordError();
                            }
                            throw e;
                        }
                        return storage;
                    });
                }
                importAndCachePrivateKey(rawKeyData) {
                    this.cachedPrivateKey = this.options.virgilCrypto.importPrivateKey({
                        value: rawKeyData,
                        encoding: 'base64',
                    });
                    return this.cachedPrivateKey;
                }
            }

            const VIRGIL_STREAM_SIGNING_STATE = 'Signing';
            const VIRGIL_STREAM_ENCRYPTING_STATE = 'Encrypting';
            const VIRGIL_STREAM_DECRYPTING_STATE = 'Decrypting';
            const VIRGIL_STREAM_VERIFYING_STATE = 'Verifying';

            /*! *****************************************************************************
            Copyright (c) Microsoft Corporation. All rights reserved.
            Licensed under the Apache License, Version 2.0 (the "License"); you may not use
            this file except in compliance with the License. You may obtain a copy of the
            License at http://www.apache.org/licenses/LICENSE-2.0

            THIS CODE IS PROVIDED ON AN *AS IS* BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
            KIND, EITHER EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION ANY IMPLIED
            WARRANTIES OR CONDITIONS OF TITLE, FITNESS FOR A PARTICULAR PURPOSE,
            MERCHANTABLITY OR NON-INFRINGEMENT.

            See the Apache Version 2.0 License for specific language governing permissions
            and limitations under the License.
            ***************************************************************************** */

            function __awaiter$3(thisArg, _arguments, P, generator) {
                return new (P || (P = Promise))(function (resolve, reject) {
                    function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
                    function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
                    function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
                    step((generator = generator.apply(thisArg, _arguments || [])).next());
                });
            }

            var t,e,r$1,n$1;r$1=e={exports:{}},n$1=function(){var t="undefined"!=typeof document&&document.currentScript?document.currentScript.src:void 0;return function(e){function r(t,e,r){var n=e+r;for(r=e;t[r]&&!(r>=n);)++r;if(16<r-e&&t.subarray&&Q)return Q.decode(t.subarray(e,r));for(n="";e<r;){var _=t[e++];if(128&_){var s=63&t[e++];if(192==(224&_))n+=String.fromCharCode((31&_)<<6|s);else{var c=63&t[e++];65536>(_=224==(240&_)?(15&_)<<12|s<<6|c:(7&_)<<18|s<<12|c<<6|63&t[e++])?n+=String.fromCharCode(_):(_-=65536,n+=String.fromCharCode(55296|_>>10,56320|1023&_));}}else n+=String.fromCharCode(_);}return n}function n(t){return 0<t%65536&&(t+=65536-t%65536),t}function _(t){tt=t,O.HEAP8=et=new Int8Array(t),O.HEAP16=nt=new Int16Array(t),O.HEAP32=_t=new Int32Array(t),O.HEAPU8=rt=new Uint8Array(t),O.HEAPU16=new Uint16Array(t),O.HEAPU32=new Uint32Array(t),O.HEAPF32=new Float32Array(t),O.HEAPF64=new Float64Array(t);}function s(t){for(;0<t.length;){var e=t.shift();if("function"==typeof e)e();else{var r=e.Vp;"number"==typeof r?void 0===e.sp?O.dynCall_v(r):O.dynCall_vi(r,e.sp):r(void 0===e.sp?null:e.sp);}}}function c(){var t=O.preRun.shift();ct.unshift(t);}function a(t){throw O.onAbort&&O.onAbort(t),j(t),W(t),J=!0,"abort("+t+"). Build with -s ASSERTIONS=1 for more info."}function i(){var t=yt;return String.prototype.startsWith?t.startsWith("data:application/octet-stream;base64,"):0===t.indexOf("data:application/octet-stream;base64,")}function l(){try{if(Z)return new Uint8Array(Z);throw "both async and sync fetching of the wasm failed"}catch(t){a(t);}}function u(t,e){for(var r=0,n=t.length-1;0<=n;n--){var _=t[n];"."===_?t.splice(n,1):".."===_?(t.splice(n,1),r++):r&&(t.splice(n,1),r--);}if(e)for(;r;r--)t.unshift("..");return t}function o(t){var e="/"===t.charAt(0),r="/"===t.substr(-1);return (t=u(t.split("/").filter((function(t){return !!t})),!e).join("/"))||e||(t="."),t&&r&&(t+="/"),(e?"/":"")+t}function f(t){var e=/^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/.exec(t).slice(1);return t=e[0],e=e[1],t||e?(e&&(e=e.substr(0,e.length-1)),t+e):"."}function p(t){if("/"===t)return "/";var e=t.lastIndexOf("/");return -1===e?t:t.substr(e+1)}function d(){for(var t="",e=!1,r=arguments.length-1;-1<=r&&!e;r--){if("string"!=typeof(e=0<=r?arguments[r]:"/"))throw new TypeError("Arguments to path.resolve must be strings");if(!e)return "";t=e+"/"+t,e="/"===e.charAt(0);}return (e?"/":"")+(t=u(t.split("/").filter((function(t){return !!t})),!e).join("/"))||"."}function h(t,e){bt[t]={input:[],cp:[],lp:e},I(t,At);}function v(t,e){if(e=e||{},!(t=d("/",t)))return {path:"",node:null};var r,n={Ap:!0,vp:0};for(r in n)void 0===e[r]&&(e[r]=n[r]);if(8<e.vp)throw new Yt(32);t=u(t.split("/").filter((function(t){return !!t})),!1);var _=Ft;for(n="/",r=0;r<t.length;r++){var s=r===t.length-1;if(s&&e.parent)break;if(_=x(_,t[r]),n=o(n+"/"+t[r]),_.pp&&(!s||s&&e.Ap)&&(_=_.pp.root),!s||e.zp)for(s=0;40960==(61440&_.mode);)if(_=F(n),_=v(n=d(f(n),_),{vp:e.vp}).node,40<s++)throw new Yt(32)}return {path:n,node:_}}function y(t){for(var e;;){if(t===t.parent)return t=t.gp.Dp,e?"/"!==t[t.length-1]?t+"/"+e:t+e:t;e=e?t.name+"/"+e:t.name,t=t.parent;}}function P(t,e){for(var r=0,n=0;n<e.length;n++)r=(r<<5)-r+e.charCodeAt(n)|0;return (t+r>>>0)%Rt.length}function x(t,e){var r;if(r=(r=E(t,"x"))?r:t.Zo.mp?0:2)throw new Yt(r,t);for(r=Rt[P(t.id,e)];r;r=r.Mp){var n=r.name;if(r.parent.id===t.id&&n===e)return r}return t.Zo.mp(t,e)}function m(t,e,r,n){return Nt||((Nt=function(t,e,r,n){t||(t=this),this.parent=t,this.gp=t.gp,this.pp=null,this.id=Lt++,this.name=e,this.mode=r,this.Zo={},this.$o={},this.qp=n;}).prototype={},Object.defineProperties(Nt.prototype,{read:{get:function(){return 365==(365&this.mode)},set:function(t){t?this.mode|=365:this.mode&=-366;}},write:{get:function(){return 146==(146&this.mode)},set:function(t){t?this.mode|=146:this.mode&=-147;}}})),function(t){var e=P(t.parent.id,t.name);t.Mp=Rt[e],Rt[e]=t;}(t=new Nt(t,e,r,n)),t}function g(t){var e=["r","w","rw"][3&t];return 512&t&&(e+="w"),e}function E(t,e){return zt?0:(-1===e.indexOf("r")||292&t.mode)&&(-1===e.indexOf("w")||146&t.mode)&&(-1===e.indexOf("x")||73&t.mode)?0:2}function N(t,e){try{return x(t,e),20}catch(t){}return E(t,"wx")}function w(t,e){wt||((wt=function(){}).prototype={},Object.defineProperties(wt.prototype,{object:{get:function(){return this.node},set:function(t){this.node=t;}}}));var r,n=new wt;for(r in t)n[r]=t[r];return t=n,e=function(t){for(t=t||0;4096>=t;t++)if(!Kt[t])return t;throw new Yt(33)}(e),t.hp=e,Kt[e]=t}function I(t,e){St[t]={$o:e};}function b(t,e){var r="/"===e,n=!e;if(r&&Ft)throw new Yt(10);if(!r&&!n){var _=v(e,{Ap:!1});if(e=_.path,(_=_.node).pp)throw new Yt(10);if(16384!=(61440&_.mode))throw new Yt(54)}e={type:t,bq:{},Dp:e,Lp:[]},(t=t.gp(e)).gp=e,e.root=t,r?Ft=t:_&&(_.pp=e,_.gp&&_.gp.Lp.push(e));}function A(t,e,r){var n=v(t,{parent:!0}).node;if(!(t=p(t))||"."===t||".."===t)throw new Yt(28);var _=N(n,t);if(_)throw new Yt(_);if(!n.Zo.op)throw new Yt(63);return n.Zo.op(n,t,e,r)}function k(t){A(t,16895,0);}function C(t,e,r){void 0===r&&(r=e,e=438),A(t,8192|e,r);}function T(t,e){if(!d(t))throw new Yt(44);var r=v(e,{parent:!0}).node;if(!r)throw new Yt(44);var n=N(r,e=p(e));if(n)throw new Yt(n);if(!r.Zo.rp)throw new Yt(63);r.Zo.rp(r,e,t);}function F(t){if(!(t=v(t).node))throw new Yt(44);if(!t.Zo.np)throw new Yt(28);return d(y(t.parent),t.Zo.np(t))}function S(t,e,r,n){if(""===t)throw new Yt(44);if("string"==typeof e){var _=Ut[e];if(void 0===_)throw Error("Unknown file open mode: "+e);e=_;}if(r=64&e?4095&(void 0===r?438:r)|32768:0,"object"==typeof t)var s=t;else{t=o(t);try{s=v(t,{zp:!(131072&e)}).node;}catch(t){}}if(_=!1,64&e)if(s){if(128&e)throw new Yt(20)}else s=A(t,r,0),_=!0;if(!s)throw new Yt(44);if(8192==(61440&s.mode)&&(e&=-513),65536&e&&16384!=(61440&s.mode))throw new Yt(54);if(!_&&(r=s?40960==(61440&s.mode)?32:16384==(61440&s.mode)&&("r"!==g(e)||512&e)?31:E(s,g(e)):44))throw new Yt(r);if(512&e){var c;if(!(c="string"==typeof(r=s)?v(r,{zp:!0}).node:r).Zo.fp)throw new Yt(63);if(16384==(61440&c.mode))throw new Yt(31);if(32768!=(61440&c.mode))throw new Yt(28);if(r=E(c,"w"))throw new Yt(r);c.Zo.fp(c,{size:0,timestamp:Date.now()});}e&=-641,(n=w({node:s,path:y(s),flags:e,seekable:!0,position:0,$o:s.$o,Pp:[],error:!1},n)).$o.open&&n.$o.open(n),!O.logReadFiles||1&e||(It||(It={}),t in It||(It[t]=1,console.log("FS.trackingDelegate error on read file: "+t)));try{Bt.onOpenFile&&(s=0,1!=(2097155&e)&&(s|=1),0!=(2097155&e)&&(s|=2),Bt.onOpenFile(t,s));}catch(e){console.log("FS.trackingDelegate['onOpenFile']('"+t+"', flags) threw an exception: "+e.message);}return n}function K(t,e,r){if(null===t.hp)throw new Yt(8);if(!t.seekable||!t.$o.kp)throw new Yt(70);if(0!=r&&1!=r&&2!=r)throw new Yt(28);t.position=t.$o.kp(t,e,r),t.Pp=[];}function L(){Yt||((Yt=function(t,e){this.node=e,this.Op=function(t){this.jp=t;},this.Op(t),this.message="FS error";}).prototype=Error(),Yt.prototype.constructor=Yt,[44].forEach((function(t){Ht[t]=new Yt(t),Ht[t].stack="<generic error, no stack>";})));}function R(t,e,r){t=o("/dev/"+t);var n=function(t,e){var r=0;return t&&(r|=365),e&&(r|=146),r}(!!e,!!r);Et||(Et=64);var _=Et++<<8|0;I(_,{open:function(t){t.seekable=!1;},close:function(){r&&r.buffer&&r.buffer.length&&r(10);},read:function(t,r,n,_){for(var s=0,c=0;c<_;c++){try{var a=e();}catch(t){throw new Yt(29)}if(void 0===a&&0===s)throw new Yt(6);if(null==a)break;s++,r[n+c]=a;}return s&&(t.node.timestamp=Date.now()),s},write:function(t,e,n,_){for(var s=0;s<_;s++)try{r(e[n+s]);}catch(t){throw new Yt(29)}return _&&(t.node.timestamp=Date.now()),s}}),C(t,n,_);}function z(){return _t[(Dt+=4)-4>>2]}function B(t){if(t||(t=z()),!(t=Kt[t]))throw new Yt(8);return t}function Y(t){try{var e=B(t);if(null===e.hp)throw new Yt(8);e.tp&&(e.tp=null);try{e.$o.close&&e.$o.close(e);}catch(t){throw t}finally{Kt[e.hp]=null;}return e.hp=null,0}catch(t){return void 0!==Ot&&t instanceof Yt||a(t),t.jp}}function H(t,e,r,n){try{t:{for(var _=B(t),s=t=0;s<r;s++){var c=_,i=_t[e+8*s>>2],l=_t[e+(8*s+4)>>2],u=void 0,o=et;if(0>l||0>u)throw new Yt(28);if(null===c.hp)throw new Yt(8);if(0==(2097155&c.flags))throw new Yt(8);if(16384==(61440&c.node.mode))throw new Yt(31);if(!c.$o.write)throw new Yt(28);1024&c.flags&&K(c,0,2);var f=void 0!==u;if(f){if(!c.seekable)throw new Yt(70)}else u=c.position;var p=c.$o.write(c,o,i,l,u,void 0);f||(c.position+=p);try{c.path&&Bt.onWriteToFile&&Bt.onWriteToFile(c.path);}catch(t){console.log("FS.trackingDelegate['onWriteToFile']('"+c.path+"') threw an exception: "+t.message);}if(0>(c=p)){var d=-1;break t}t+=c;}d=t;}return _t[n>>2]=d,0}catch(t){return void 0!==Ot&&t instanceof Yt||a(t),t.jp}}function U(){return et.length}function M(){function t(){if(!jt&&(jt=!0,!J)){if(O.noFSInit||gt||(gt=!0,L(),O.stdin=O.stdin,O.stdout=O.stdout,O.stderr=O.stderr,O.stdin?R("stdin",O.stdin):T("/dev/tty","/dev/stdin"),O.stdout?R("stdout",null,O.stdout):T("/dev/tty","/dev/stdout"),O.stderr?R("stderr",null,O.stderr):T("/dev/tty1","/dev/stderr"),S("/dev/stdin","r"),S("/dev/stdout","w"),S("/dev/stderr","w")),s(at),zt=!1,s(it),O.onRuntimeInitialized&&O.onRuntimeInitialized(),O.postRun)for("function"==typeof O.postRun&&(O.postRun=[O.postRun]);O.postRun.length;){var t=O.postRun.shift();lt.unshift(t);}s(lt);}}if(!(0<dt)){if(O.preRun)for("function"==typeof O.preRun&&(O.preRun=[O.preRun]);O.preRun.length;)c();s(ct),0<dt||(O.setStatus?(O.setStatus("Running..."),setTimeout((function(){setTimeout((function(){O.setStatus("");}),1),t();}),1)):t());}}var O;e=e||{},O||(O=void 0!==e?e:{});var D,G={};for(D in O)O.hasOwnProperty(D)&&(G[D]=O[D]);var V="";document.currentScript&&(V=document.currentScript.src),t&&(V=t),V=0!==V.indexOf("blob:")?V.substr(0,V.lastIndexOf("/")+1):"";var j=O.print||console.log.bind(console),W=O.printErr||console.warn.bind(console);for(D in G)G.hasOwnProperty(D)&&(O[D]=G[D]);G=null;var Z,X={"f64-rem":function(t,e){return t%e},debugger:function(){}};O.wasmBinary&&(Z=O.wasmBinary),"object"!=typeof WebAssembly&&W("no native wasm support detected");var $,q=new WebAssembly.Table({initial:766,maximum:766,element:"anyfunc"}),J=!1,Q="undefined"!=typeof TextDecoder?new TextDecoder("utf8"):void 0;"undefined"!=typeof TextDecoder&&new TextDecoder("utf-16le");var tt,et,rt,nt,_t,st=O.TOTAL_MEMORY||16777216;($=O.wasmMemory?O.wasmMemory:new WebAssembly.Memory({initial:st/65536}))&&(tt=$.buffer),st=tt.byteLength,_(tt),_t[24176]=5339792;var ct=[],at=[],it=[],lt=[],ut=Math.abs,ot=Math.ceil,ft=Math.floor,pt=Math.min,dt=0,vt=null;O.preloadedImages={},O.preloadedAudios={};var yt="libfoundation.browser.wasm";if(!i()){var Pt=yt;yt=O.locateFile?O.locateFile(Pt,V):V+Pt;}O.asm=function(){function t(t){O.asm=t.exports,dt--,O.monitorRunDependencies&&O.monitorRunDependencies(dt),0==dt&&(vt&&(t=vt,vt=null,t()));}function e(e){t(e.instance);}function r(t){return (Z||"function"!=typeof fetch?new Promise((function(t){t(l());})):fetch(yt,{credentials:"same-origin"}).then((function(t){if(!t.ok)throw "failed to load wasm binary file at '"+yt+"'";return t.arrayBuffer()})).catch((function(){return l()}))).then((function(t){return WebAssembly.instantiate(t,n)})).then(t,(function(t){W("failed to asynchronously prepare wasm: "+t),a(t);}))}var n={env:Gt,wasi_unstable:Gt,global:{NaN:NaN,Infinity:1/0},"global.Math":Math,asm2wasm:X};if(dt++,O.monitorRunDependencies&&O.monitorRunDependencies(dt),O.instantiateWasm)try{return O.instantiateWasm(n,t)}catch(t){return W("Module.instantiateWasm callback failed with error: "+t),!1}return function(){if(Z||"function"!=typeof WebAssembly.instantiateStreaming||i()||"function"!=typeof fetch)return r(e);fetch(yt,{credentials:"same-origin"}).then((function(t){return WebAssembly.instantiateStreaming(t,n).then(e,(function(t){W("wasm streaming compile failed: "+t),W("falling back to ArrayBuffer instantiation"),r(e);}))}));}(),{}};var xt,mt,gt,Et,Nt,wt,It,bt=[],At={open:function(t){var e=bt[t.node.qp];if(!e)throw new Yt(43);t.bp=e,t.seekable=!1;},close:function(t){t.bp.lp.flush(t.bp);},flush:function(t){t.bp.lp.flush(t.bp);},read:function(t,e,r,n){if(!t.bp||!t.bp.lp.Bp)throw new Yt(60);for(var _=0,s=0;s<n;s++){try{var c=t.bp.lp.Bp(t.bp);}catch(t){throw new Yt(29)}if(void 0===c&&0===_)throw new Yt(6);if(null==c)break;_++,e[r+s]=c;}return _&&(t.node.timestamp=Date.now()),_},write:function(t,e,r,n){if(!t.bp||!t.bp.lp.up)throw new Yt(60);try{for(var _=0;_<n;_++)t.bp.lp.up(t.bp,e[r+_]);}catch(t){throw new Yt(29)}return n&&(t.node.timestamp=Date.now()),_}},kt={Bp:function(t){if(!t.input.length){var e=null;if("undefined"!=typeof window&&"function"==typeof window.prompt?null!==(e=window.prompt("Input: "))&&(e+="\n"):"function"==typeof readline&&null!==(e=readline())&&(e+="\n"),!e)return null;for(var r=0,n=0;n<e.length;++n){var _=e.charCodeAt(n);55296<=_&&57343>=_&&(_=65536+((1023&_)<<10)|1023&e.charCodeAt(++n)),127>=_?++r:r=2047>=_?r+2:65535>=_?r+3:r+4;}var s=(r=Array(r+1)).length;if(n=0,0<s){_=n,s=n+s-1;for(var c=0;c<e.length;++c){var a=e.charCodeAt(c);if(55296<=a&&57343>=a&&(a=65536+((1023&a)<<10)|1023&e.charCodeAt(++c)),127>=a){if(n>=s)break;r[n++]=a;}else{if(2047>=a){if(n+1>=s)break;r[n++]=192|a>>6;}else{if(65535>=a){if(n+2>=s)break;r[n++]=224|a>>12;}else{if(n+3>=s)break;r[n++]=240|a>>18,r[n++]=128|a>>12&63;}r[n++]=128|a>>6&63;}r[n++]=128|63&a;}}r[n]=0,e=n-_;}else e=0;r.length=e,t.input=r;}return t.input.shift()},up:function(t,e){null===e||10===e?(j(r(t.cp,0)),t.cp=[]):0!=e&&t.cp.push(e);},flush:function(t){t.cp&&0<t.cp.length&&(j(r(t.cp,0)),t.cp=[]);}},Ct={up:function(t,e){null===e||10===e?(W(r(t.cp,0)),t.cp=[]):0!=e&&t.cp.push(e);},flush:function(t){t.cp&&0<t.cp.length&&(W(r(t.cp,0)),t.cp=[]);}},Tt={ep:null,gp:function(){return Tt.createNode(null,"/",16895,0)},createNode:function(t,e,r,n){if(24576==(61440&r)||4096==(61440&r))throw new Yt(63);return Tt.ep||(Tt.ep={dir:{node:{ip:Tt.Zo.ip,fp:Tt.Zo.fp,mp:Tt.Zo.mp,op:Tt.Zo.op,Gp:Tt.Zo.Gp,Ip:Tt.Zo.Ip,Hp:Tt.Zo.Hp,Fp:Tt.Zo.Fp,rp:Tt.Zo.rp},stream:{kp:Tt.$o.kp}},file:{node:{ip:Tt.Zo.ip,fp:Tt.Zo.fp},stream:{kp:Tt.$o.kp,read:Tt.$o.read,write:Tt.$o.write,wp:Tt.$o.wp,Cp:Tt.$o.Cp,Ep:Tt.$o.Ep}},link:{node:{ip:Tt.Zo.ip,fp:Tt.Zo.fp,np:Tt.Zo.np},stream:{}},xp:{node:{ip:Tt.Zo.ip,fp:Tt.Zo.fp},stream:Mt}}),16384==(61440&(r=m(t,e,r,n)).mode)?(r.Zo=Tt.ep.dir.node,r.$o=Tt.ep.dir.stream,r.Yo={}):32768==(61440&r.mode)?(r.Zo=Tt.ep.file.node,r.$o=Tt.ep.file.stream,r.ap=0,r.Yo=null):40960==(61440&r.mode)?(r.Zo=Tt.ep.link.node,r.$o=Tt.ep.link.stream):8192==(61440&r.mode)&&(r.Zo=Tt.ep.xp.node,r.$o=Tt.ep.xp.stream),r.timestamp=Date.now(),t&&(t.Yo[e]=r),r},Wp:function(t){if(t.Yo&&t.Yo.subarray){for(var e=[],r=0;r<t.ap;++r)e.push(t.Yo[r]);return e}return t.Yo},Xp:function(t){return t.Yo?t.Yo.subarray?t.Yo.subarray(0,t.ap):new Uint8Array(t.Yo):new Uint8Array},yp:function(t,e){var r=t.Yo?t.Yo.length:0;r>=e||(e=Math.max(e,r*(1048576>r?2:1.125)|0),0!=r&&(e=Math.max(e,256)),r=t.Yo,t.Yo=new Uint8Array(e),0<t.ap&&t.Yo.set(r.subarray(0,t.ap),0));},Np:function(t,e){if(t.ap!=e)if(0==e)t.Yo=null,t.ap=0;else{if(!t.Yo||t.Yo.subarray){var r=t.Yo;t.Yo=new Uint8Array(new ArrayBuffer(e)),r&&t.Yo.set(r.subarray(0,Math.min(e,t.ap)));}else if(t.Yo||(t.Yo=[]),t.Yo.length>e)t.Yo.length=e;else for(;t.Yo.length<e;)t.Yo.push(0);t.ap=e;}},Zo:{ip:function(t){var e={};return e.Up=8192==(61440&t.mode)?t.id:1,e.Zp=t.id,e.mode=t.mode,e.aq=1,e.uid=0,e.Yp=0,e.qp=t.qp,16384==(61440&t.mode)?e.size=4096:32768==(61440&t.mode)?e.size=t.ap:40960==(61440&t.mode)?e.size=t.link.length:e.size=0,e.Rp=new Date(t.timestamp),e.$p=new Date(t.timestamp),e.Tp=new Date(t.timestamp),e.Jp=4096,e.Sp=Math.ceil(e.size/e.Jp),e},fp:function(t,e){void 0!==e.mode&&(t.mode=e.mode),void 0!==e.timestamp&&(t.timestamp=e.timestamp),void 0!==e.size&&Tt.Np(t,e.size);},mp:function(){throw Ht[44]},op:function(t,e,r,n){return Tt.createNode(t,e,r,n)},Gp:function(t,e,r){if(16384==(61440&t.mode)){try{var n=x(e,r);}catch(t){}if(n)for(var _ in n.Yo)throw new Yt(55)}delete t.parent.Yo[t.name],t.name=r,e.Yo[r]=t,t.parent=e;},Ip:function(t,e){delete t.Yo[e];},Hp:function(t,e){var r,n=x(t,e);for(r in n.Yo)throw new Yt(55);delete t.Yo[e];},Fp:function(t){var e,r=[".",".."];for(e in t.Yo)t.Yo.hasOwnProperty(e)&&r.push(e);return r},rp:function(t,e,r){return (t=Tt.createNode(t,e,41471,0)).link=r,t},np:function(t){if(40960!=(61440&t.mode))throw new Yt(28);return t.link}},$o:{read:function(t,e,r,n,_){var s=t.node.Yo;if(_>=t.node.ap)return 0;if(8<(t=Math.min(t.node.ap-_,n))&&s.subarray)e.set(s.subarray(_,_+t),r);else for(n=0;n<t;n++)e[r+n]=s[_+n];return t},write:function(t,e,r,n,_,s){if(s=!1,!n)return 0;if((t=t.node).timestamp=Date.now(),e.subarray&&(!t.Yo||t.Yo.subarray)){if(s)return t.Yo=e.subarray(r,r+n),t.ap=n;if(0===t.ap&&0===_)return t.Yo=new Uint8Array(e.subarray(r,r+n)),t.ap=n;if(_+n<=t.ap)return t.Yo.set(e.subarray(r,r+n),_),n}if(Tt.yp(t,_+n),t.Yo.subarray&&e.subarray)t.Yo.set(e.subarray(r,r+n),_);else for(s=0;s<n;s++)t.Yo[_+s]=e[r+s];return t.ap=Math.max(t.ap,_+n),n},kp:function(t,e,r){if(1===r?e+=t.position:2===r&&32768==(61440&t.node.mode)&&(e+=t.node.ap),0>e)throw new Yt(28);return e},wp:function(t,e,r){Tt.yp(t.node,e+r),t.node.ap=Math.max(t.node.ap,e+r);},Cp:function(t,e,r,n,_,s,c){if(32768!=(61440&t.node.mode))throw new Yt(43);if(r=t.node.Yo,2&c||r.buffer!==e&&r.buffer!==e.buffer){if((0<_||_+n<t.node.ap)&&(r=r.subarray?r.subarray(_,_+n):Array.prototype.slice.call(r,_,_+n)),t=!0,_=e.buffer==et.buffer,!(n=Wt(n)))throw new Yt(48);(_?et:e).set(r,n);}else t=!1,n=r.byteOffset;return {cq:n,Qp:t}},Ep:function(t,e,r,n,_){if(32768!=(61440&t.node.mode))throw new Yt(43);return 2&_?0:(Tt.$o.write(t,e,0,n,r,!1),0)}}},Ft=null,St={},Kt=[],Lt=1,Rt=null,zt=!0,Bt={},Yt=null,Ht={},Ut={r:0,rs:1052672,"r+":2,w:577,wx:705,xw:705,"w+":578,"wx+":706,"xw+":706,a:1089,ax:1217,xa:1217,"a+":1090,"ax+":1218,"xa+":1218},Mt={open:function(t){t.$o=St[t.node.qp].$o,t.$o.open&&t.$o.open(t);},kp:function(){throw new Yt(70)}},Ot={},Dt=0;L(),Rt=Array(4096),b(Tt,"/"),k("/tmp"),k("/home"),k("/home/web_user"),function(){if(k("/dev"),I(259,{read:function(){return 0},write:function(t,e,r,n){return n}}),C("/dev/null",259),h(1280,kt),h(1536,Ct),C("/dev/tty",1280),C("/dev/tty1",1536),"object"==typeof crypto&&"function"==typeof crypto.getRandomValues)var t=new Uint8Array(1),e=function(){return crypto.getRandomValues(t),t[0]};e||(e=function(){a("random_device");}),R("random",e),R("urandom",e),k("/dev/shm"),k("/dev/shm/tmp");}(),k("/proc"),k("/proc/self"),k("/proc/self/fd"),b({gp:function(){var t=m("/proc/self","fd",16895,73);return t.Zo={mp:function(t,e){var r=Kt[+e];if(!r)throw new Yt(8);return (t={parent:null,gp:{Dp:"fake"},Zo:{np:function(){return r.path}}}).parent=t}},t}},"/proc/self/fd");var Gt={c:function(){},l:function(t,e){Dt=e;try{var r=B(),n=z(),_=z(),s=z(),c=z();return -9007199254740992>=(t=4294967296*n+(_>>>0))||9007199254740992<=t?-61:(K(r,t,c),mt=[r.position>>>0,(xt=r.position,1<=+ut(xt)?0<xt?(0|pt(+ft(xt/4294967296),4294967295))>>>0:~~+ot((xt-+(~~xt>>>0))/4294967296)>>>0:0)],_t[s>>2]=mt[0],_t[s+4>>2]=mt[1],r.tp&&0===t&&0===c&&(r.tp=null),0)}catch(t){return void 0!==Ot&&t instanceof Yt||a(t),-t.jp}},k:function(t,e){Dt=e;try{var r=B(),n=z();t:{var _=z();for(e=t=0;e<_;e++){var s=_t[n+(8*e+4)>>2],c=r,i=_t[n+8*e>>2],l=s,u=void 0,o=et;if(0>l||0>u)throw new Yt(28);if(null===c.hp)throw new Yt(8);if(1==(2097155&c.flags))throw new Yt(8);if(16384==(61440&c.node.mode))throw new Yt(31);if(!c.$o.read)throw new Yt(28);var f=void 0!==u;if(f){if(!c.seekable)throw new Yt(70)}else u=c.position;var p=c.$o.read(c,o,i,l,u);if(f||(c.position+=p),0>(c=p)){var d=-1;break t}if(t+=c,c<s)break}d=t;}return d}catch(t){return void 0!==Ot&&t instanceof Yt||a(t),-t.jp}},e:function(t,e){Dt=e;try{var r=B();switch(z()){case 0:var n=z();return 0>n?-28:S(r.path,r.flags,0,n).hp;case 1:case 2:return 0;case 3:return r.flags;case 4:return n=z(),r.flags|=n,0;case 12:return n=z(),nt[n+0>>1]=2,0;case 13:case 14:return 0;case 16:case 8:return -28;case 9:return O.___errno_location&&(_t[O.___errno_location()>>2]=28),-1;default:return -28}}catch(t){return void 0!==Ot&&t instanceof Yt||a(t),-t.jp}},j:function(t,e){Dt=e;try{var n=z();return S(n?r(rt,n,void 0):"",z(),z()).hp}catch(t){return void 0!==Ot&&t instanceof Yt||a(t),-t.jp}},i:function(t,e){Dt=e;try{var r=B(),n=z();switch(n){case 21509:case 21505:return r.bp?0:-59;case 21510:case 21511:case 21512:case 21506:case 21507:case 21508:return r.bp?0:-59;case 21519:if(!r.bp)return -59;var _=z();return _t[_>>2]=0;case 21520:return r.bp?-28:-59;case 21531:if(t=z(),!r.$o.Kp)throw new Yt(59);return r.$o.Kp(r,n,t);case 21523:case 21524:return r.bp?0:-59;default:a("bad ioctl syscall "+n);}}catch(t){return void 0!==Ot&&t instanceof Yt||a(t),-t.jp}},b:function(){},d:function(){return Y.apply(null,arguments)},h:function(){return H.apply(null,arguments)},__memory_base:1024,__table_base:0,p:function(){a();},o:U,n:function(t,e,r){rt.set(rt.subarray(e,e+r),t);},m:function(t){if(2147418112<t)return !1;for(var e=Math.max(U(),16777216);e<t;)e=536870912>=e?n(2*e):Math.min(n((3*e+2147483648)/4),2147418112);t:{try{$.grow(e-tt.byteLength+65535>>16),_($.buffer),t=1;break t}catch(t){}t=void 0;}return !!t},g:function(t){var e=Date.now();return _t[t>>2]=e/1e3|0,_t[t+4>>2]=e%1e3*1e3|0,0},a:a,memory:$,f:function(){},table:q},Vt=O.asm({},Gt,tt);O.asm=Vt,O.___errno_location=function(){return O.asm.q.apply(null,arguments)},O._free=function(){return O.asm.r.apply(null,arguments)};var jt,Wt=O._malloc=function(){return O.asm.s.apply(null,arguments)};if(O._vsc_buffer_bytes=function(){return O.asm.t.apply(null,arguments)},O._vsc_buffer_data=function(){return O.asm.u.apply(null,arguments)},O._vsc_buffer_delete=function(){return O.asm.v.apply(null,arguments)},O._vsc_buffer_len=function(){return O.asm.w.apply(null,arguments)},O._vsc_buffer_make_secure=function(){return O.asm.x.apply(null,arguments)},O._vsc_buffer_new=function(){return O.asm.y.apply(null,arguments)},O._vsc_buffer_new_with_capacity=function(){return O.asm.z.apply(null,arguments)},O._vsc_data=function(){return O.asm.A.apply(null,arguments)},O._vsc_data_bytes=function(){return O.asm.B.apply(null,arguments)},O._vsc_data_ctx_size=function(){return O.asm.C.apply(null,arguments)},O._vsc_data_len=function(){return O.asm.D.apply(null,arguments)},O._vscf_aes256_cbc_alg_id=function(){return O.asm.E.apply(null,arguments)},O._vscf_aes256_cbc_decrypt=function(){return O.asm.F.apply(null,arguments)},O._vscf_aes256_cbc_decrypted_len=function(){return O.asm.G.apply(null,arguments)},O._vscf_aes256_cbc_decrypted_out_len=function(){return O.asm.H.apply(null,arguments)},O._vscf_aes256_cbc_delete=function(){return O.asm.I.apply(null,arguments)},O._vscf_aes256_cbc_encrypt=function(){return O.asm.J.apply(null,arguments)},O._vscf_aes256_cbc_encrypted_len=function(){return O.asm.K.apply(null,arguments)},O._vscf_aes256_cbc_encrypted_out_len=function(){return O.asm.L.apply(null,arguments)},O._vscf_aes256_cbc_finish=function(){return O.asm.M.apply(null,arguments)},O._vscf_aes256_cbc_new=function(){return O.asm.N.apply(null,arguments)},O._vscf_aes256_cbc_out_len=function(){return O.asm.O.apply(null,arguments)},O._vscf_aes256_cbc_precise_encrypted_len=function(){return O.asm.P.apply(null,arguments)},O._vscf_aes256_cbc_produce_alg_info=function(){return O.asm.Q.apply(null,arguments)},O._vscf_aes256_cbc_restore_alg_info=function(){return O.asm.R.apply(null,arguments)},O._vscf_aes256_cbc_set_key=function(){return O.asm.S.apply(null,arguments)},O._vscf_aes256_cbc_set_nonce=function(){return O.asm.T.apply(null,arguments)},O._vscf_aes256_cbc_shallow_copy=function(){return O.asm.U.apply(null,arguments)},O._vscf_aes256_cbc_start_decryption=function(){return O.asm.V.apply(null,arguments)},O._vscf_aes256_cbc_start_encryption=function(){return O.asm.W.apply(null,arguments)},O._vscf_aes256_cbc_update=function(){return O.asm.X.apply(null,arguments)},O._vscf_aes256_gcm_alg_id=function(){return O.asm.Y.apply(null,arguments)},O._vscf_aes256_gcm_auth_decrypt=function(){return O.asm.Z.apply(null,arguments)},O._vscf_aes256_gcm_auth_decrypted_len=function(){return O.asm._.apply(null,arguments)},O._vscf_aes256_gcm_auth_encrypt=function(){return O.asm.$.apply(null,arguments)},O._vscf_aes256_gcm_auth_encrypted_len=function(){return O.asm.aa.apply(null,arguments)},O._vscf_aes256_gcm_decrypt=function(){return O.asm.ba.apply(null,arguments)},O._vscf_aes256_gcm_decrypted_len=function(){return O.asm.ca.apply(null,arguments)},O._vscf_aes256_gcm_decrypted_out_len=function(){return O.asm.da.apply(null,arguments)},O._vscf_aes256_gcm_delete=function(){return O.asm.ea.apply(null,arguments)},O._vscf_aes256_gcm_encrypt=function(){return O.asm.fa.apply(null,arguments)},O._vscf_aes256_gcm_encrypted_len=function(){return O.asm.ga.apply(null,arguments)},O._vscf_aes256_gcm_encrypted_out_len=function(){return O.asm.ha.apply(null,arguments)},O._vscf_aes256_gcm_finish=function(){return O.asm.ia.apply(null,arguments)},O._vscf_aes256_gcm_finish_auth_decryption=function(){return O.asm.ja.apply(null,arguments)},O._vscf_aes256_gcm_finish_auth_encryption=function(){return O.asm.ka.apply(null,arguments)},O._vscf_aes256_gcm_new=function(){return O.asm.la.apply(null,arguments)},O._vscf_aes256_gcm_out_len=function(){return O.asm.ma.apply(null,arguments)},O._vscf_aes256_gcm_precise_encrypted_len=function(){return O.asm.na.apply(null,arguments)},O._vscf_aes256_gcm_produce_alg_info=function(){return O.asm.oa.apply(null,arguments)},O._vscf_aes256_gcm_restore_alg_info=function(){return O.asm.pa.apply(null,arguments)},O._vscf_aes256_gcm_set_auth_data=function(){return O.asm.qa.apply(null,arguments)},O._vscf_aes256_gcm_set_key=function(){return O.asm.ra.apply(null,arguments)},O._vscf_aes256_gcm_set_nonce=function(){return O.asm.sa.apply(null,arguments)},O._vscf_aes256_gcm_shallow_copy=function(){return O.asm.ta.apply(null,arguments)},O._vscf_aes256_gcm_start_decryption=function(){return O.asm.ua.apply(null,arguments)},O._vscf_aes256_gcm_start_encryption=function(){return O.asm.va.apply(null,arguments)},O._vscf_aes256_gcm_update=function(){return O.asm.wa.apply(null,arguments)},O._vscf_alg_factory_create_cipher_from_info=function(){return O.asm.xa.apply(null,arguments)},O._vscf_alg_factory_create_hash_from_info=function(){return O.asm.ya.apply(null,arguments)},O._vscf_alg_factory_create_kdf_from_info=function(){return O.asm.za.apply(null,arguments)},O._vscf_alg_factory_create_mac_from_info=function(){return O.asm.Aa.apply(null,arguments)},O._vscf_alg_factory_create_salted_kdf_from_info=function(){return O.asm.Ba.apply(null,arguments)},O._vscf_alg_info_der_deserializer_delete=function(){return O.asm.Ca.apply(null,arguments)},O._vscf_alg_info_der_deserializer_deserialize=function(){return O.asm.Da.apply(null,arguments)},O._vscf_alg_info_der_deserializer_deserialize_inplace=function(){return O.asm.Ea.apply(null,arguments)},O._vscf_alg_info_der_deserializer_new=function(){return O.asm.Fa.apply(null,arguments)},O._vscf_alg_info_der_deserializer_release_asn1_reader=function(){return O.asm.Ga.apply(null,arguments)},O._vscf_alg_info_der_deserializer_setup_defaults=function(){return O.asm.Ha.apply(null,arguments)},O._vscf_alg_info_der_deserializer_shallow_copy=function(){return O.asm.Ia.apply(null,arguments)},O._vscf_alg_info_der_deserializer_use_asn1_reader=function(){return O.asm.Ja.apply(null,arguments)},O._vscf_alg_info_der_serializer_delete=function(){return O.asm.Ka.apply(null,arguments)},O._vscf_alg_info_der_serializer_new=function(){return O.asm.La.apply(null,arguments)},O._vscf_alg_info_der_serializer_release_asn1_writer=function(){return O.asm.Ma.apply(null,arguments)},O._vscf_alg_info_der_serializer_serialize=function(){return O.asm.Na.apply(null,arguments)},O._vscf_alg_info_der_serializer_serialize_inplace=function(){return O.asm.Oa.apply(null,arguments)},O._vscf_alg_info_der_serializer_serialized_len=function(){return O.asm.Pa.apply(null,arguments)},O._vscf_alg_info_der_serializer_setup_defaults=function(){return O.asm.Qa.apply(null,arguments)},O._vscf_alg_info_der_serializer_shallow_copy=function(){return O.asm.Ra.apply(null,arguments)},O._vscf_alg_info_der_serializer_use_asn1_writer=function(){return O.asm.Sa.apply(null,arguments)},O._vscf_asn1rd_delete=function(){return O.asm.Ta.apply(null,arguments)},O._vscf_asn1rd_get_data_len=function(){return O.asm.Ua.apply(null,arguments)},O._vscf_asn1rd_get_len=function(){return O.asm.Va.apply(null,arguments)},O._vscf_asn1rd_get_tag=function(){return O.asm.Wa.apply(null,arguments)},O._vscf_asn1rd_has_error=function(){return O.asm.Xa.apply(null,arguments)},O._vscf_asn1rd_left_len=function(){return O.asm.Ya.apply(null,arguments)},O._vscf_asn1rd_new=function(){return O.asm.Za.apply(null,arguments)},O._vscf_asn1rd_read_bitstring_as_octet_str=function(){return O.asm._a.apply(null,arguments)},O._vscf_asn1rd_read_bool=function(){return O.asm.$a.apply(null,arguments)},O._vscf_asn1rd_read_context_tag=function(){return O.asm.ab.apply(null,arguments)},O._vscf_asn1rd_read_data=function(){return O.asm.bb.apply(null,arguments)},O._vscf_asn1rd_read_int=function(){return O.asm.cb.apply(null,arguments)},O._vscf_asn1rd_read_int16=function(){return O.asm.db.apply(null,arguments)},O._vscf_asn1rd_read_int32=function(){return O.asm.eb.apply(null,arguments)},O._vscf_asn1rd_read_int64=function(){return O.asm.fb.apply(null,arguments)},O._vscf_asn1rd_read_int8=function(){return O.asm.gb.apply(null,arguments)},O._vscf_asn1rd_read_null=function(){return O.asm.hb.apply(null,arguments)},O._vscf_asn1rd_read_null_optional=function(){return O.asm.ib.apply(null,arguments)},O._vscf_asn1rd_read_octet_str=function(){return O.asm.jb.apply(null,arguments)},O._vscf_asn1rd_read_oid=function(){return O.asm.kb.apply(null,arguments)},O._vscf_asn1rd_read_sequence=function(){return O.asm.lb.apply(null,arguments)},O._vscf_asn1rd_read_set=function(){return O.asm.mb.apply(null,arguments)},O._vscf_asn1rd_read_tag=function(){return O.asm.nb.apply(null,arguments)},O._vscf_asn1rd_read_uint=function(){return O.asm.ob.apply(null,arguments)},O._vscf_asn1rd_read_uint16=function(){return O.asm.pb.apply(null,arguments)},O._vscf_asn1rd_read_uint32=function(){return O.asm.qb.apply(null,arguments)},O._vscf_asn1rd_read_uint64=function(){return O.asm.rb.apply(null,arguments)},O._vscf_asn1rd_read_uint8=function(){return O.asm.sb.apply(null,arguments)},O._vscf_asn1rd_read_utf8_str=function(){return O.asm.tb.apply(null,arguments)},O._vscf_asn1rd_reset=function(){return O.asm.ub.apply(null,arguments)},O._vscf_asn1rd_shallow_copy=function(){return O.asm.vb.apply(null,arguments)},O._vscf_asn1rd_status=function(){return O.asm.wb.apply(null,arguments)},O._vscf_asn1wr_bytes=function(){return O.asm.xb.apply(null,arguments)},O._vscf_asn1wr_delete=function(){return O.asm.yb.apply(null,arguments)},O._vscf_asn1wr_finish=function(){return O.asm.zb.apply(null,arguments)},O._vscf_asn1wr_has_error=function(){return O.asm.Ab.apply(null,arguments)},O._vscf_asn1wr_len=function(){return O.asm.Bb.apply(null,arguments)},O._vscf_asn1wr_new=function(){return O.asm.Cb.apply(null,arguments)},O._vscf_asn1wr_reserve=function(){return O.asm.Db.apply(null,arguments)},O._vscf_asn1wr_reset=function(){return O.asm.Eb.apply(null,arguments)},O._vscf_asn1wr_shallow_copy=function(){return O.asm.Fb.apply(null,arguments)},O._vscf_asn1wr_status=function(){return O.asm.Gb.apply(null,arguments)},O._vscf_asn1wr_unwritten_len=function(){return O.asm.Hb.apply(null,arguments)},O._vscf_asn1wr_write_bool=function(){return O.asm.Ib.apply(null,arguments)},O._vscf_asn1wr_write_context_tag=function(){return O.asm.Jb.apply(null,arguments)},O._vscf_asn1wr_write_data=function(){return O.asm.Kb.apply(null,arguments)},O._vscf_asn1wr_write_int=function(){return O.asm.Lb.apply(null,arguments)},O._vscf_asn1wr_write_int16=function(){return O.asm.Mb.apply(null,arguments)},O._vscf_asn1wr_write_int32=function(){return O.asm.Nb.apply(null,arguments)},O._vscf_asn1wr_write_int64=function(){return O.asm.Ob.apply(null,arguments)},O._vscf_asn1wr_write_int8=function(){return O.asm.Pb.apply(null,arguments)},O._vscf_asn1wr_write_len=function(){return O.asm.Qb.apply(null,arguments)},O._vscf_asn1wr_write_null=function(){return O.asm.Rb.apply(null,arguments)},O._vscf_asn1wr_write_octet_str=function(){return O.asm.Sb.apply(null,arguments)},O._vscf_asn1wr_write_octet_str_as_bitstring=function(){return O.asm.Tb.apply(null,arguments)},O._vscf_asn1wr_write_oid=function(){return O.asm.Ub.apply(null,arguments)},O._vscf_asn1wr_write_sequence=function(){return O.asm.Vb.apply(null,arguments)},O._vscf_asn1wr_write_set=function(){return O.asm.Wb.apply(null,arguments)},O._vscf_asn1wr_write_tag=function(){return O.asm.Xb.apply(null,arguments)},O._vscf_asn1wr_write_uint=function(){return O.asm.Yb.apply(null,arguments)},O._vscf_asn1wr_write_uint16=function(){return O.asm.Zb.apply(null,arguments)},O._vscf_asn1wr_write_uint32=function(){return O.asm._b.apply(null,arguments)},O._vscf_asn1wr_write_uint64=function(){return O.asm.$b.apply(null,arguments)},O._vscf_asn1wr_write_uint8=function(){return O.asm.ac.apply(null,arguments)},O._vscf_asn1wr_write_utf8_str=function(){return O.asm.bc.apply(null,arguments)},O._vscf_asn1wr_written_len=function(){return O.asm.cc.apply(null,arguments)},O._vscf_base64_decode=function(){return O.asm.dc.apply(null,arguments)},O._vscf_base64_decoded_len=function(){return O.asm.ec.apply(null,arguments)},O._vscf_base64_encode=function(){return O.asm.fc.apply(null,arguments)},O._vscf_base64_encoded_len=function(){return O.asm.gc.apply(null,arguments)},O._vscf_brainkey_client_blind=function(){return O.asm.hc.apply(null,arguments)},O._vscf_brainkey_client_deblind=function(){return O.asm.ic.apply(null,arguments)},O._vscf_brainkey_client_delete=function(){return O.asm.jc.apply(null,arguments)},O._vscf_brainkey_client_new=function(){return O.asm.kc.apply(null,arguments)},O._vscf_brainkey_client_release_operation_random=function(){return O.asm.lc.apply(null,arguments)},O._vscf_brainkey_client_release_random=function(){return O.asm.mc.apply(null,arguments)},O._vscf_brainkey_client_setup_defaults=function(){return O.asm.nc.apply(null,arguments)},O._vscf_brainkey_client_shallow_copy=function(){return O.asm.oc.apply(null,arguments)},O._vscf_brainkey_client_use_operation_random=function(){return O.asm.pc.apply(null,arguments)},O._vscf_brainkey_client_use_random=function(){return O.asm.qc.apply(null,arguments)},O._vscf_brainkey_server_delete=function(){return O.asm.rc.apply(null,arguments)},O._vscf_brainkey_server_generate_identity_secret=function(){return O.asm.sc.apply(null,arguments)},O._vscf_brainkey_server_harden=function(){return O.asm.tc.apply(null,arguments)},O._vscf_brainkey_server_new=function(){return O.asm.uc.apply(null,arguments)},O._vscf_brainkey_server_release_operation_random=function(){return O.asm.vc.apply(null,arguments)},O._vscf_brainkey_server_release_random=function(){return O.asm.wc.apply(null,arguments)},O._vscf_brainkey_server_setup_defaults=function(){return O.asm.xc.apply(null,arguments)},O._vscf_brainkey_server_shallow_copy=function(){return O.asm.yc.apply(null,arguments)},O._vscf_brainkey_server_use_operation_random=function(){return O.asm.zc.apply(null,arguments)},O._vscf_brainkey_server_use_random=function(){return O.asm.Ac.apply(null,arguments)},O._vscf_cipher_alg_info_alg_id=function(){return O.asm.Bc.apply(null,arguments)},O._vscf_cipher_alg_info_delete=function(){return O.asm.Cc.apply(null,arguments)},O._vscf_cipher_alg_info_new=function(){return O.asm.Dc.apply(null,arguments)},O._vscf_cipher_alg_info_new_with_members=function(){return O.asm.Ec.apply(null,arguments)},O._vscf_cipher_alg_info_nonce=function(){return O.asm.Fc.apply(null,arguments)},O._vscf_cipher_alg_info_shallow_copy=function(){return O.asm.Gc.apply(null,arguments)},O._vscf_ctr_drbg_delete=function(){return O.asm.Hc.apply(null,arguments)},O._vscf_ctr_drbg_enable_prediction_resistance=function(){return O.asm.Ic.apply(null,arguments)},O._vscf_ctr_drbg_new=function(){return O.asm.Jc.apply(null,arguments)},O._vscf_ctr_drbg_random=function(){return O.asm.Kc.apply(null,arguments)},O._vscf_ctr_drbg_release_entropy_source=function(){return O.asm.Lc.apply(null,arguments)},O._vscf_ctr_drbg_reseed=function(){return O.asm.Mc.apply(null,arguments)},O._vscf_ctr_drbg_set_entropy_len=function(){return O.asm.Nc.apply(null,arguments)},O._vscf_ctr_drbg_set_reseed_interval=function(){return O.asm.Oc.apply(null,arguments)},O._vscf_ctr_drbg_setup_defaults=function(){return O.asm.Pc.apply(null,arguments)},O._vscf_ctr_drbg_shallow_copy=function(){return O.asm.Qc.apply(null,arguments)},O._vscf_ctr_drbg_use_entropy_source=function(){return O.asm.Rc.apply(null,arguments)},O._vscf_curve25519_alg_id=function(){return O.asm.Sc.apply(null,arguments)},O._vscf_curve25519_can_decrypt=function(){return O.asm.Tc.apply(null,arguments)},O._vscf_curve25519_can_encrypt=function(){return O.asm.Uc.apply(null,arguments)},O._vscf_curve25519_compute_shared_key=function(){return O.asm.Vc.apply(null,arguments)},O._vscf_curve25519_decrypt=function(){return O.asm.Wc.apply(null,arguments)},O._vscf_curve25519_decrypted_len=function(){return O.asm.Xc.apply(null,arguments)},O._vscf_curve25519_delete=function(){return O.asm.Yc.apply(null,arguments)},O._vscf_curve25519_encrypt=function(){return O.asm.Zc.apply(null,arguments)},O._vscf_curve25519_encrypted_len=function(){return O.asm._c.apply(null,arguments)},O._vscf_curve25519_export_private_key=function(){return O.asm.$c.apply(null,arguments)},O._vscf_curve25519_export_public_key=function(){return O.asm.ad.apply(null,arguments)},O._vscf_curve25519_generate_ephemeral_key=function(){return O.asm.bd.apply(null,arguments)},O._vscf_curve25519_generate_key=function(){return O.asm.cd.apply(null,arguments)},O._vscf_curve25519_import_private_key=function(){return O.asm.dd.apply(null,arguments)},O._vscf_curve25519_import_public_key=function(){return O.asm.ed.apply(null,arguments)},O._vscf_curve25519_new=function(){return O.asm.fd.apply(null,arguments)},O._vscf_curve25519_produce_alg_info=function(){return O.asm.gd.apply(null,arguments)},O._vscf_curve25519_release_ecies=function(){return O.asm.hd.apply(null,arguments)},O._vscf_curve25519_release_random=function(){return O.asm.id.apply(null,arguments)},O._vscf_curve25519_restore_alg_info=function(){return O.asm.jd.apply(null,arguments)},O._vscf_curve25519_setup_defaults=function(){return O.asm.kd.apply(null,arguments)},O._vscf_curve25519_shallow_copy=function(){return O.asm.ld.apply(null,arguments)},O._vscf_curve25519_shared_key_len=function(){return O.asm.md.apply(null,arguments)},O._vscf_curve25519_use_ecies=function(){return O.asm.nd.apply(null,arguments)},O._vscf_curve25519_use_random=function(){return O.asm.od.apply(null,arguments)},O._vscf_ecc_alg_id=function(){return O.asm.pd.apply(null,arguments)},O._vscf_ecc_alg_info_alg_id=function(){return O.asm.qd.apply(null,arguments)},O._vscf_ecc_alg_info_delete=function(){return O.asm.rd.apply(null,arguments)},O._vscf_ecc_alg_info_domain_id=function(){return O.asm.sd.apply(null,arguments)},O._vscf_ecc_alg_info_key_id=function(){return O.asm.td.apply(null,arguments)},O._vscf_ecc_alg_info_new=function(){return O.asm.ud.apply(null,arguments)},O._vscf_ecc_alg_info_new_with_members=function(){return O.asm.vd.apply(null,arguments)},O._vscf_ecc_alg_info_shallow_copy=function(){return O.asm.wd.apply(null,arguments)},O._vscf_ecc_can_decrypt=function(){return O.asm.xd.apply(null,arguments)},O._vscf_ecc_can_encrypt=function(){return O.asm.yd.apply(null,arguments)},O._vscf_ecc_can_sign=function(){return O.asm.zd.apply(null,arguments)},O._vscf_ecc_can_verify=function(){return O.asm.Ad.apply(null,arguments)},O._vscf_ecc_compute_shared_key=function(){return O.asm.Bd.apply(null,arguments)},O._vscf_ecc_decrypt=function(){return O.asm.Cd.apply(null,arguments)},O._vscf_ecc_decrypted_len=function(){return O.asm.Dd.apply(null,arguments)},O._vscf_ecc_delete=function(){return O.asm.Ed.apply(null,arguments)},O._vscf_ecc_encrypt=function(){return O.asm.Fd.apply(null,arguments)},O._vscf_ecc_encrypted_len=function(){return O.asm.Gd.apply(null,arguments)},O._vscf_ecc_export_private_key=function(){return O.asm.Hd.apply(null,arguments)},O._vscf_ecc_export_public_key=function(){return O.asm.Id.apply(null,arguments)},O._vscf_ecc_generate_ephemeral_key=function(){return O.asm.Jd.apply(null,arguments)},O._vscf_ecc_generate_key=function(){return O.asm.Kd.apply(null,arguments)},O._vscf_ecc_import_private_key=function(){return O.asm.Ld.apply(null,arguments)},O._vscf_ecc_import_public_key=function(){return O.asm.Md.apply(null,arguments)},O._vscf_ecc_new=function(){return O.asm.Nd.apply(null,arguments)},O._vscf_ecc_private_key_alg_id=function(){return O.asm.Od.apply(null,arguments)},O._vscf_ecc_private_key_alg_info=function(){return O.asm.Pd.apply(null,arguments)},O._vscf_ecc_private_key_bitlen=function(){return O.asm.Qd.apply(null,arguments)},O._vscf_ecc_private_key_delete=function(){return O.asm.Rd.apply(null,arguments)},O._vscf_ecc_private_key_extract_public_key=function(){return O.asm.Sd.apply(null,arguments)},O._vscf_ecc_private_key_impl_tag=function(){return O.asm.Td.apply(null,arguments)},O._vscf_ecc_private_key_is_valid=function(){return O.asm.Ud.apply(null,arguments)},O._vscf_ecc_private_key_len=function(){return O.asm.Vd.apply(null,arguments)},O._vscf_ecc_private_key_new=function(){return O.asm.Wd.apply(null,arguments)},O._vscf_ecc_private_key_shallow_copy=function(){return O.asm.Xd.apply(null,arguments)},O._vscf_ecc_produce_alg_info=function(){return O.asm.Yd.apply(null,arguments)},O._vscf_ecc_public_key_alg_id=function(){return O.asm.Zd.apply(null,arguments)},O._vscf_ecc_public_key_alg_info=function(){return O.asm._d.apply(null,arguments)},O._vscf_ecc_public_key_bitlen=function(){return O.asm.$d.apply(null,arguments)},O._vscf_ecc_public_key_delete=function(){return O.asm.ae.apply(null,arguments)},O._vscf_ecc_public_key_impl_tag=function(){return O.asm.be.apply(null,arguments)},O._vscf_ecc_public_key_is_valid=function(){return O.asm.ce.apply(null,arguments)},O._vscf_ecc_public_key_len=function(){return O.asm.de.apply(null,arguments)},O._vscf_ecc_public_key_new=function(){return O.asm.ee.apply(null,arguments)},O._vscf_ecc_public_key_shallow_copy=function(){return O.asm.fe.apply(null,arguments)},O._vscf_ecc_release_ecies=function(){return O.asm.ge.apply(null,arguments)},O._vscf_ecc_release_random=function(){return O.asm.he.apply(null,arguments)},O._vscf_ecc_restore_alg_info=function(){return O.asm.ie.apply(null,arguments)},O._vscf_ecc_setup_defaults=function(){return O.asm.je.apply(null,arguments)},O._vscf_ecc_shallow_copy=function(){return O.asm.ke.apply(null,arguments)},O._vscf_ecc_shared_key_len=function(){return O.asm.le.apply(null,arguments)},O._vscf_ecc_sign_hash=function(){return O.asm.me.apply(null,arguments)},O._vscf_ecc_signature_len=function(){return O.asm.ne.apply(null,arguments)},O._vscf_ecc_use_ecies=function(){return O.asm.oe.apply(null,arguments)},O._vscf_ecc_use_random=function(){return O.asm.pe.apply(null,arguments)},O._vscf_ecc_verify_hash=function(){return O.asm.qe.apply(null,arguments)},O._vscf_ecies_decrypt=function(){return O.asm.re.apply(null,arguments)},O._vscf_ecies_decrypted_len=function(){return O.asm.se.apply(null,arguments)},O._vscf_ecies_delete=function(){return O.asm.te.apply(null,arguments)},O._vscf_ecies_encrypt=function(){return O.asm.ue.apply(null,arguments)},O._vscf_ecies_encrypted_len=function(){return O.asm.ve.apply(null,arguments)},O._vscf_ecies_new=function(){return O.asm.we.apply(null,arguments)},O._vscf_ecies_release_cipher=function(){return O.asm.xe.apply(null,arguments)},O._vscf_ecies_release_ephemeral_key=function(){return O.asm.ye.apply(null,arguments)},O._vscf_ecies_release_kdf=function(){return O.asm.ze.apply(null,arguments)},O._vscf_ecies_release_key_alg=function(){return O.asm.Ae.apply(null,arguments)},O._vscf_ecies_release_mac=function(){return O.asm.Be.apply(null,arguments)},O._vscf_ecies_release_random=function(){return O.asm.Ce.apply(null,arguments)},O._vscf_ecies_set_key_alg=function(){return O.asm.De.apply(null,arguments)},O._vscf_ecies_setup_defaults=function(){return O.asm.Ee.apply(null,arguments)},O._vscf_ecies_setup_defaults_no_random=function(){return O.asm.Fe.apply(null,arguments)},O._vscf_ecies_shallow_copy=function(){return O.asm.Ge.apply(null,arguments)},O._vscf_ecies_use_cipher=function(){return O.asm.He.apply(null,arguments)},O._vscf_ecies_use_ephemeral_key=function(){return O.asm.Ie.apply(null,arguments)},O._vscf_ecies_use_kdf=function(){return O.asm.Je.apply(null,arguments)},O._vscf_ecies_use_mac=function(){return O.asm.Ke.apply(null,arguments)},O._vscf_ecies_use_random=function(){return O.asm.Le.apply(null,arguments)},O._vscf_ed25519_alg_id=function(){return O.asm.Me.apply(null,arguments)},O._vscf_ed25519_can_decrypt=function(){return O.asm.Ne.apply(null,arguments)},O._vscf_ed25519_can_encrypt=function(){return O.asm.Oe.apply(null,arguments)},O._vscf_ed25519_can_sign=function(){return O.asm.Pe.apply(null,arguments)},O._vscf_ed25519_can_verify=function(){return O.asm.Qe.apply(null,arguments)},O._vscf_ed25519_compute_shared_key=function(){return O.asm.Re.apply(null,arguments)},O._vscf_ed25519_decrypt=function(){return O.asm.Se.apply(null,arguments)},O._vscf_ed25519_decrypted_len=function(){return O.asm.Te.apply(null,arguments)},O._vscf_ed25519_delete=function(){return O.asm.Ue.apply(null,arguments)},O._vscf_ed25519_encrypt=function(){return O.asm.Ve.apply(null,arguments)},O._vscf_ed25519_encrypted_len=function(){return O.asm.We.apply(null,arguments)},O._vscf_ed25519_export_private_key=function(){return O.asm.Xe.apply(null,arguments)},O._vscf_ed25519_export_public_key=function(){return O.asm.Ye.apply(null,arguments)},O._vscf_ed25519_generate_ephemeral_key=function(){return O.asm.Ze.apply(null,arguments)},O._vscf_ed25519_generate_key=function(){return O.asm._e.apply(null,arguments)},O._vscf_ed25519_import_private_key=function(){return O.asm.$e.apply(null,arguments)},O._vscf_ed25519_import_public_key=function(){return O.asm.af.apply(null,arguments)},O._vscf_ed25519_new=function(){return O.asm.bf.apply(null,arguments)},O._vscf_ed25519_produce_alg_info=function(){return O.asm.cf.apply(null,arguments)},O._vscf_ed25519_release_ecies=function(){return O.asm.df.apply(null,arguments)},O._vscf_ed25519_release_random=function(){return O.asm.ef.apply(null,arguments)},O._vscf_ed25519_restore_alg_info=function(){return O.asm.ff.apply(null,arguments)},O._vscf_ed25519_setup_defaults=function(){return O.asm.gf.apply(null,arguments)},O._vscf_ed25519_shallow_copy=function(){return O.asm.hf.apply(null,arguments)},O._vscf_ed25519_shared_key_len=function(){return O.asm.jf.apply(null,arguments)},O._vscf_ed25519_sign_hash=function(){return O.asm.kf.apply(null,arguments)},O._vscf_ed25519_signature_len=function(){return O.asm.lf.apply(null,arguments)},O._vscf_ed25519_use_ecies=function(){return O.asm.mf.apply(null,arguments)},O._vscf_ed25519_use_random=function(){return O.asm.nf.apply(null,arguments)},O._vscf_ed25519_verify_hash=function(){return O.asm.of.apply(null,arguments)},O._vscf_entropy_accumulator_add_source=function(){return O.asm.pf.apply(null,arguments)},O._vscf_entropy_accumulator_delete=function(){return O.asm.qf.apply(null,arguments)},O._vscf_entropy_accumulator_gather=function(){return O.asm.rf.apply(null,arguments)},O._vscf_entropy_accumulator_is_strong=function(){return O.asm.sf.apply(null,arguments)},O._vscf_entropy_accumulator_new=function(){return O.asm.tf.apply(null,arguments)},O._vscf_entropy_accumulator_setup_defaults=function(){return O.asm.uf.apply(null,arguments)},O._vscf_entropy_accumulator_shallow_copy=function(){return O.asm.vf.apply(null,arguments)},O._vscf_error_ctx_size=function(){return O.asm.wf.apply(null,arguments)},O._vscf_error_reset=function(){return O.asm.xf.apply(null,arguments)},O._vscf_error_status=function(){return O.asm.yf.apply(null,arguments)},O._vscf_fake_random_delete=function(){return O.asm.zf.apply(null,arguments)},O._vscf_fake_random_gather=function(){return O.asm.Af.apply(null,arguments)},O._vscf_fake_random_is_strong=function(){return O.asm.Bf.apply(null,arguments)},O._vscf_fake_random_new=function(){return O.asm.Cf.apply(null,arguments)},O._vscf_fake_random_random=function(){return O.asm.Df.apply(null,arguments)},O._vscf_fake_random_reseed=function(){return O.asm.Ef.apply(null,arguments)},O._vscf_fake_random_setup_source_byte=function(){return O.asm.Ff.apply(null,arguments)},O._vscf_fake_random_setup_source_data=function(){return O.asm.Gf.apply(null,arguments)},O._vscf_fake_random_shallow_copy=function(){return O.asm.Hf.apply(null,arguments)},O._vscf_footer_info_data_size=function(){return O.asm.If.apply(null,arguments)},O._vscf_footer_info_delete=function(){return O.asm.Jf.apply(null,arguments)},O._vscf_footer_info_has_signed_data_info=function(){return O.asm.Kf.apply(null,arguments)},O._vscf_footer_info_new=function(){return O.asm.Lf.apply(null,arguments)},O._vscf_footer_info_set_data_size=function(){return O.asm.Mf.apply(null,arguments)},O._vscf_footer_info_shallow_copy=function(){return O.asm.Nf.apply(null,arguments)},O._vscf_footer_info_signed_data_info=function(){return O.asm.Of.apply(null,arguments)},O._vscf_group_session_add_epoch=function(){return O.asm.Pf.apply(null,arguments)},O._vscf_group_session_create_group_ticket=function(){return O.asm.Qf.apply(null,arguments)},O._vscf_group_session_decrypt=function(){return O.asm.Rf.apply(null,arguments)},O._vscf_group_session_decrypt_len=function(){return O.asm.Sf.apply(null,arguments)},O._vscf_group_session_delete=function(){return O.asm.Tf.apply(null,arguments)},O._vscf_group_session_encrypt=function(){return O.asm.Uf.apply(null,arguments)},O._vscf_group_session_get_current_epoch=function(){return O.asm.Vf.apply(null,arguments)},O._vscf_group_session_get_session_id=function(){return O.asm.Wf.apply(null,arguments)},O._vscf_group_session_message_delete=function(){return O.asm.Xf.apply(null,arguments)},O._vscf_group_session_message_deserialize=function(){return O.asm.Yf.apply(null,arguments)},O._vscf_group_session_message_get_epoch=function(){return O.asm.Zf.apply(null,arguments)},O._vscf_group_session_message_get_session_id=function(){return O.asm._f.apply(null,arguments)},O._vscf_group_session_message_get_type=function(){return O.asm.$f.apply(null,arguments)},O._vscf_group_session_message_new=function(){return O.asm.ag.apply(null,arguments)},O._vscf_group_session_message_serialize=function(){return O.asm.bg.apply(null,arguments)},O._vscf_group_session_message_serialize_len=function(){return O.asm.cg.apply(null,arguments)},O._vscf_group_session_message_shallow_copy=function(){return O.asm.dg.apply(null,arguments)},O._vscf_group_session_new=function(){return O.asm.eg.apply(null,arguments)},O._vscf_group_session_release_rng=function(){return O.asm.fg.apply(null,arguments)},O._vscf_group_session_setup_defaults=function(){return O.asm.gg.apply(null,arguments)},O._vscf_group_session_shallow_copy=function(){return O.asm.hg.apply(null,arguments)},O._vscf_group_session_ticket_delete=function(){return O.asm.ig.apply(null,arguments)},O._vscf_group_session_ticket_get_ticket_message=function(){return O.asm.jg.apply(null,arguments)},O._vscf_group_session_ticket_new=function(){return O.asm.kg.apply(null,arguments)},O._vscf_group_session_ticket_release_rng=function(){return O.asm.lg.apply(null,arguments)},O._vscf_group_session_ticket_setup_defaults=function(){return O.asm.mg.apply(null,arguments)},O._vscf_group_session_ticket_setup_ticket_as_new=function(){return O.asm.ng.apply(null,arguments)},O._vscf_group_session_ticket_shallow_copy=function(){return O.asm.og.apply(null,arguments)},O._vscf_group_session_ticket_use_rng=function(){return O.asm.pg.apply(null,arguments)},O._vscf_group_session_use_rng=function(){return O.asm.qg.apply(null,arguments)},O._vscf_hash_based_alg_info_alg_id=function(){return O.asm.rg.apply(null,arguments)},O._vscf_hash_based_alg_info_delete=function(){return O.asm.sg.apply(null,arguments)},O._vscf_hash_based_alg_info_hash_alg_info=function(){return O.asm.tg.apply(null,arguments)},O._vscf_hash_based_alg_info_new=function(){return O.asm.ug.apply(null,arguments)},O._vscf_hash_based_alg_info_new_with_members=function(){return O.asm.vg.apply(null,arguments)},O._vscf_hash_based_alg_info_shallow_copy=function(){return O.asm.wg.apply(null,arguments)},O._vscf_hkdf_alg_id=function(){return O.asm.xg.apply(null,arguments)},O._vscf_hkdf_delete=function(){return O.asm.yg.apply(null,arguments)},O._vscf_hkdf_derive=function(){return O.asm.zg.apply(null,arguments)},O._vscf_hkdf_new=function(){return O.asm.Ag.apply(null,arguments)},O._vscf_hkdf_produce_alg_info=function(){return O.asm.Bg.apply(null,arguments)},O._vscf_hkdf_release_hash=function(){return O.asm.Cg.apply(null,arguments)},O._vscf_hkdf_reset=function(){return O.asm.Dg.apply(null,arguments)},O._vscf_hkdf_restore_alg_info=function(){return O.asm.Eg.apply(null,arguments)},O._vscf_hkdf_set_info=function(){return O.asm.Fg.apply(null,arguments)},O._vscf_hkdf_shallow_copy=function(){return O.asm.Gg.apply(null,arguments)},O._vscf_hkdf_use_hash=function(){return O.asm.Hg.apply(null,arguments)},O._vscf_hmac_alg_id=function(){return O.asm.Ig.apply(null,arguments)},O._vscf_hmac_delete=function(){return O.asm.Jg.apply(null,arguments)},O._vscf_hmac_digest_len=function(){return O.asm.Kg.apply(null,arguments)},O._vscf_hmac_finish=function(){return O.asm.Lg.apply(null,arguments)},O._vscf_hmac_mac=function(){return O.asm.Mg.apply(null,arguments)},O._vscf_hmac_new=function(){return O.asm.Ng.apply(null,arguments)},O._vscf_hmac_produce_alg_info=function(){return O.asm.Og.apply(null,arguments)},O._vscf_hmac_release_hash=function(){return O.asm.Pg.apply(null,arguments)},O._vscf_hmac_reset=function(){return O.asm.Qg.apply(null,arguments)},O._vscf_hmac_restore_alg_info=function(){return O.asm.Rg.apply(null,arguments)},O._vscf_hmac_shallow_copy=function(){return O.asm.Sg.apply(null,arguments)},O._vscf_hmac_start=function(){return O.asm.Tg.apply(null,arguments)},O._vscf_hmac_update=function(){return O.asm.Ug.apply(null,arguments)},O._vscf_hmac_use_hash=function(){return O.asm.Vg.apply(null,arguments)},O._vscf_impl_api=function(){return O.asm.Wg.apply(null,arguments)},O._vscf_impl_shallow_copy=function(){return O.asm.Xg.apply(null,arguments)},O._vscf_impl_tag=function(){return O.asm.Yg.apply(null,arguments)},O._vscf_kdf1_alg_id=function(){return O.asm.Zg.apply(null,arguments)},O._vscf_kdf1_delete=function(){return O.asm._g.apply(null,arguments)},O._vscf_kdf1_derive=function(){return O.asm.$g.apply(null,arguments)},O._vscf_kdf1_new=function(){return O.asm.ah.apply(null,arguments)},O._vscf_kdf1_produce_alg_info=function(){return O.asm.bh.apply(null,arguments)},O._vscf_kdf1_release_hash=function(){return O.asm.ch.apply(null,arguments)},O._vscf_kdf1_restore_alg_info=function(){return O.asm.dh.apply(null,arguments)},O._vscf_kdf1_shallow_copy=function(){return O.asm.eh.apply(null,arguments)},O._vscf_kdf1_use_hash=function(){return O.asm.fh.apply(null,arguments)},O._vscf_kdf2_alg_id=function(){return O.asm.gh.apply(null,arguments)},O._vscf_kdf2_delete=function(){return O.asm.hh.apply(null,arguments)},O._vscf_kdf2_derive=function(){return O.asm.ih.apply(null,arguments)},O._vscf_kdf2_new=function(){return O.asm.jh.apply(null,arguments)},O._vscf_kdf2_produce_alg_info=function(){return O.asm.kh.apply(null,arguments)},O._vscf_kdf2_release_hash=function(){return O.asm.lh.apply(null,arguments)},O._vscf_kdf2_restore_alg_info=function(){return O.asm.mh.apply(null,arguments)},O._vscf_kdf2_shallow_copy=function(){return O.asm.nh.apply(null,arguments)},O._vscf_kdf2_use_hash=function(){return O.asm.oh.apply(null,arguments)},O._vscf_key_alg_factory_create_from_alg_id=function(){return O.asm.ph.apply(null,arguments)},O._vscf_key_alg_factory_create_from_key=function(){return O.asm.qh.apply(null,arguments)},O._vscf_key_alg_factory_create_from_raw_private_key=function(){return O.asm.rh.apply(null,arguments)},O._vscf_key_alg_factory_create_from_raw_public_key=function(){return O.asm.sh.apply(null,arguments)},O._vscf_key_asn1_deserializer_delete=function(){return O.asm.th.apply(null,arguments)},O._vscf_key_asn1_deserializer_deserialize_private_key=function(){return O.asm.uh.apply(null,arguments)},O._vscf_key_asn1_deserializer_deserialize_private_key_inplace=function(){return O.asm.vh.apply(null,arguments)},O._vscf_key_asn1_deserializer_deserialize_public_key=function(){return O.asm.wh.apply(null,arguments)},O._vscf_key_asn1_deserializer_deserialize_public_key_inplace=function(){return O.asm.xh.apply(null,arguments)},O._vscf_key_asn1_deserializer_new=function(){return O.asm.yh.apply(null,arguments)},O._vscf_key_asn1_deserializer_release_asn1_reader=function(){return O.asm.zh.apply(null,arguments)},O._vscf_key_asn1_deserializer_setup_defaults=function(){return O.asm.Ah.apply(null,arguments)},O._vscf_key_asn1_deserializer_shallow_copy=function(){return O.asm.Bh.apply(null,arguments)},O._vscf_key_asn1_deserializer_use_asn1_reader=function(){return O.asm.Ch.apply(null,arguments)},O._vscf_key_asn1_serializer_delete=function(){return O.asm.Dh.apply(null,arguments)},O._vscf_key_asn1_serializer_new=function(){return O.asm.Eh.apply(null,arguments)},O._vscf_key_asn1_serializer_release_asn1_writer=function(){return O.asm.Fh.apply(null,arguments)},O._vscf_key_asn1_serializer_serialize_private_key=function(){return O.asm.Gh.apply(null,arguments)},O._vscf_key_asn1_serializer_serialize_private_key_inplace=function(){return O.asm.Hh.apply(null,arguments)},O._vscf_key_asn1_serializer_serialize_public_key=function(){return O.asm.Ih.apply(null,arguments)},O._vscf_key_asn1_serializer_serialize_public_key_inplace=function(){return O.asm.Jh.apply(null,arguments)},O._vscf_key_asn1_serializer_serialized_private_key_len=function(){return O.asm.Kh.apply(null,arguments)},O._vscf_key_asn1_serializer_serialized_public_key_len=function(){return O.asm.Lh.apply(null,arguments)},O._vscf_key_asn1_serializer_setup_defaults=function(){return O.asm.Mh.apply(null,arguments)},O._vscf_key_asn1_serializer_shallow_copy=function(){return O.asm.Nh.apply(null,arguments)},O._vscf_key_asn1_serializer_use_asn1_writer=function(){return O.asm.Oh.apply(null,arguments)},O._vscf_key_material_rng_delete=function(){return O.asm.Ph.apply(null,arguments)},O._vscf_key_material_rng_new=function(){return O.asm.Qh.apply(null,arguments)},O._vscf_key_material_rng_random=function(){return O.asm.Rh.apply(null,arguments)},O._vscf_key_material_rng_reseed=function(){return O.asm.Sh.apply(null,arguments)},O._vscf_key_material_rng_reset_key_material=function(){return O.asm.Th.apply(null,arguments)},O._vscf_key_material_rng_shallow_copy=function(){return O.asm.Uh.apply(null,arguments)},O._vscf_key_provider_delete=function(){return O.asm.Vh.apply(null,arguments)},O._vscf_key_provider_export_private_key=function(){return O.asm.Wh.apply(null,arguments)},O._vscf_key_provider_export_public_key=function(){return O.asm.Xh.apply(null,arguments)},O._vscf_key_provider_exported_private_key_len=function(){return O.asm.Yh.apply(null,arguments)},O._vscf_key_provider_exported_public_key_len=function(){return O.asm.Zh.apply(null,arguments)},O._vscf_key_provider_generate_private_key=function(){return O.asm._h.apply(null,arguments)},O._vscf_key_provider_import_private_key=function(){return O.asm.$h.apply(null,arguments)},O._vscf_key_provider_import_public_key=function(){return O.asm.ai.apply(null,arguments)},O._vscf_key_provider_new=function(){return O.asm.bi.apply(null,arguments)},O._vscf_key_provider_release_ecies=function(){return O.asm.ci.apply(null,arguments)},O._vscf_key_provider_release_random=function(){return O.asm.di.apply(null,arguments)},O._vscf_key_provider_set_rsa_params=function(){return O.asm.ei.apply(null,arguments)},O._vscf_key_provider_setup_defaults=function(){return O.asm.fi.apply(null,arguments)},O._vscf_key_provider_shallow_copy=function(){return O.asm.gi.apply(null,arguments)},O._vscf_key_provider_use_ecies=function(){return O.asm.hi.apply(null,arguments)},O._vscf_key_provider_use_random=function(){return O.asm.ii.apply(null,arguments)},O._vscf_key_recipient_info_delete=function(){return O.asm.ji.apply(null,arguments)},O._vscf_key_recipient_info_encrypted_key=function(){return O.asm.ki.apply(null,arguments)},O._vscf_key_recipient_info_key_encryption_algorithm=function(){return O.asm.li.apply(null,arguments)},O._vscf_key_recipient_info_list_clear=function(){return O.asm.mi.apply(null,arguments)},O._vscf_key_recipient_info_list_delete=function(){return O.asm.ni.apply(null,arguments)},O._vscf_key_recipient_info_list_has_item=function(){return O.asm.oi.apply(null,arguments)},O._vscf_key_recipient_info_list_has_next=function(){return O.asm.pi.apply(null,arguments)},O._vscf_key_recipient_info_list_has_prev=function(){return O.asm.qi.apply(null,arguments)},O._vscf_key_recipient_info_list_item=function(){return O.asm.ri.apply(null,arguments)},O._vscf_key_recipient_info_list_new=function(){return O.asm.si.apply(null,arguments)},O._vscf_key_recipient_info_list_next=function(){return O.asm.ti.apply(null,arguments)},O._vscf_key_recipient_info_list_prev=function(){return O.asm.ui.apply(null,arguments)},O._vscf_key_recipient_info_list_shallow_copy=function(){return O.asm.vi.apply(null,arguments)},O._vscf_key_recipient_info_new=function(){return O.asm.wi.apply(null,arguments)},O._vscf_key_recipient_info_new_with_data=function(){return O.asm.xi.apply(null,arguments)},O._vscf_key_recipient_info_recipient_id=function(){return O.asm.yi.apply(null,arguments)},O._vscf_key_recipient_info_shallow_copy=function(){return O.asm.zi.apply(null,arguments)},O._vscf_message_info_cipher_kdf_alg_info=function(){return O.asm.Ai.apply(null,arguments)},O._vscf_message_info_clear=function(){return O.asm.Bi.apply(null,arguments)},O._vscf_message_info_custom_params=function(){return O.asm.Ci.apply(null,arguments)},O._vscf_message_info_custom_params_add_data=function(){return O.asm.Di.apply(null,arguments)},O._vscf_message_info_custom_params_add_int=function(){return O.asm.Ei.apply(null,arguments)},O._vscf_message_info_custom_params_add_string=function(){return O.asm.Fi.apply(null,arguments)},O._vscf_message_info_custom_params_clear=function(){return O.asm.Gi.apply(null,arguments)},O._vscf_message_info_custom_params_delete=function(){return O.asm.Hi.apply(null,arguments)},O._vscf_message_info_custom_params_find_data=function(){return O.asm.Ii.apply(null,arguments)},O._vscf_message_info_custom_params_find_int=function(){return O.asm.Ji.apply(null,arguments)},O._vscf_message_info_custom_params_find_string=function(){return O.asm.Ki.apply(null,arguments)},O._vscf_message_info_custom_params_has_params=function(){return O.asm.Li.apply(null,arguments)},O._vscf_message_info_custom_params_new=function(){return O.asm.Mi.apply(null,arguments)},O._vscf_message_info_custom_params_shallow_copy=function(){return O.asm.Ni.apply(null,arguments)},O._vscf_message_info_data_encryption_alg_info=function(){return O.asm.Oi.apply(null,arguments)},O._vscf_message_info_delete=function(){return O.asm.Pi.apply(null,arguments)},O._vscf_message_info_der_serializer_delete=function(){return O.asm.Qi.apply(null,arguments)},O._vscf_message_info_der_serializer_deserialize=function(){return O.asm.Ri.apply(null,arguments)},O._vscf_message_info_der_serializer_deserialize_footer=function(){return O.asm.Si.apply(null,arguments)},O._vscf_message_info_der_serializer_new=function(){return O.asm.Ti.apply(null,arguments)},O._vscf_message_info_der_serializer_read_prefix=function(){return O.asm.Ui.apply(null,arguments)},O._vscf_message_info_der_serializer_release_asn1_reader=function(){return O.asm.Vi.apply(null,arguments)},O._vscf_message_info_der_serializer_release_asn1_writer=function(){return O.asm.Wi.apply(null,arguments)},O._vscf_message_info_der_serializer_serialize=function(){return O.asm.Xi.apply(null,arguments)},O._vscf_message_info_der_serializer_serialize_footer=function(){return O.asm.Yi.apply(null,arguments)},O._vscf_message_info_der_serializer_serialized_footer_len=function(){return O.asm.Zi.apply(null,arguments)},O._vscf_message_info_der_serializer_serialized_len=function(){return O.asm._i.apply(null,arguments)},O._vscf_message_info_der_serializer_setup_defaults=function(){return O.asm.$i.apply(null,arguments)},O._vscf_message_info_der_serializer_shallow_copy=function(){return O.asm.aj.apply(null,arguments)},O._vscf_message_info_der_serializer_use_asn1_reader=function(){return O.asm.bj.apply(null,arguments)},O._vscf_message_info_der_serializer_use_asn1_writer=function(){return O.asm.cj.apply(null,arguments)},O._vscf_message_info_editor_add_key_recipient=function(){return O.asm.dj.apply(null,arguments)},O._vscf_message_info_editor_delete=function(){return O.asm.ej.apply(null,arguments)},O._vscf_message_info_editor_new=function(){return O.asm.fj.apply(null,arguments)},O._vscf_message_info_editor_pack=function(){return O.asm.gj.apply(null,arguments)},O._vscf_message_info_editor_packed_len=function(){return O.asm.hj.apply(null,arguments)},O._vscf_message_info_editor_release_random=function(){return O.asm.ij.apply(null,arguments)},O._vscf_message_info_editor_remove_all=function(){return O.asm.jj.apply(null,arguments)},O._vscf_message_info_editor_remove_key_recipient=function(){return O.asm.kj.apply(null,arguments)},O._vscf_message_info_editor_setup_defaults=function(){return O.asm.lj.apply(null,arguments)},O._vscf_message_info_editor_shallow_copy=function(){return O.asm.mj.apply(null,arguments)},O._vscf_message_info_editor_unlock=function(){return O.asm.nj.apply(null,arguments)},O._vscf_message_info_editor_unpack=function(){return O.asm.oj.apply(null,arguments)},O._vscf_message_info_editor_use_random=function(){return O.asm.pj.apply(null,arguments)},O._vscf_message_info_footer_delete=function(){return O.asm.qj.apply(null,arguments)},O._vscf_message_info_footer_has_signer_infos=function(){return O.asm.rj.apply(null,arguments)},O._vscf_message_info_footer_info=function(){return O.asm.sj.apply(null,arguments)},O._vscf_message_info_footer_new=function(){return O.asm.tj.apply(null,arguments)},O._vscf_message_info_footer_shallow_copy=function(){return O.asm.uj.apply(null,arguments)},O._vscf_message_info_footer_signer_digest=function(){return O.asm.vj.apply(null,arguments)},O._vscf_message_info_footer_signer_hash_alg_info=function(){return O.asm.wj.apply(null,arguments)},O._vscf_message_info_footer_signer_infos=function(){return O.asm.xj.apply(null,arguments)},O._vscf_message_info_has_cipher_kdf_alg_info=function(){return O.asm.yj.apply(null,arguments)},O._vscf_message_info_has_custom_params=function(){return O.asm.zj.apply(null,arguments)},O._vscf_message_info_has_footer_info=function(){return O.asm.Aj.apply(null,arguments)},O._vscf_message_info_key_recipient_info_list=function(){return O.asm.Bj.apply(null,arguments)},O._vscf_message_info_new=function(){return O.asm.Cj.apply(null,arguments)},O._vscf_message_info_password_recipient_info_list=function(){return O.asm.Dj.apply(null,arguments)},O._vscf_message_info_shallow_copy=function(){return O.asm.Ej.apply(null,arguments)},O._vscf_oid_equal=function(){return O.asm.Fj.apply(null,arguments)},O._vscf_oid_from_alg_id=function(){return O.asm.Gj.apply(null,arguments)},O._vscf_oid_from_id=function(){return O.asm.Hj.apply(null,arguments)},O._vscf_oid_id_to_alg_id=function(){return O.asm.Ij.apply(null,arguments)},O._vscf_oid_to_alg_id=function(){return O.asm.Jj.apply(null,arguments)},O._vscf_oid_to_id=function(){return O.asm.Kj.apply(null,arguments)},O._vscf_password_recipient_info_delete=function(){return O.asm.Lj.apply(null,arguments)},O._vscf_password_recipient_info_encrypted_key=function(){return O.asm.Mj.apply(null,arguments)},O._vscf_password_recipient_info_key_encryption_algorithm=function(){return O.asm.Nj.apply(null,arguments)},O._vscf_password_recipient_info_list_clear=function(){return O.asm.Oj.apply(null,arguments)},O._vscf_password_recipient_info_list_delete=function(){return O.asm.Pj.apply(null,arguments)},O._vscf_password_recipient_info_list_has_item=function(){return O.asm.Qj.apply(null,arguments)},O._vscf_password_recipient_info_list_has_next=function(){return O.asm.Rj.apply(null,arguments)},O._vscf_password_recipient_info_list_has_prev=function(){return O.asm.Sj.apply(null,arguments)},O._vscf_password_recipient_info_list_item=function(){return O.asm.Tj.apply(null,arguments)},O._vscf_password_recipient_info_list_new=function(){return O.asm.Uj.apply(null,arguments)},O._vscf_password_recipient_info_list_next=function(){return O.asm.Vj.apply(null,arguments)},O._vscf_password_recipient_info_list_prev=function(){return O.asm.Wj.apply(null,arguments)},O._vscf_password_recipient_info_list_shallow_copy=function(){return O.asm.Xj.apply(null,arguments)},O._vscf_password_recipient_info_new=function(){return O.asm.Yj.apply(null,arguments)},O._vscf_password_recipient_info_new_with_members=function(){return O.asm.Zj.apply(null,arguments)},O._vscf_password_recipient_info_shallow_copy=function(){return O.asm._j.apply(null,arguments)},O._vscf_pbe_alg_info_alg_id=function(){return O.asm.$j.apply(null,arguments)},O._vscf_pbe_alg_info_cipher_alg_info=function(){return O.asm.ak.apply(null,arguments)},O._vscf_pbe_alg_info_delete=function(){return O.asm.bk.apply(null,arguments)},O._vscf_pbe_alg_info_kdf_alg_info=function(){return O.asm.ck.apply(null,arguments)},O._vscf_pbe_alg_info_new=function(){return O.asm.dk.apply(null,arguments)},O._vscf_pbe_alg_info_new_with_members=function(){return O.asm.ek.apply(null,arguments)},O._vscf_pbe_alg_info_shallow_copy=function(){return O.asm.fk.apply(null,arguments)},O._vscf_pem_title=function(){return O.asm.gk.apply(null,arguments)},O._vscf_pem_unwrap=function(){return O.asm.hk.apply(null,arguments)},O._vscf_pem_unwrapped_len=function(){return O.asm.ik.apply(null,arguments)},O._vscf_pem_wrap=function(){return O.asm.jk.apply(null,arguments)},O._vscf_pem_wrapped_len=function(){return O.asm.kk.apply(null,arguments)},O._vscf_pkcs5_pbes2_alg_id=function(){return O.asm.lk.apply(null,arguments)},O._vscf_pkcs5_pbes2_decrypt=function(){return O.asm.mk.apply(null,arguments)},O._vscf_pkcs5_pbes2_decrypted_len=function(){return O.asm.nk.apply(null,arguments)},O._vscf_pkcs5_pbes2_delete=function(){return O.asm.ok.apply(null,arguments)},O._vscf_pkcs5_pbes2_encrypt=function(){return O.asm.pk.apply(null,arguments)},O._vscf_pkcs5_pbes2_encrypted_len=function(){return O.asm.qk.apply(null,arguments)},O._vscf_pkcs5_pbes2_new=function(){return O.asm.rk.apply(null,arguments)},O._vscf_pkcs5_pbes2_precise_encrypted_len=function(){return O.asm.sk.apply(null,arguments)},O._vscf_pkcs5_pbes2_produce_alg_info=function(){return O.asm.tk.apply(null,arguments)},O._vscf_pkcs5_pbes2_release_cipher=function(){return O.asm.uk.apply(null,arguments)},O._vscf_pkcs5_pbes2_release_kdf=function(){return O.asm.vk.apply(null,arguments)},O._vscf_pkcs5_pbes2_reset=function(){return O.asm.wk.apply(null,arguments)},O._vscf_pkcs5_pbes2_restore_alg_info=function(){return O.asm.xk.apply(null,arguments)},O._vscf_pkcs5_pbes2_shallow_copy=function(){return O.asm.yk.apply(null,arguments)},O._vscf_pkcs5_pbes2_use_cipher=function(){return O.asm.zk.apply(null,arguments)},O._vscf_pkcs5_pbes2_use_kdf=function(){return O.asm.Ak.apply(null,arguments)},O._vscf_pkcs5_pbkdf2_alg_id=function(){return O.asm.Bk.apply(null,arguments)},O._vscf_pkcs5_pbkdf2_delete=function(){return O.asm.Ck.apply(null,arguments)},O._vscf_pkcs5_pbkdf2_derive=function(){return O.asm.Dk.apply(null,arguments)},O._vscf_pkcs5_pbkdf2_new=function(){return O.asm.Ek.apply(null,arguments)},O._vscf_pkcs5_pbkdf2_produce_alg_info=function(){return O.asm.Fk.apply(null,arguments)},O._vscf_pkcs5_pbkdf2_release_hmac=function(){return O.asm.Gk.apply(null,arguments)},O._vscf_pkcs5_pbkdf2_reset=function(){return O.asm.Hk.apply(null,arguments)},O._vscf_pkcs5_pbkdf2_restore_alg_info=function(){return O.asm.Ik.apply(null,arguments)},O._vscf_pkcs5_pbkdf2_set_info=function(){return O.asm.Jk.apply(null,arguments)},O._vscf_pkcs5_pbkdf2_setup_defaults=function(){return O.asm.Kk.apply(null,arguments)},O._vscf_pkcs5_pbkdf2_shallow_copy=function(){return O.asm.Lk.apply(null,arguments)},O._vscf_pkcs5_pbkdf2_use_hmac=function(){return O.asm.Mk.apply(null,arguments)},O._vscf_pkcs8_serializer_delete=function(){return O.asm.Nk.apply(null,arguments)},O._vscf_pkcs8_serializer_new=function(){return O.asm.Ok.apply(null,arguments)},O._vscf_pkcs8_serializer_release_asn1_writer=function(){return O.asm.Pk.apply(null,arguments)},O._vscf_pkcs8_serializer_serialize_private_key=function(){return O.asm.Qk.apply(null,arguments)},O._vscf_pkcs8_serializer_serialize_private_key_inplace=function(){return O.asm.Rk.apply(null,arguments)},O._vscf_pkcs8_serializer_serialize_public_key=function(){return O.asm.Sk.apply(null,arguments)},O._vscf_pkcs8_serializer_serialize_public_key_inplace=function(){return O.asm.Tk.apply(null,arguments)},O._vscf_pkcs8_serializer_serialized_private_key_len=function(){return O.asm.Uk.apply(null,arguments)},O._vscf_pkcs8_serializer_serialized_public_key_len=function(){return O.asm.Vk.apply(null,arguments)},O._vscf_pkcs8_serializer_setup_defaults=function(){return O.asm.Wk.apply(null,arguments)},O._vscf_pkcs8_serializer_shallow_copy=function(){return O.asm.Xk.apply(null,arguments)},O._vscf_pkcs8_serializer_use_asn1_writer=function(){return O.asm.Yk.apply(null,arguments)},O._vscf_raw_private_key_alg_id=function(){return O.asm.Zk.apply(null,arguments)},O._vscf_raw_private_key_alg_info=function(){return O.asm._k.apply(null,arguments)},O._vscf_raw_private_key_bitlen=function(){return O.asm.$k.apply(null,arguments)},O._vscf_raw_private_key_data=function(){return O.asm.al.apply(null,arguments)},O._vscf_raw_private_key_delete=function(){return O.asm.bl.apply(null,arguments)},O._vscf_raw_private_key_extract_public_key=function(){return O.asm.cl.apply(null,arguments)},O._vscf_raw_private_key_get_public_key=function(){return O.asm.dl.apply(null,arguments)},O._vscf_raw_private_key_has_public_key=function(){return O.asm.el.apply(null,arguments)},O._vscf_raw_private_key_impl_tag=function(){return O.asm.fl.apply(null,arguments)},O._vscf_raw_private_key_is_valid=function(){return O.asm.gl.apply(null,arguments)},O._vscf_raw_private_key_len=function(){return O.asm.hl.apply(null,arguments)},O._vscf_raw_private_key_new=function(){return O.asm.il.apply(null,arguments)},O._vscf_raw_private_key_set_public_key=function(){return O.asm.jl.apply(null,arguments)},O._vscf_raw_private_key_shallow_copy=function(){return O.asm.kl.apply(null,arguments)},O._vscf_raw_public_key_alg_id=function(){return O.asm.ll.apply(null,arguments)},O._vscf_raw_public_key_alg_info=function(){return O.asm.ml.apply(null,arguments)},O._vscf_raw_public_key_bitlen=function(){return O.asm.nl.apply(null,arguments)},O._vscf_raw_public_key_data=function(){return O.asm.ol.apply(null,arguments)},O._vscf_raw_public_key_delete=function(){return O.asm.pl.apply(null,arguments)},O._vscf_raw_public_key_impl_tag=function(){return O.asm.ql.apply(null,arguments)},O._vscf_raw_public_key_is_valid=function(){return O.asm.rl.apply(null,arguments)},O._vscf_raw_public_key_len=function(){return O.asm.sl.apply(null,arguments)},O._vscf_raw_public_key_new=function(){return O.asm.tl.apply(null,arguments)},O._vscf_raw_public_key_shallow_copy=function(){return O.asm.ul.apply(null,arguments)},O._vscf_recipient_cipher_add_key_recipient=function(){return O.asm.vl.apply(null,arguments)},O._vscf_recipient_cipher_add_signer=function(){return O.asm.wl.apply(null,arguments)},O._vscf_recipient_cipher_clear_recipients=function(){return O.asm.xl.apply(null,arguments)},O._vscf_recipient_cipher_clear_signers=function(){return O.asm.yl.apply(null,arguments)},O._vscf_recipient_cipher_custom_params=function(){return O.asm.zl.apply(null,arguments)},O._vscf_recipient_cipher_decryption_out_len=function(){return O.asm.Al.apply(null,arguments)},O._vscf_recipient_cipher_delete=function(){return O.asm.Bl.apply(null,arguments)},O._vscf_recipient_cipher_encryption_out_len=function(){return O.asm.Cl.apply(null,arguments)},O._vscf_recipient_cipher_finish_decryption=function(){return O.asm.Dl.apply(null,arguments)},O._vscf_recipient_cipher_finish_encryption=function(){return O.asm.El.apply(null,arguments)},O._vscf_recipient_cipher_has_key_recipient=function(){return O.asm.Fl.apply(null,arguments)},O._vscf_recipient_cipher_is_data_signed=function(){return O.asm.Gl.apply(null,arguments)},O._vscf_recipient_cipher_message_info_footer_len=function(){return O.asm.Hl.apply(null,arguments)},O._vscf_recipient_cipher_message_info_len=function(){return O.asm.Il.apply(null,arguments)},O._vscf_recipient_cipher_new=function(){return O.asm.Jl.apply(null,arguments)},O._vscf_recipient_cipher_pack_message_info=function(){return O.asm.Kl.apply(null,arguments)},O._vscf_recipient_cipher_pack_message_info_footer=function(){return O.asm.Ll.apply(null,arguments)},O._vscf_recipient_cipher_process_decryption=function(){return O.asm.Ml.apply(null,arguments)},O._vscf_recipient_cipher_process_encryption=function(){return O.asm.Nl.apply(null,arguments)},O._vscf_recipient_cipher_release_encryption_cipher=function(){return O.asm.Ol.apply(null,arguments)},O._vscf_recipient_cipher_release_random=function(){return O.asm.Pl.apply(null,arguments)},O._vscf_recipient_cipher_release_signer_hash=function(){return O.asm.Ql.apply(null,arguments)},O._vscf_recipient_cipher_shallow_copy=function(){return O.asm.Rl.apply(null,arguments)},O._vscf_recipient_cipher_signer_infos=function(){return O.asm.Sl.apply(null,arguments)},O._vscf_recipient_cipher_start_decryption_with_key=function(){return O.asm.Tl.apply(null,arguments)},O._vscf_recipient_cipher_start_encryption=function(){return O.asm.Ul.apply(null,arguments)},O._vscf_recipient_cipher_start_signed_encryption=function(){return O.asm.Vl.apply(null,arguments)},O._vscf_recipient_cipher_start_verified_decryption_with_key=function(){return O.asm.Wl.apply(null,arguments)},O._vscf_recipient_cipher_use_encryption_cipher=function(){return O.asm.Xl.apply(null,arguments)},O._vscf_recipient_cipher_use_random=function(){return O.asm.Yl.apply(null,arguments)},O._vscf_recipient_cipher_use_signer_hash=function(){return O.asm.Zl.apply(null,arguments)},O._vscf_recipient_cipher_verify_signer_info=function(){return O.asm._l.apply(null,arguments)},O._vscf_rsa_alg_id=function(){return O.asm.$l.apply(null,arguments)},O._vscf_rsa_can_decrypt=function(){return O.asm.am.apply(null,arguments)},O._vscf_rsa_can_encrypt=function(){return O.asm.bm.apply(null,arguments)},O._vscf_rsa_can_sign=function(){return O.asm.cm.apply(null,arguments)},O._vscf_rsa_can_verify=function(){return O.asm.dm.apply(null,arguments)},O._vscf_rsa_decrypt=function(){return O.asm.em.apply(null,arguments)},O._vscf_rsa_decrypted_len=function(){return O.asm.fm.apply(null,arguments)},O._vscf_rsa_delete=function(){return O.asm.gm.apply(null,arguments)},O._vscf_rsa_encrypt=function(){return O.asm.hm.apply(null,arguments)},O._vscf_rsa_encrypted_len=function(){return O.asm.im.apply(null,arguments)},O._vscf_rsa_export_private_key=function(){return O.asm.jm.apply(null,arguments)},O._vscf_rsa_export_public_key=function(){return O.asm.km.apply(null,arguments)},O._vscf_rsa_generate_ephemeral_key=function(){return O.asm.lm.apply(null,arguments)},O._vscf_rsa_generate_key=function(){return O.asm.mm.apply(null,arguments)},O._vscf_rsa_import_private_key=function(){return O.asm.nm.apply(null,arguments)},O._vscf_rsa_import_public_key=function(){return O.asm.om.apply(null,arguments)},O._vscf_rsa_new=function(){return O.asm.pm.apply(null,arguments)},O._vscf_rsa_private_key_alg_id=function(){return O.asm.qm.apply(null,arguments)},O._vscf_rsa_private_key_alg_info=function(){return O.asm.rm.apply(null,arguments)},O._vscf_rsa_private_key_bitlen=function(){return O.asm.sm.apply(null,arguments)},O._vscf_rsa_private_key_delete=function(){return O.asm.tm.apply(null,arguments)},O._vscf_rsa_private_key_extract_public_key=function(){return O.asm.um.apply(null,arguments)},O._vscf_rsa_private_key_impl_tag=function(){return O.asm.vm.apply(null,arguments)},O._vscf_rsa_private_key_is_valid=function(){return O.asm.wm.apply(null,arguments)},O._vscf_rsa_private_key_len=function(){return O.asm.xm.apply(null,arguments)},O._vscf_rsa_private_key_new=function(){return O.asm.ym.apply(null,arguments)},O._vscf_rsa_private_key_shallow_copy=function(){return O.asm.zm.apply(null,arguments)},O._vscf_rsa_produce_alg_info=function(){return O.asm.Am.apply(null,arguments)},O._vscf_rsa_public_key_alg_id=function(){return O.asm.Bm.apply(null,arguments)},O._vscf_rsa_public_key_alg_info=function(){return O.asm.Cm.apply(null,arguments)},O._vscf_rsa_public_key_bitlen=function(){return O.asm.Dm.apply(null,arguments)},O._vscf_rsa_public_key_delete=function(){return O.asm.Em.apply(null,arguments)},O._vscf_rsa_public_key_impl_tag=function(){return O.asm.Fm.apply(null,arguments)},O._vscf_rsa_public_key_is_valid=function(){return O.asm.Gm.apply(null,arguments)},O._vscf_rsa_public_key_key_exponent=function(){return O.asm.Hm.apply(null,arguments)},O._vscf_rsa_public_key_len=function(){return O.asm.Im.apply(null,arguments)},O._vscf_rsa_public_key_new=function(){return O.asm.Jm.apply(null,arguments)},O._vscf_rsa_public_key_shallow_copy=function(){return O.asm.Km.apply(null,arguments)},O._vscf_rsa_release_random=function(){return O.asm.Lm.apply(null,arguments)},O._vscf_rsa_restore_alg_info=function(){return O.asm.Mm.apply(null,arguments)},O._vscf_rsa_setup_defaults=function(){return O.asm.Nm.apply(null,arguments)},O._vscf_rsa_shallow_copy=function(){return O.asm.Om.apply(null,arguments)},O._vscf_rsa_sign_hash=function(){return O.asm.Pm.apply(null,arguments)},O._vscf_rsa_signature_len=function(){return O.asm.Qm.apply(null,arguments)},O._vscf_rsa_use_random=function(){return O.asm.Rm.apply(null,arguments)},O._vscf_rsa_verify_hash=function(){return O.asm.Sm.apply(null,arguments)},O._vscf_salted_kdf_alg_info_alg_id=function(){return O.asm.Tm.apply(null,arguments)},O._vscf_salted_kdf_alg_info_delete=function(){return O.asm.Um.apply(null,arguments)},O._vscf_salted_kdf_alg_info_hash_alg_info=function(){return O.asm.Vm.apply(null,arguments)},O._vscf_salted_kdf_alg_info_iteration_count=function(){return O.asm.Wm.apply(null,arguments)},O._vscf_salted_kdf_alg_info_new=function(){return O.asm.Xm.apply(null,arguments)},O._vscf_salted_kdf_alg_info_new_with_members=function(){return O.asm.Ym.apply(null,arguments)},O._vscf_salted_kdf_alg_info_salt=function(){return O.asm.Zm.apply(null,arguments)},O._vscf_salted_kdf_alg_info_shallow_copy=function(){return O.asm._m.apply(null,arguments)},O._vscf_sec1_serializer_delete=function(){return O.asm.$m.apply(null,arguments)},O._vscf_sec1_serializer_new=function(){return O.asm.an.apply(null,arguments)},O._vscf_sec1_serializer_release_asn1_writer=function(){return O.asm.bn.apply(null,arguments)},O._vscf_sec1_serializer_serialize_private_key=function(){return O.asm.cn.apply(null,arguments)},O._vscf_sec1_serializer_serialize_private_key_inplace=function(){return O.asm.dn.apply(null,arguments)},O._vscf_sec1_serializer_serialize_public_key=function(){return O.asm.en.apply(null,arguments)},O._vscf_sec1_serializer_serialize_public_key_inplace=function(){return O.asm.fn.apply(null,arguments)},O._vscf_sec1_serializer_serialized_private_key_len=function(){return O.asm.gn.apply(null,arguments)},O._vscf_sec1_serializer_serialized_public_key_len=function(){return O.asm.hn.apply(null,arguments)},O._vscf_sec1_serializer_setup_defaults=function(){return O.asm.jn.apply(null,arguments)},O._vscf_sec1_serializer_shallow_copy=function(){return O.asm.kn.apply(null,arguments)},O._vscf_sec1_serializer_use_asn1_writer=function(){return O.asm.ln.apply(null,arguments)},O._vscf_seed_entropy_source_delete=function(){return O.asm.mn.apply(null,arguments)},O._vscf_seed_entropy_source_gather=function(){return O.asm.nn.apply(null,arguments)},O._vscf_seed_entropy_source_is_strong=function(){return O.asm.on.apply(null,arguments)},O._vscf_seed_entropy_source_new=function(){return O.asm.pn.apply(null,arguments)},O._vscf_seed_entropy_source_reset_seed=function(){return O.asm.qn.apply(null,arguments)},O._vscf_seed_entropy_source_shallow_copy=function(){return O.asm.rn.apply(null,arguments)},O._vscf_sha224_alg_id=function(){return O.asm.sn.apply(null,arguments)},O._vscf_sha224_delete=function(){return O.asm.tn.apply(null,arguments)},O._vscf_sha224_finish=function(){return O.asm.un.apply(null,arguments)},O._vscf_sha224_hash=function(){return O.asm.vn.apply(null,arguments)},O._vscf_sha224_new=function(){return O.asm.wn.apply(null,arguments)},O._vscf_sha224_produce_alg_info=function(){return O.asm.xn.apply(null,arguments)},O._vscf_sha224_restore_alg_info=function(){return O.asm.yn.apply(null,arguments)},O._vscf_sha224_shallow_copy=function(){return O.asm.zn.apply(null,arguments)},O._vscf_sha224_start=function(){return O.asm.An.apply(null,arguments)},O._vscf_sha224_update=function(){return O.asm.Bn.apply(null,arguments)},O._vscf_sha256_alg_id=function(){return O.asm.Cn.apply(null,arguments)},O._vscf_sha256_delete=function(){return O.asm.Dn.apply(null,arguments)},O._vscf_sha256_finish=function(){return O.asm.En.apply(null,arguments)},O._vscf_sha256_hash=function(){return O.asm.Fn.apply(null,arguments)},O._vscf_sha256_new=function(){return O.asm.Gn.apply(null,arguments)},O._vscf_sha256_produce_alg_info=function(){return O.asm.Hn.apply(null,arguments)},O._vscf_sha256_restore_alg_info=function(){return O.asm.In.apply(null,arguments)},O._vscf_sha256_shallow_copy=function(){return O.asm.Jn.apply(null,arguments)},O._vscf_sha256_start=function(){return O.asm.Kn.apply(null,arguments)},O._vscf_sha256_update=function(){return O.asm.Ln.apply(null,arguments)},O._vscf_sha384_alg_id=function(){return O.asm.Mn.apply(null,arguments)},O._vscf_sha384_delete=function(){return O.asm.Nn.apply(null,arguments)},O._vscf_sha384_finish=function(){return O.asm.On.apply(null,arguments)},O._vscf_sha384_hash=function(){return O.asm.Pn.apply(null,arguments)},O._vscf_sha384_new=function(){return O.asm.Qn.apply(null,arguments)},O._vscf_sha384_produce_alg_info=function(){return O.asm.Rn.apply(null,arguments)},O._vscf_sha384_restore_alg_info=function(){return O.asm.Sn.apply(null,arguments)},O._vscf_sha384_shallow_copy=function(){return O.asm.Tn.apply(null,arguments)},O._vscf_sha384_start=function(){return O.asm.Un.apply(null,arguments)},O._vscf_sha384_update=function(){return O.asm.Vn.apply(null,arguments)},O._vscf_sha512_alg_id=function(){return O.asm.Wn.apply(null,arguments)},O._vscf_sha512_delete=function(){return O.asm.Xn.apply(null,arguments)},O._vscf_sha512_finish=function(){return O.asm.Yn.apply(null,arguments)},O._vscf_sha512_hash=function(){return O.asm.Zn.apply(null,arguments)},O._vscf_sha512_new=function(){return O.asm._n.apply(null,arguments)},O._vscf_sha512_produce_alg_info=function(){return O.asm.$n.apply(null,arguments)},O._vscf_sha512_restore_alg_info=function(){return O.asm.ao.apply(null,arguments)},O._vscf_sha512_shallow_copy=function(){return O.asm.bo.apply(null,arguments)},O._vscf_sha512_start=function(){return O.asm.co.apply(null,arguments)},O._vscf_sha512_update=function(){return O.asm.eo.apply(null,arguments)},O._vscf_signed_data_info_delete=function(){return O.asm.fo.apply(null,arguments)},O._vscf_signed_data_info_hash_alg_info=function(){return O.asm.go.apply(null,arguments)},O._vscf_signed_data_info_new=function(){return O.asm.ho.apply(null,arguments)},O._vscf_signed_data_info_set_hash_alg_info=function(){return O.asm.io.apply(null,arguments)},O._vscf_signed_data_info_shallow_copy=function(){return O.asm.jo.apply(null,arguments)},O._vscf_signer_append_data=function(){return O.asm.ko.apply(null,arguments)},O._vscf_signer_delete=function(){return O.asm.lo.apply(null,arguments)},O._vscf_signer_info_delete=function(){return O.asm.mo.apply(null,arguments)},O._vscf_signer_info_list_clear=function(){return O.asm.no.apply(null,arguments)},O._vscf_signer_info_list_delete=function(){return O.asm.oo.apply(null,arguments)},O._vscf_signer_info_list_has_item=function(){return O.asm.po.apply(null,arguments)},O._vscf_signer_info_list_has_next=function(){return O.asm.qo.apply(null,arguments)},O._vscf_signer_info_list_has_prev=function(){return O.asm.ro.apply(null,arguments)},O._vscf_signer_info_list_item=function(){return O.asm.so.apply(null,arguments)},O._vscf_signer_info_list_new=function(){return O.asm.to.apply(null,arguments)},O._vscf_signer_info_list_next=function(){return O.asm.uo.apply(null,arguments)},O._vscf_signer_info_list_prev=function(){return O.asm.vo.apply(null,arguments)},O._vscf_signer_info_list_shallow_copy=function(){return O.asm.wo.apply(null,arguments)},O._vscf_signer_info_new=function(){return O.asm.xo.apply(null,arguments)},O._vscf_signer_info_shallow_copy=function(){return O.asm.yo.apply(null,arguments)},O._vscf_signer_info_signature=function(){return O.asm.zo.apply(null,arguments)},O._vscf_signer_info_signer_alg_info=function(){return O.asm.Ao.apply(null,arguments)},O._vscf_signer_info_signer_id=function(){return O.asm.Bo.apply(null,arguments)},O._vscf_signer_new=function(){return O.asm.Co.apply(null,arguments)},O._vscf_signer_release_hash=function(){return O.asm.Do.apply(null,arguments)},O._vscf_signer_release_random=function(){return O.asm.Eo.apply(null,arguments)},O._vscf_signer_reset=function(){return O.asm.Fo.apply(null,arguments)},O._vscf_signer_shallow_copy=function(){return O.asm.Go.apply(null,arguments)},O._vscf_signer_sign=function(){return O.asm.Ho.apply(null,arguments)},O._vscf_signer_signature_len=function(){return O.asm.Io.apply(null,arguments)},O._vscf_signer_use_hash=function(){return O.asm.Jo.apply(null,arguments)},O._vscf_signer_use_random=function(){return O.asm.Ko.apply(null,arguments)},O._vscf_simple_alg_info_alg_id=function(){return O.asm.Lo.apply(null,arguments)},O._vscf_simple_alg_info_delete=function(){return O.asm.Mo.apply(null,arguments)},O._vscf_simple_alg_info_new=function(){return O.asm.No.apply(null,arguments)},O._vscf_simple_alg_info_new_with_alg_id=function(){return O.asm.Oo.apply(null,arguments)},O._vscf_simple_alg_info_shallow_copy=function(){return O.asm.Po.apply(null,arguments)},O._vscf_verifier_append_data=function(){return O.asm.Qo.apply(null,arguments)},O._vscf_verifier_delete=function(){return O.asm.Ro.apply(null,arguments)},O._vscf_verifier_new=function(){return O.asm.So.apply(null,arguments)},O._vscf_verifier_reset=function(){return O.asm.To.apply(null,arguments)},O._vscf_verifier_shallow_copy=function(){return O.asm.Uo.apply(null,arguments)},O._vscf_verifier_verify=function(){return O.asm.Vo.apply(null,arguments)},O.stackAlloc=function(){return O.asm.Xo.apply(null,arguments)},O.dynCall_vi=function(){return O.asm.Wo.apply(null,arguments)},O.asm=Vt,O.then=function(t){if(jt)t(O);else{var e=O.onRuntimeInitialized;O.onRuntimeInitialized=function(){e&&e(),t(O);};}return O},vt=function t(){jt||M(),jt||(vt=t);},O.run=M,O.preInit)for("function"==typeof O.preInit&&(O.preInit=[O.preInit]);0<O.preInit.length;)O.preInit.pop()();return M(),e}}(),r$1.exports=n$1,t=e.exports;var _=()=>{class t extends Error{constructor(t){super(t),this.name="FoundationError",this.message=t;}static handleStatusCode(e){if(0!=e){if(-1==e)throw new t("This error should not be returned if assertions is enabled.");if(-2==e)throw new t("Can be used to define that not all context prerequisites are satisfied. Note, this error should not be returned if assertions is enabled.");if(-3==e)throw new t("Define that error code from one of third-party module was not handled. Note, this error should not be returned if assertions is enabled.");if(-101==e)throw new t("Buffer capacity is not enough to hold result.");if(-200==e)throw new t("Unsupported algorithm.");if(-201==e)throw new t("Authentication failed during decryption.");if(-202==e)throw new t("Attempt to read data out of buffer bounds.");if(-203==e)throw new t("ASN.1 encoded data is corrupted.");if(-204==e)throw new t("Attempt to read ASN.1 type that is bigger then requested C type.");if(-205==e)throw new t("ASN.1 representation of PKCS#1 public key is corrupted.");if(-206==e)throw new t("ASN.1 representation of PKCS#1 private key is corrupted.");if(-207==e)throw new t("ASN.1 representation of PKCS#8 public key is corrupted.");if(-208==e)throw new t("ASN.1 representation of PKCS#8 private key is corrupted.");if(-209==e)throw new t("Encrypted data is corrupted.");if(-210==e)throw new t("Underlying random operation returns error.");if(-211==e)throw new t("Generation of the private or secret key failed.");if(-212==e)throw new t("One of the entropy sources failed.");if(-213==e)throw new t("Requested data to be generated is too big.");if(-214==e)throw new t("Base64 encoded string contains invalid characters.");if(-215==e)throw new t("PEM data is corrupted.");if(-216==e)throw new t("Exchange key return zero.");if(-217==e)throw new t("Ed25519 public key is corrupted.");if(-218==e)throw new t("Ed25519 private key is corrupted.");if(-219==e)throw new t("CURVE25519 public key is corrupted.");if(-220==e)throw new t("CURVE25519 private key is corrupted.");if(-221==e)throw new t("Elliptic curve public key format is corrupted see RFC 5480.");if(-222==e)throw new t("Elliptic curve public key format is corrupted see RFC 5915.");if(-223==e)throw new t("ASN.1 representation of a public key is corrupted.");if(-224==e)throw new t("ASN.1 representation of a private key is corrupted.");if(-225==e)throw new t("Key algorithm does not accept given type of public key.");if(-226==e)throw new t("Key algorithm does not accept given type of private key.");if(-301==e)throw new t("Decryption failed, because message info was not given explicitly, and was not part of an encrypted message.");if(-302==e)throw new t("Message Info is corrupted.");if(-303==e)throw new t("Recipient defined with id is not found within message info during data decryption.");if(-304==e)throw new t("Content encryption key can not be decrypted with a given private key.");if(-305==e)throw new t("Content encryption key can not be decrypted with a given password.");if(-306==e)throw new t("Custom parameter with a given key is not found within message info.");if(-307==e)throw new t("A custom parameter with a given key is found, but the requested value type does not correspond to the actual type.");if(-308==e)throw new t("Signature format is corrupted.");if(-309==e)throw new t("Message Info footer is corrupted.");if(-401==e)throw new t("Brainkey password length is out of range.");if(-402==e)throw new t("Brainkey number length should be 32 byte.");if(-403==e)throw new t("Brainkey point length should be 65 bytes.");if(-404==e)throw new t("Brainkey name is out of range.");if(-405==e)throw new t("Brainkey internal error.");if(-406==e)throw new t("Brainkey point is invalid.");if(-407==e)throw new t("Brainkey number buffer length capacity should be >= 32 byte.");if(-408==e)throw new t("Brainkey point buffer length capacity should be >= 32 byte.");if(-409==e)throw new t("Brainkey seed buffer length capacity should be >= 32 byte.");if(-410==e)throw new t("Brainkey identity secret is invalid.");if(-501==e)throw new t("Invalid padding.");if(-601==e)throw new t("Protobuf error.");if(-701==e)throw new t("Session id doesnt match.");if(-702==e)throw new t("Epoch not found.");if(-703==e)throw new t("Wrong key type.");if(-704==e)throw new t("Invalid signature.");if(-705==e)throw new t("Ed25519 error.");if(-706==e)throw new t("Duplicate epoch.");if(-707==e)throw new t("Plain text too long.");throw new t("Unexpected status code:"+e)}}}return t};function s$1(t,e){if(!("number"==typeof e||e instanceof Number))throw new TypeError(`'${t}' is not a number`);if(Number.isNaN(e))throw new TypeError(`'${t}' is NaN`);if(1/0===e)throw new TypeError(`'${t}' is Infinity`);if(-1/0===e)throw new TypeError(`'${t}' is -Infinity`)}function c$1(t,e){if(s$1(t,e),0==e)throw new TypeError(`'${t}' is NULL`)}var a$1={ensureNumber:s$1,ensureString:function(t,e){if(!("string"==typeof e||e instanceof String))throw new TypeError(`'${t}' is not a string`)},ensureBoolean:function(t,e){if("boolean"!=typeof e)throw new TypeError(`'${t}' is not a boolean`)},ensureByteArray:function(t,e){if(!(e instanceof Uint8Array))throw new TypeError(`'${t}' is not an Uint8Array`)},ensureClass:function(t,e,r){if(!(e instanceof r))throw new TypeError(`'${t}' is not an instance of the class ${r.name}`);c$1(t,e.ctxPtr);},ensureNotNull:c$1,ensureImplementInterface:function(t,e,r,n,_){if(c$1(t,e.ctxPtr),!_.isImplemented(e.ctxPtr,n))throw new TypeError(`'${t}' does not implement interface '${r}'`)}},i=(t,e)=>{class r{constructor(e){this.name="MessageInfo",this.ctxPtr=void 0===e?t._vscf_message_info_new():e;}static newAndUseCContext(e){return new r(t._vscf_message_info_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_message_info_delete(this.ctxPtr),this.ctxPtr=null);}dataEncryptionAlgInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_message_info_data_encryption_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}keyRecipientInfoList(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_message_info_key_recipient_info_list(this.ctxPtr),e.KeyRecipientInfoList.newAndUseCContext(r)}passwordRecipientInfoList(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_message_info_password_recipient_info_list(this.ctxPtr),e.PasswordRecipientInfoList.newAndUseCContext(r)}hasCustomParams(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_message_info_has_custom_params(this.ctxPtr)}customParams(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_message_info_custom_params(this.ctxPtr),e.MessageInfoCustomParams.newAndUseCContext(r)}hasCipherKdfAlgInfo(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_message_info_has_cipher_kdf_alg_info(this.ctxPtr)}cipherKdfAlgInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_message_info_cipher_kdf_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}hasFooterInfo(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_message_info_has_footer_info(this.ctxPtr)}footerInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_message_info_footer_info(this.ctxPtr),e.FooterInfo.newAndUseCContext(r)}clear(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_message_info_clear(this.ctxPtr);}}return r},l$1=(t,e)=>{class r{constructor(e){this.name="KeyRecipientInfo",this.ctxPtr=void 0===e?t._vscf_key_recipient_info_new():e;}static newAndUseCContext(e){return new r(t._vscf_key_recipient_info_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_key_recipient_info_delete(this.ctxPtr),this.ctxPtr=null);}static newWithData(n,_,s){a$1.ensureByteArray("recipientId",n),a$1.ensureImplementInterface("keyEncryptionAlgorithm",_,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),a$1.ensureByteArray("encryptedKey",s);var c=n.length*n.BYTES_PER_ELEMENT;const i=t._malloc(c);t.HEAP8.set(n,i),n=t._vsc_data_ctx_size(),n=t._malloc(n),t._vsc_data(n,i,c),c=s.length*s.BYTES_PER_ELEMENT;const l=t._malloc(c);let u;t.HEAP8.set(s,l),s=t._vsc_data_ctx_size(),s=t._malloc(s),t._vsc_data(s,l,c);try{return u=t._vscf_key_recipient_info_new_with_data(n,_.ctxPtr,s),r.newAndTakeCContext(u)}finally{t._free(i),t._free(n),t._free(l),t._free(s);}}recipientId(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var e=t._vsc_data_ctx_size();e=t._malloc(e);try{t._vscf_key_recipient_info_recipient_id(e,this.ctxPtr);const r=t._vsc_data_len(e),n=t._vsc_data_bytes(e);return t.HEAPU8.slice(n,n+r)}finally{t._free(e);}}keyEncryptionAlgorithm(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_key_recipient_info_key_encryption_algorithm(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}encryptedKey(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var e=t._vsc_data_ctx_size();e=t._malloc(e);try{t._vscf_key_recipient_info_encrypted_key(e,this.ctxPtr);const r=t._vsc_data_len(e),n=t._vsc_data_bytes(e);return t.HEAPU8.slice(n,n+r)}finally{t._free(e);}}}return r},u$1=(t,e)=>{class r{constructor(e){this.name="KeyRecipientInfoList",this.ctxPtr=void 0===e?t._vscf_key_recipient_info_list_new():e;}static newAndUseCContext(e){return new r(t._vscf_key_recipient_info_list_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_key_recipient_info_list_delete(this.ctxPtr),this.ctxPtr=null);}hasItem(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_key_recipient_info_list_has_item(this.ctxPtr)}item(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_key_recipient_info_list_item(this.ctxPtr),e.KeyRecipientInfo.newAndUseCContext(r)}hasNext(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_key_recipient_info_list_has_next(this.ctxPtr)}next(){let e;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),e=t._vscf_key_recipient_info_list_next(this.ctxPtr),r.newAndTakeCContext(e)}hasPrev(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_key_recipient_info_list_has_prev(this.ctxPtr)}prev(){let e;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),e=t._vscf_key_recipient_info_list_prev(this.ctxPtr),r.newAndTakeCContext(e)}clear(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_key_recipient_info_list_clear(this.ctxPtr);}}return r},o$1=(t,e)=>{class r{constructor(e){this.name="PasswordRecipientInfo",this.ctxPtr=void 0===e?t._vscf_password_recipient_info_new():e;}static newAndUseCContext(e){return new r(t._vscf_password_recipient_info_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_password_recipient_info_delete(this.ctxPtr),this.ctxPtr=null);}static newWithMembers(n,_){a$1.ensureImplementInterface("keyEncryptionAlgorithm",n,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),a$1.ensureByteArray("encryptedKey",_);const s=_.length*_.BYTES_PER_ELEMENT,c=t._malloc(s);let i;t.HEAP8.set(_,c),_=t._vsc_data_ctx_size(),_=t._malloc(_),t._vsc_data(_,c,s);try{return i=t._vscf_password_recipient_info_new_with_members(n.ctxPtr,_),r.newAndTakeCContext(i)}finally{t._free(c),t._free(_);}}keyEncryptionAlgorithm(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_password_recipient_info_key_encryption_algorithm(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}encryptedKey(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var e=t._vsc_data_ctx_size();e=t._malloc(e);try{t._vscf_password_recipient_info_encrypted_key(e,this.ctxPtr);const r=t._vsc_data_len(e),n=t._vsc_data_bytes(e);return t.HEAPU8.slice(n,n+r)}finally{t._free(e);}}}return r},f$1=(t,e)=>{class r{constructor(e){this.name="PasswordRecipientInfoList",this.ctxPtr=void 0===e?t._vscf_password_recipient_info_list_new():e;}static newAndUseCContext(e){return new r(t._vscf_password_recipient_info_list_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_password_recipient_info_list_delete(this.ctxPtr),this.ctxPtr=null);}hasItem(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_password_recipient_info_list_has_item(this.ctxPtr)}item(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_password_recipient_info_list_item(this.ctxPtr),e.PasswordRecipientInfo.newAndUseCContext(r)}hasNext(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_password_recipient_info_list_has_next(this.ctxPtr)}next(){let e;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),e=t._vscf_password_recipient_info_list_next(this.ctxPtr),r.newAndTakeCContext(e)}hasPrev(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_password_recipient_info_list_has_prev(this.ctxPtr)}prev(){let e;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),e=t._vscf_password_recipient_info_list_prev(this.ctxPtr),r.newAndTakeCContext(e)}clear(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_password_recipient_info_list_clear(this.ctxPtr);}}return r},p$1=(t,e)=>{class r{constructor(e){this.name="Ecies",this.ctxPtr=void 0===e?t._vscf_ecies_new():e;}static newAndUseCContext(e){return new r(t._vscf_ecies_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_ecies_delete(this.ctxPtr),this.ctxPtr=null);}set random(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("random",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_ecies_release_random(this.ctxPtr),t._vscf_ecies_use_random(this.ctxPtr,r.ctxPtr);}set cipher(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("cipher",r,"Foundation.Cipher",e.FoundationInterfaceTag.CIPHER,e.FoundationInterface),t._vscf_ecies_release_cipher(this.ctxPtr),t._vscf_ecies_use_cipher(this.ctxPtr,r.ctxPtr);}set mac(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("mac",r,"Foundation.Mac",e.FoundationInterfaceTag.MAC,e.FoundationInterface),t._vscf_ecies_release_mac(this.ctxPtr),t._vscf_ecies_use_mac(this.ctxPtr,r.ctxPtr);}set kdf(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("kdf",r,"Foundation.Kdf",e.FoundationInterfaceTag.KDF,e.FoundationInterface),t._vscf_ecies_release_kdf(this.ctxPtr),t._vscf_ecies_use_kdf(this.ctxPtr,r.ctxPtr);}set ephemeralKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("ephemeralKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),t._vscf_ecies_release_ephemeral_key(this.ctxPtr),t._vscf_ecies_use_ephemeral_key(this.ctxPtr,r.ctxPtr);}setKeyAlg(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("keyAlg",r,"Foundation.KeyAlg",e.FoundationInterfaceTag.KEY_ALG,e.FoundationInterface),t._vscf_ecies_set_key_alg(this.ctxPtr,r.ctxPtr);}releaseKeyAlg(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecies_release_key_alg(this.ctxPtr);}setupDefaults(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_ecies_setup_defaults(this.ctxPtr);e.FoundationError.handleStatusCode(r);}setupDefaultsNoRandom(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecies_setup_defaults_no_random(this.ctxPtr);}encryptedLen(r,n){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$1.ensureNumber("dataLen",n),t._vscf_ecies_encrypted_len(this.ctxPtr,r.ctxPtr,n)}encrypt(r,n){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$1.ensureByteArray("data",n);const _=n.length*n.BYTES_PER_ELEMENT,s=t._malloc(_);t.HEAP8.set(n,s);var c=t._vsc_data_ctx_size();c=t._malloc(c),t._vsc_data(c,s,_),n=this.encryptedLen(r,n.length),n=t._vsc_buffer_new_with_capacity(n);try{const _=t._vscf_ecies_encrypt(this.ctxPtr,r.ctxPtr,c,n);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(n),a=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+a)}finally{t._free(s),t._free(c),t._vsc_buffer_delete(n);}}decryptedLen(r,n){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$1.ensureNumber("dataLen",n),t._vscf_ecies_decrypted_len(this.ctxPtr,r.ctxPtr,n)}decrypt(r,n){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$1.ensureByteArray("data",n);const _=n.length*n.BYTES_PER_ELEMENT,s=t._malloc(_);t.HEAP8.set(n,s);var c=t._vsc_data_ctx_size();c=t._malloc(c),t._vsc_data(c,s,_),n=this.decryptedLen(r,n.length),n=t._vsc_buffer_new_with_capacity(n);try{const _=t._vscf_ecies_decrypt(this.ctxPtr,r.ctxPtr,c,n);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(n),a=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+a)}finally{t._free(s),t._free(c),t._vsc_buffer_delete(n);}}}return r},d=(t,e)=>{class r{constructor(e){this.name="RecipientCipher",this.ctxPtr=void 0===e?t._vscf_recipient_cipher_new():e;}static newAndUseCContext(e){return new r(t._vscf_recipient_cipher_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_recipient_cipher_delete(this.ctxPtr),this.ctxPtr=null);}set random(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("random",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_recipient_cipher_release_random(this.ctxPtr),t._vscf_recipient_cipher_use_random(this.ctxPtr,r.ctxPtr);}set encryptionCipher(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("encryptionCipher",r,"Foundation.Cipher",e.FoundationInterfaceTag.CIPHER,e.FoundationInterface),t._vscf_recipient_cipher_release_encryption_cipher(this.ctxPtr),t._vscf_recipient_cipher_use_encryption_cipher(this.ctxPtr,r.ctxPtr);}set signerHash(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("signerHash",r,"Foundation.Hash",e.FoundationInterfaceTag.HASH,e.FoundationInterface),t._vscf_recipient_cipher_release_signer_hash(this.ctxPtr),t._vscf_recipient_cipher_use_signer_hash(this.ctxPtr,r.ctxPtr);}hasKeyRecipient(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("recipientId",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);let _;t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{return !!(_=t._vscf_recipient_cipher_has_key_recipient(this.ctxPtr,e))}finally{t._free(n),t._free(e);}}addKeyRecipient(r,n){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("recipientId",r),a$1.ensureImplementInterface("publicKey",n,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface);const _=r.length*r.BYTES_PER_ELEMENT,s=t._malloc(_);t.HEAP8.set(r,s),r=t._vsc_data_ctx_size(),r=t._malloc(r),t._vsc_data(r,s,_);try{t._vscf_recipient_cipher_add_key_recipient(this.ctxPtr,r,n.ctxPtr);}finally{t._free(s),t._free(r);}}clearRecipients(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_recipient_cipher_clear_recipients(this.ctxPtr);}addSigner(r,n){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("signerId",r),a$1.ensureImplementInterface("privateKey",n,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface);const _=r.length*r.BYTES_PER_ELEMENT,s=t._malloc(_);t.HEAP8.set(r,s),r=t._vsc_data_ctx_size(),r=t._malloc(r),t._vsc_data(r,s,_);try{const _=t._vscf_recipient_cipher_add_signer(this.ctxPtr,r,n.ctxPtr);e.FoundationError.handleStatusCode(_);}finally{t._free(s),t._free(r);}}clearSigners(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_recipient_cipher_clear_signers(this.ctxPtr);}customParams(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_recipient_cipher_custom_params(this.ctxPtr),e.MessageInfoCustomParams.newAndUseCContext(r)}startEncryption(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_recipient_cipher_start_encryption(this.ctxPtr);e.FoundationError.handleStatusCode(r);}startSignedEncryption(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("dataSize",r),r=t._vscf_recipient_cipher_start_signed_encryption(this.ctxPtr,r),e.FoundationError.handleStatusCode(r);}messageInfoLen(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_recipient_cipher_message_info_len(this.ctxPtr)}packMessageInfo(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var e=this.messageInfoLen();e=t._vsc_buffer_new_with_capacity(e);try{t._vscf_recipient_cipher_pack_message_info(this.ctxPtr,e);const r=t._vsc_buffer_bytes(e),n=t._vsc_buffer_len(e);return t.HEAPU8.slice(r,r+n)}finally{t._vsc_buffer_delete(e);}}encryptionOutLen(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("dataLen",e),t._vscf_recipient_cipher_encryption_out_len(this.ctxPtr,e)}processEncryption(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",r);const n=r.length*r.BYTES_PER_ELEMENT,_=t._malloc(n);t.HEAP8.set(r,_);var s=t._vsc_data_ctx_size();s=t._malloc(s),t._vsc_data(s,_,n),r=this.encryptionOutLen(r.length),r=t._vsc_buffer_new_with_capacity(r);try{const n=t._vscf_recipient_cipher_process_encryption(this.ctxPtr,s,r);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(r),c=t._vsc_buffer_len(r);return t.HEAPU8.slice(_,_+c)}finally{t._free(_),t._free(s),t._vsc_buffer_delete(r);}}finishEncryption(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var r=this.encryptionOutLen(0);r=t._vsc_buffer_new_with_capacity(r);try{const n=t._vscf_recipient_cipher_finish_encryption(this.ctxPtr,r);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(r),s=t._vsc_buffer_len(r);return t.HEAPU8.slice(_,_+s)}finally{t._vsc_buffer_delete(r);}}startDecryptionWithKey(r,n,_){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("recipientId",r),a$1.ensureImplementInterface("privateKey",n,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$1.ensureByteArray("messageInfo",_);var s=r.length*r.BYTES_PER_ELEMENT;const c=t._malloc(s);t.HEAP8.set(r,c),r=t._vsc_data_ctx_size(),r=t._malloc(r),t._vsc_data(r,c,s),s=_.length*_.BYTES_PER_ELEMENT;const i=t._malloc(s);t.HEAP8.set(_,i),_=t._vsc_data_ctx_size(),_=t._malloc(_),t._vsc_data(_,i,s);try{const s=t._vscf_recipient_cipher_start_decryption_with_key(this.ctxPtr,r,n.ctxPtr,_);e.FoundationError.handleStatusCode(s);}finally{t._free(c),t._free(r),t._free(i),t._free(_);}}startVerifiedDecryptionWithKey(r,n,_,s){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("recipientId",r),a$1.ensureImplementInterface("privateKey",n,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$1.ensureByteArray("messageInfo",_),a$1.ensureByteArray("messageInfoFooter",s);var c=r.length*r.BYTES_PER_ELEMENT;const i=t._malloc(c);t.HEAP8.set(r,i),r=t._vsc_data_ctx_size(),r=t._malloc(r),t._vsc_data(r,i,c);var l=_.length*_.BYTES_PER_ELEMENT;c=t._malloc(l),t.HEAP8.set(_,c),_=t._vsc_data_ctx_size(),_=t._malloc(_),t._vsc_data(_,c,l),l=s.length*s.BYTES_PER_ELEMENT;const u=t._malloc(l);t.HEAP8.set(s,u),s=t._vsc_data_ctx_size(),s=t._malloc(s),t._vsc_data(s,u,l);try{const c=t._vscf_recipient_cipher_start_verified_decryption_with_key(this.ctxPtr,r,n.ctxPtr,_,s);e.FoundationError.handleStatusCode(c);}finally{t._free(i),t._free(r),t._free(c),t._free(_),t._free(u),t._free(s);}}decryptionOutLen(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("dataLen",e),t._vscf_recipient_cipher_decryption_out_len(this.ctxPtr,e)}processDecryption(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",r);const n=r.length*r.BYTES_PER_ELEMENT,_=t._malloc(n);t.HEAP8.set(r,_);var s=t._vsc_data_ctx_size();s=t._malloc(s),t._vsc_data(s,_,n),r=this.decryptionOutLen(r.length),r=t._vsc_buffer_new_with_capacity(r);try{const n=t._vscf_recipient_cipher_process_decryption(this.ctxPtr,s,r);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(r),c=t._vsc_buffer_len(r);return t.HEAPU8.slice(_,_+c)}finally{t._free(_),t._free(s),t._vsc_buffer_delete(r);}}finishDecryption(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var r=this.decryptionOutLen(0);r=t._vsc_buffer_new_with_capacity(r);try{const n=t._vscf_recipient_cipher_finish_decryption(this.ctxPtr,r);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(r),s=t._vsc_buffer_len(r);return t.HEAPU8.slice(_,_+s)}finally{t._vsc_buffer_delete(r);}}isDataSigned(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_recipient_cipher_is_data_signed(this.ctxPtr)}signerInfos(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_recipient_cipher_signer_infos(this.ctxPtr),e.SignerInfoList.newAndUseCContext(r)}verifySignerInfo(r,n){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("signerInfo",r,e.SignerInfo),a$1.ensureImplementInterface("publicKey",n,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),!!t._vscf_recipient_cipher_verify_signer_info(this.ctxPtr,r.ctxPtr,n.ctxPtr)}messageInfoFooterLen(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_recipient_cipher_message_info_footer_len(this.ctxPtr)}packMessageInfoFooter(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var r=this.messageInfoFooterLen();r=t._vsc_buffer_new_with_capacity(r);try{const n=t._vscf_recipient_cipher_pack_message_info_footer(this.ctxPtr,r);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(r),s=t._vsc_buffer_len(r);return t.HEAPU8.slice(_,_+s)}finally{t._vsc_buffer_delete(r);}}}return r},h=(t,e)=>{class r{constructor(e){this.name="MessageInfoCustomParams",this.ctxPtr=void 0===e?t._vscf_message_info_custom_params_new():e;}static newAndUseCContext(e){return new r(t._vscf_message_info_custom_params_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_message_info_custom_params_delete(this.ctxPtr),this.ctxPtr=null);}addInt(e,r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("key",e),a$1.ensureNumber("value",r);const n=e.length*e.BYTES_PER_ELEMENT,_=t._malloc(n);t.HEAP8.set(e,_),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,_,n);try{t._vscf_message_info_custom_params_add_int(this.ctxPtr,e,r);}finally{t._free(_),t._free(e);}}addString(e,r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("key",e),a$1.ensureByteArray("value",r);var n=e.length*e.BYTES_PER_ELEMENT;const _=t._malloc(n);t.HEAP8.set(e,_),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,_,n),n=r.length*r.BYTES_PER_ELEMENT;const s=t._malloc(n);t.HEAP8.set(r,s),r=t._vsc_data_ctx_size(),r=t._malloc(r),t._vsc_data(r,s,n);try{t._vscf_message_info_custom_params_add_string(this.ctxPtr,e,r);}finally{t._free(_),t._free(e),t._free(s),t._free(r);}}addData(e,r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("key",e),a$1.ensureByteArray("value",r);var n=e.length*e.BYTES_PER_ELEMENT;const _=t._malloc(n);t.HEAP8.set(e,_),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,_,n),n=r.length*r.BYTES_PER_ELEMENT;const s=t._malloc(n);t.HEAP8.set(r,s),r=t._vsc_data_ctx_size(),r=t._malloc(r),t._vsc_data(r,s,n);try{t._vscf_message_info_custom_params_add_data(this.ctxPtr,e,r);}finally{t._free(_),t._free(e),t._free(s),t._free(r);}}clear(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_message_info_custom_params_clear(this.ctxPtr);}findInt(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("key",r);var n=r.length*r.BYTES_PER_ELEMENT;const _=t._malloc(n);let s;t.HEAP8.set(r,_),r=t._vsc_data_ctx_size(),r=t._malloc(r),t._vsc_data(r,_,n),n=t._vscf_error_ctx_size(),n=t._malloc(n),t._vscf_error_reset(n);try{s=t._vscf_message_info_custom_params_find_int(this.ctxPtr,r,n);const _=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(_),s}finally{t._free(_),t._free(r),t._free(n);}}findString(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("key",r);var n=r.length*r.BYTES_PER_ELEMENT;const _=t._malloc(n);t.HEAP8.set(r,_),r=t._vsc_data_ctx_size(),r=t._malloc(r),t._vsc_data(r,_,n),n=t._vscf_error_ctx_size(),n=t._malloc(n),t._vscf_error_reset(n);var s=t._vsc_data_ctx_size();s=t._malloc(s);try{t._vscf_message_info_custom_params_find_string(s,this.ctxPtr,r,n);const _=t._vscf_error_status(n);e.FoundationError.handleStatusCode(_);const c=t._vsc_data_len(s),a=t._vsc_data_bytes(s);return t.HEAPU8.slice(a,a+c)}finally{t._free(_),t._free(r),t._free(n),t._free(s);}}findData(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("key",r);var n=r.length*r.BYTES_PER_ELEMENT;const _=t._malloc(n);t.HEAP8.set(r,_),r=t._vsc_data_ctx_size(),r=t._malloc(r),t._vsc_data(r,_,n),n=t._vscf_error_ctx_size(),n=t._malloc(n),t._vscf_error_reset(n);var s=t._vsc_data_ctx_size();s=t._malloc(s);try{t._vscf_message_info_custom_params_find_data(s,this.ctxPtr,r,n);const _=t._vscf_error_status(n);e.FoundationError.handleStatusCode(_);const c=t._vsc_data_len(s),a=t._vsc_data_bytes(s);return t.HEAPU8.slice(a,a+c)}finally{t._free(_),t._free(r),t._free(n),t._free(s);}}hasParams(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_message_info_custom_params_has_params(this.ctxPtr)}}return r},v$2=(t,e)=>{class r{constructor(e){this.name="KeyProvider",this.ctxPtr=void 0===e?t._vscf_key_provider_new():e;}static newAndUseCContext(e){return new r(t._vscf_key_provider_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_key_provider_delete(this.ctxPtr),this.ctxPtr=null);}set random(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("random",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_key_provider_release_random(this.ctxPtr),t._vscf_key_provider_use_random(this.ctxPtr,r.ctxPtr);}set ecies(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("ecies",r,e.Ecies),t._vscf_key_provider_release_ecies(this.ctxPtr),t._vscf_key_provider_use_ecies(this.ctxPtr,r.ctxPtr);}setupDefaults(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_key_provider_setup_defaults(this.ctxPtr);e.FoundationError.handleStatusCode(r);}setRsaParams(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("bitlen",e),t._vscf_key_provider_set_rsa_params(this.ctxPtr,e);}generatePrivateKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("algId",r);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_key_provider_generate_private_key(this.ctxPtr,r,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(n);}}importPrivateKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("keyData",r);var n=r.length*r.BYTES_PER_ELEMENT;const _=t._malloc(n);let s;t.HEAP8.set(r,_),r=t._vsc_data_ctx_size(),r=t._malloc(r),t._vsc_data(r,_,n),n=t._vscf_error_ctx_size(),n=t._malloc(n),t._vscf_error_reset(n);try{s=t._vscf_key_provider_import_private_key(this.ctxPtr,r,n);const _=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(_),e.FoundationInterface.newAndTakeCContext(s)}finally{t._free(_),t._free(r),t._free(n);}}importPublicKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("keyData",r);var n=r.length*r.BYTES_PER_ELEMENT;const _=t._malloc(n);let s;t.HEAP8.set(r,_),r=t._vsc_data_ctx_size(),r=t._malloc(r),t._vsc_data(r,_,n),n=t._vscf_error_ctx_size(),n=t._malloc(n),t._vscf_error_reset(n);try{s=t._vscf_key_provider_import_public_key(this.ctxPtr,r,n);const _=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(_),e.FoundationInterface.newAndTakeCContext(s)}finally{t._free(_),t._free(r),t._free(n);}}exportedPublicKeyLen(r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),t._vscf_key_provider_exported_public_key_len(this.ctxPtr,r.ctxPtr)}exportPublicKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface);var n=this.exportedPublicKeyLen(r);n=t._vsc_buffer_new_with_capacity(n);try{const _=t._vscf_key_provider_export_public_key(this.ctxPtr,r.ctxPtr,n);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(n),c=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+c)}finally{t._vsc_buffer_delete(n);}}exportedPrivateKeyLen(r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),t._vscf_key_provider_exported_private_key_len(this.ctxPtr,r.ctxPtr)}exportPrivateKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface);var n=this.exportedPrivateKeyLen(r);n=t._vsc_buffer_new_with_capacity(n);try{const _=t._vscf_key_provider_export_private_key(this.ctxPtr,r.ctxPtr,n);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(n),c=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+c)}finally{t._vsc_buffer_delete(n);}}}return r},y$1=(t,e)=>{class r{constructor(e){this.name="Signer",this.ctxPtr=void 0===e?t._vscf_signer_new():e;}static newAndUseCContext(e){return new r(t._vscf_signer_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_signer_delete(this.ctxPtr),this.ctxPtr=null);}set hash(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("hash",r,"Foundation.Hash",e.FoundationInterfaceTag.HASH,e.FoundationInterface),t._vscf_signer_release_hash(this.ctxPtr),t._vscf_signer_use_hash(this.ctxPtr,r.ctxPtr);}set random(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("random",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_signer_release_random(this.ctxPtr),t._vscf_signer_use_random(this.ctxPtr,r.ctxPtr);}reset(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_signer_reset(this.ctxPtr);}appendData(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{t._vscf_signer_append_data(this.ctxPtr,e);}finally{t._free(n),t._free(e);}}signatureLen(r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),t._vscf_signer_signature_len(this.ctxPtr,r.ctxPtr)}sign(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface);var n=this.signatureLen(r);n=t._vsc_buffer_new_with_capacity(n);try{const _=t._vscf_signer_sign(this.ctxPtr,r.ctxPtr,n);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(n),c=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+c)}finally{t._vsc_buffer_delete(n);}}}return r},P=(t,e)=>{class r{constructor(e){this.name="Verifier",this.ctxPtr=void 0===e?t._vscf_verifier_new():e;}static newAndUseCContext(e){return new r(t._vscf_verifier_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_verifier_delete(this.ctxPtr),this.ctxPtr=null);}reset(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("signature",r);const n=r.length*r.BYTES_PER_ELEMENT,_=t._malloc(n);t.HEAP8.set(r,_),r=t._vsc_data_ctx_size(),r=t._malloc(r),t._vsc_data(r,_,n);try{const n=t._vscf_verifier_reset(this.ctxPtr,r);e.FoundationError.handleStatusCode(n);}finally{t._free(_),t._free(r);}}appendData(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{t._vscf_verifier_append_data(this.ctxPtr,e);}finally{t._free(n),t._free(e);}}verify(r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),!!t._vscf_verifier_verify(this.ctxPtr,r.ctxPtr)}}return r},x$1=(t,e)=>{class r{static get POINT_LEN(){return 65}get POINT_LEN(){return r.POINT_LEN}static get MPI_LEN(){return 32}get MPI_LEN(){return r.MPI_LEN}static get SEED_LEN(){return 32}get SEED_LEN(){return r.SEED_LEN}static get MAX_PASSWORD_LEN(){return 128}get MAX_PASSWORD_LEN(){return r.MAX_PASSWORD_LEN}static get MAX_KEY_NAME_LEN(){return 128}get MAX_KEY_NAME_LEN(){return r.MAX_KEY_NAME_LEN}constructor(e){this.name="BrainkeyClient",this.ctxPtr=void 0===e?t._vscf_brainkey_client_new():e;}static newAndUseCContext(e){return new r(t._vscf_brainkey_client_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_brainkey_client_delete(this.ctxPtr),this.ctxPtr=null);}set random(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("random",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_brainkey_client_release_random(this.ctxPtr),t._vscf_brainkey_client_use_random(this.ctxPtr,r.ctxPtr);}set operationRandom(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("operationRandom",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_brainkey_client_release_operation_random(this.ctxPtr),t._vscf_brainkey_client_use_operation_random(this.ctxPtr,r.ctxPtr);}setupDefaults(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_brainkey_client_setup_defaults(this.ctxPtr);e.FoundationError.handleStatusCode(r);}blind(n){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("password",n);var _=n.length*n.BYTES_PER_ELEMENT;const s=t._malloc(_);t.HEAP8.set(n,s),n=t._vsc_data_ctx_size(),n=t._malloc(n),t._vsc_data(n,s,_),_=t._vsc_buffer_new_with_capacity(r.MPI_LEN);const c=t._vsc_buffer_new_with_capacity(r.POINT_LEN);try{const r=t._vscf_brainkey_client_blind(this.ctxPtr,n,_,c);e.FoundationError.handleStatusCode(r);const s=t._vsc_buffer_bytes(_),a=t._vsc_buffer_len(_),i=t.HEAPU8.slice(s,s+a),l=t._vsc_buffer_bytes(c),u=t._vsc_buffer_len(c);return {deblindFactor:i,blindedPoint:t.HEAPU8.slice(l,l+u)}}finally{t._free(r),t._free(n),t._vsc_buffer_delete(_),t._vsc_buffer_delete(c);}}deblind(n,_,s,c){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("password",n),a$1.ensureByteArray("hardenedPoint",_),a$1.ensureByteArray("deblindFactor",s),a$1.ensureByteArray("keyName",c);var i=n.length*n.BYTES_PER_ELEMENT;const l=t._malloc(i);t.HEAP8.set(n,l),n=t._vsc_data_ctx_size(),n=t._malloc(n),t._vsc_data(n,l,i);var u=_.length*_.BYTES_PER_ELEMENT;i=t._malloc(u),t.HEAP8.set(_,i),_=t._vsc_data_ctx_size(),_=t._malloc(_),t._vsc_data(_,i,u);var o=s.length*s.BYTES_PER_ELEMENT;u=t._malloc(o),t.HEAP8.set(s,u),s=t._vsc_data_ctx_size(),s=t._malloc(s),t._vsc_data(s,u,o);var f=c.length*c.BYTES_PER_ELEMENT;o=t._malloc(f),t.HEAP8.set(c,o),c=t._vsc_data_ctx_size(),c=t._malloc(c),t._vsc_data(c,o,f),f=t._vsc_buffer_new_with_capacity(r.POINT_LEN);try{const r=t._vscf_brainkey_client_deblind(this.ctxPtr,n,_,s,c,f);e.FoundationError.handleStatusCode(r);const a=t._vsc_buffer_bytes(f),i=t._vsc_buffer_len(f);return t.HEAPU8.slice(a,a+i)}finally{t._free(i),t._free(n),t._free(a$1),t._free(_),t._free(u),t._free(s),t._free(o),t._free(c),t._vsc_buffer_delete(f);}}}return r},m$1=(t,e)=>{class r{static get POINT_LEN(){return 65}get POINT_LEN(){return r.POINT_LEN}static get MPI_LEN(){return 32}get MPI_LEN(){return r.MPI_LEN}constructor(e){this.name="BrainkeyServer",this.ctxPtr=void 0===e?t._vscf_brainkey_server_new():e;}static newAndUseCContext(e){return new r(t._vscf_brainkey_server_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_brainkey_server_delete(this.ctxPtr),this.ctxPtr=null);}set random(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("random",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_brainkey_server_release_random(this.ctxPtr),t._vscf_brainkey_server_use_random(this.ctxPtr,r.ctxPtr);}set operationRandom(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("operationRandom",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_brainkey_server_release_operation_random(this.ctxPtr),t._vscf_brainkey_server_use_operation_random(this.ctxPtr,r.ctxPtr);}setupDefaults(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_brainkey_server_setup_defaults(this.ctxPtr);e.FoundationError.handleStatusCode(r);}generateIdentitySecret(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);const n=t._vsc_buffer_new_with_capacity(r.MPI_LEN);try{const r=t._vscf_brainkey_server_generate_identity_secret(this.ctxPtr,n);e.FoundationError.handleStatusCode(r);const _=t._vsc_buffer_bytes(n),s=t._vsc_buffer_len(n);return t.HEAPU8.slice(_,_+s)}finally{t._vsc_buffer_delete(n);}}harden(n,_){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("identitySecret",n),a$1.ensureByteArray("blindedPoint",_);var s=n.length*n.BYTES_PER_ELEMENT;const c=t._malloc(s);t.HEAP8.set(n,c),n=t._vsc_data_ctx_size(),n=t._malloc(n),t._vsc_data(n,c,s);var i=_.length*_.BYTES_PER_ELEMENT;s=t._malloc(i),t.HEAP8.set(_,s),_=t._vsc_data_ctx_size(),_=t._malloc(_),t._vsc_data(_,s,i),i=t._vsc_buffer_new_with_capacity(r.POINT_LEN);try{const r=t._vscf_brainkey_server_harden(this.ctxPtr,n,_,i);e.FoundationError.handleStatusCode(r);const s=t._vsc_buffer_bytes(i),c=t._vsc_buffer_len(i);return t.HEAPU8.slice(s,s+c)}finally{t._free(s),t._free(n),t._free(r),t._free(_),t._vsc_buffer_delete(i);}}}return r},g$1=(t,e)=>{class r{static get MAX_MESSAGE_LEN(){return 30188}get MAX_MESSAGE_LEN(){return r.MAX_MESSAGE_LEN}static get MESSAGE_VERSION(){return 1}get MESSAGE_VERSION(){return r.MESSAGE_VERSION}constructor(e){this.name="GroupSessionMessage",this.ctxPtr=void 0===e?t._vscf_group_session_message_new():e;}static newAndUseCContext(e){return new r(t._vscf_group_session_message_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_group_session_message_delete(this.ctxPtr),this.ctxPtr=null);}getType(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_group_session_message_get_type(this.ctxPtr)}getSessionId(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var e=t._vsc_data_ctx_size();e=t._malloc(e);try{t._vscf_group_session_message_get_session_id(e,this.ctxPtr);const r=t._vsc_data_len(e),n=t._vsc_data_bytes(e);return t.HEAPU8.slice(n,n+r)}finally{t._free(e);}}getEpoch(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_group_session_message_get_epoch(this.ctxPtr)}serializeLen(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_group_session_message_serialize_len(this.ctxPtr)}serialize(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var e=this.serializeLen();e=t._vsc_buffer_new_with_capacity(e);try{t._vscf_group_session_message_serialize(this.ctxPtr,e);const r=t._vsc_buffer_bytes(e),n=t._vsc_buffer_len(e);return t.HEAPU8.slice(r,r+n)}finally{t._vsc_buffer_delete(e);}}static deserialize(n){a$1.ensureByteArray("input",n);var _=n.length*n.BYTES_PER_ELEMENT;const s=t._malloc(_);let c;t.HEAP8.set(n,s),n=t._vsc_data_ctx_size(),n=t._malloc(n),t._vsc_data(n,s,_),_=t._vscf_error_ctx_size(),_=t._malloc(_),t._vscf_error_reset(_);try{c=t._vscf_group_session_message_deserialize(n,_);const s=t._vscf_error_status(_);return e.FoundationError.handleStatusCode(s),r.newAndTakeCContext(c)}finally{t._free(s),t._free(n),t._free(_);}}}return r},E=(t,e)=>{class r{constructor(e){this.name="GroupSessionTicket",this.ctxPtr=void 0===e?t._vscf_group_session_ticket_new():e;}static newAndUseCContext(e){return new r(t._vscf_group_session_ticket_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_group_session_ticket_delete(this.ctxPtr),this.ctxPtr=null);}set rng(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("rng",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_group_session_ticket_release_rng(this.ctxPtr),t._vscf_group_session_ticket_use_rng(this.ctxPtr,r.ctxPtr);}setupDefaults(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_group_session_ticket_setup_defaults(this.ctxPtr);e.FoundationError.handleStatusCode(r);}setupTicketAsNew(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("sessionId",r);const n=r.length*r.BYTES_PER_ELEMENT,_=t._malloc(n);t.HEAP8.set(r,_),r=t._vsc_data_ctx_size(),r=t._malloc(r),t._vsc_data(r,_,n);try{const n=t._vscf_group_session_ticket_setup_ticket_as_new(this.ctxPtr,r);e.FoundationError.handleStatusCode(n);}finally{t._free(_),t._free(r);}}getTicketMessage(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_group_session_ticket_get_ticket_message(this.ctxPtr),e.GroupSessionMessage.newAndUseCContext(r)}}return r},N=(t,e)=>{class r{static get SENDER_ID_LEN(){return 32}get SENDER_ID_LEN(){return r.SENDER_ID_LEN}static get MAX_PLAIN_TEXT_LEN(){return 3e4}get MAX_PLAIN_TEXT_LEN(){return r.MAX_PLAIN_TEXT_LEN}static get MAX_EPOCHS_COUNT(){return 50}get MAX_EPOCHS_COUNT(){return r.MAX_EPOCHS_COUNT}static get SALT_SIZE(){return 32}get SALT_SIZE(){return r.SALT_SIZE}constructor(e){this.name="GroupSession",this.ctxPtr=void 0===e?t._vscf_group_session_new():e;}static newAndUseCContext(e){return new r(t._vscf_group_session_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_group_session_delete(this.ctxPtr),this.ctxPtr=null);}set rng(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("rng",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_group_session_release_rng(this.ctxPtr),t._vscf_group_session_use_rng(this.ctxPtr,r.ctxPtr);}getCurrentEpoch(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_group_session_get_current_epoch(this.ctxPtr)}setupDefaults(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_group_session_setup_defaults(this.ctxPtr);e.FoundationError.handleStatusCode(r);}getSessionId(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var e=t._vsc_data_ctx_size();e=t._malloc(e);try{t._vscf_group_session_get_session_id(e,this.ctxPtr);const r=t._vsc_data_len(e),n=t._vsc_data_bytes(e);return t.HEAPU8.slice(n,n+r)}finally{t._free(e);}}addEpoch(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("message",r,e.GroupSessionMessage),r=t._vscf_group_session_add_epoch(this.ctxPtr,r.ctxPtr),e.FoundationError.handleStatusCode(r);}encrypt(r,n){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("plainText",r),a$1.ensureImplementInterface("privateKey",n,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface);var _=r.length*r.BYTES_PER_ELEMENT;const s=t._malloc(_);let c;t.HEAP8.set(r,s),r=t._vsc_data_ctx_size(),r=t._malloc(r),t._vsc_data(r,s,_),_=t._vscf_error_ctx_size(),_=t._malloc(_),t._vscf_error_reset(_);try{c=t._vscf_group_session_encrypt(this.ctxPtr,r,n.ctxPtr,_);const s=t._vscf_error_status(_);return e.FoundationError.handleStatusCode(s),e.GroupSessionMessage.newAndTakeCContext(c)}finally{t._free(s),t._free(r),t._free(_);}}decryptLen(r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("message",r,e.GroupSessionMessage),t._vscf_group_session_decrypt_len(this.ctxPtr,r.ctxPtr)}decrypt(r,n){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("message",r,e.GroupSessionMessage),a$1.ensureImplementInterface("publicKey",n,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface);var _=this.decryptLen(r);_=t._vsc_buffer_new_with_capacity(_);try{const s=t._vscf_group_session_decrypt(this.ctxPtr,r.ctxPtr,n.ctxPtr,_);e.FoundationError.handleStatusCode(s);const c=t._vsc_buffer_bytes(_),a=t._vsc_buffer_len(_);return t.HEAPU8.slice(c,c+a)}finally{t._vsc_buffer_delete(_);}}createGroupTicket(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var r=t._vscf_error_ctx_size();let n;r=t._malloc(r),t._vscf_error_reset(r);try{n=t._vscf_group_session_create_group_ticket(this.ctxPtr,r);const _=t._vscf_error_status(r);return e.FoundationError.handleStatusCode(_),e.GroupSessionTicket.newAndTakeCContext(n)}finally{t._free(r);}}}return r},w=(t,e)=>{class r{constructor(e){this.name="MessageInfoEditor",this.ctxPtr=void 0===e?t._vscf_message_info_editor_new():e;}static newAndUseCContext(e){return new r(t._vscf_message_info_editor_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_message_info_editor_delete(this.ctxPtr),this.ctxPtr=null);}set random(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("random",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_message_info_editor_release_random(this.ctxPtr),t._vscf_message_info_editor_use_random(this.ctxPtr,r.ctxPtr);}setupDefaults(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_message_info_editor_setup_defaults(this.ctxPtr);e.FoundationError.handleStatusCode(r);}unpack(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("messageInfoData",r);const n=r.length*r.BYTES_PER_ELEMENT,_=t._malloc(n);t.HEAP8.set(r,_),r=t._vsc_data_ctx_size(),r=t._malloc(r),t._vsc_data(r,_,n);try{const n=t._vscf_message_info_editor_unpack(this.ctxPtr,r);e.FoundationError.handleStatusCode(n);}finally{t._free(_),t._free(r);}}unlock(r,n){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("ownerRecipientId",r),a$1.ensureImplementInterface("ownerPrivateKey",n,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface);const _=r.length*r.BYTES_PER_ELEMENT,s=t._malloc(_);t.HEAP8.set(r,s),r=t._vsc_data_ctx_size(),r=t._malloc(r),t._vsc_data(r,s,_);try{const _=t._vscf_message_info_editor_unlock(this.ctxPtr,r,n.ctxPtr);e.FoundationError.handleStatusCode(_);}finally{t._free(s),t._free(r);}}addKeyRecipient(r,n){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("recipientId",r),a$1.ensureImplementInterface("publicKey",n,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface);const _=r.length*r.BYTES_PER_ELEMENT,s=t._malloc(_);t.HEAP8.set(r,s),r=t._vsc_data_ctx_size(),r=t._malloc(r),t._vsc_data(r,s,_);try{const _=t._vscf_message_info_editor_add_key_recipient(this.ctxPtr,r,n.ctxPtr);e.FoundationError.handleStatusCode(_);}finally{t._free(s),t._free(r);}}removeKeyRecipient(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("recipientId",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);let _;t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{return !!(_=t._vscf_message_info_editor_remove_key_recipient(this.ctxPtr,e))}finally{t._free(n),t._free(e);}}removeAll(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_message_info_editor_remove_all(this.ctxPtr);}packedLen(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_message_info_editor_packed_len(this.ctxPtr)}pack(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var e=this.packedLen();e=t._vsc_buffer_new_with_capacity(e);try{t._vscf_message_info_editor_pack(this.ctxPtr,e);const r=t._vsc_buffer_bytes(e),n=t._vsc_buffer_len(e);return t.HEAPU8.slice(r,r+n)}finally{t._vsc_buffer_delete(e);}}}return r},I=(t,e)=>{class r{constructor(e){this.name="SignerInfo",this.ctxPtr=void 0===e?t._vscf_signer_info_new():e;}static newAndUseCContext(e){return new r(t._vscf_signer_info_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_signer_info_delete(this.ctxPtr),this.ctxPtr=null);}signerId(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var e=t._vsc_data_ctx_size();e=t._malloc(e);try{t._vscf_signer_info_signer_id(e,this.ctxPtr);const r=t._vsc_data_len(e),n=t._vsc_data_bytes(e);return t.HEAPU8.slice(n,n+r)}finally{t._free(e);}}signerAlgInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_signer_info_signer_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}signature(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var e=t._vsc_data_ctx_size();e=t._malloc(e);try{t._vscf_signer_info_signature(e,this.ctxPtr);const r=t._vsc_data_len(e),n=t._vsc_data_bytes(e);return t.HEAPU8.slice(n,n+r)}finally{t._free(e);}}}return r},b=(t,e)=>{class r{constructor(e){this.name="SignerInfoList",this.ctxPtr=void 0===e?t._vscf_signer_info_list_new():e;}static newAndUseCContext(e){return new r(t._vscf_signer_info_list_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_signer_info_list_delete(this.ctxPtr),this.ctxPtr=null);}hasItem(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_signer_info_list_has_item(this.ctxPtr)}item(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_signer_info_list_item(this.ctxPtr),e.SignerInfo.newAndUseCContext(r)}hasNext(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_signer_info_list_has_next(this.ctxPtr)}next(){let e;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),e=t._vscf_signer_info_list_next(this.ctxPtr),r.newAndTakeCContext(e)}hasPrev(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_signer_info_list_has_prev(this.ctxPtr)}prev(){let e;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),e=t._vscf_signer_info_list_prev(this.ctxPtr),r.newAndTakeCContext(e)}clear(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_signer_info_list_clear(this.ctxPtr);}}return r},A=(t,e)=>{class r{constructor(e){this.name="MessageInfoFooter",this.ctxPtr=void 0===e?t._vscf_message_info_footer_new():e;}static newAndUseCContext(e){return new r(t._vscf_message_info_footer_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_message_info_footer_delete(this.ctxPtr),this.ctxPtr=null);}hasSignerInfos(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_message_info_footer_has_signer_infos(this.ctxPtr)}signerInfos(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_message_info_footer_signer_infos(this.ctxPtr),e.SignerInfoList.newAndUseCContext(r)}signerHashAlgInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_message_info_footer_signer_hash_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}signerDigest(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var e=t._vsc_data_ctx_size();e=t._malloc(e);try{t._vscf_message_info_footer_signer_digest(e,this.ctxPtr);const r=t._vsc_data_len(e),n=t._vsc_data_bytes(e);return t.HEAPU8.slice(n,n+r)}finally{t._free(e);}}}return r},k$1=(t,e)=>{class r{constructor(e){this.name="SignedDataInfo",this.ctxPtr=void 0===e?t._vscf_signed_data_info_new():e;}static newAndUseCContext(e){return new r(t._vscf_signed_data_info_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_signed_data_info_delete(this.ctxPtr),this.ctxPtr=null);}setHashAlgInfo(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("hashAlgInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),t._vscf_signed_data_info_set_hash_alg_info(this.ctxPtr,r.ctxPtr);}hashAlgInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_signed_data_info_hash_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}}return r},C=(t,e)=>{class r{constructor(e){this.name="FooterInfo",this.ctxPtr=void 0===e?t._vscf_footer_info_new():e;}static newAndUseCContext(e){return new r(t._vscf_footer_info_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_footer_info_delete(this.ctxPtr),this.ctxPtr=null);}hasSignedDataInfo(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_footer_info_has_signed_data_info(this.ctxPtr)}signedDataInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_footer_info_signed_data_info(this.ctxPtr),e.SignedDataInfo.newAndUseCContext(r)}setDataSize(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("dataSize",e),t._vscf_footer_info_set_data_size(this.ctxPtr,e);}dataSize(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_footer_info_data_size(this.ctxPtr)}}return r},T=(t,e)=>{class r{static get DIGEST_LEN(){return 28}get DIGEST_LEN(){return r.DIGEST_LEN}static get BLOCK_LEN(){return 64}get BLOCK_LEN(){return r.BLOCK_LEN}constructor(e){this.name="Sha224",this.ctxPtr=void 0===e?t._vscf_sha224_new():e;}static newAndUseCContext(e){return new r(t._vscf_sha224_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_sha224_delete(this.ctxPtr),this.ctxPtr=null);}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_sha224_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_sha224_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),r=t._vscf_sha224_restore_alg_info(this.ctxPtr,r.ctxPtr),e.FoundationError.handleStatusCode(r);}hash(e){a$1.ensureByteArray("data",e);var r=e.length*e.BYTES_PER_ELEMENT;const n=t._malloc(r);t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r),r=t._vsc_buffer_new_with_capacity(this.DIGEST_LEN);try{t._vscf_sha224_hash(e,r);const n=t._vsc_buffer_bytes(r),_=t._vsc_buffer_len(r);return t.HEAPU8.slice(n,n+_)}finally{t._free(n),t._free(e),t._vsc_buffer_delete(r);}}start(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_sha224_start(this.ctxPtr);}update(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{t._vscf_sha224_update(this.ctxPtr,e);}finally{t._free(n),t._free(e);}}finish(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=t._vsc_buffer_new_with_capacity(this.DIGEST_LEN);try{t._vscf_sha224_finish(this.ctxPtr,e);const r=t._vsc_buffer_bytes(e),n=t._vsc_buffer_len(e);return t.HEAPU8.slice(r,r+n)}finally{t._vsc_buffer_delete(e);}}}return r},F=(t,e)=>{class r{static get DIGEST_LEN(){return 32}get DIGEST_LEN(){return r.DIGEST_LEN}static get BLOCK_LEN(){return 64}get BLOCK_LEN(){return r.BLOCK_LEN}constructor(e){this.name="Sha256",this.ctxPtr=void 0===e?t._vscf_sha256_new():e;}static newAndUseCContext(e){return new r(t._vscf_sha256_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_sha256_delete(this.ctxPtr),this.ctxPtr=null);}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_sha256_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_sha256_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),r=t._vscf_sha256_restore_alg_info(this.ctxPtr,r.ctxPtr),e.FoundationError.handleStatusCode(r);}hash(e){a$1.ensureByteArray("data",e);var r=e.length*e.BYTES_PER_ELEMENT;const n=t._malloc(r);t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r),r=t._vsc_buffer_new_with_capacity(this.DIGEST_LEN);try{t._vscf_sha256_hash(e,r);const n=t._vsc_buffer_bytes(r),_=t._vsc_buffer_len(r);return t.HEAPU8.slice(n,n+_)}finally{t._free(n),t._free(e),t._vsc_buffer_delete(r);}}start(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_sha256_start(this.ctxPtr);}update(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{t._vscf_sha256_update(this.ctxPtr,e);}finally{t._free(n),t._free(e);}}finish(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=t._vsc_buffer_new_with_capacity(this.DIGEST_LEN);try{t._vscf_sha256_finish(this.ctxPtr,e);const r=t._vsc_buffer_bytes(e),n=t._vsc_buffer_len(e);return t.HEAPU8.slice(r,r+n)}finally{t._vsc_buffer_delete(e);}}}return r},S=(t,e)=>{class r{static get DIGEST_LEN(){return 48}get DIGEST_LEN(){return r.DIGEST_LEN}static get BLOCK_LEN(){return 128}get BLOCK_LEN(){return r.BLOCK_LEN}constructor(e){this.name="Sha384",this.ctxPtr=void 0===e?t._vscf_sha384_new():e;}static newAndUseCContext(e){return new r(t._vscf_sha384_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_sha384_delete(this.ctxPtr),this.ctxPtr=null);}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_sha384_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_sha384_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),r=t._vscf_sha384_restore_alg_info(this.ctxPtr,r.ctxPtr),e.FoundationError.handleStatusCode(r);}hash(e){a$1.ensureByteArray("data",e);var r=e.length*e.BYTES_PER_ELEMENT;const n=t._malloc(r);t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r),r=t._vsc_buffer_new_with_capacity(this.DIGEST_LEN);try{t._vscf_sha384_hash(e,r);const n=t._vsc_buffer_bytes(r),_=t._vsc_buffer_len(r);return t.HEAPU8.slice(n,n+_)}finally{t._free(n),t._free(e),t._vsc_buffer_delete(r);}}start(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_sha384_start(this.ctxPtr);}update(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{t._vscf_sha384_update(this.ctxPtr,e);}finally{t._free(n),t._free(e);}}finish(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=t._vsc_buffer_new_with_capacity(this.DIGEST_LEN);try{t._vscf_sha384_finish(this.ctxPtr,e);const r=t._vsc_buffer_bytes(e),n=t._vsc_buffer_len(e);return t.HEAPU8.slice(r,r+n)}finally{t._vsc_buffer_delete(e);}}}return r},K$1=(t,e)=>{class r{static get DIGEST_LEN(){return 64}get DIGEST_LEN(){return r.DIGEST_LEN}static get BLOCK_LEN(){return 128}get BLOCK_LEN(){return r.BLOCK_LEN}constructor(e){this.name="Sha512",this.ctxPtr=void 0===e?t._vscf_sha512_new():e;}static newAndUseCContext(e){return new r(t._vscf_sha512_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_sha512_delete(this.ctxPtr),this.ctxPtr=null);}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_sha512_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_sha512_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),r=t._vscf_sha512_restore_alg_info(this.ctxPtr,r.ctxPtr),e.FoundationError.handleStatusCode(r);}hash(e){a$1.ensureByteArray("data",e);var r=e.length*e.BYTES_PER_ELEMENT;const n=t._malloc(r);t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r),r=t._vsc_buffer_new_with_capacity(this.DIGEST_LEN);try{t._vscf_sha512_hash(e,r);const n=t._vsc_buffer_bytes(r),_=t._vsc_buffer_len(r);return t.HEAPU8.slice(n,n+_)}finally{t._free(n),t._free(e),t._vsc_buffer_delete(r);}}start(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_sha512_start(this.ctxPtr);}update(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{t._vscf_sha512_update(this.ctxPtr,e);}finally{t._free(n),t._free(e);}}finish(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=t._vsc_buffer_new_with_capacity(this.DIGEST_LEN);try{t._vscf_sha512_finish(this.ctxPtr,e);const r=t._vsc_buffer_bytes(e),n=t._vsc_buffer_len(e);return t.HEAPU8.slice(r,r+n)}finally{t._vsc_buffer_delete(e);}}}return r},L=(t,e)=>{class r{static get NONCE_LEN(){return 12}get NONCE_LEN(){return r.NONCE_LEN}static get KEY_LEN(){return 32}get KEY_LEN(){return r.KEY_LEN}static get KEY_BITLEN(){return 256}get KEY_BITLEN(){return r.KEY_BITLEN}static get BLOCK_LEN(){return 16}get BLOCK_LEN(){return r.BLOCK_LEN}static get AUTH_TAG_LEN(){return 16}get AUTH_TAG_LEN(){return r.AUTH_TAG_LEN}constructor(e){this.name="Aes256Gcm",this.ctxPtr=void 0===e?t._vscf_aes256_gcm_new():e;}static newAndUseCContext(e){return new r(t._vscf_aes256_gcm_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_aes256_gcm_delete(this.ctxPtr),this.ctxPtr=null);}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_aes256_gcm_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_aes256_gcm_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),r=t._vscf_aes256_gcm_restore_alg_info(this.ctxPtr,r.ctxPtr),e.FoundationError.handleStatusCode(r);}encrypt(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",r);const n=r.length*r.BYTES_PER_ELEMENT,_=t._malloc(n);t.HEAP8.set(r,_);var s=t._vsc_data_ctx_size();s=t._malloc(s),t._vsc_data(s,_,n),r=this.encryptedLen(r.length),r=t._vsc_buffer_new_with_capacity(r);try{const n=t._vscf_aes256_gcm_encrypt(this.ctxPtr,s,r);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(r),c=t._vsc_buffer_len(r);return t.HEAPU8.slice(_,_+c)}finally{t._free(_),t._free(s),t._vsc_buffer_delete(r);}}encryptedLen(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("dataLen",e),t._vscf_aes256_gcm_encrypted_len(this.ctxPtr,e)}preciseEncryptedLen(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("dataLen",e),t._vscf_aes256_gcm_precise_encrypted_len(this.ctxPtr,e)}decrypt(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",r);const n=r.length*r.BYTES_PER_ELEMENT,_=t._malloc(n);t.HEAP8.set(r,_);var s=t._vsc_data_ctx_size();s=t._malloc(s),t._vsc_data(s,_,n),r=this.decryptedLen(r.length),r=t._vsc_buffer_new_with_capacity(r);try{const n=t._vscf_aes256_gcm_decrypt(this.ctxPtr,s,r);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(r),c=t._vsc_buffer_len(r);return t.HEAPU8.slice(_,_+c)}finally{t._free(_),t._free(s),t._vsc_buffer_delete(r);}}decryptedLen(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("dataLen",e),t._vscf_aes256_gcm_decrypted_len(this.ctxPtr,e)}setNonce(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("nonce",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{t._vscf_aes256_gcm_set_nonce(this.ctxPtr,e);}finally{t._free(n),t._free(e);}}setKey(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("key",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{t._vscf_aes256_gcm_set_key(this.ctxPtr,e);}finally{t._free(n),t._free(e);}}startEncryption(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_aes256_gcm_start_encryption(this.ctxPtr);}startDecryption(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_aes256_gcm_start_decryption(this.ctxPtr);}update(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);var _=t._vsc_data_ctx_size();_=t._malloc(_),t._vsc_data(_,n,r),e=this.outLen(e.length),e=t._vsc_buffer_new_with_capacity(e);try{t._vscf_aes256_gcm_update(this.ctxPtr,_,e);const r=t._vsc_buffer_bytes(e),n=t._vsc_buffer_len(e);return t.HEAPU8.slice(r,r+n)}finally{t._free(n),t._free(_),t._vsc_buffer_delete(e);}}outLen(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("dataLen",e),t._vscf_aes256_gcm_out_len(this.ctxPtr,e)}encryptedOutLen(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("dataLen",e),t._vscf_aes256_gcm_encrypted_out_len(this.ctxPtr,e)}decryptedOutLen(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("dataLen",e),t._vscf_aes256_gcm_decrypted_out_len(this.ctxPtr,e)}finish(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var r=this.outLen(0);r=t._vsc_buffer_new_with_capacity(r);try{const n=t._vscf_aes256_gcm_finish(this.ctxPtr,r);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(r),s=t._vsc_buffer_len(r);return t.HEAPU8.slice(_,_+s)}finally{t._vsc_buffer_delete(r);}}authEncrypt(r,n){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",r),a$1.ensureByteArray("authData",n);var _=r.length*r.BYTES_PER_ELEMENT;const s=t._malloc(_);t.HEAP8.set(r,s);var c=t._vsc_data_ctx_size();c=t._malloc(c),t._vsc_data(c,s,_);var i=n.length*n.BYTES_PER_ELEMENT;_=t._malloc(i),t.HEAP8.set(n,_),n=t._vsc_data_ctx_size(),n=t._malloc(n),t._vsc_data(n,_,i),r=this.authEncryptedLen(r.length),r=t._vsc_buffer_new_with_capacity(r),i=t._vsc_buffer_new_with_capacity(this.AUTH_TAG_LEN);try{const _=t._vscf_aes256_gcm_auth_encrypt(this.ctxPtr,c,n,r,i);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(r),a=t._vsc_buffer_len(r),l=t.HEAPU8.slice(s,s+a),u=t._vsc_buffer_bytes(i),o=t._vsc_buffer_len(i);return {out:l,tag:t.HEAPU8.slice(u,u+o)}}finally{t._free(s),t._free(c),t._free(_),t._free(n),t._vsc_buffer_delete(r),t._vsc_buffer_delete(i);}}authEncryptedLen(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("dataLen",e),t._vscf_aes256_gcm_auth_encrypted_len(this.ctxPtr,e)}authDecrypt(r,n,_){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",r),a$1.ensureByteArray("authData",n),a$1.ensureByteArray("tag",_);var s=r.length*r.BYTES_PER_ELEMENT;const c=t._malloc(s);t.HEAP8.set(r,c);var i=t._vsc_data_ctx_size();i=t._malloc(i),t._vsc_data(i,c,s);var l=n.length*n.BYTES_PER_ELEMENT;s=t._malloc(l),t.HEAP8.set(n,s),n=t._vsc_data_ctx_size(),n=t._malloc(n),t._vsc_data(n,s,l);const u=_.length*_.BYTES_PER_ELEMENT;l=t._malloc(u),t.HEAP8.set(_,l),_=t._vsc_data_ctx_size(),_=t._malloc(_),t._vsc_data(_,l,u),r=this.authDecryptedLen(r.length),r=t._vsc_buffer_new_with_capacity(r);try{const s=t._vscf_aes256_gcm_auth_decrypt(this.ctxPtr,i,n,_,r);e.FoundationError.handleStatusCode(s);const c=t._vsc_buffer_bytes(r),a=t._vsc_buffer_len(r);return t.HEAPU8.slice(c,c+a)}finally{t._free(c),t._free(i),t._free(s),t._free(n),t._free(l),t._free(_),t._vsc_buffer_delete(r);}}authDecryptedLen(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("dataLen",e),t._vscf_aes256_gcm_auth_decrypted_len(this.ctxPtr,e)}setAuthData(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("authData",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{t._vscf_aes256_gcm_set_auth_data(this.ctxPtr,e);}finally{t._free(n),t._free(e);}}finishAuthEncryption(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var r=this.outLen(0);r=t._vsc_buffer_new_with_capacity(r);const n=t._vsc_buffer_new_with_capacity(this.AUTH_TAG_LEN);try{const _=t._vscf_aes256_gcm_finish_auth_encryption(this.ctxPtr,r,n);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(r),c=t._vsc_buffer_len(r),a=t.HEAPU8.slice(s,s+c),i=t._vsc_buffer_bytes(n),l=t._vsc_buffer_len(n);return {out:a,tag:t.HEAPU8.slice(i,i+l)}}finally{t._vsc_buffer_delete(r),t._vsc_buffer_delete(n);}}finishAuthDecryption(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("tag",r);var n=r.length*r.BYTES_PER_ELEMENT;const _=t._malloc(n);t.HEAP8.set(r,_),r=t._vsc_data_ctx_size(),r=t._malloc(r),t._vsc_data(r,_,n),n=this.outLen(0),n=t._vsc_buffer_new_with_capacity(n);try{const _=t._vscf_aes256_gcm_finish_auth_decryption(this.ctxPtr,r,n);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(n),c=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+c)}finally{t._free(_),t._free(r),t._vsc_buffer_delete(n);}}}return r},R=(t,e)=>{class r{static get NONCE_LEN(){return 16}get NONCE_LEN(){return r.NONCE_LEN}static get KEY_LEN(){return 32}get KEY_LEN(){return r.KEY_LEN}static get KEY_BITLEN(){return 256}get KEY_BITLEN(){return r.KEY_BITLEN}static get BLOCK_LEN(){return 16}get BLOCK_LEN(){return r.BLOCK_LEN}constructor(e){this.name="Aes256Cbc",this.ctxPtr=void 0===e?t._vscf_aes256_cbc_new():e;}static newAndUseCContext(e){return new r(t._vscf_aes256_cbc_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_aes256_cbc_delete(this.ctxPtr),this.ctxPtr=null);}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_aes256_cbc_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_aes256_cbc_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),r=t._vscf_aes256_cbc_restore_alg_info(this.ctxPtr,r.ctxPtr),e.FoundationError.handleStatusCode(r);}encrypt(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",r);const n=r.length*r.BYTES_PER_ELEMENT,_=t._malloc(n);t.HEAP8.set(r,_);var s=t._vsc_data_ctx_size();s=t._malloc(s),t._vsc_data(s,_,n),r=this.encryptedLen(r.length),r=t._vsc_buffer_new_with_capacity(r);try{const n=t._vscf_aes256_cbc_encrypt(this.ctxPtr,s,r);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(r),c=t._vsc_buffer_len(r);return t.HEAPU8.slice(_,_+c)}finally{t._free(_),t._free(s),t._vsc_buffer_delete(r);}}encryptedLen(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("dataLen",e),t._vscf_aes256_cbc_encrypted_len(this.ctxPtr,e)}preciseEncryptedLen(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("dataLen",e),t._vscf_aes256_cbc_precise_encrypted_len(this.ctxPtr,e)}decrypt(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",r);const n=r.length*r.BYTES_PER_ELEMENT,_=t._malloc(n);t.HEAP8.set(r,_);var s=t._vsc_data_ctx_size();s=t._malloc(s),t._vsc_data(s,_,n),r=this.decryptedLen(r.length),r=t._vsc_buffer_new_with_capacity(r);try{const n=t._vscf_aes256_cbc_decrypt(this.ctxPtr,s,r);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(r),c=t._vsc_buffer_len(r);return t.HEAPU8.slice(_,_+c)}finally{t._free(_),t._free(s),t._vsc_buffer_delete(r);}}decryptedLen(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("dataLen",e),t._vscf_aes256_cbc_decrypted_len(this.ctxPtr,e)}setNonce(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("nonce",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{t._vscf_aes256_cbc_set_nonce(this.ctxPtr,e);}finally{t._free(n),t._free(e);}}setKey(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("key",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{t._vscf_aes256_cbc_set_key(this.ctxPtr,e);}finally{t._free(n),t._free(e);}}startEncryption(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_aes256_cbc_start_encryption(this.ctxPtr);}startDecryption(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_aes256_cbc_start_decryption(this.ctxPtr);}update(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);var _=t._vsc_data_ctx_size();_=t._malloc(_),t._vsc_data(_,n,r),e=this.outLen(e.length),e=t._vsc_buffer_new_with_capacity(e);try{t._vscf_aes256_cbc_update(this.ctxPtr,_,e);const r=t._vsc_buffer_bytes(e),n=t._vsc_buffer_len(e);return t.HEAPU8.slice(r,r+n)}finally{t._free(n),t._free(_),t._vsc_buffer_delete(e);}}outLen(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("dataLen",e),t._vscf_aes256_cbc_out_len(this.ctxPtr,e)}encryptedOutLen(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("dataLen",e),t._vscf_aes256_cbc_encrypted_out_len(this.ctxPtr,e)}decryptedOutLen(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("dataLen",e),t._vscf_aes256_cbc_decrypted_out_len(this.ctxPtr,e)}finish(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var r=this.outLen(0);r=t._vsc_buffer_new_with_capacity(r);try{const n=t._vscf_aes256_cbc_finish(this.ctxPtr,r);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(r),s=t._vsc_buffer_len(r);return t.HEAPU8.slice(_,_+s)}finally{t._vsc_buffer_delete(r);}}}return r},z=(t,e)=>{class r{constructor(e){this.name="Asn1rd",this.ctxPtr=void 0===e?t._vscf_asn1rd_new():e;}static newAndUseCContext(e){return new r(t._vscf_asn1rd_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_asn1rd_delete(this.ctxPtr),this.ctxPtr=null);}reset(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{t._vscf_asn1rd_reset(this.ctxPtr,e);}finally{t._free(n),t._free(e);}}leftLen(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_left_len(this.ctxPtr)}hasError(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_asn1rd_has_error(this.ctxPtr)}status(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_asn1rd_status(this.ctxPtr);e.FoundationError.handleStatusCode(r);}getTag(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_get_tag(this.ctxPtr)}getLen(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_get_len(this.ctxPtr)}getDataLen(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_get_data_len(this.ctxPtr)}readTag(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("tag",e),t._vscf_asn1rd_read_tag(this.ctxPtr,e)}readContextTag(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("tag",e),t._vscf_asn1rd_read_context_tag(this.ctxPtr,e)}readInt(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_int(this.ctxPtr)}readInt8(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_int8(this.ctxPtr)}readInt16(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_int16(this.ctxPtr)}readInt32(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_int32(this.ctxPtr)}readInt64(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_int64(this.ctxPtr)}readUint(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_uint(this.ctxPtr)}readUint8(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_uint8(this.ctxPtr)}readUint16(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_uint16(this.ctxPtr)}readUint32(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_uint32(this.ctxPtr)}readUint64(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_uint64(this.ctxPtr)}readBool(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_asn1rd_read_bool(this.ctxPtr)}readNull(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_null(this.ctxPtr);}readNullOptional(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_null_optional(this.ctxPtr);}readOctetStr(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var e=t._vsc_data_ctx_size();e=t._malloc(e);try{t._vscf_asn1rd_read_octet_str(e,this.ctxPtr);const r=t._vsc_data_len(e),n=t._vsc_data_bytes(e);return t.HEAPU8.slice(n,n+r)}finally{t._free(e);}}readBitstringAsOctetStr(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var e=t._vsc_data_ctx_size();e=t._malloc(e);try{t._vscf_asn1rd_read_bitstring_as_octet_str(e,this.ctxPtr);const r=t._vsc_data_len(e),n=t._vsc_data_bytes(e);return t.HEAPU8.slice(n,n+r)}finally{t._free(e);}}readUtf8Str(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var e=t._vsc_data_ctx_size();e=t._malloc(e);try{t._vscf_asn1rd_read_utf8_str(e,this.ctxPtr);const r=t._vsc_data_len(e),n=t._vsc_data_bytes(e);return t.HEAPU8.slice(n,n+r)}finally{t._free(e);}}readOid(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var e=t._vsc_data_ctx_size();e=t._malloc(e);try{t._vscf_asn1rd_read_oid(e,this.ctxPtr);const r=t._vsc_data_len(e),n=t._vsc_data_bytes(e);return t.HEAPU8.slice(n,n+r)}finally{t._free(e);}}readData(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("len",e);var r=t._vsc_data_ctx_size();r=t._malloc(r);try{t._vscf_asn1rd_read_data(r,this.ctxPtr,e);const n=t._vsc_data_len(r),_=t._vsc_data_bytes(r);return t.HEAPU8.slice(_,_+n)}finally{t._free(r);}}readSequence(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_sequence(this.ctxPtr)}readSet(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_set(this.ctxPtr)}}return r},B=(t,e)=>{class r{constructor(e){this.name="Asn1wr",this.ctxPtr=void 0===e?t._vscf_asn1wr_new():e;}static newAndUseCContext(e){return new r(t._vscf_asn1wr_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_asn1wr_delete(this.ctxPtr),this.ctxPtr=null);}reset(e,r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("out",e),a$1.ensureNumber("outLen",r),t._vscf_asn1wr_reset(this.ctxPtr,e,r);}finish(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureBoolean("doNotAdjust",e),t._vscf_asn1wr_finish(this.ctxPtr,e)}bytes(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1wr_bytes(this.ctxPtr)}len(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1wr_len(this.ctxPtr)}writtenLen(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1wr_written_len(this.ctxPtr)}unwrittenLen(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1wr_unwritten_len(this.ctxPtr)}hasError(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_asn1wr_has_error(this.ctxPtr)}status(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_asn1wr_status(this.ctxPtr);e.FoundationError.handleStatusCode(r);}reserve(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("len",e),t._vscf_asn1wr_reserve(this.ctxPtr,e)}writeTag(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("tag",e),t._vscf_asn1wr_write_tag(this.ctxPtr,e)}writeContextTag(e,r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("tag",e),a$1.ensureNumber("len",r),t._vscf_asn1wr_write_context_tag(this.ctxPtr,e,r)}writeLen(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("len",e),t._vscf_asn1wr_write_len(this.ctxPtr,e)}writeInt(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("value",e),t._vscf_asn1wr_write_int(this.ctxPtr,e)}writeInt8(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("value",e),t._vscf_asn1wr_write_int8(this.ctxPtr,e)}writeInt16(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("value",e),t._vscf_asn1wr_write_int16(this.ctxPtr,e)}writeInt32(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("value",e),t._vscf_asn1wr_write_int32(this.ctxPtr,e)}writeInt64(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("value",e),t._vscf_asn1wr_write_int64(this.ctxPtr,e)}writeUint(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("value",e),t._vscf_asn1wr_write_uint(this.ctxPtr,e)}writeUint8(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("value",e),t._vscf_asn1wr_write_uint8(this.ctxPtr,e)}writeUint16(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("value",e),t._vscf_asn1wr_write_uint16(this.ctxPtr,e)}writeUint32(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("value",e),t._vscf_asn1wr_write_uint32(this.ctxPtr,e)}writeUint64(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("value",e),t._vscf_asn1wr_write_uint64(this.ctxPtr,e)}writeBool(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureBoolean("value",e),t._vscf_asn1wr_write_bool(this.ctxPtr,e)}writeNull(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1wr_write_null(this.ctxPtr)}writeOctetStr(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("value",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);let _;t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{return _=t._vscf_asn1wr_write_octet_str(this.ctxPtr,e)}finally{t._free(n),t._free(e);}}writeOctetStrAsBitstring(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("value",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);let _;t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{return _=t._vscf_asn1wr_write_octet_str_as_bitstring(this.ctxPtr,e)}finally{t._free(n),t._free(e);}}writeData(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);let _;t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{return _=t._vscf_asn1wr_write_data(this.ctxPtr,e)}finally{t._free(n),t._free(e);}}writeUtf8Str(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("value",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);let _;t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{return _=t._vscf_asn1wr_write_utf8_str(this.ctxPtr,e)}finally{t._free(n),t._free(e);}}writeOid(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("value",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);let _;t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{return _=t._vscf_asn1wr_write_oid(this.ctxPtr,e)}finally{t._free(n),t._free(e);}}writeSequence(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("len",e),t._vscf_asn1wr_write_sequence(this.ctxPtr,e)}writeSet(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("len",e),t._vscf_asn1wr_write_set(this.ctxPtr,e)}}return r},Y=(t,e)=>{class r{constructor(e){this.name="RsaPublicKey",this.ctxPtr=void 0===e?t._vscf_rsa_public_key_new():e;}static newAndUseCContext(e){return new r(t._vscf_rsa_public_key_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_rsa_public_key_delete(this.ctxPtr),this.ctxPtr=null);}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_rsa_public_key_alg_id(this.ctxPtr)}algInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_rsa_public_key_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}len(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_rsa_public_key_len(this.ctxPtr)}bitlen(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_rsa_public_key_bitlen(this.ctxPtr)}implTag(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_rsa_public_key_impl_tag(this.ctxPtr)}isValid(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_rsa_public_key_is_valid(this.ctxPtr)}keyExponent(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_rsa_public_key_key_exponent(this.ctxPtr)}}return r},H=(t,e)=>{class r{constructor(e){this.name="RsaPrivateKey",this.ctxPtr=void 0===e?t._vscf_rsa_private_key_new():e;}static newAndUseCContext(e){return new r(t._vscf_rsa_private_key_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_rsa_private_key_delete(this.ctxPtr),this.ctxPtr=null);}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_rsa_private_key_alg_id(this.ctxPtr)}algInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_rsa_private_key_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}len(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_rsa_private_key_len(this.ctxPtr)}bitlen(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_rsa_private_key_bitlen(this.ctxPtr)}implTag(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_rsa_private_key_impl_tag(this.ctxPtr)}isValid(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_rsa_private_key_is_valid(this.ctxPtr)}extractPublicKey(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_rsa_private_key_extract_public_key(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}}return r},U=(t,e)=>{class r{static get CAN_IMPORT_PUBLIC_KEY(){return !0}get CAN_IMPORT_PUBLIC_KEY(){return r.CAN_IMPORT_PUBLIC_KEY}static get CAN_EXPORT_PUBLIC_KEY(){return !0}get CAN_EXPORT_PUBLIC_KEY(){return r.CAN_EXPORT_PUBLIC_KEY}static get CAN_IMPORT_PRIVATE_KEY(){return !0}get CAN_IMPORT_PRIVATE_KEY(){return r.CAN_IMPORT_PRIVATE_KEY}static get CAN_EXPORT_PRIVATE_KEY(){return !0}get CAN_EXPORT_PRIVATE_KEY(){return r.CAN_EXPORT_PRIVATE_KEY}constructor(e){this.name="Rsa",this.ctxPtr=void 0===e?t._vscf_rsa_new():e;}static newAndUseCContext(e){return new r(t._vscf_rsa_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_rsa_delete(this.ctxPtr),this.ctxPtr=null);}set random(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("random",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_rsa_release_random(this.ctxPtr),t._vscf_rsa_use_random(this.ctxPtr,r.ctxPtr);}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_rsa_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_rsa_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),r=t._vscf_rsa_restore_alg_info(this.ctxPtr,r.ctxPtr),e.FoundationError.handleStatusCode(r);}generateEphemeralKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("key",r,"Foundation.Key",e.FoundationInterfaceTag.KEY,e.FoundationInterface);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_rsa_generate_ephemeral_key(this.ctxPtr,r.ctxPtr,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(n);}}importPublicKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("rawKey",r,e.RawPublicKey);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_rsa_import_public_key(this.ctxPtr,r.ctxPtr,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(n);}}exportPublicKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_rsa_export_public_key(this.ctxPtr,r.ctxPtr,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),e.RawPublicKey.newAndTakeCContext(_)}finally{t._free(n);}}importPrivateKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("rawKey",r,e.RawPrivateKey);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_rsa_import_private_key(this.ctxPtr,r.ctxPtr,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(n);}}exportPrivateKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_rsa_export_private_key(this.ctxPtr,r.ctxPtr,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),e.RawPrivateKey.newAndTakeCContext(_)}finally{t._free(n);}}canEncrypt(r,n){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$1.ensureNumber("dataLen",n),!!t._vscf_rsa_can_encrypt(this.ctxPtr,r.ctxPtr,n)}encryptedLen(r,n){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$1.ensureNumber("dataLen",n),t._vscf_rsa_encrypted_len(this.ctxPtr,r.ctxPtr,n)}encrypt(r,n){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$1.ensureByteArray("data",n);const _=n.length*n.BYTES_PER_ELEMENT,s=t._malloc(_);t.HEAP8.set(n,s);var c=t._vsc_data_ctx_size();c=t._malloc(c),t._vsc_data(c,s,_),n=this.encryptedLen(r,n.length),n=t._vsc_buffer_new_with_capacity(n);try{const _=t._vscf_rsa_encrypt(this.ctxPtr,r.ctxPtr,c,n);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(n),a=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+a)}finally{t._free(s),t._free(c),t._vsc_buffer_delete(n);}}canDecrypt(r,n){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$1.ensureNumber("dataLen",n),!!t._vscf_rsa_can_decrypt(this.ctxPtr,r.ctxPtr,n)}decryptedLen(r,n){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$1.ensureNumber("dataLen",n),t._vscf_rsa_decrypted_len(this.ctxPtr,r.ctxPtr,n)}decrypt(r,n){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$1.ensureByteArray("data",n);const _=n.length*n.BYTES_PER_ELEMENT,s=t._malloc(_);t.HEAP8.set(n,s);var c=t._vsc_data_ctx_size();c=t._malloc(c),t._vsc_data(c,s,_),n=this.decryptedLen(r,n.length),n=t._vsc_buffer_new_with_capacity(n);try{const _=t._vscf_rsa_decrypt(this.ctxPtr,r.ctxPtr,c,n);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(n),a=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+a)}finally{t._free(s),t._free(c),t._vsc_buffer_delete(n);}}canSign(r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),!!t._vscf_rsa_can_sign(this.ctxPtr,r.ctxPtr)}signatureLen(r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("key",r,"Foundation.Key",e.FoundationInterfaceTag.KEY,e.FoundationInterface),t._vscf_rsa_signature_len(this.ctxPtr,r.ctxPtr)}signHash(r,n,_){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$1.ensureNumber("hashId",n),a$1.ensureByteArray("digest",_);var s=_.length*_.BYTES_PER_ELEMENT;const c=t._malloc(s);t.HEAP8.set(_,c),_=t._vsc_data_ctx_size(),_=t._malloc(_),t._vsc_data(_,c,s),s=this.signatureLen(r),s=t._vsc_buffer_new_with_capacity(s);try{const c=t._vscf_rsa_sign_hash(this.ctxPtr,r.ctxPtr,n,_,s);e.FoundationError.handleStatusCode(c);const a=t._vsc_buffer_bytes(s),i=t._vsc_buffer_len(s);return t.HEAPU8.slice(a,a+i)}finally{t._free(c),t._free(_),t._vsc_buffer_delete(s);}}canVerify(r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),!!t._vscf_rsa_can_verify(this.ctxPtr,r.ctxPtr)}verifyHash(r,n,_,s){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$1.ensureNumber("hashId",n),a$1.ensureByteArray("digest",_),a$1.ensureByteArray("signature",s);var c=_.length*_.BYTES_PER_ELEMENT;const i=t._malloc(c);t.HEAP8.set(_,i),_=t._vsc_data_ctx_size(),_=t._malloc(_),t._vsc_data(_,i,c),c=s.length*s.BYTES_PER_ELEMENT;const l=t._malloc(c);let u;t.HEAP8.set(s,l),s=t._vsc_data_ctx_size(),s=t._malloc(s),t._vsc_data(s,l,c);try{return !!(u=t._vscf_rsa_verify_hash(this.ctxPtr,r.ctxPtr,n,_,s))}finally{t._free(i),t._free(_),t._free(l),t._free(s);}}setupDefaults(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_rsa_setup_defaults(this.ctxPtr);e.FoundationError.handleStatusCode(r);}generateKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("bitlen",r);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_rsa_generate_key(this.ctxPtr,r,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(n);}}}return r},M=(t,e)=>{class r{constructor(e){this.name="EccPublicKey",this.ctxPtr=void 0===e?t._vscf_ecc_public_key_new():e;}static newAndUseCContext(e){return new r(t._vscf_ecc_public_key_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_ecc_public_key_delete(this.ctxPtr),this.ctxPtr=null);}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecc_public_key_alg_id(this.ctxPtr)}algInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_ecc_public_key_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}len(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecc_public_key_len(this.ctxPtr)}bitlen(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecc_public_key_bitlen(this.ctxPtr)}implTag(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecc_public_key_impl_tag(this.ctxPtr)}isValid(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_ecc_public_key_is_valid(this.ctxPtr)}}return r},O=(t,e)=>{class r{constructor(e){this.name="EccPrivateKey",this.ctxPtr=void 0===e?t._vscf_ecc_private_key_new():e;}static newAndUseCContext(e){return new r(t._vscf_ecc_private_key_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_ecc_private_key_delete(this.ctxPtr),this.ctxPtr=null);}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecc_private_key_alg_id(this.ctxPtr)}algInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_ecc_private_key_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}len(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecc_private_key_len(this.ctxPtr)}bitlen(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecc_private_key_bitlen(this.ctxPtr)}implTag(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecc_private_key_impl_tag(this.ctxPtr)}isValid(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_ecc_private_key_is_valid(this.ctxPtr)}extractPublicKey(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_ecc_private_key_extract_public_key(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}}return r},D=(t,e)=>{class r{static get CAN_IMPORT_PUBLIC_KEY(){return !0}get CAN_IMPORT_PUBLIC_KEY(){return r.CAN_IMPORT_PUBLIC_KEY}static get CAN_EXPORT_PUBLIC_KEY(){return !0}get CAN_EXPORT_PUBLIC_KEY(){return r.CAN_EXPORT_PUBLIC_KEY}static get CAN_IMPORT_PRIVATE_KEY(){return !0}get CAN_IMPORT_PRIVATE_KEY(){return r.CAN_IMPORT_PRIVATE_KEY}static get CAN_EXPORT_PRIVATE_KEY(){return !0}get CAN_EXPORT_PRIVATE_KEY(){return r.CAN_EXPORT_PRIVATE_KEY}constructor(e){this.name="Ecc",this.ctxPtr=void 0===e?t._vscf_ecc_new():e;}static newAndUseCContext(e){return new r(t._vscf_ecc_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_ecc_delete(this.ctxPtr),this.ctxPtr=null);}set random(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("random",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_ecc_release_random(this.ctxPtr),t._vscf_ecc_use_random(this.ctxPtr,r.ctxPtr);}set ecies(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("ecies",r,e.Ecies),t._vscf_ecc_release_ecies(this.ctxPtr),t._vscf_ecc_use_ecies(this.ctxPtr,r.ctxPtr);}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecc_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_ecc_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),r=t._vscf_ecc_restore_alg_info(this.ctxPtr,r.ctxPtr),e.FoundationError.handleStatusCode(r);}generateEphemeralKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("key",r,"Foundation.Key",e.FoundationInterfaceTag.KEY,e.FoundationInterface);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_ecc_generate_ephemeral_key(this.ctxPtr,r.ctxPtr,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(n);}}importPublicKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("rawKey",r,e.RawPublicKey);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_ecc_import_public_key(this.ctxPtr,r.ctxPtr,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(n);}}exportPublicKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_ecc_export_public_key(this.ctxPtr,r.ctxPtr,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),e.RawPublicKey.newAndTakeCContext(_)}finally{t._free(n);}}importPrivateKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("rawKey",r,e.RawPrivateKey);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_ecc_import_private_key(this.ctxPtr,r.ctxPtr,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(n);}}exportPrivateKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_ecc_export_private_key(this.ctxPtr,r.ctxPtr,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),e.RawPrivateKey.newAndTakeCContext(_)}finally{t._free(n);}}canEncrypt(r,n){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$1.ensureNumber("dataLen",n),!!t._vscf_ecc_can_encrypt(this.ctxPtr,r.ctxPtr,n)}encryptedLen(r,n){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$1.ensureNumber("dataLen",n),t._vscf_ecc_encrypted_len(this.ctxPtr,r.ctxPtr,n)}encrypt(r,n){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$1.ensureByteArray("data",n);const _=n.length*n.BYTES_PER_ELEMENT,s=t._malloc(_);t.HEAP8.set(n,s);var c=t._vsc_data_ctx_size();c=t._malloc(c),t._vsc_data(c,s,_),n=this.encryptedLen(r,n.length),n=t._vsc_buffer_new_with_capacity(n);try{const _=t._vscf_ecc_encrypt(this.ctxPtr,r.ctxPtr,c,n);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(n),a=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+a)}finally{t._free(s),t._free(c),t._vsc_buffer_delete(n);}}canDecrypt(r,n){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$1.ensureNumber("dataLen",n),!!t._vscf_ecc_can_decrypt(this.ctxPtr,r.ctxPtr,n)}decryptedLen(r,n){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$1.ensureNumber("dataLen",n),t._vscf_ecc_decrypted_len(this.ctxPtr,r.ctxPtr,n)}decrypt(r,n){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$1.ensureByteArray("data",n);const _=n.length*n.BYTES_PER_ELEMENT,s=t._malloc(_);t.HEAP8.set(n,s);var c=t._vsc_data_ctx_size();c=t._malloc(c),t._vsc_data(c,s,_),n=this.decryptedLen(r,n.length),n=t._vsc_buffer_new_with_capacity(n);try{const _=t._vscf_ecc_decrypt(this.ctxPtr,r.ctxPtr,c,n);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(n),a=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+a)}finally{t._free(s),t._free(c),t._vsc_buffer_delete(n);}}canSign(r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),!!t._vscf_ecc_can_sign(this.ctxPtr,r.ctxPtr)}signatureLen(r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("key",r,"Foundation.Key",e.FoundationInterfaceTag.KEY,e.FoundationInterface),t._vscf_ecc_signature_len(this.ctxPtr,r.ctxPtr)}signHash(r,n,_){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$1.ensureNumber("hashId",n),a$1.ensureByteArray("digest",_);var s=_.length*_.BYTES_PER_ELEMENT;const c=t._malloc(s);t.HEAP8.set(_,c),_=t._vsc_data_ctx_size(),_=t._malloc(_),t._vsc_data(_,c,s),s=this.signatureLen(r),s=t._vsc_buffer_new_with_capacity(s);try{const c=t._vscf_ecc_sign_hash(this.ctxPtr,r.ctxPtr,n,_,s);e.FoundationError.handleStatusCode(c);const a=t._vsc_buffer_bytes(s),i=t._vsc_buffer_len(s);return t.HEAPU8.slice(a,a+i)}finally{t._free(c),t._free(_),t._vsc_buffer_delete(s);}}canVerify(r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),!!t._vscf_ecc_can_verify(this.ctxPtr,r.ctxPtr)}verifyHash(r,n,_,s){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$1.ensureNumber("hashId",n),a$1.ensureByteArray("digest",_),a$1.ensureByteArray("signature",s);var c=_.length*_.BYTES_PER_ELEMENT;const i=t._malloc(c);t.HEAP8.set(_,i),_=t._vsc_data_ctx_size(),_=t._malloc(_),t._vsc_data(_,i,c),c=s.length*s.BYTES_PER_ELEMENT;const l=t._malloc(c);let u;t.HEAP8.set(s,l),s=t._vsc_data_ctx_size(),s=t._malloc(s),t._vsc_data(s,l,c);try{return !!(u=t._vscf_ecc_verify_hash(this.ctxPtr,r.ctxPtr,n,_,s))}finally{t._free(i),t._free(_),t._free(l),t._free(s);}}computeSharedKey(r,n){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$1.ensureImplementInterface("privateKey",n,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface);var _=this.sharedKeyLen(n);_=t._vsc_buffer_new_with_capacity(_);try{const s=t._vscf_ecc_compute_shared_key(this.ctxPtr,r.ctxPtr,n.ctxPtr,_);e.FoundationError.handleStatusCode(s);const c=t._vsc_buffer_bytes(_),a=t._vsc_buffer_len(_);return t.HEAPU8.slice(c,c+a)}finally{t._vsc_buffer_delete(_);}}sharedKeyLen(r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("key",r,"Foundation.Key",e.FoundationInterfaceTag.KEY,e.FoundationInterface),t._vscf_ecc_shared_key_len(this.ctxPtr,r.ctxPtr)}setupDefaults(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_ecc_setup_defaults(this.ctxPtr);e.FoundationError.handleStatusCode(r);}generateKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("algId",r);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_ecc_generate_key(this.ctxPtr,r,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(n);}}}return r},G=(t,e)=>{class r{static get SOURCES_MAX(){return 15}get SOURCES_MAX(){return r.SOURCES_MAX}constructor(e){this.name="EntropyAccumulator",this.ctxPtr=void 0===e?t._vscf_entropy_accumulator_new():e;}static newAndUseCContext(e){return new r(t._vscf_entropy_accumulator_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_entropy_accumulator_delete(this.ctxPtr),this.ctxPtr=null);}isStrong(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_entropy_accumulator_is_strong(this.ctxPtr)}gather(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("len",r);const n=t._vsc_buffer_new_with_capacity(r);try{const _=t._vscf_entropy_accumulator_gather(this.ctxPtr,r,n);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(n),c=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+c)}finally{t._vsc_buffer_delete(n);}}setupDefaults(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_entropy_accumulator_setup_defaults(this.ctxPtr);}addSource(r,n){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("source",r,"Foundation.EntropySource",e.FoundationInterfaceTag.ENTROPY_SOURCE,e.FoundationInterface),a$1.ensureNumber("threshold",n),t._vscf_entropy_accumulator_add_source(this.ctxPtr,r.ctxPtr,n);}}return r},V=(t,e)=>{class r{static get RESEED_INTERVAL(){return 1e4}get RESEED_INTERVAL(){return r.RESEED_INTERVAL}static get ENTROPY_LEN(){return 48}get ENTROPY_LEN(){return r.ENTROPY_LEN}constructor(e){this.name="CtrDrbg",this.ctxPtr=void 0===e?t._vscf_ctr_drbg_new():e;}static newAndUseCContext(e){return new r(t._vscf_ctr_drbg_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_ctr_drbg_delete(this.ctxPtr),this.ctxPtr=null);}set entropySource(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("entropySource",r,"Foundation.EntropySource",e.FoundationInterfaceTag.ENTROPY_SOURCE,e.FoundationInterface),t._vscf_ctr_drbg_release_entropy_source(this.ctxPtr),r=t._vscf_ctr_drbg_use_entropy_source(this.ctxPtr,r.ctxPtr),e.FoundationError.handleStatusCode(r);}random(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("dataLen",r);const n=t._vsc_buffer_new_with_capacity(r);try{const _=t._vscf_ctr_drbg_random(this.ctxPtr,r,n);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(n),c=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+c)}finally{t._vsc_buffer_delete(n);}}reseed(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_ctr_drbg_reseed(this.ctxPtr);e.FoundationError.handleStatusCode(r);}setupDefaults(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_ctr_drbg_setup_defaults(this.ctxPtr);e.FoundationError.handleStatusCode(r);}enablePredictionResistance(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ctr_drbg_enable_prediction_resistance(this.ctxPtr);}setReseedInterval(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("interval",e),t._vscf_ctr_drbg_set_reseed_interval(this.ctxPtr,e);}setEntropyLen(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("len",e),t._vscf_ctr_drbg_set_entropy_len(this.ctxPtr,e);}}return r},j=(t,e)=>{class r{constructor(e){this.name="Hmac",this.ctxPtr=void 0===e?t._vscf_hmac_new():e;}static newAndUseCContext(e){return new r(t._vscf_hmac_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_hmac_delete(this.ctxPtr),this.ctxPtr=null);}set hash(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("hash",r,"Foundation.Hash",e.FoundationInterfaceTag.HASH,e.FoundationInterface),t._vscf_hmac_release_hash(this.ctxPtr),t._vscf_hmac_use_hash(this.ctxPtr,r.ctxPtr);}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_hmac_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_hmac_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),r=t._vscf_hmac_restore_alg_info(this.ctxPtr,r.ctxPtr),e.FoundationError.handleStatusCode(r);}digestLen(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_hmac_digest_len(this.ctxPtr)}mac(e,r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("key",e),a$1.ensureByteArray("data",r);var n=e.length*e.BYTES_PER_ELEMENT;const _=t._malloc(n);t.HEAP8.set(e,_),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,_,n);var s=r.length*r.BYTES_PER_ELEMENT;n=t._malloc(s),t.HEAP8.set(r,n),r=t._vsc_data_ctx_size(),r=t._malloc(r),t._vsc_data(r,n,s),s=this.digestLen(),s=t._vsc_buffer_new_with_capacity(s);try{t._vscf_hmac_mac(this.ctxPtr,e,r,s);const n=t._vsc_buffer_bytes(s),c=t._vsc_buffer_len(s);return t.HEAPU8.slice(n,n+c)}finally{t._free(_),t._free(e),t._free(n),t._free(r),t._vsc_buffer_delete(s);}}start(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("key",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{t._vscf_hmac_start(this.ctxPtr,e);}finally{t._free(n),t._free(e);}}update(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{t._vscf_hmac_update(this.ctxPtr,e);}finally{t._free(n),t._free(e);}}finish(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var e=this.digestLen();e=t._vsc_buffer_new_with_capacity(e);try{t._vscf_hmac_finish(this.ctxPtr,e);const r=t._vsc_buffer_bytes(e),n=t._vsc_buffer_len(e);return t.HEAPU8.slice(r,r+n)}finally{t._vsc_buffer_delete(e);}}reset(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_hmac_reset(this.ctxPtr);}}return r},W=(t,e)=>{class r{constructor(e){this.name="Hkdf",this.ctxPtr=void 0===e?t._vscf_hkdf_new():e;}static newAndUseCContext(e){return new r(t._vscf_hkdf_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_hkdf_delete(this.ctxPtr),this.ctxPtr=null);}set hash(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("hash",r,"Foundation.Hash",e.FoundationInterfaceTag.HASH,e.FoundationInterface),t._vscf_hkdf_release_hash(this.ctxPtr),t._vscf_hkdf_use_hash(this.ctxPtr,r.ctxPtr);}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_hkdf_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_hkdf_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),r=t._vscf_hkdf_restore_alg_info(this.ctxPtr,r.ctxPtr),e.FoundationError.handleStatusCode(r);}derive(e,r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",e),a$1.ensureNumber("keyLen",r);var n=e.length*e.BYTES_PER_ELEMENT;const _=t._malloc(n);t.HEAP8.set(e,_),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,_,n),n=t._vsc_buffer_new_with_capacity(r);try{t._vscf_hkdf_derive(this.ctxPtr,e,r,n);const _=t._vsc_buffer_bytes(n),s=t._vsc_buffer_len(n);return t.HEAPU8.slice(_,_+s)}finally{t._free(s$1),t._free(e),t._vsc_buffer_delete(n);}}reset(e,r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("salt",e),a$1.ensureNumber("iterationCount",r);const n=e.length*e.BYTES_PER_ELEMENT,_=t._malloc(n);t.HEAP8.set(e,_),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,_,n);try{t._vscf_hkdf_reset(this.ctxPtr,e,r);}finally{t._free(_),t._free(e);}}setInfo(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("info",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{t._vscf_hkdf_set_info(this.ctxPtr,e);}finally{t._free(n),t._free(e);}}}return r},Z=(t,e)=>{class r{constructor(e){this.name="Kdf1",this.ctxPtr=void 0===e?t._vscf_kdf1_new():e;}static newAndUseCContext(e){return new r(t._vscf_kdf1_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_kdf1_delete(this.ctxPtr),this.ctxPtr=null);}set hash(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("hash",r,"Foundation.Hash",e.FoundationInterfaceTag.HASH,e.FoundationInterface),t._vscf_kdf1_release_hash(this.ctxPtr),t._vscf_kdf1_use_hash(this.ctxPtr,r.ctxPtr);}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_kdf1_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_kdf1_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),r=t._vscf_kdf1_restore_alg_info(this.ctxPtr,r.ctxPtr),e.FoundationError.handleStatusCode(r);}derive(e,r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",e),a$1.ensureNumber("keyLen",r);var n=e.length*e.BYTES_PER_ELEMENT;const _=t._malloc(n);t.HEAP8.set(e,_),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,_,n),n=t._vsc_buffer_new_with_capacity(r);try{t._vscf_kdf1_derive(this.ctxPtr,e,r,n);const _=t._vsc_buffer_bytes(n),s=t._vsc_buffer_len(n);return t.HEAPU8.slice(_,_+s)}finally{t._free(s$1),t._free(e),t._vsc_buffer_delete(n);}}}return r},X=(t,e)=>{class r{constructor(e){this.name="Kdf2",this.ctxPtr=void 0===e?t._vscf_kdf2_new():e;}static newAndUseCContext(e){return new r(t._vscf_kdf2_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_kdf2_delete(this.ctxPtr),this.ctxPtr=null);}set hash(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("hash",r,"Foundation.Hash",e.FoundationInterfaceTag.HASH,e.FoundationInterface),t._vscf_kdf2_release_hash(this.ctxPtr),t._vscf_kdf2_use_hash(this.ctxPtr,r.ctxPtr);}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_kdf2_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_kdf2_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),r=t._vscf_kdf2_restore_alg_info(this.ctxPtr,r.ctxPtr),e.FoundationError.handleStatusCode(r);}derive(e,r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",e),a$1.ensureNumber("keyLen",r);var n=e.length*e.BYTES_PER_ELEMENT;const _=t._malloc(n);t.HEAP8.set(e,_),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,_,n),n=t._vsc_buffer_new_with_capacity(r);try{t._vscf_kdf2_derive(this.ctxPtr,e,r,n);const _=t._vsc_buffer_bytes(n),s=t._vsc_buffer_len(n);return t.HEAPU8.slice(_,_+s)}finally{t._free(s$1),t._free(e),t._vsc_buffer_delete(n);}}}return r},$=(t,e)=>{class r{constructor(e){this.name="FakeRandom",this.ctxPtr=void 0===e?t._vscf_fake_random_new():e;}static newAndUseCContext(e){return new r(t._vscf_fake_random_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_fake_random_delete(this.ctxPtr),this.ctxPtr=null);}random(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("dataLen",r);const n=t._vsc_buffer_new_with_capacity(r);try{const _=t._vscf_fake_random_random(this.ctxPtr,r,n);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(n),c=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+c)}finally{t._vsc_buffer_delete(n);}}reseed(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_fake_random_reseed(this.ctxPtr);e.FoundationError.handleStatusCode(r);}isStrong(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_fake_random_is_strong(this.ctxPtr)}gather(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("len",r);const n=t._vsc_buffer_new_with_capacity(r);try{const _=t._vscf_fake_random_gather(this.ctxPtr,r,n);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(n),c=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+c)}finally{t._vsc_buffer_delete(n);}}setupSourceByte(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("byteSource",e),t._vscf_fake_random_setup_source_byte(this.ctxPtr,e);}setupSourceData(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("dataSource",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{t._vscf_fake_random_setup_source_data(this.ctxPtr,e);}finally{t._free(n),t._free(e);}}}return r},q=(t,e)=>{class r{constructor(e){this.name="Pkcs5Pbkdf2",this.ctxPtr=void 0===e?t._vscf_pkcs5_pbkdf2_new():e;}static newAndUseCContext(e){return new r(t._vscf_pkcs5_pbkdf2_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_pkcs5_pbkdf2_delete(this.ctxPtr),this.ctxPtr=null);}set hmac(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("hmac",r,"Foundation.Mac",e.FoundationInterfaceTag.MAC,e.FoundationInterface),t._vscf_pkcs5_pbkdf2_release_hmac(this.ctxPtr),t._vscf_pkcs5_pbkdf2_use_hmac(this.ctxPtr,r.ctxPtr);}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_pkcs5_pbkdf2_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_pkcs5_pbkdf2_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),r=t._vscf_pkcs5_pbkdf2_restore_alg_info(this.ctxPtr,r.ctxPtr),e.FoundationError.handleStatusCode(r);}derive(e,r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",e),a$1.ensureNumber("keyLen",r);var n=e.length*e.BYTES_PER_ELEMENT;const _=t._malloc(n);t.HEAP8.set(e,_),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,_,n),n=t._vsc_buffer_new_with_capacity(r);try{t._vscf_pkcs5_pbkdf2_derive(this.ctxPtr,e,r,n);const _=t._vsc_buffer_bytes(n),s=t._vsc_buffer_len(n);return t.HEAPU8.slice(_,_+s)}finally{t._free(s$1),t._free(e),t._vsc_buffer_delete(n);}}reset(e,r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("salt",e),a$1.ensureNumber("iterationCount",r);const n=e.length*e.BYTES_PER_ELEMENT,_=t._malloc(n);t.HEAP8.set(e,_),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,_,n);try{t._vscf_pkcs5_pbkdf2_reset(this.ctxPtr,e,r);}finally{t._free(_),t._free(e);}}setInfo(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("info",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{t._vscf_pkcs5_pbkdf2_set_info(this.ctxPtr,e);}finally{t._free(n),t._free(e);}}setupDefaults(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_pkcs5_pbkdf2_setup_defaults(this.ctxPtr);}}return r},J=(t,e)=>{class r{constructor(e){this.name="Pkcs5Pbes2",this.ctxPtr=void 0===e?t._vscf_pkcs5_pbes2_new():e;}static newAndUseCContext(e){return new r(t._vscf_pkcs5_pbes2_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_pkcs5_pbes2_delete(this.ctxPtr),this.ctxPtr=null);}set kdf(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("kdf",r,"Foundation.SaltedKdf",e.FoundationInterfaceTag.SALTED_KDF,e.FoundationInterface),t._vscf_pkcs5_pbes2_release_kdf(this.ctxPtr),t._vscf_pkcs5_pbes2_use_kdf(this.ctxPtr,r.ctxPtr);}set cipher(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("cipher",r,"Foundation.Cipher",e.FoundationInterfaceTag.CIPHER,e.FoundationInterface),t._vscf_pkcs5_pbes2_release_cipher(this.ctxPtr),t._vscf_pkcs5_pbes2_use_cipher(this.ctxPtr,r.ctxPtr);}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_pkcs5_pbes2_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_pkcs5_pbes2_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),r=t._vscf_pkcs5_pbes2_restore_alg_info(this.ctxPtr,r.ctxPtr),e.FoundationError.handleStatusCode(r);}encrypt(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",r);const n=r.length*r.BYTES_PER_ELEMENT,_=t._malloc(n);t.HEAP8.set(r,_);var s=t._vsc_data_ctx_size();s=t._malloc(s),t._vsc_data(s,_,n),r=this.encryptedLen(r.length),r=t._vsc_buffer_new_with_capacity(r);try{const n=t._vscf_pkcs5_pbes2_encrypt(this.ctxPtr,s,r);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(r),c=t._vsc_buffer_len(r);return t.HEAPU8.slice(_,_+c)}finally{t._free(_),t._free(s),t._vsc_buffer_delete(r);}}encryptedLen(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("dataLen",e),t._vscf_pkcs5_pbes2_encrypted_len(this.ctxPtr,e)}preciseEncryptedLen(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("dataLen",e),t._vscf_pkcs5_pbes2_precise_encrypted_len(this.ctxPtr,e)}decrypt(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",r);const n=r.length*r.BYTES_PER_ELEMENT,_=t._malloc(n);t.HEAP8.set(r,_);var s=t._vsc_data_ctx_size();s=t._malloc(s),t._vsc_data(s,_,n),r=this.decryptedLen(r.length),r=t._vsc_buffer_new_with_capacity(r);try{const n=t._vscf_pkcs5_pbes2_decrypt(this.ctxPtr,s,r);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(r),c=t._vsc_buffer_len(r);return t.HEAPU8.slice(_,_+c)}finally{t._free(_),t._free(s),t._vsc_buffer_delete(r);}}decryptedLen(e){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("dataLen",e),t._vscf_pkcs5_pbes2_decrypted_len(this.ctxPtr,e)}reset(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("pwd",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{t._vscf_pkcs5_pbes2_reset(this.ctxPtr,e);}finally{t._free(n),t._free(e);}}}return r},Q=(t,e)=>{class r{constructor(e){this.name="SeedEntropySource",this.ctxPtr=void 0===e?t._vscf_seed_entropy_source_new():e;}static newAndUseCContext(e){return new r(t._vscf_seed_entropy_source_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_seed_entropy_source_delete(this.ctxPtr),this.ctxPtr=null);}isStrong(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_seed_entropy_source_is_strong(this.ctxPtr)}gather(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("len",r);const n=t._vsc_buffer_new_with_capacity(r);try{const _=t._vscf_seed_entropy_source_gather(this.ctxPtr,r,n);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(n),c=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+c)}finally{t._vsc_buffer_delete(n);}}resetSeed(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("seed",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{t._vscf_seed_entropy_source_reset_seed(this.ctxPtr,e);}finally{t._free(n),t._free(e);}}}return r},tt=(t,e)=>{class r{static get KEY_MATERIAL_LEN_MIN(){return 32}get KEY_MATERIAL_LEN_MIN(){return r.KEY_MATERIAL_LEN_MIN}static get KEY_MATERIAL_LEN_MAX(){return 512}get KEY_MATERIAL_LEN_MAX(){return r.KEY_MATERIAL_LEN_MAX}constructor(e){this.name="KeyMaterialRng",this.ctxPtr=void 0===e?t._vscf_key_material_rng_new():e;}static newAndUseCContext(e){return new r(t._vscf_key_material_rng_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_key_material_rng_delete(this.ctxPtr),this.ctxPtr=null);}random(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureNumber("dataLen",r);const n=t._vsc_buffer_new_with_capacity(r);try{const _=t._vscf_key_material_rng_random(this.ctxPtr,r,n);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(n),c=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+c)}finally{t._vsc_buffer_delete(n);}}reseed(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_key_material_rng_reseed(this.ctxPtr);e.FoundationError.handleStatusCode(r);}resetKeyMaterial(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("keyMaterial",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{t._vscf_key_material_rng_reset_key_material(this.ctxPtr,e);}finally{t._free(n),t._free(e);}}}return r},et=(t,e)=>{class r{constructor(e){this.name="RawPublicKey",this.ctxPtr=void 0===e?t._vscf_raw_public_key_new():e;}static newAndUseCContext(e){return new r(t._vscf_raw_public_key_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_raw_public_key_delete(this.ctxPtr),this.ctxPtr=null);}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_raw_public_key_alg_id(this.ctxPtr)}algInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_raw_public_key_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}len(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_raw_public_key_len(this.ctxPtr)}bitlen(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_raw_public_key_bitlen(this.ctxPtr)}implTag(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_raw_public_key_impl_tag(this.ctxPtr)}isValid(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_raw_public_key_is_valid(this.ctxPtr)}data(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var e=t._vsc_data_ctx_size();e=t._malloc(e);try{t._vscf_raw_public_key_data(e,this.ctxPtr);const r=t._vsc_data_len(e),n=t._vsc_data_bytes(e);return t.HEAPU8.slice(n,n+r)}finally{t._free(e);}}}return r},rt=(t,e)=>{class r{constructor(e){this.name="RawPrivateKey",this.ctxPtr=void 0===e?t._vscf_raw_private_key_new():e;}static newAndUseCContext(e){return new r(t._vscf_raw_private_key_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_raw_private_key_delete(this.ctxPtr),this.ctxPtr=null);}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_raw_private_key_alg_id(this.ctxPtr)}algInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_raw_private_key_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}len(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_raw_private_key_len(this.ctxPtr)}bitlen(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_raw_private_key_bitlen(this.ctxPtr)}implTag(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_raw_private_key_impl_tag(this.ctxPtr)}isValid(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_raw_private_key_is_valid(this.ctxPtr)}extractPublicKey(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_raw_private_key_extract_public_key(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}data(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var e=t._vsc_data_ctx_size();e=t._malloc(e);try{t._vscf_raw_private_key_data(e,this.ctxPtr);const r=t._vsc_data_len(e),n=t._vsc_data_bytes(e);return t.HEAPU8.slice(n,n+r)}finally{t._free(e);}}hasPublicKey(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),!!t._vscf_raw_private_key_has_public_key(this.ctxPtr)}setPublicKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("rawPublicKey",r,e.RawPublicKey),t._vscf_raw_private_key_set_public_key(this.ctxPtr,r.ctxPtr);}getPublicKey(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_raw_private_key_get_public_key(this.ctxPtr),e.RawPublicKey.newAndUseCContext(r)}}return r},nt=(t,e)=>{class r{constructor(e){this.name="Pkcs8Serializer",this.ctxPtr=void 0===e?t._vscf_pkcs8_serializer_new():e;}static newAndUseCContext(e){return new r(t._vscf_pkcs8_serializer_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_pkcs8_serializer_delete(this.ctxPtr),this.ctxPtr=null);}set asn1Writer(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("asn1Writer",r,"Foundation.Asn1Writer",e.FoundationInterfaceTag.ASN1_WRITER,e.FoundationInterface),t._vscf_pkcs8_serializer_release_asn1_writer(this.ctxPtr),t._vscf_pkcs8_serializer_use_asn1_writer(this.ctxPtr,r.ctxPtr);}serializedPublicKeyLen(r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("publicKey",r,e.RawPublicKey),t._vscf_pkcs8_serializer_serialized_public_key_len(this.ctxPtr,r.ctxPtr)}serializePublicKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("publicKey",r,e.RawPublicKey);var n=this.serializedPublicKeyLen(r);n=t._vsc_buffer_new_with_capacity(n);try{const _=t._vscf_pkcs8_serializer_serialize_public_key(this.ctxPtr,r.ctxPtr,n);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(n),c=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+c)}finally{t._vsc_buffer_delete(n);}}serializedPrivateKeyLen(r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("privateKey",r,e.RawPrivateKey),t._vscf_pkcs8_serializer_serialized_private_key_len(this.ctxPtr,r.ctxPtr)}serializePrivateKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("privateKey",r,e.RawPrivateKey);var n=this.serializedPrivateKeyLen(r);n=t._vsc_buffer_new_with_capacity(n);try{const _=t._vscf_pkcs8_serializer_serialize_private_key(this.ctxPtr,r.ctxPtr,n);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(n),c=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+c)}finally{t._vsc_buffer_delete(n);}}setupDefaults(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_pkcs8_serializer_setup_defaults(this.ctxPtr);}serializePublicKeyInplace(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("publicKey",r,e.RawPublicKey);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_pkcs8_serializer_serialize_public_key_inplace(this.ctxPtr,r.ctxPtr,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),_}finally{t._free(n);}}serializePrivateKeyInplace(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("privateKey",r,e.RawPrivateKey);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_pkcs8_serializer_serialize_private_key_inplace(this.ctxPtr,r.ctxPtr,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),_}finally{t._free(n);}}}return r},_t=(t,e)=>{class r{constructor(e){this.name="Sec1Serializer",this.ctxPtr=void 0===e?t._vscf_sec1_serializer_new():e;}static newAndUseCContext(e){return new r(t._vscf_sec1_serializer_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_sec1_serializer_delete(this.ctxPtr),this.ctxPtr=null);}set asn1Writer(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("asn1Writer",r,"Foundation.Asn1Writer",e.FoundationInterfaceTag.ASN1_WRITER,e.FoundationInterface),t._vscf_sec1_serializer_release_asn1_writer(this.ctxPtr),t._vscf_sec1_serializer_use_asn1_writer(this.ctxPtr,r.ctxPtr);}serializedPublicKeyLen(r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("publicKey",r,e.RawPublicKey),t._vscf_sec1_serializer_serialized_public_key_len(this.ctxPtr,r.ctxPtr)}serializePublicKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("publicKey",r,e.RawPublicKey);var n=this.serializedPublicKeyLen(r);n=t._vsc_buffer_new_with_capacity(n);try{const _=t._vscf_sec1_serializer_serialize_public_key(this.ctxPtr,r.ctxPtr,n);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(n),c=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+c)}finally{t._vsc_buffer_delete(n);}}serializedPrivateKeyLen(r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("privateKey",r,e.RawPrivateKey),t._vscf_sec1_serializer_serialized_private_key_len(this.ctxPtr,r.ctxPtr)}serializePrivateKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("privateKey",r,e.RawPrivateKey);var n=this.serializedPrivateKeyLen(r);n=t._vsc_buffer_new_with_capacity(n);try{const _=t._vscf_sec1_serializer_serialize_private_key(this.ctxPtr,r.ctxPtr,n);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(n),c=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+c)}finally{t._vsc_buffer_delete(n);}}setupDefaults(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_sec1_serializer_setup_defaults(this.ctxPtr);}serializePublicKeyInplace(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("publicKey",r,e.RawPublicKey);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_sec1_serializer_serialize_public_key_inplace(this.ctxPtr,r.ctxPtr,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),_}finally{t._free(n);}}serializePrivateKeyInplace(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("privateKey",r,e.RawPrivateKey);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_sec1_serializer_serialize_private_key_inplace(this.ctxPtr,r.ctxPtr,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),_}finally{t._free(n);}}}return r},st=(t,e)=>{class r{constructor(e){this.name="KeyAsn1Serializer",this.ctxPtr=void 0===e?t._vscf_key_asn1_serializer_new():e;}static newAndUseCContext(e){return new r(t._vscf_key_asn1_serializer_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_key_asn1_serializer_delete(this.ctxPtr),this.ctxPtr=null);}set asn1Writer(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("asn1Writer",r,"Foundation.Asn1Writer",e.FoundationInterfaceTag.ASN1_WRITER,e.FoundationInterface),t._vscf_key_asn1_serializer_release_asn1_writer(this.ctxPtr),t._vscf_key_asn1_serializer_use_asn1_writer(this.ctxPtr,r.ctxPtr);}serializedPublicKeyLen(r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("publicKey",r,e.RawPublicKey),t._vscf_key_asn1_serializer_serialized_public_key_len(this.ctxPtr,r.ctxPtr)}serializePublicKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("publicKey",r,e.RawPublicKey);var n=this.serializedPublicKeyLen(r);n=t._vsc_buffer_new_with_capacity(n);try{const _=t._vscf_key_asn1_serializer_serialize_public_key(this.ctxPtr,r.ctxPtr,n);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(n),c=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+c)}finally{t._vsc_buffer_delete(n);}}serializedPrivateKeyLen(r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("privateKey",r,e.RawPrivateKey),t._vscf_key_asn1_serializer_serialized_private_key_len(this.ctxPtr,r.ctxPtr)}serializePrivateKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("privateKey",r,e.RawPrivateKey);var n=this.serializedPrivateKeyLen(r);n=t._vsc_buffer_new_with_capacity(n);try{const _=t._vscf_key_asn1_serializer_serialize_private_key(this.ctxPtr,r.ctxPtr,n);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(n),c=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+c)}finally{t._vsc_buffer_delete(n);}}setupDefaults(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_key_asn1_serializer_setup_defaults(this.ctxPtr);}serializePublicKeyInplace(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("publicKey",r,e.RawPublicKey);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_key_asn1_serializer_serialize_public_key_inplace(this.ctxPtr,r.ctxPtr,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),_}finally{t._free(n);}}serializePrivateKeyInplace(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("privateKey",r,e.RawPrivateKey);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_key_asn1_serializer_serialize_private_key_inplace(this.ctxPtr,r.ctxPtr,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),_}finally{t._free(n);}}}return r},ct=(t,e)=>{class r{constructor(e){this.name="KeyAsn1Deserializer",this.ctxPtr=void 0===e?t._vscf_key_asn1_deserializer_new():e;}static newAndUseCContext(e){return new r(t._vscf_key_asn1_deserializer_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_key_asn1_deserializer_delete(this.ctxPtr),this.ctxPtr=null);}set asn1Reader(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("asn1Reader",r,"Foundation.Asn1Reader",e.FoundationInterfaceTag.ASN1_READER,e.FoundationInterface),t._vscf_key_asn1_deserializer_release_asn1_reader(this.ctxPtr),t._vscf_key_asn1_deserializer_use_asn1_reader(this.ctxPtr,r.ctxPtr);}deserializePublicKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("publicKeyData",r);var n=r.length*r.BYTES_PER_ELEMENT;const _=t._malloc(n);let s;t.HEAP8.set(r,_),r=t._vsc_data_ctx_size(),r=t._malloc(r),t._vsc_data(r,_,n),n=t._vscf_error_ctx_size(),n=t._malloc(n),t._vscf_error_reset(n);try{s=t._vscf_key_asn1_deserializer_deserialize_public_key(this.ctxPtr,r,n);const _=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(_),e.RawPublicKey.newAndTakeCContext(s)}finally{t._free(_),t._free(r),t._free(n);}}deserializePrivateKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("privateKeyData",r);var n=r.length*r.BYTES_PER_ELEMENT;const _=t._malloc(n);let s;t.HEAP8.set(r,_),r=t._vsc_data_ctx_size(),r=t._malloc(r),t._vsc_data(r,_,n),n=t._vscf_error_ctx_size(),n=t._malloc(n),t._vscf_error_reset(n);try{s=t._vscf_key_asn1_deserializer_deserialize_private_key(this.ctxPtr,r,n);const _=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(_),e.RawPrivateKey.newAndTakeCContext(s)}finally{t._free(_),t._free(r),t._free(n);}}setupDefaults(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_key_asn1_deserializer_setup_defaults(this.ctxPtr);}deserializePublicKeyInplace(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var r=t._vscf_error_ctx_size();let n;r=t._malloc(r),t._vscf_error_reset(r);try{n=t._vscf_key_asn1_deserializer_deserialize_public_key_inplace(this.ctxPtr,r);const _=t._vscf_error_status(r);return e.FoundationError.handleStatusCode(_),e.RawPublicKey.newAndTakeCContext(n)}finally{t._free(r);}}deserializePrivateKeyInplace(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var r=t._vscf_error_ctx_size();let n;r=t._malloc(r),t._vscf_error_reset(r);try{n=t._vscf_key_asn1_deserializer_deserialize_private_key_inplace(this.ctxPtr,r);const _=t._vscf_error_status(r);return e.FoundationError.handleStatusCode(_),e.RawPrivateKey.newAndTakeCContext(n)}finally{t._free(r);}}}return r},at=(t,e)=>{class r{static get CAN_IMPORT_PUBLIC_KEY(){return !0}get CAN_IMPORT_PUBLIC_KEY(){return r.CAN_IMPORT_PUBLIC_KEY}static get CAN_EXPORT_PUBLIC_KEY(){return !0}get CAN_EXPORT_PUBLIC_KEY(){return r.CAN_EXPORT_PUBLIC_KEY}static get CAN_IMPORT_PRIVATE_KEY(){return !0}get CAN_IMPORT_PRIVATE_KEY(){return r.CAN_IMPORT_PRIVATE_KEY}static get CAN_EXPORT_PRIVATE_KEY(){return !0}get CAN_EXPORT_PRIVATE_KEY(){return r.CAN_EXPORT_PRIVATE_KEY}constructor(e){this.name="Ed25519",this.ctxPtr=void 0===e?t._vscf_ed25519_new():e;}static newAndUseCContext(e){return new r(t._vscf_ed25519_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_ed25519_delete(this.ctxPtr),this.ctxPtr=null);}set random(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("random",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_ed25519_release_random(this.ctxPtr),t._vscf_ed25519_use_random(this.ctxPtr,r.ctxPtr);}set ecies(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("ecies",r,e.Ecies),t._vscf_ed25519_release_ecies(this.ctxPtr),t._vscf_ed25519_use_ecies(this.ctxPtr,r.ctxPtr);}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ed25519_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_ed25519_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),r=t._vscf_ed25519_restore_alg_info(this.ctxPtr,r.ctxPtr),e.FoundationError.handleStatusCode(r);}generateEphemeralKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("key",r,"Foundation.Key",e.FoundationInterfaceTag.KEY,e.FoundationInterface);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_ed25519_generate_ephemeral_key(this.ctxPtr,r.ctxPtr,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(n);}}importPublicKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("rawKey",r,e.RawPublicKey);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_ed25519_import_public_key(this.ctxPtr,r.ctxPtr,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(n);}}exportPublicKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_ed25519_export_public_key(this.ctxPtr,r.ctxPtr,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),e.RawPublicKey.newAndTakeCContext(_)}finally{t._free(n);}}importPrivateKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("rawKey",r,e.RawPrivateKey);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_ed25519_import_private_key(this.ctxPtr,r.ctxPtr,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(n);}}exportPrivateKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_ed25519_export_private_key(this.ctxPtr,r.ctxPtr,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),e.RawPrivateKey.newAndTakeCContext(_)}finally{t._free(n);}}canEncrypt(r,n){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$1.ensureNumber("dataLen",n),!!t._vscf_ed25519_can_encrypt(this.ctxPtr,r.ctxPtr,n)}encryptedLen(r,n){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$1.ensureNumber("dataLen",n),t._vscf_ed25519_encrypted_len(this.ctxPtr,r.ctxPtr,n)}encrypt(r,n){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$1.ensureByteArray("data",n);const _=n.length*n.BYTES_PER_ELEMENT,s=t._malloc(_);t.HEAP8.set(n,s);var c=t._vsc_data_ctx_size();c=t._malloc(c),t._vsc_data(c,s,_),n=this.encryptedLen(r,n.length),n=t._vsc_buffer_new_with_capacity(n);try{const _=t._vscf_ed25519_encrypt(this.ctxPtr,r.ctxPtr,c,n);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(n),a=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+a)}finally{t._free(s),t._free(c),t._vsc_buffer_delete(n);}}canDecrypt(r,n){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$1.ensureNumber("dataLen",n),!!t._vscf_ed25519_can_decrypt(this.ctxPtr,r.ctxPtr,n)}decryptedLen(r,n){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$1.ensureNumber("dataLen",n),t._vscf_ed25519_decrypted_len(this.ctxPtr,r.ctxPtr,n)}decrypt(r,n){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$1.ensureByteArray("data",n);const _=n.length*n.BYTES_PER_ELEMENT,s=t._malloc(_);t.HEAP8.set(n,s);var c=t._vsc_data_ctx_size();c=t._malloc(c),t._vsc_data(c,s,_),n=this.decryptedLen(r,n.length),n=t._vsc_buffer_new_with_capacity(n);try{const _=t._vscf_ed25519_decrypt(this.ctxPtr,r.ctxPtr,c,n);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(n),a=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+a)}finally{t._free(s),t._free(c),t._vsc_buffer_delete(n);}}canSign(r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),!!t._vscf_ed25519_can_sign(this.ctxPtr,r.ctxPtr)}signatureLen(r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("key",r,"Foundation.Key",e.FoundationInterfaceTag.KEY,e.FoundationInterface),t._vscf_ed25519_signature_len(this.ctxPtr,r.ctxPtr)}signHash(r,n,_){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$1.ensureNumber("hashId",n),a$1.ensureByteArray("digest",_);var s=_.length*_.BYTES_PER_ELEMENT;const c=t._malloc(s);t.HEAP8.set(_,c),_=t._vsc_data_ctx_size(),_=t._malloc(_),t._vsc_data(_,c,s),s=this.signatureLen(r),s=t._vsc_buffer_new_with_capacity(s);try{const c=t._vscf_ed25519_sign_hash(this.ctxPtr,r.ctxPtr,n,_,s);e.FoundationError.handleStatusCode(c);const a=t._vsc_buffer_bytes(s),i=t._vsc_buffer_len(s);return t.HEAPU8.slice(a,a+i)}finally{t._free(c),t._free(_),t._vsc_buffer_delete(s);}}canVerify(r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),!!t._vscf_ed25519_can_verify(this.ctxPtr,r.ctxPtr)}verifyHash(r,n,_,s){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$1.ensureNumber("hashId",n),a$1.ensureByteArray("digest",_),a$1.ensureByteArray("signature",s);var c=_.length*_.BYTES_PER_ELEMENT;const i=t._malloc(c);t.HEAP8.set(_,i),_=t._vsc_data_ctx_size(),_=t._malloc(_),t._vsc_data(_,i,c),c=s.length*s.BYTES_PER_ELEMENT;const l=t._malloc(c);let u;t.HEAP8.set(s,l),s=t._vsc_data_ctx_size(),s=t._malloc(s),t._vsc_data(s,l,c);try{return !!(u=t._vscf_ed25519_verify_hash(this.ctxPtr,r.ctxPtr,n,_,s))}finally{t._free(i),t._free(_),t._free(l),t._free(s);}}computeSharedKey(r,n){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$1.ensureImplementInterface("privateKey",n,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface);var _=this.sharedKeyLen(n);_=t._vsc_buffer_new_with_capacity(_);try{const s=t._vscf_ed25519_compute_shared_key(this.ctxPtr,r.ctxPtr,n.ctxPtr,_);e.FoundationError.handleStatusCode(s);const c=t._vsc_buffer_bytes(_),a=t._vsc_buffer_len(_);return t.HEAPU8.slice(c,c+a)}finally{t._vsc_buffer_delete(_);}}sharedKeyLen(r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("key",r,"Foundation.Key",e.FoundationInterfaceTag.KEY,e.FoundationInterface),t._vscf_ed25519_shared_key_len(this.ctxPtr,r.ctxPtr)}setupDefaults(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_ed25519_setup_defaults(this.ctxPtr);e.FoundationError.handleStatusCode(r);}generateKey(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var r=t._vscf_error_ctx_size();let n;r=t._malloc(r),t._vscf_error_reset(r);try{n=t._vscf_ed25519_generate_key(this.ctxPtr,r);const _=t._vscf_error_status(r);return e.FoundationError.handleStatusCode(_),e.FoundationInterface.newAndTakeCContext(n)}finally{t._free(r);}}}return r},it=(t,e)=>{class r{static get CAN_IMPORT_PUBLIC_KEY(){return !0}get CAN_IMPORT_PUBLIC_KEY(){return r.CAN_IMPORT_PUBLIC_KEY}static get CAN_EXPORT_PUBLIC_KEY(){return !0}get CAN_EXPORT_PUBLIC_KEY(){return r.CAN_EXPORT_PUBLIC_KEY}static get CAN_IMPORT_PRIVATE_KEY(){return !0}get CAN_IMPORT_PRIVATE_KEY(){return r.CAN_IMPORT_PRIVATE_KEY}static get CAN_EXPORT_PRIVATE_KEY(){return !0}get CAN_EXPORT_PRIVATE_KEY(){return r.CAN_EXPORT_PRIVATE_KEY}constructor(e){this.name="Curve25519",this.ctxPtr=void 0===e?t._vscf_curve25519_new():e;}static newAndUseCContext(e){return new r(t._vscf_curve25519_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_curve25519_delete(this.ctxPtr),this.ctxPtr=null);}set random(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("random",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_curve25519_release_random(this.ctxPtr),t._vscf_curve25519_use_random(this.ctxPtr,r.ctxPtr);}set ecies(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("ecies",r,e.Ecies),t._vscf_curve25519_release_ecies(this.ctxPtr),t._vscf_curve25519_use_ecies(this.ctxPtr,r.ctxPtr);}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_curve25519_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_curve25519_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),r=t._vscf_curve25519_restore_alg_info(this.ctxPtr,r.ctxPtr),e.FoundationError.handleStatusCode(r);}generateEphemeralKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("key",r,"Foundation.Key",e.FoundationInterfaceTag.KEY,e.FoundationInterface);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_curve25519_generate_ephemeral_key(this.ctxPtr,r.ctxPtr,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(n);}}importPublicKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("rawKey",r,e.RawPublicKey);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_curve25519_import_public_key(this.ctxPtr,r.ctxPtr,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(n);}}exportPublicKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_curve25519_export_public_key(this.ctxPtr,r.ctxPtr,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),e.RawPublicKey.newAndTakeCContext(_)}finally{t._free(n);}}importPrivateKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("rawKey",r,e.RawPrivateKey);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_curve25519_import_private_key(this.ctxPtr,r.ctxPtr,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(n);}}exportPrivateKey(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface);var n=t._vscf_error_ctx_size();let _;n=t._malloc(n),t._vscf_error_reset(n);try{_=t._vscf_curve25519_export_private_key(this.ctxPtr,r.ctxPtr,n);const s=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(s),e.RawPrivateKey.newAndTakeCContext(_)}finally{t._free(n);}}canEncrypt(r,n){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$1.ensureNumber("dataLen",n),!!t._vscf_curve25519_can_encrypt(this.ctxPtr,r.ctxPtr,n)}encryptedLen(r,n){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$1.ensureNumber("dataLen",n),t._vscf_curve25519_encrypted_len(this.ctxPtr,r.ctxPtr,n)}encrypt(r,n){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$1.ensureByteArray("data",n);const _=n.length*n.BYTES_PER_ELEMENT,s=t._malloc(_);t.HEAP8.set(n,s);var c=t._vsc_data_ctx_size();c=t._malloc(c),t._vsc_data(c,s,_),n=this.encryptedLen(r,n.length),n=t._vsc_buffer_new_with_capacity(n);try{const _=t._vscf_curve25519_encrypt(this.ctxPtr,r.ctxPtr,c,n);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(n),a=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+a)}finally{t._free(s),t._free(c),t._vsc_buffer_delete(n);}}canDecrypt(r,n){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$1.ensureNumber("dataLen",n),!!t._vscf_curve25519_can_decrypt(this.ctxPtr,r.ctxPtr,n)}decryptedLen(r,n){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$1.ensureNumber("dataLen",n),t._vscf_curve25519_decrypted_len(this.ctxPtr,r.ctxPtr,n)}decrypt(r,n){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$1.ensureByteArray("data",n);const _=n.length*n.BYTES_PER_ELEMENT,s=t._malloc(_);t.HEAP8.set(n,s);var c=t._vsc_data_ctx_size();c=t._malloc(c),t._vsc_data(c,s,_),n=this.decryptedLen(r,n.length),n=t._vsc_buffer_new_with_capacity(n);try{const _=t._vscf_curve25519_decrypt(this.ctxPtr,r.ctxPtr,c,n);e.FoundationError.handleStatusCode(_);const s=t._vsc_buffer_bytes(n),a=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+a)}finally{t._free(s),t._free(c),t._vsc_buffer_delete(n);}}computeSharedKey(r,n){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$1.ensureImplementInterface("privateKey",n,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface);var _=this.sharedKeyLen(n);_=t._vsc_buffer_new_with_capacity(_);try{const s=t._vscf_curve25519_compute_shared_key(this.ctxPtr,r.ctxPtr,n.ctxPtr,_);e.FoundationError.handleStatusCode(s);const c=t._vsc_buffer_bytes(_),a=t._vsc_buffer_len(_);return t.HEAPU8.slice(c,c+a)}finally{t._vsc_buffer_delete(_);}}sharedKeyLen(r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("key",r,"Foundation.Key",e.FoundationInterfaceTag.KEY,e.FoundationInterface),t._vscf_curve25519_shared_key_len(this.ctxPtr,r.ctxPtr)}setupDefaults(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_curve25519_setup_defaults(this.ctxPtr);e.FoundationError.handleStatusCode(r);}generateKey(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var r=t._vscf_error_ctx_size();let n;r=t._malloc(r),t._vscf_error_reset(r);try{n=t._vscf_curve25519_generate_key(this.ctxPtr,r);const _=t._vscf_error_status(r);return e.FoundationError.handleStatusCode(_),e.FoundationInterface.newAndTakeCContext(n)}finally{t._free(r);}}}return r},lt=t=>{class e{constructor(e){this.name="SimpleAlgInfo",this.ctxPtr=void 0===e?t._vscf_simple_alg_info_new():e;}static newAndUseCContext(r){return new e(t._vscf_simple_alg_info_shallow_copy(r))}static newAndTakeCContext(t){return new e(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_simple_alg_info_delete(this.ctxPtr),this.ctxPtr=null);}static newWithAlgId(r){return a$1.ensureNumber("algId",r),r=t._vscf_simple_alg_info_new_with_alg_id(r),e.newAndTakeCContext(r)}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_simple_alg_info_alg_id(this.ctxPtr)}}return e},ut=(t,e)=>{class r{constructor(e){this.name="HashBasedAlgInfo",this.ctxPtr=void 0===e?t._vscf_hash_based_alg_info_new():e;}static newAndUseCContext(e){return new r(t._vscf_hash_based_alg_info_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_hash_based_alg_info_delete(this.ctxPtr),this.ctxPtr=null);}static newWithMembers(n,_){return a$1.ensureNumber("algId",n),a$1.ensureImplementInterface("hashAlgInfo",_,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),n=t._vscf_hash_based_alg_info_new_with_members(n,_.ctxPtr),r.newAndTakeCContext(n)}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_hash_based_alg_info_alg_id(this.ctxPtr)}hashAlgInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_hash_based_alg_info_hash_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}}return r},ot=t=>{class e{constructor(e){this.name="CipherAlgInfo",this.ctxPtr=void 0===e?t._vscf_cipher_alg_info_new():e;}static newAndUseCContext(r){return new e(t._vscf_cipher_alg_info_shallow_copy(r))}static newAndTakeCContext(t){return new e(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_cipher_alg_info_delete(this.ctxPtr),this.ctxPtr=null);}static newWithMembers(r,n){a$1.ensureNumber("algId",r),a$1.ensureByteArray("nonce",n);const _=n.length*n.BYTES_PER_ELEMENT,s=t._malloc(_);let c;t.HEAP8.set(n,s),n=t._vsc_data_ctx_size(),n=t._malloc(n),t._vsc_data(n,s,_);try{return c=t._vscf_cipher_alg_info_new_with_members(r,n),e.newAndTakeCContext(c)}finally{t._free(s),t._free(n);}}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_cipher_alg_info_alg_id(this.ctxPtr)}nonce(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var e=t._vsc_data_ctx_size();e=t._malloc(e);try{t._vscf_cipher_alg_info_nonce(e,this.ctxPtr);const r=t._vsc_data_len(e),n=t._vsc_data_bytes(e);return t.HEAPU8.slice(n,n+r)}finally{t._free(e);}}}return e},ft=(t,e)=>{class r{constructor(e){this.name="SaltedKdfAlgInfo",this.ctxPtr=void 0===e?t._vscf_salted_kdf_alg_info_new():e;}static newAndUseCContext(e){return new r(t._vscf_salted_kdf_alg_info_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_salted_kdf_alg_info_delete(this.ctxPtr),this.ctxPtr=null);}static newWithMembers(n,_,s,c){a$1.ensureNumber("algId",n),a$1.ensureImplementInterface("hashAlgInfo",_,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),a$1.ensureByteArray("salt",s),a$1.ensureNumber("iterationCount",c);const i=s.length*s.BYTES_PER_ELEMENT,l=t._malloc(i);let u;t.HEAP8.set(s,l),s=t._vsc_data_ctx_size(),s=t._malloc(s),t._vsc_data(s,l,i);try{return u=t._vscf_salted_kdf_alg_info_new_with_members(n,_.ctxPtr,s,c),r.newAndTakeCContext(u)}finally{t._free(l),t._free(s);}}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_salted_kdf_alg_info_alg_id(this.ctxPtr)}hashAlgInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_salted_kdf_alg_info_hash_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}salt(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var e=t._vsc_data_ctx_size();e=t._malloc(e);try{t._vscf_salted_kdf_alg_info_salt(e,this.ctxPtr);const r=t._vsc_data_len(e),n=t._vsc_data_bytes(e);return t.HEAPU8.slice(n,n+r)}finally{t._free(e);}}iterationCount(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_salted_kdf_alg_info_iteration_count(this.ctxPtr)}}return r},pt=(t,e)=>{class r{constructor(e){this.name="PbeAlgInfo",this.ctxPtr=void 0===e?t._vscf_pbe_alg_info_new():e;}static newAndUseCContext(e){return new r(t._vscf_pbe_alg_info_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_pbe_alg_info_delete(this.ctxPtr),this.ctxPtr=null);}static newWithMembers(n,_,s){return a$1.ensureNumber("algId",n),a$1.ensureImplementInterface("kdfAlgInfo",_,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),a$1.ensureImplementInterface("cipherAlgInfo",s,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),n=t._vscf_pbe_alg_info_new_with_members(n,_.ctxPtr,s.ctxPtr),r.newAndTakeCContext(n)}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_pbe_alg_info_alg_id(this.ctxPtr)}kdfAlgInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_pbe_alg_info_kdf_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}cipherAlgInfo(){let r;return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_pbe_alg_info_cipher_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}}return r},dt=t=>{class e{constructor(e){this.name="EccAlgInfo",this.ctxPtr=void 0===e?t._vscf_ecc_alg_info_new():e;}static newAndUseCContext(r){return new e(t._vscf_ecc_alg_info_shallow_copy(r))}static newAndTakeCContext(t){return new e(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_ecc_alg_info_delete(this.ctxPtr),this.ctxPtr=null);}static newWithMembers(r,n,_){return a$1.ensureNumber("algId",r),a$1.ensureNumber("keyId",n),a$1.ensureNumber("domainId",_),r=t._vscf_ecc_alg_info_new_with_members(r,n,_),e.newAndTakeCContext(r)}algId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecc_alg_info_alg_id(this.ctxPtr)}keyId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecc_alg_info_key_id(this.ctxPtr)}domainId(){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecc_alg_info_domain_id(this.ctxPtr)}}return e},ht=(t,e)=>{class r{constructor(e){this.name="AlgInfoDerSerializer",this.ctxPtr=void 0===e?t._vscf_alg_info_der_serializer_new():e;}static newAndUseCContext(e){return new r(t._vscf_alg_info_der_serializer_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_alg_info_der_serializer_delete(this.ctxPtr),this.ctxPtr=null);}set asn1Writer(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("asn1Writer",r,"Foundation.Asn1Writer",e.FoundationInterfaceTag.ASN1_WRITER,e.FoundationInterface),t._vscf_alg_info_der_serializer_release_asn1_writer(this.ctxPtr),t._vscf_alg_info_der_serializer_use_asn1_writer(this.ctxPtr,r.ctxPtr);}serializedLen(r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),t._vscf_alg_info_der_serializer_serialized_len(this.ctxPtr,r.ctxPtr)}serialize(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface);var n=this.serializedLen(r);n=t._vsc_buffer_new_with_capacity(n);try{t._vscf_alg_info_der_serializer_serialize(this.ctxPtr,r.ctxPtr,n);const e=t._vsc_buffer_bytes(n),_=t._vsc_buffer_len(n);return t.HEAPU8.slice(e,e+_)}finally{t._vsc_buffer_delete(n);}}setupDefaults(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_alg_info_der_serializer_setup_defaults(this.ctxPtr);}serializeInplace(r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),t._vscf_alg_info_der_serializer_serialize_inplace(this.ctxPtr,r.ctxPtr)}}return r},vt=(t,e)=>{class r{constructor(e){this.name="AlgInfoDerDeserializer",this.ctxPtr=void 0===e?t._vscf_alg_info_der_deserializer_new():e;}static newAndUseCContext(e){return new r(t._vscf_alg_info_der_deserializer_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_alg_info_der_deserializer_delete(this.ctxPtr),this.ctxPtr=null);}set asn1Reader(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("asn1Reader",r,"Foundation.Asn1Reader",e.FoundationInterfaceTag.ASN1_READER,e.FoundationInterface),t._vscf_alg_info_der_deserializer_release_asn1_reader(this.ctxPtr),t._vscf_alg_info_der_deserializer_use_asn1_reader(this.ctxPtr,r.ctxPtr);}deserialize(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",r);var n=r.length*r.BYTES_PER_ELEMENT;const _=t._malloc(n);let s;t.HEAP8.set(r,_),r=t._vsc_data_ctx_size(),r=t._malloc(r),t._vsc_data(r,_,n),n=t._vscf_error_ctx_size(),n=t._malloc(n),t._vscf_error_reset(n);try{s=t._vscf_alg_info_der_deserializer_deserialize(this.ctxPtr,r,n);const _=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(_),e.FoundationInterface.newAndTakeCContext(s)}finally{t._free(_),t._free(r),t._free(n);}}setupDefaults(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_alg_info_der_deserializer_setup_defaults(this.ctxPtr);}deserializeInplace(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr);var r=t._vscf_error_ctx_size();let n;r=t._malloc(r),t._vscf_error_reset(r);try{n=t._vscf_alg_info_der_deserializer_deserialize_inplace(this.ctxPtr,r);const _=t._vscf_error_status(r);return e.FoundationError.handleStatusCode(_),e.FoundationInterface.newAndTakeCContext(n)}finally{t._free(r);}}}return r},yt=(t,e)=>{class r{static get PREFIX_LEN(){return 32}get PREFIX_LEN(){return r.PREFIX_LEN}constructor(e){this.name="MessageInfoDerSerializer",this.ctxPtr=void 0===e?t._vscf_message_info_der_serializer_new():e;}static newAndUseCContext(e){return new r(t._vscf_message_info_der_serializer_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_message_info_der_serializer_delete(this.ctxPtr),this.ctxPtr=null);}set asn1Reader(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("asn1Reader",r,"Foundation.Asn1Reader",e.FoundationInterfaceTag.ASN1_READER,e.FoundationInterface),t._vscf_message_info_der_serializer_release_asn1_reader(this.ctxPtr),t._vscf_message_info_der_serializer_use_asn1_reader(this.ctxPtr,r.ctxPtr);}set asn1Writer(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureImplementInterface("asn1Writer",r,"Foundation.Asn1Writer",e.FoundationInterfaceTag.ASN1_WRITER,e.FoundationInterface),t._vscf_message_info_der_serializer_release_asn1_writer(this.ctxPtr),t._vscf_message_info_der_serializer_use_asn1_writer(this.ctxPtr,r.ctxPtr);}serializedLen(r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("messageInfo",r,e.MessageInfo),t._vscf_message_info_der_serializer_serialized_len(this.ctxPtr,r.ctxPtr)}serialize(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("messageInfo",r,e.MessageInfo);var n=this.serializedLen(r);n=t._vsc_buffer_new_with_capacity(n);try{t._vscf_message_info_der_serializer_serialize(this.ctxPtr,r.ctxPtr,n);const e=t._vsc_buffer_bytes(n),_=t._vsc_buffer_len(n);return t.HEAPU8.slice(e,e+_)}finally{t._vsc_buffer_delete(n);}}readPrefix(e){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);let _;t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{return _=t._vscf_message_info_der_serializer_read_prefix(this.ctxPtr,e)}finally{t._free(n),t._free(e);}}deserialize(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",r);var n=r.length*r.BYTES_PER_ELEMENT;const _=t._malloc(n);let s;t.HEAP8.set(r,_),r=t._vsc_data_ctx_size(),r=t._malloc(r),t._vsc_data(r,_,n),n=t._vscf_error_ctx_size(),n=t._malloc(n),t._vscf_error_reset(n);try{s=t._vscf_message_info_der_serializer_deserialize(this.ctxPtr,r,n);const _=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(_),e.MessageInfo.newAndTakeCContext(s)}finally{t._free(_),t._free(r),t._free(n);}}serializedFooterLen(r){return a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("messageInfoFooter",r,e.MessageInfoFooter),t._vscf_message_info_der_serializer_serialized_footer_len(this.ctxPtr,r.ctxPtr)}serializeFooter(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureClass("messageInfoFooter",r,e.MessageInfoFooter);var n=this.serializedFooterLen(r);n=t._vsc_buffer_new_with_capacity(n);try{t._vscf_message_info_der_serializer_serialize_footer(this.ctxPtr,r.ctxPtr,n);const e=t._vsc_buffer_bytes(n),_=t._vsc_buffer_len(n);return t.HEAPU8.slice(e,e+_)}finally{t._vsc_buffer_delete(n);}}deserializeFooter(r){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),a$1.ensureByteArray("data",r);var n=r.length*r.BYTES_PER_ELEMENT;const _=t._malloc(n);let s;t.HEAP8.set(r,_),r=t._vsc_data_ctx_size(),r=t._malloc(r),t._vsc_data(r,_,n),n=t._vscf_error_ctx_size(),n=t._malloc(n),t._vscf_error_reset(n);try{s=t._vscf_message_info_der_serializer_deserialize_footer(this.ctxPtr,r,n);const _=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(_),e.MessageInfoFooter.newAndTakeCContext(s)}finally{t._free(_),t._free(r),t._free(n);}}setupDefaults(){a$1.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_message_info_der_serializer_setup_defaults(this.ctxPtr);}}return r};var initFoundation = ()=>{const e=new t;return new Promise((t,r)=>{e.onRuntimeInitialized=()=>{const r={};r.FoundationInterfaceTag=Object.freeze({ALG:1,ALG_INFO:2,ALG_INFO_DESERIALIZER:3,ALG_INFO_SERIALIZER:4,ASN1_READER:5,ASN1_WRITER:6,AUTH_DECRYPT:7,AUTH_ENCRYPT:8,CIPHER:9,CIPHER_AUTH:10,CIPHER_AUTH_INFO:11,CIPHER_INFO:12,COMPUTE_SHARED_KEY:13,DECRYPT:14,ENCRYPT:15,ENTROPY_SOURCE:16,HASH:17,KDF:18,KEY:19,KEY_ALG:20,KEY_CIPHER:21,KEY_DESERIALIZER:22,KEY_SERIALIZER:23,KEY_SIGNER:24,MAC:25,MESSAGE_INFO_FOOTER_SERIALIZER:26,MESSAGE_INFO_SERIALIZER:27,PRIVATE_KEY:28,PUBLIC_KEY:29,RANDOM:30,SALTED_KDF:31}),r.FoundationInterface=((t,e)=>{return class{static newAndTakeCContext(r){const n=t._vscf_impl_tag(r);switch(n){case e.FoundationImplTag.SHA224:return e.Sha224.newAndTakeCContext(r);case e.FoundationImplTag.SHA256:return e.Sha256.newAndTakeCContext(r);case e.FoundationImplTag.SHA384:return e.Sha384.newAndTakeCContext(r);case e.FoundationImplTag.SHA512:return e.Sha512.newAndTakeCContext(r);case e.FoundationImplTag.AES256_GCM:return e.Aes256Gcm.newAndTakeCContext(r);case e.FoundationImplTag.AES256_CBC:return e.Aes256Cbc.newAndTakeCContext(r);case e.FoundationImplTag.ASN1RD:return e.Asn1rd.newAndTakeCContext(r);case e.FoundationImplTag.ASN1WR:return e.Asn1wr.newAndTakeCContext(r);case e.FoundationImplTag.RSA_PUBLIC_KEY:return e.RsaPublicKey.newAndTakeCContext(r);case e.FoundationImplTag.RSA_PRIVATE_KEY:return e.RsaPrivateKey.newAndTakeCContext(r);case e.FoundationImplTag.RSA:return e.Rsa.newAndTakeCContext(r);case e.FoundationImplTag.ECC_PUBLIC_KEY:return e.EccPublicKey.newAndTakeCContext(r);case e.FoundationImplTag.ECC_PRIVATE_KEY:return e.EccPrivateKey.newAndTakeCContext(r);case e.FoundationImplTag.ECC:return e.Ecc.newAndTakeCContext(r);case e.FoundationImplTag.ENTROPY_ACCUMULATOR:return e.EntropyAccumulator.newAndTakeCContext(r);case e.FoundationImplTag.CTR_DRBG:return e.CtrDrbg.newAndTakeCContext(r);case e.FoundationImplTag.HMAC:return e.Hmac.newAndTakeCContext(r);case e.FoundationImplTag.HKDF:return e.Hkdf.newAndTakeCContext(r);case e.FoundationImplTag.KDF1:return e.Kdf1.newAndTakeCContext(r);case e.FoundationImplTag.KDF2:return e.Kdf2.newAndTakeCContext(r);case e.FoundationImplTag.FAKE_RANDOM:return e.FakeRandom.newAndTakeCContext(r);case e.FoundationImplTag.PKCS5_PBKDF2:return e.Pkcs5Pbkdf2.newAndTakeCContext(r);case e.FoundationImplTag.PKCS5_PBES2:return e.Pkcs5Pbes2.newAndTakeCContext(r);case e.FoundationImplTag.SEED_ENTROPY_SOURCE:return e.SeedEntropySource.newAndTakeCContext(r);case e.FoundationImplTag.KEY_MATERIAL_RNG:return e.KeyMaterialRng.newAndTakeCContext(r);case e.FoundationImplTag.RAW_PUBLIC_KEY:return e.RawPublicKey.newAndTakeCContext(r);case e.FoundationImplTag.RAW_PRIVATE_KEY:return e.RawPrivateKey.newAndTakeCContext(r);case e.FoundationImplTag.PKCS8_SERIALIZER:return e.Pkcs8Serializer.newAndTakeCContext(r);case e.FoundationImplTag.SEC1_SERIALIZER:return e.Sec1Serializer.newAndTakeCContext(r);case e.FoundationImplTag.KEY_ASN1_SERIALIZER:return e.KeyAsn1Serializer.newAndTakeCContext(r);case e.FoundationImplTag.KEY_ASN1_DESERIALIZER:return e.KeyAsn1Deserializer.newAndTakeCContext(r);case e.FoundationImplTag.ED25519:return e.Ed25519.newAndTakeCContext(r);case e.FoundationImplTag.CURVE25519:return e.Curve25519.newAndTakeCContext(r);case e.FoundationImplTag.SIMPLE_ALG_INFO:return e.SimpleAlgInfo.newAndTakeCContext(r);case e.FoundationImplTag.HASH_BASED_ALG_INFO:return e.HashBasedAlgInfo.newAndTakeCContext(r);case e.FoundationImplTag.CIPHER_ALG_INFO:return e.CipherAlgInfo.newAndTakeCContext(r);case e.FoundationImplTag.SALTED_KDF_ALG_INFO:return e.SaltedKdfAlgInfo.newAndTakeCContext(r);case e.FoundationImplTag.PBE_ALG_INFO:return e.PbeAlgInfo.newAndTakeCContext(r);case e.FoundationImplTag.ECC_ALG_INFO:return e.EccAlgInfo.newAndTakeCContext(r);case e.FoundationImplTag.ALG_INFO_DER_SERIALIZER:return e.AlgInfoDerSerializer.newAndTakeCContext(r);case e.FoundationImplTag.ALG_INFO_DER_DESERIALIZER:return e.AlgInfoDerDeserializer.newAndTakeCContext(r);case e.FoundationImplTag.MESSAGE_INFO_DER_SERIALIZER:return e.MessageInfoDerSerializer.newAndTakeCContext(r);default:throw Error("Unexpected implementation tag found: "+n)}}static newAndUseCContext(r){return new e.FoundationInterface.newAndTakeCContext(t._vscf_impl_shallow_copy(r))}static isImplemented(e,r){return 0!=t._vscf_impl_api(e,r)}}})(e,r),r.FoundationImplTag=Object.freeze({AES256_CBC:1,AES256_GCM:2,ALG_INFO_DER_DESERIALIZER:3,ALG_INFO_DER_SERIALIZER:4,ASN1RD:5,ASN1WR:6,CIPHER_ALG_INFO:7,CTR_DRBG:8,CURVE25519:9,ECC:10,ECC_ALG_INFO:11,ECC_PRIVATE_KEY:12,ECC_PUBLIC_KEY:13,ED25519:14,ENTROPY_ACCUMULATOR:15,FAKE_RANDOM:16,HASH_BASED_ALG_INFO:17,HKDF:18,HMAC:19,KDF1:20,KDF2:21,KEY_ASN1_DESERIALIZER:22,KEY_ASN1_SERIALIZER:23,KEY_MATERIAL_RNG:24,MESSAGE_INFO_DER_SERIALIZER:25,PBE_ALG_INFO:26,PKCS5_PBES2:27,PKCS5_PBKDF2:28,PKCS8_SERIALIZER:29,RAW_PRIVATE_KEY:30,RAW_PUBLIC_KEY:31,RSA:32,RSA_PRIVATE_KEY:33,RSA_PUBLIC_KEY:34,SALTED_KDF_ALG_INFO:35,SEC1_SERIALIZER:36,SEED_ENTROPY_SOURCE:37,SHA224:38,SHA256:39,SHA384:40,SHA512:41,SIMPLE_ALG_INFO:42}),r.FoundationError=_(),r.Asn1Tag=Object.freeze({BOOLEAN:0,INTEGER:1,BIT_STRING:2,OCTET_STRING:3,NULL:4,OID:5,UTF8_STRING:6,SEQUENCE:7,SET:8,PRINTABLE_STRING:9,T61_STRING:10,IA5_STRING:11,UTC_TIME:12,GENERALIZED_TIME:13,UNIVERSAL_STRING:14,BMP_STRING:15,PRIMITIVE:16,CONSTRUCTED:17,CONTEXT_SPECIFIC:18}),r.AlgId=Object.freeze({NONE:0,SHA224:1,SHA256:2,SHA384:3,SHA512:4,KDF1:5,KDF2:6,RSA:7,ECC:8,ED25519:9,CURVE25519:10,SECP256R1:11,AES256_GCM:12,AES256_CBC:13,HMAC:14,HKDF:15,PKCS5_PBKDF2:16,PKCS5_PBES2:17}),r.OidId=Object.freeze({NONE:0,RSA:1,ED25519:2,CURVE25519:3,SHA224:4,SHA256:5,SHA384:6,SHA512:7,KDF1:8,KDF2:9,AES256_GCM:10,AES256_CBC:11,PKCS5_PBKDF2:12,PKCS5_PBES2:13,CMS_DATA:14,CMS_ENVELOPED_DATA:15,HKDF_WITH_SHA256:16,HKDF_WITH_SHA384:17,HKDF_WITH_SHA512:18,HMAC_WITH_SHA224:19,HMAC_WITH_SHA256:20,HMAC_WITH_SHA384:21,HMAC_WITH_SHA512:22,EC_GENERIC_KEY:23,EC_DOMAIN_SECP256R1:24}),r.GroupMsgType=Object.freeze({GROUP_INFO:0,REGULAR:1}),r.Oid=(t=>{return class{static fromAlgId(e){a$1.ensureNumber("algId",e);var r=t._vsc_data_ctx_size();r=t._malloc(r);try{t._vscf_oid_from_alg_id(r,e);const n=t._vsc_data_len(r),_=t._vsc_data_bytes(r);return t.HEAPU8.slice(_,_+n)}finally{t._free(r);}}static toAlgId(e){a$1.ensureByteArray("oid",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);let _;t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{return _=t._vscf_oid_to_alg_id(e)}finally{t._free(n),t._free(e);}}static fromId(e){a$1.ensureNumber("oidId",e);var r=t._vsc_data_ctx_size();r=t._malloc(r);try{t._vscf_oid_from_id(r,e);const n=t._vsc_data_len(r),_=t._vsc_data_bytes(r);return t.HEAPU8.slice(_,_+n)}finally{t._free(r);}}static toId(e){a$1.ensureByteArray("oid",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);let _;t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r);try{return _=t._vscf_oid_to_id(e)}finally{t._free(n),t._free(e);}}static idToAlgId(e){return a$1.ensureNumber("oidId",e),t._vscf_oid_id_to_alg_id(e)}static equal(e,r){a$1.ensureByteArray("lhs",e),a$1.ensureByteArray("rhs",r);var n=e.length*e.BYTES_PER_ELEMENT;const _=t._malloc(n);t.HEAP8.set(e,_),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,_,n),n=r.length*r.BYTES_PER_ELEMENT;const s=t._malloc(n);let c;t.HEAP8.set(r,s),r=t._vsc_data_ctx_size(),r=t._malloc(r),t._vsc_data(r,s,n);try{return !!(c=t._vscf_oid_equal(e,r))}finally{t._free(_),t._free(e),t._free(s),t._free(r);}}}})(e),r.Base64=((t,e)=>{class r{static encodedLen(e){return a$1.ensureNumber("dataLen",e),t._vscf_base64_encoded_len(e)}static encode(e){a$1.ensureByteArray("data",e);const n=e.length*e.BYTES_PER_ELEMENT,_=t._malloc(n);t.HEAP8.set(e,_);var s=t._vsc_data_ctx_size();s=t._malloc(s),t._vsc_data(s,_,n),e=r.encodedLen(e.length),e=t._vsc_buffer_new_with_capacity(e);try{t._vscf_base64_encode(s,e);const r=t._vsc_buffer_bytes(e),n=t._vsc_buffer_len(e);return t.HEAPU8.slice(r,r+n)}finally{t._free(n),t._free(s),t._vsc_buffer_delete(e);}}static decodedLen(e){return a$1.ensureNumber("strLen",e),t._vscf_base64_decoded_len(e)}static decode(n){a$1.ensureByteArray("str",n);const _=n.length*n.BYTES_PER_ELEMENT,s=t._malloc(_);t.HEAP8.set(n,s);var c=t._vsc_data_ctx_size();c=t._malloc(c),t._vsc_data(c,s,_),n=r.decodedLen(n.length),n=t._vsc_buffer_new_with_capacity(n);try{const r=t._vscf_base64_decode(c,n);e.FoundationError.handleStatusCode(r);const _=t._vsc_buffer_bytes(n),s=t._vsc_buffer_len(n);return t.HEAPU8.slice(_,_+s)}finally{t._free(_),t._free(c),t._vsc_buffer_delete(n);}}}return r})(e,r),r.Pem=((t,e)=>{class r{static wrappedLen(e,r){return a$1.ensureNumber("title",e),a$1.ensureNumber("dataLen",r),t._vscf_pem_wrapped_len(e,r)}static wrap(e,n){a$1.ensureNumber("title",e),a$1.ensureByteArray("data",n);const _=n.length*n.BYTES_PER_ELEMENT,s=t._malloc(_);t.HEAP8.set(n,s);var c=t._vsc_data_ctx_size();c=t._malloc(c),t._vsc_data(c,s,_),n=r.wrappedLen(e,n.length),n=t._vsc_buffer_new_with_capacity(n);try{t._vscf_pem_wrap(e,c,n);const r=t._vsc_buffer_bytes(n),_=t._vsc_buffer_len(n);return t.HEAPU8.slice(r,r+_)}finally{t._free(s),t._free(c),t._vsc_buffer_delete(n);}}static unwrappedLen(e){return a$1.ensureNumber("pemLen",e),t._vscf_pem_unwrapped_len(e)}static unwrap(n){a$1.ensureByteArray("pem",n);const _=n.length*n.BYTES_PER_ELEMENT,s=t._malloc(_);t.HEAP8.set(n,s);var c=t._vsc_data_ctx_size();c=t._malloc(c),t._vsc_data(c,s,_),n=r.unwrappedLen(n.length),n=t._vsc_buffer_new_with_capacity(n);try{const r=t._vscf_pem_unwrap(c,n);e.FoundationError.handleStatusCode(r);const _=t._vsc_buffer_bytes(n),s=t._vsc_buffer_len(n);return t.HEAPU8.slice(_,_+s)}finally{t._free(_),t._free(c),t._vsc_buffer_delete(n);}}static title(e){a$1.ensureByteArray("pem",e);var r=e.length*e.BYTES_PER_ELEMENT;const n=t._malloc(r);t.HEAP8.set(e,n),e=t._vsc_data_ctx_size(),e=t._malloc(e),t._vsc_data(e,n,r),r=t._vsc_data_ctx_size(),r=t._malloc(r);try{t._vscf_pem_title(r,e);const n=t._vsc_data_len(r),_=t._vsc_data_bytes(r);return t.HEAPU8.slice(_,_+n)}finally{t._free(n),t._free(e),t._free(r);}}}return r})(e,r),r.MessageInfo=i(e,r),r.KeyRecipientInfo=l$1(e,r),r.KeyRecipientInfoList=u$1(e,r),r.PasswordRecipientInfo=o$1(e,r),r.PasswordRecipientInfoList=f$1(e,r),r.AlgFactory=((t,e)=>{return class{static createHashFromInfo(r){return a$1.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),r=t._vscf_alg_factory_create_hash_from_info(r.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}static createMacFromInfo(r){return a$1.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),r=t._vscf_alg_factory_create_mac_from_info(r.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}static createKdfFromInfo(r){return a$1.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),r=t._vscf_alg_factory_create_kdf_from_info(r.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}static createSaltedKdfFromInfo(r){return a$1.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),r=t._vscf_alg_factory_create_salted_kdf_from_info(r.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}static createCipherFromInfo(r){return a$1.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),r=t._vscf_alg_factory_create_cipher_from_info(r.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}}})(e,r),r.KeyAlgFactory=((t,e)=>{return class{static createFromAlgId(r,n){a$1.ensureNumber("algId",r),a$1.ensureImplementInterface("random",n,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface);var _=t._vscf_error_ctx_size();let s;_=t._malloc(_),t._vscf_error_reset(_);try{s=t._vscf_key_alg_factory_create_from_alg_id(r,n.ctxPtr,_);const c=t._vscf_error_status(_);return e.FoundationError.handleStatusCode(c),e.FoundationInterface.newAndTakeCContext(s)}finally{t._free(_);}}static createFromKey(r,n){a$1.ensureImplementInterface("key",r,"Foundation.Key",e.FoundationInterfaceTag.KEY,e.FoundationInterface),a$1.ensureImplementInterface("random",n,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface);var _=t._vscf_error_ctx_size();let s;_=t._malloc(_),t._vscf_error_reset(_);try{s=t._vscf_key_alg_factory_create_from_key(r.ctxPtr,n.ctxPtr,_);const c=t._vscf_error_status(_);return e.FoundationError.handleStatusCode(c),e.FoundationInterface.newAndTakeCContext(s)}finally{t._free(_);}}static createFromRawPublicKey(r,n){a$1.ensureClass("publicKey",r,e.RawPublicKey),a$1.ensureImplementInterface("random",n,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface);var _=t._vscf_error_ctx_size();let s;_=t._malloc(_),t._vscf_error_reset(_);try{s=t._vscf_key_alg_factory_create_from_raw_public_key(r.ctxPtr,n.ctxPtr,_);const c=t._vscf_error_status(_);return e.FoundationError.handleStatusCode(c),e.FoundationInterface.newAndTakeCContext(s)}finally{t._free(_);}}static createFromRawPrivateKey(r,n){a$1.ensureClass("privateKey",r,e.RawPrivateKey),a$1.ensureImplementInterface("random",n,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface);var _=t._vscf_error_ctx_size();let s;_=t._malloc(_),t._vscf_error_reset(_);try{s=t._vscf_key_alg_factory_create_from_raw_private_key(r.ctxPtr,n.ctxPtr,_);const c=t._vscf_error_status(_);return e.FoundationError.handleStatusCode(c),e.FoundationInterface.newAndTakeCContext(s)}finally{t._free(_);}}}})(e,r),r.Ecies=p$1(e,r),r.RecipientCipher=d(e,r),r.MessageInfoCustomParams=h(e,r),r.KeyProvider=v$2(e,r),r.Signer=y$1(e,r),r.Verifier=P(e,r),r.BrainkeyClient=x$1(e,r),r.BrainkeyServer=m$1(e,r),r.GroupSessionMessage=g$1(e,r),r.GroupSessionTicket=E(e,r),r.GroupSession=N(e,r),r.MessageInfoEditor=w(e,r),r.SignerInfo=I(e,r),r.SignerInfoList=b(e,r),r.MessageInfoFooter=A(e,r),r.SignedDataInfo=k$1(e,r),r.FooterInfo=C(e,r),r.Sha224=T(e,r),r.Sha256=F(e,r),r.Sha384=S(e,r),r.Sha512=K$1(e,r),r.Aes256Gcm=L(e,r),r.Aes256Cbc=R(e,r),r.Asn1rd=z(e,r),r.Asn1wr=B(e,r),r.RsaPublicKey=Y(e,r),r.RsaPrivateKey=H(e,r),r.Rsa=U(e,r),r.EccPublicKey=M(e,r),r.EccPrivateKey=O(e,r),r.Ecc=D(e,r),r.EntropyAccumulator=G(e,r),r.CtrDrbg=V(e,r),r.Hmac=j(e,r),r.Hkdf=W(e,r),r.Kdf1=Z(e,r),r.Kdf2=X(e,r),r.FakeRandom=$(e,r),r.Pkcs5Pbkdf2=q(e,r),r.Pkcs5Pbes2=J(e,r),r.SeedEntropySource=Q(e,r),r.KeyMaterialRng=tt(e,r),r.RawPublicKey=et(e,r),r.RawPrivateKey=rt(e,r),r.Pkcs8Serializer=nt(e,r),r.Sec1Serializer=_t(e,r),r.KeyAsn1Serializer=st(e,r),r.KeyAsn1Deserializer=ct(e,r),r.Ed25519=at(e,r),r.Curve25519=it(e,r),r.SimpleAlgInfo=lt(e),r.HashBasedAlgInfo=ut(e,r),r.CipherAlgInfo=ot(e),r.SaltedKdfAlgInfo=ft(e,r),r.PbeAlgInfo=pt(e,r),r.EccAlgInfo=dt(e),r.AlgInfoDerSerializer=ht(e,r),r.AlgInfoDerDeserializer=vt(e,r),r.MessageInfoDerSerializer=yt(e,r),t(r);},e.onAbort=t=>{r(Error(t));};})};

            var e$1,t$1,n$2,r$2;n$2=t$1={exports:{}},r$2=function(){var e="undefined"!=typeof document&&document.currentScript?document.currentScript.src:void 0;return function(t){function n(e,t){throw t}function r(e,t,n){var r=t+n;for(n=t;e[n]&&!(n>=r);)++n;if(16<n-t&&e.subarray&&oe)return oe.decode(e.subarray(t,n));for(r="";t<n;){var a=e[t++];if(128&a){var i=63&e[t++];if(192==(224&a))r+=String.fromCharCode((31&a)<<6|i);else{var o=63&e[t++];65536>(a=224==(240&a)?(15&a)<<12|i<<6|o:(7&a)<<18|i<<12|o<<6|63&e[t++])?r+=String.fromCharCode(a):(a-=65536,r+=String.fromCharCode(55296|a>>10,56320|1023&a));}}else r+=String.fromCharCode(a);}return r}function a(e){return 0<e%65536&&(e+=65536-e%65536),e}function i(e){se=e,K.HEAP8=ue=new Int8Array(e),K.HEAP16=ce=new Int16Array(e),K.HEAP32=le=new Int32Array(e),K.HEAPU8=fe=new Uint8Array(e),K.HEAPU16=new Uint16Array(e),K.HEAPU32=new Uint32Array(e),K.HEAPF32=new Float32Array(e),K.HEAPF64=new Float64Array(e);}function o(e){for(;0<e.length;){var t=e.shift();if("function"==typeof t)t();else{var n=t.Jb;"number"==typeof n?void 0===t.gb?K.dynCall_v(n):K.dynCall_vi(n,t.gb):n(void 0===t.gb?null:t.gb);}}}function s(){var e=K.preRun.shift();de.unshift(e);}function u(e){throw K.onAbort&&K.onAbort(e),Z(e),G(e),ie=!0,"abort("+e+"). Build with -s ASSERTIONS=1 for more info."}function f(){var e=Ae;return String.prototype.startsWith?e.startsWith("data:application/octet-stream;base64,"):0===e.indexOf("data:application/octet-stream;base64,")}function c(){try{if(J)return new Uint8Array(J);throw "both async and sync fetching of the wasm failed"}catch(e){u(e);}}function l(e,t){for(var n=0,r=e.length-1;0<=r;r--){var a=e[r];"."===a?e.splice(r,1):".."===a?(e.splice(r,1),n++):n&&(e.splice(r,1),n--);}if(t)for(;n;n--)e.unshift("..");return e}function _(e){var t="/"===e.charAt(0),n="/"===e.substr(-1);return (e=l(e.split("/").filter((function(e){return !!e})),!t).join("/"))||t||(e="."),e&&n&&(e+="/"),(t?"/":"")+e}function d(e){var t=/^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/.exec(e).slice(1);return e=t[0],t=t[1],e||t?(t&&(t=t.substr(0,t.length-1)),e+t):"."}function p(e){if("/"===e)return "/";var t=e.lastIndexOf("/");return -1===t?e:e.substr(t+1)}function y(){for(var e="",t=!1,n=arguments.length-1;-1<=n&&!t;n--){if("string"!=typeof(t=0<=n?arguments[n]:"/"))throw new TypeError("Arguments to path.resolve must be strings");if(!t)return "";e=t+"/"+e,t="/"===t.charAt(0);}return (t?"/":"")+(e=l(e.split("/").filter((function(e){return !!e})),!t).join("/"))||"."}function h(e,t){Re[e]={input:[],Qa:[],Ya:t},T(e,Ue);}function v(e,t){if(t=t||{},!(e=y("/",e)))return {path:"",node:null};var n,r={ob:!0,jb:0};for(n in r)void 0===t[n]&&(t[n]=r[n]);if(8<t.jb)throw new $e(32);e=l(e.split("/").filter((function(e){return !!e})),!1);var a=Oe;for(r="/",n=0;n<e.length;n++){var i=n===e.length-1;if(i&&t.parent)break;if(a=w(a,e[n]),r=_(r+"/"+e[n]),a.cb&&(!i||i&&t.ob)&&(a=a.cb.root),!i||t.nb)for(i=0;40960==(61440&a.mode);)if(a=k(r),a=v(r=y(d(r),a),{jb:t.jb}).node,40<i++)throw new $e(32)}return {path:r,node:a}}function m(e){for(var t;;){if(e===e.parent)return e=e.Ta.rb,t?"/"!==e[e.length-1]?e+"/"+t:e+t:e;t=t?e.name+"/"+t:e.name,e=e.parent;}}function b(e,t){for(var n=0,r=0;r<t.length;r++)n=(n<<5)-n+t.charCodeAt(r)|0;return (e+n>>>0)%De.length}function w(e,t){var n;if(n=(n=P(e,"x"))?n:e.Ma.$a?0:2)throw new $e(n,e);for(n=De[b(e.id,t)];n;n=n.Ab){var r=n.name;if(n.parent.id===e.id&&r===t)return n}return e.Ma.$a(e,t)}function E(e,t,n,r){return xe||((xe=function(e,t,n,r){e||(e=this),this.parent=e,this.Ta=e.Ta,this.cb=null,this.id=je++,this.name=t,this.mode=n,this.Ma={},this.Na={},this.eb=r;}).prototype={},Object.defineProperties(xe.prototype,{read:{get:function(){return 365==(365&this.mode)},set:function(e){e?this.mode|=365:this.mode&=-366;}},write:{get:function(){return 146==(146&this.mode)},set:function(e){e?this.mode|=146:this.mode&=-147;}}})),function(e){var t=b(e.parent.id,e.name);e.Ab=De[t],De[t]=e;}(e=new xe(e,t,n,r)),e}function g(e){var t=["r","w","rw"][3&e];return 512&e&&(t+="w"),t}function P(e,t){return We?0:(-1===t.indexOf("r")||292&e.mode)&&(-1===t.indexOf("w")||146&e.mode)&&(-1===t.indexOf("x")||73&e.mode)?0:2}function A(e,t){try{return w(e,t),20}catch(e){}return P(e,"wx")}function L(e,t){Ne||((Ne=function(){}).prototype={},Object.defineProperties(Ne.prototype,{object:{get:function(){return this.node},set:function(e){this.node=e;}}}));var n,r=new Ne;for(n in e)r[n]=e[n];return e=r,t=function(e){for(e=e||0;4096>=e;e++)if(!Ie[e])return e;throw new $e(33)}(t),e.Va=t,Ie[t]=e}function T(e,t){Ye[e]={Na:t};}function M(e,t){var n="/"===t,r=!t;if(n&&Oe)throw new $e(10);if(!n&&!r){var a=v(t,{ob:!1});if(t=a.path,(a=a.node).cb)throw new $e(10);if(16384!=(61440&a.mode))throw new $e(54)}t={type:e,Qb:{},rb:t,zb:[]},(e=e.Ta(t)).Ta=t,t.root=e,n?Oe=e:a&&(a.cb=t,a.Ta&&a.Ta.zb.push(t));}function B(e,t,n){var r=v(e,{parent:!0}).node;if(!(e=p(e))||"."===e||".."===e)throw new $e(28);var a=A(r,e);if(a)throw new $e(a);if(!r.Ma.bb)throw new $e(63);return r.Ma.bb(r,e,t,n)}function S(e){B(e,16895,0);}function x(e,t,n){void 0===n&&(n=t,t=438),B(e,8192|t,n);}function N(e,t){if(!y(e))throw new $e(44);var n=v(t,{parent:!0}).node;if(!n)throw new $e(44);var r=A(n,t=p(t));if(r)throw new $e(r);if(!n.Ma.fb)throw new $e(63);n.Ma.fb(n,t,e);}function k(e){if(!(e=v(e).node))throw new $e(44);if(!e.Ma.ab)throw new $e(28);return y(m(e.parent),e.Ma.ab(e))}function R(e,t,n,r){if(""===e)throw new $e(44);if("string"==typeof t){var a=Ke[t];if(void 0===a)throw Error("Unknown file open mode: "+t);t=a;}if(n=64&t?4095&(void 0===n?438:n)|32768:0,"object"==typeof e)var i=e;else{e=_(e);try{i=v(e,{nb:!(131072&t)}).node;}catch(e){}}if(a=!1,64&t)if(i){if(128&t)throw new $e(20)}else i=B(e,n,0),a=!0;if(!i)throw new $e(44);if(8192==(61440&i.mode)&&(t&=-513),65536&t&&16384!=(61440&i.mode))throw new $e(54);if(!a&&(n=i?40960==(61440&i.mode)?32:16384==(61440&i.mode)&&("r"!==g(t)||512&t)?31:P(i,g(t)):44))throw new $e(n);if(512&t){var o;if(!(o="string"==typeof(n=i)?v(n,{nb:!0}).node:n).Ma.Sa)throw new $e(63);if(16384==(61440&o.mode))throw new $e(31);if(32768!=(61440&o.mode))throw new $e(28);if(n=P(o,"w"))throw new $e(n);o.Ma.Sa(o,{size:0,timestamp:Date.now()});}t&=-641,(r=L({node:i,path:m(i),flags:t,seekable:!0,position:0,Na:i.Na,Db:[],error:!1},r)).Na.open&&r.Na.open(r),!K.logReadFiles||1&t||(ke||(ke={}),e in ke||(ke[e]=1,console.log("FS.trackingDelegate error on read file: "+e)));try{Fe.onOpenFile&&(i=0,1!=(2097155&t)&&(i|=1),0!=(2097155&t)&&(i|=2),Fe.onOpenFile(e,i));}catch(t){console.log("FS.trackingDelegate['onOpenFile']('"+e+"', flags) threw an exception: "+t.message);}return r}function U(e,t,n){if(null===e.Va)throw new $e(8);if(!e.seekable||!e.Na.Xa)throw new $e(70);if(0!=n&&1!=n&&2!=n)throw new $e(28);e.position=e.Na.Xa(e,t,n),e.Db=[];}function C(e,t,n,r){var a=ue;if(0>n||0>r)throw new $e(28);if(null===e.Va)throw new $e(8);if(1==(2097155&e.flags))throw new $e(8);if(16384==(61440&e.node.mode))throw new $e(31);if(!e.Na.read)throw new $e(28);var i=void 0!==r;if(i){if(!e.seekable)throw new $e(70)}else r=e.position;return t=e.Na.read(e,a,t,n,r),i||(e.position+=t),t}function H(){$e||(($e=function(e,t){this.node=t,this.Cb=function(e){this.Ua=e;},this.Cb(e),this.message="FS error";}).prototype=Error(),$e.prototype.constructor=$e,[44].forEach((function(e){Ve[e]=new $e(e),Ve[e].stack="<generic error, no stack>";})));}function z(e,t,n){e=_("/dev/"+e);var r=function(e,t){var n=0;return e&&(n|=365),t&&(n|=146),n}(!!t,!!n);Se||(Se=64);var a=Se++<<8|0;T(a,{open:function(e){e.seekable=!1;},close:function(){n&&n.buffer&&n.buffer.length&&n(10);},read:function(e,n,r,a){for(var i=0,o=0;o<a;o++){try{var s=t();}catch(e){throw new $e(29)}if(void 0===s&&0===i)throw new $e(6);if(null==s)break;i++,n[r+o]=s;}return i&&(e.node.timestamp=Date.now()),i},write:function(e,t,r,a){for(var i=0;i<a;i++)try{n(t[r+i]);}catch(e){throw new $e(29)}return a&&(e.node.timestamp=Date.now()),i}}),x(e,r,a);}function O(){return le[(qe+=4)-4>>2]}function Y(e){if(e||(e=O()),!(e=Ie[e]))throw new $e(8);return e}function I(e){try{var t=Y(e);if(null===t.Va)throw new $e(8);t.hb&&(t.hb=null);try{t.Na.close&&t.Na.close(t);}catch(e){throw e}finally{Ie[t.Va]=null;}return t.Va=null,0}catch(e){return void 0!==Xe&&e instanceof $e||u(e),e.Ua}}function j(e,t,n,r){try{e:{for(var a=Y(e),i=e=0;i<n;i++){var o=a,s=le[t+8*i>>2],f=le[t+(8*i+4)>>2],c=void 0,l=ue;if(0>f||0>c)throw new $e(28);if(null===o.Va)throw new $e(8);if(0==(2097155&o.flags))throw new $e(8);if(16384==(61440&o.node.mode))throw new $e(31);if(!o.Na.write)throw new $e(28);1024&o.flags&&U(o,0,2);var _=void 0!==c;if(_){if(!o.seekable)throw new $e(70)}else c=o.position;var d=o.Na.write(o,l,s,f,c,void 0);_||(o.position+=d);try{o.path&&Fe.onWriteToFile&&Fe.onWriteToFile(o.path);}catch(e){console.log("FS.trackingDelegate['onWriteToFile']('"+o.path+"') threw an exception: "+e.message);}if(0>(o=d)){var p=-1;break e}e+=o;}p=e;}return le[r>>2]=p,0}catch(e){return void 0!==Xe&&e instanceof $e||u(e),e.Ua}}function D(){return ue.length}function W(e,t){throw et(e,t||1),"longjmp"}function F(){return F.Za||(F.Za=[]),F.Za.push(rt()),F.Za.length-1}function $(e){this.name="ExitStatus",this.message="Program terminated with exit("+e+")",this.status=e;}function V(){function e(){if(!tt&&(tt=!0,!ie)){if(K.noFSInit||Be||(Be=!0,H(),K.stdin=K.stdin,K.stdout=K.stdout,K.stderr=K.stderr,K.stdin?z("stdin",K.stdin):N("/dev/tty","/dev/stdin"),K.stdout?z("stdout",null,K.stdout):N("/dev/tty","/dev/stdout"),K.stderr?z("stderr",null,K.stderr):N("/dev/tty1","/dev/stderr"),R("/dev/stdin","r"),R("/dev/stdout","w"),R("/dev/stderr","w")),o(pe),We=!1,o(ye),K.onRuntimeInitialized&&K.onRuntimeInitialized(),K.postRun)for("function"==typeof K.postRun&&(K.postRun=[K.postRun]);K.postRun.length;){var e=K.postRun.shift();he.unshift(e);}o(he);}}if(!(0<Ee)){if(K.preRun)for("function"==typeof K.preRun&&(K.preRun=[K.preRun]);K.preRun.length;)s();o(de),0<Ee||(K.setStatus?(K.setStatus("Running..."),setTimeout((function(){setTimeout((function(){K.setStatus("");}),1),e();}),1)):e());}}var K;t=t||{},K||(K=void 0!==t?t:{});var Q,X={};for(Q in K)K.hasOwnProperty(Q)&&(X[Q]=K[Q]);var q="";document.currentScript&&(q=document.currentScript.src),e&&(q=e),q=0!==q.indexOf("blob:")?q.substr(0,q.lastIndexOf("/")+1):"";var Z=K.print||console.log.bind(console),G=K.printErr||console.warn.bind(console);for(Q in X)X.hasOwnProperty(Q)&&(K[Q]=X[Q]);X=null,K.quit&&(n=K.quit);var J,ee,te={"f64-rem":function(e,t){return e%t},debugger:function(){}},ne=0;K.wasmBinary&&(J=K.wasmBinary),K.noExitRuntime&&(ee=K.noExitRuntime),"object"!=typeof WebAssembly&&G("no native wasm support detected");var re,ae=new WebAssembly.Table({initial:462,maximum:462,element:"anyfunc"}),ie=!1,oe="undefined"!=typeof TextDecoder?new TextDecoder("utf8"):void 0;"undefined"!=typeof TextDecoder&&new TextDecoder("utf-16le");var se,ue,fe,ce,le,_e=K.TOTAL_MEMORY||16777216;(re=K.wasmMemory?K.wasmMemory:new WebAssembly.Memory({initial:_e/65536}))&&(se=re.buffer),_e=se.byteLength,i(se),le[15676]=5305792;var de=[],pe=[],ye=[],he=[],ve=Math.abs,me=Math.ceil,be=Math.floor,we=Math.min,Ee=0,Pe=null;K.preloadedImages={},K.preloadedAudios={};var Ae="libpythia.browser.wasm";if(!f()){var Le=Ae;Ae=K.locateFile?K.locateFile(Le,q):q+Le;}K.asm=function(){function e(e){K.asm=e.exports,Ee--,K.monitorRunDependencies&&K.monitorRunDependencies(Ee),0==Ee&&(Pe&&(e=Pe,Pe=null,e()));}function t(t){e(t.instance);}function n(e){return (J||"function"!=typeof fetch?new Promise((function(e){e(c());})):fetch(Ae,{credentials:"same-origin"}).then((function(e){if(!e.ok)throw "failed to load wasm binary file at '"+Ae+"'";return e.arrayBuffer()})).catch((function(){return c()}))).then((function(e){return WebAssembly.instantiate(e,r)})).then(e,(function(e){G("failed to asynchronously prepare wasm: "+e),u(e);}))}var r={env:Ze,wasi_unstable:Ze,global:{NaN:NaN,Infinity:1/0},"global.Math":Math,asm2wasm:te};if(Ee++,K.monitorRunDependencies&&K.monitorRunDependencies(Ee),K.instantiateWasm)try{return K.instantiateWasm(r,e)}catch(e){return G("Module.instantiateWasm callback failed with error: "+e),!1}return function(){if(J||"function"!=typeof WebAssembly.instantiateStreaming||f()||"function"!=typeof fetch)return n(t);fetch(Ae,{credentials:"same-origin"}).then((function(e){return WebAssembly.instantiateStreaming(e,r).then(t,(function(e){G("wasm streaming compile failed: "+e),G("falling back to ArrayBuffer instantiation"),n(t);}))}));}(),{}};var Te,Me,Be,Se,xe,Ne,ke,Re=[],Ue={open:function(e){var t=Re[e.node.eb];if(!t)throw new $e(43);e.Pa=t,e.seekable=!1;},close:function(e){e.Pa.Ya.flush(e.Pa);},flush:function(e){e.Pa.Ya.flush(e.Pa);},read:function(e,t,n,r){if(!e.Pa||!e.Pa.Ya.pb)throw new $e(60);for(var a=0,i=0;i<r;i++){try{var o=e.Pa.Ya.pb(e.Pa);}catch(e){throw new $e(29)}if(void 0===o&&0===a)throw new $e(6);if(null==o)break;a++,t[n+i]=o;}return a&&(e.node.timestamp=Date.now()),a},write:function(e,t,n,r){if(!e.Pa||!e.Pa.Ya.ib)throw new $e(60);try{for(var a=0;a<r;a++)e.Pa.Ya.ib(e.Pa,t[n+a]);}catch(e){throw new $e(29)}return r&&(e.node.timestamp=Date.now()),a}},Ce={pb:function(e){if(!e.input.length){var t=null;if("undefined"!=typeof window&&"function"==typeof window.prompt?null!==(t=window.prompt("Input: "))&&(t+="\n"):"function"==typeof readline&&null!==(t=readline())&&(t+="\n"),!t)return null;for(var n=0,r=0;r<t.length;++r){var a=t.charCodeAt(r);55296<=a&&57343>=a&&(a=65536+((1023&a)<<10)|1023&t.charCodeAt(++r)),127>=a?++n:n=2047>=a?n+2:65535>=a?n+3:n+4;}var i=(n=Array(n+1)).length;if(r=0,0<i){a=r,i=r+i-1;for(var o=0;o<t.length;++o){var s=t.charCodeAt(o);if(55296<=s&&57343>=s&&(s=65536+((1023&s)<<10)|1023&t.charCodeAt(++o)),127>=s){if(r>=i)break;n[r++]=s;}else{if(2047>=s){if(r+1>=i)break;n[r++]=192|s>>6;}else{if(65535>=s){if(r+2>=i)break;n[r++]=224|s>>12;}else{if(r+3>=i)break;n[r++]=240|s>>18,n[r++]=128|s>>12&63;}n[r++]=128|s>>6&63;}n[r++]=128|63&s;}}n[r]=0,t=r-a;}else t=0;n.length=t,e.input=n;}return e.input.shift()},ib:function(e,t){null===t||10===t?(Z(r(e.Qa,0)),e.Qa=[]):0!=t&&e.Qa.push(t);},flush:function(e){e.Qa&&0<e.Qa.length&&(Z(r(e.Qa,0)),e.Qa=[]);}},He={ib:function(e,t){null===t||10===t?(G(r(e.Qa,0)),e.Qa=[]):0!=t&&e.Qa.push(t);},flush:function(e){e.Qa&&0<e.Qa.length&&(G(r(e.Qa,0)),e.Qa=[]);}},ze={Ra:null,Ta:function(){return ze.createNode(null,"/",16895,0)},createNode:function(e,t,n,r){if(24576==(61440&n)||4096==(61440&n))throw new $e(63);return ze.Ra||(ze.Ra={dir:{node:{Wa:ze.Ma.Wa,Sa:ze.Ma.Sa,$a:ze.Ma.$a,bb:ze.Ma.bb,ub:ze.Ma.ub,wb:ze.Ma.wb,vb:ze.Ma.vb,tb:ze.Ma.tb,fb:ze.Ma.fb},stream:{Xa:ze.Na.Xa}},file:{node:{Wa:ze.Ma.Wa,Sa:ze.Ma.Sa},stream:{Xa:ze.Na.Xa,read:ze.Na.read,write:ze.Na.write,kb:ze.Na.kb,qb:ze.Na.qb,sb:ze.Na.sb}},link:{node:{Wa:ze.Ma.Wa,Sa:ze.Ma.Sa,ab:ze.Ma.ab},stream:{}},lb:{node:{Wa:ze.Ma.Wa,Sa:ze.Ma.Sa},stream:Qe}}),16384==(61440&(n=E(e,t,n,r)).mode)?(n.Ma=ze.Ra.dir.node,n.Na=ze.Ra.dir.stream,n.La={}):32768==(61440&n.mode)?(n.Ma=ze.Ra.file.node,n.Na=ze.Ra.file.stream,n.Oa=0,n.La=null):40960==(61440&n.mode)?(n.Ma=ze.Ra.link.node,n.Na=ze.Ra.link.stream):8192==(61440&n.mode)&&(n.Ma=ze.Ra.lb.node,n.Na=ze.Ra.lb.stream),n.timestamp=Date.now(),e&&(e.La[t]=n),n},Kb:function(e){if(e.La&&e.La.subarray){for(var t=[],n=0;n<e.Oa;++n)t.push(e.La[n]);return t}return e.La},Lb:function(e){return e.La?e.La.subarray?e.La.subarray(0,e.Oa):new Uint8Array(e.La):new Uint8Array},mb:function(e,t){var n=e.La?e.La.length:0;n>=t||(t=Math.max(t,n*(1048576>n?2:1.125)|0),0!=n&&(t=Math.max(t,256)),n=e.La,e.La=new Uint8Array(t),0<e.Oa&&e.La.set(n.subarray(0,e.Oa),0));},Bb:function(e,t){if(e.Oa!=t)if(0==t)e.La=null,e.Oa=0;else{if(!e.La||e.La.subarray){var n=e.La;e.La=new Uint8Array(new ArrayBuffer(t)),n&&e.La.set(n.subarray(0,Math.min(t,e.Oa)));}else if(e.La||(e.La=[]),e.La.length>t)e.La.length=t;else for(;e.La.length<t;)e.La.push(0);e.Oa=t;}},Ma:{Wa:function(e){var t={};return t.Ib=8192==(61440&e.mode)?e.id:1,t.Nb=e.id,t.mode=e.mode,t.Pb=1,t.uid=0,t.Mb=0,t.eb=e.eb,16384==(61440&e.mode)?t.size=4096:32768==(61440&e.mode)?t.size=e.Oa:40960==(61440&e.mode)?t.size=e.link.length:t.size=0,t.Fb=new Date(e.timestamp),t.Ob=new Date(e.timestamp),t.Hb=new Date(e.timestamp),t.xb=4096,t.Gb=Math.ceil(t.size/t.xb),t},Sa:function(e,t){void 0!==t.mode&&(e.mode=t.mode),void 0!==t.timestamp&&(e.timestamp=t.timestamp),void 0!==t.size&&ze.Bb(e,t.size);},$a:function(){throw Ve[44]},bb:function(e,t,n,r){return ze.createNode(e,t,n,r)},ub:function(e,t,n){if(16384==(61440&e.mode)){try{var r=w(t,n);}catch(e){}if(r)for(var a in r.La)throw new $e(55)}delete e.parent.La[e.name],e.name=n,t.La[n]=e,e.parent=t;},wb:function(e,t){delete e.La[t];},vb:function(e,t){var n,r=w(e,t);for(n in r.La)throw new $e(55);delete e.La[t];},tb:function(e){var t,n=[".",".."];for(t in e.La)e.La.hasOwnProperty(t)&&n.push(t);return n},fb:function(e,t,n){return (e=ze.createNode(e,t,41471,0)).link=n,e},ab:function(e){if(40960!=(61440&e.mode))throw new $e(28);return e.link}},Na:{read:function(e,t,n,r,a){var i=e.node.La;if(a>=e.node.Oa)return 0;if(8<(e=Math.min(e.node.Oa-a,r))&&i.subarray)t.set(i.subarray(a,a+e),n);else for(r=0;r<e;r++)t[n+r]=i[a+r];return e},write:function(e,t,n,r,a,i){if(i=!1,!r)return 0;if((e=e.node).timestamp=Date.now(),t.subarray&&(!e.La||e.La.subarray)){if(i)return e.La=t.subarray(n,n+r),e.Oa=r;if(0===e.Oa&&0===a)return e.La=new Uint8Array(t.subarray(n,n+r)),e.Oa=r;if(a+r<=e.Oa)return e.La.set(t.subarray(n,n+r),a),r}if(ze.mb(e,a+r),e.La.subarray&&t.subarray)e.La.set(t.subarray(n,n+r),a);else for(i=0;i<r;i++)e.La[a+i]=t[n+i];return e.Oa=Math.max(e.Oa,a+r),r},Xa:function(e,t,n){if(1===n?t+=e.position:2===n&&32768==(61440&e.node.mode)&&(t+=e.node.Oa),0>t)throw new $e(28);return t},kb:function(e,t,n){ze.mb(e.node,t+n),e.node.Oa=Math.max(e.node.Oa,t+n);},qb:function(e,t,n,r,a,i,o){if(32768!=(61440&e.node.mode))throw new $e(43);if(n=e.node.La,2&o||n.buffer!==t&&n.buffer!==t.buffer){if((0<a||a+r<e.node.Oa)&&(n=n.subarray?n.subarray(a,a+r):Array.prototype.slice.call(n,a,a+r)),e=!0,a=t.buffer==ue.buffer,!(r=Je(r)))throw new $e(48);(a?ue:t).set(n,r);}else e=!1,r=n.byteOffset;return {Rb:r,Eb:e}},sb:function(e,t,n,r,a){if(32768!=(61440&e.node.mode))throw new $e(43);return 2&a?0:(ze.Na.write(e,t,0,r,n,!1),0)}}},Oe=null,Ye={},Ie=[],je=1,De=null,We=!0,Fe={},$e=null,Ve={},Ke={r:0,rs:1052672,"r+":2,w:577,wx:705,xw:705,"w+":578,"wx+":706,"xw+":706,a:1089,ax:1217,xa:1217,"a+":1090,"ax+":1218,"xa+":1218},Qe={open:function(e){e.Na=Ye[e.node.eb].Na,e.Na.open&&e.Na.open(e);},Xa:function(){throw new $e(70)}},Xe={},qe=0;H(),De=Array(4096),M(ze,"/"),S("/tmp"),S("/home"),S("/home/web_user"),function(){if(S("/dev"),T(259,{read:function(){return 0},write:function(e,t,n,r){return r}}),x("/dev/null",259),h(1280,Ce),h(1536,He),x("/dev/tty",1280),x("/dev/tty1",1536),"object"==typeof crypto&&"function"==typeof crypto.getRandomValues)var e=new Uint8Array(1),t=function(){return crypto.getRandomValues(e),e[0]};t||(t=function(){u("random_device");}),z("random",t),z("urandom",t),S("/dev/shm"),S("/dev/shm/tmp");}(),S("/proc"),S("/proc/self"),S("/proc/self/fd"),M({Ta:function(){var e=E("/proc/self","fd",16895,73);return e.Ma={$a:function(e,t){var n=Ie[+t];if(!n)throw new $e(8);return (e={parent:null,Ta:{rb:"fake"},Ma:{ab:function(){return n.path}}}).parent=e}},e}},"/proc/self/fd");var Ze={u:function(){},J:function(e,t){qe=t;try{var n=Y(),r=O(),a=O(),i=O(),o=O();return -9007199254740992>=(e=4294967296*r+(a>>>0))||9007199254740992<=e?-61:(U(n,e,o),Me=[n.position>>>0,(Te=n.position,1<=+ve(Te)?0<Te?(0|we(+be(Te/4294967296),4294967295))>>>0:~~+me((Te-+(~~Te>>>0))/4294967296)>>>0:0)],le[i>>2]=Me[0],le[i+4>>2]=Me[1],n.hb&&0===e&&0===o&&(n.hb=null),0)}catch(e){return void 0!==Xe&&e instanceof $e||u(e),-e.Ua}},I:function(e,t){qe=t;try{var n=Y(),r=O();e:{var a=O();for(t=e=0;t<a;t++){var i=le[r+(8*t+4)>>2],o=C(n,le[r+8*t>>2],i,void 0);if(0>o){var s=-1;break e}if(e+=o,o<i)break}s=e;}return s}catch(e){return void 0!==Xe&&e instanceof $e||u(e),-e.Ua}},x:function(e,t){qe=t;try{var n=Y();switch(O()){case 0:var r=O();return 0>r?-28:R(n.path,n.flags,0,r).Va;case 1:case 2:return 0;case 3:return n.flags;case 4:return r=O(),n.flags|=r,0;case 12:return r=O(),ce[r+0>>1]=2,0;case 13:case 14:return 0;case 16:case 8:return -28;case 9:return K.___errno_location&&(le[K.___errno_location()>>2]=28),-1;default:return -28}}catch(e){return void 0!==Xe&&e instanceof $e||u(e),-e.Ua}},H:function(e,t){qe=t;try{return C(Y(),O(),O())}catch(e){return void 0!==Xe&&e instanceof $e||u(e),-e.Ua}},w:function(e,t){qe=t;try{var n=O();return R(n?r(fe,n,void 0):"",O(),O()).Va}catch(e){return void 0!==Xe&&e instanceof $e||u(e),-e.Ua}},G:function(e,t){qe=t;try{var n=Y(),r=O();switch(r){case 21509:case 21505:return n.Pa?0:-59;case 21510:case 21511:case 21512:case 21506:case 21507:case 21508:return n.Pa?0:-59;case 21519:if(!n.Pa)return -59;var a=O();return le[a>>2]=0;case 21520:return n.Pa?-28:-59;case 21531:if(e=O(),!n.Na.yb)throw new $e(59);return n.Na.yb(n,r,e);case 21523:case 21524:return n.Pa?0:-59;default:u("bad ioctl syscall "+r);}}catch(e){return void 0!==Xe&&e instanceof $e||u(e),-e.Ua}},t:function(){},s:function(){return I.apply(null,arguments)},F:function(){return j.apply(null,arguments)},__memory_base:1024,__table_base:0,E:function(){u();},D:D,C:function(e,t){W(e,t);},B:function(e,t,n){fe.set(fe.subarray(t,t+n),e);},A:function(e){if(2147418112<e)return !1;for(var t=Math.max(D(),16777216);t<e;)t=536870912>=t?a(2*t):Math.min(a((3*t+2147483648)/4),2147418112);e:{try{re.grow(t-se.byteLength+65535>>16),i(re.buffer),e=1;break e}catch(e){}e=void 0;}return !!e},j:function(e){!ee&&(ie=!0,K.onExit)&&K.onExit(e),n(e,new $(e));},v:function(e){var t=Date.now();return le[e>>2]=t/1e3|0,le[e+4>>2]=t%1e3*1e3|0,0},o:function(e){var t=F.Za[e];F.Za.splice(e,1),nt(t);},q:F,b:W,m:u,a:function(){return ne},g:function(e){var t=rt();try{return at(e)}catch(e){if(nt(t),e!==e+0&&"longjmp"!==e)throw e;et(1,0);}},i:function(e,t){var n=rt();try{return it(e,t)}catch(e){if(nt(n),e!==e+0&&"longjmp"!==e)throw e;et(1,0);}},h:function(e,t,n){var r=rt();try{return ot(e,t,n)}catch(e){if(nt(r),e!==e+0&&"longjmp"!==e)throw e;et(1,0);}},p:function(e,t,n,r){var a=rt();try{return st(e,t,n,r)}catch(e){if(nt(a),e!==e+0&&"longjmp"!==e)throw e;et(1,0);}},z:function(e,t,n,r,a){var i=rt();try{return ut(e,t,n,r,a)}catch(e){if(nt(i),e!==e+0&&"longjmp"!==e)throw e;et(1,0);}},l:function(e){var t=rt();try{ft(e);}catch(e){if(nt(t),e!==e+0&&"longjmp"!==e)throw e;et(1,0);}},d:function(e,t){var n=rt();try{ct(e,t);}catch(e){if(nt(n),e!==e+0&&"longjmp"!==e)throw e;et(1,0);}},e:function(e,t,n){var r=rt();try{lt(e,t,n);}catch(e){if(nt(r),e!==e+0&&"longjmp"!==e)throw e;et(1,0);}},f:function(e,t,n,r){var a=rt();try{_t(e,t,n,r);}catch(e){if(nt(a),e!==e+0&&"longjmp"!==e)throw e;et(1,0);}},k:function(e,t,n,r,a){var i=rt();try{dt(e,t,n,r,a);}catch(e){if(nt(i),e!==e+0&&"longjmp"!==e)throw e;et(1,0);}},r:function(e,t,n,r,a,i){var o=rt();try{pt(e,t,n,r,a,i);}catch(e){if(nt(o),e!==e+0&&"longjmp"!==e)throw e;et(1,0);}},n:function(e,t,n,r,a,i,o){var s=rt();try{yt(e,t,n,r,a,i,o);}catch(e){if(nt(s),e!==e+0&&"longjmp"!==e)throw e;et(1,0);}},K:function(e,t,n,r,a,i,o,s){var u=rt();try{ht(e,t,n,r,a,i,o,s);}catch(e){if(nt(u),e!==e+0&&"longjmp"!==e)throw e;et(1,0);}},y:function(e,t,n,r,a,i,o,s,u){var f=rt();try{vt(e,t,n,r,a,i,o,s,u);}catch(e){if(nt(f),e!==e+0&&"longjmp"!==e)throw e;et(1,0);}},memory:re,c:function(e){ne=e;},table:ae},Ge=K.asm({},Ze,se);K.asm=Ge,K.___errno_location=function(){return K.asm.L.apply(null,arguments)},K._free=function(){return K.asm.M.apply(null,arguments)};var Je=K._malloc=function(){return K.asm.N.apply(null,arguments)},et=K._setThrew=function(){return K.asm.O.apply(null,arguments)};K._vsc_buffer_bytes=function(){return K.asm.P.apply(null,arguments)},K._vsc_buffer_data=function(){return K.asm.Q.apply(null,arguments)},K._vsc_buffer_delete=function(){return K.asm.R.apply(null,arguments)},K._vsc_buffer_len=function(){return K.asm.S.apply(null,arguments)},K._vsc_buffer_make_secure=function(){return K.asm.T.apply(null,arguments)},K._vsc_buffer_new=function(){return K.asm.U.apply(null,arguments)},K._vsc_buffer_new_with_capacity=function(){return K.asm.V.apply(null,arguments)},K._vsc_data=function(){return K.asm.W.apply(null,arguments)},K._vsc_data_bytes=function(){return K.asm.X.apply(null,arguments)},K._vsc_data_ctx_size=function(){return K.asm.Y.apply(null,arguments)},K._vsc_data_len=function(){return K.asm.Z.apply(null,arguments)},K._vscp_error_ctx_size=function(){return K.asm._.apply(null,arguments)},K._vscp_error_reset=function(){return K.asm.$.apply(null,arguments)},K._vscp_error_status=function(){return K.asm.aa.apply(null,arguments)},K._vscp_pythia_blind=function(){return K.asm.ba.apply(null,arguments)},K._vscp_pythia_blinded_password_buf_len=function(){return K.asm.ca.apply(null,arguments)},K._vscp_pythia_blinding_secret_buf_len=function(){return K.asm.da.apply(null,arguments)},K._vscp_pythia_cleanup=function(){return K.asm.ea.apply(null,arguments)},K._vscp_pythia_compute_transformation_key_pair=function(){return K.asm.fa.apply(null,arguments)},K._vscp_pythia_configure=function(){return K.asm.ga.apply(null,arguments)},K._vscp_pythia_deblind=function(){return K.asm.ha.apply(null,arguments)},K._vscp_pythia_deblinded_password_buf_len=function(){return K.asm.ia.apply(null,arguments)},K._vscp_pythia_get_password_update_token=function(){return K.asm.ja.apply(null,arguments)},K._vscp_pythia_password_update_token_buf_len=function(){return K.asm.ka.apply(null,arguments)},K._vscp_pythia_proof_value_buf_len=function(){return K.asm.la.apply(null,arguments)},K._vscp_pythia_prove=function(){return K.asm.ma.apply(null,arguments)},K._vscp_pythia_transform=function(){return K.asm.na.apply(null,arguments)},K._vscp_pythia_transformation_private_key_buf_len=function(){return K.asm.oa.apply(null,arguments)},K._vscp_pythia_transformation_public_key_buf_len=function(){return K.asm.pa.apply(null,arguments)},K._vscp_pythia_transformed_password_buf_len=function(){return K.asm.qa.apply(null,arguments)},K._vscp_pythia_transformed_tweak_buf_len=function(){return K.asm.ra.apply(null,arguments)},K._vscp_pythia_update_deblinded_with_token=function(){return K.asm.sa.apply(null,arguments)},K._vscp_pythia_verify=function(){return K.asm.ta.apply(null,arguments)},K.stackAlloc=function(){return K.asm.Ia.apply(null,arguments)};var tt,nt=K.stackRestore=function(){return K.asm.Ja.apply(null,arguments)},rt=K.stackSave=function(){return K.asm.Ka.apply(null,arguments)},at=K.dynCall_i=function(){return K.asm.ua.apply(null,arguments)},it=K.dynCall_ii=function(){return K.asm.va.apply(null,arguments)},ot=K.dynCall_iii=function(){return K.asm.wa.apply(null,arguments)},st=K.dynCall_iiii=function(){return K.asm.xa.apply(null,arguments)},ut=K.dynCall_iiiii=function(){return K.asm.ya.apply(null,arguments)},ft=K.dynCall_v=function(){return K.asm.za.apply(null,arguments)},ct=K.dynCall_vi=function(){return K.asm.Aa.apply(null,arguments)},lt=K.dynCall_vii=function(){return K.asm.Ba.apply(null,arguments)},_t=K.dynCall_viii=function(){return K.asm.Ca.apply(null,arguments)},dt=K.dynCall_viiii=function(){return K.asm.Da.apply(null,arguments)},pt=K.dynCall_viiiii=function(){return K.asm.Ea.apply(null,arguments)},yt=K.dynCall_viiiiii=function(){return K.asm.Fa.apply(null,arguments)},ht=K.dynCall_viiiiiii=function(){return K.asm.Ga.apply(null,arguments)},vt=K.dynCall_viiiiiiii=function(){return K.asm.Ha.apply(null,arguments)};if(K.asm=Ge,K.then=function(e){if(tt)e(K);else{var t=K.onRuntimeInitialized;K.onRuntimeInitialized=function(){t&&t(),e(K);};}return K},Pe=function e(){tt||V(),tt||(Pe=e);},K.run=V,K.preInit)for("function"==typeof K.preInit&&(K.preInit=[K.preInit]);0<K.preInit.length;)K.preInit.pop()();return ee=!0,V(),t}}(),n$2.exports=r$2,e$1=t$1.exports;var a$2=()=>{class e extends Error{constructor(e){super(e),this.name="PythiaError",this.message=e;}static handleStatusCode(t){if(0!=t){if(-1==t)throw new e("This error should not be returned if assertions is enabled.");if(-200==t)throw new e("Underlying pythia library returns -1.");if(-202==t)throw new e("Underlying random number generator failed.");throw new e("Unexpected status code:"+t)}}}return e};function i$1(e,t){if(!("number"==typeof t||t instanceof Number))throw new TypeError(`'${e}' is not a number`);if(Number.isNaN(t))throw new TypeError(`'${e}' is NaN`);if(1/0===t)throw new TypeError(`'${e}' is Infinity`);if(-1/0===t)throw new TypeError(`'${e}' is -Infinity`)}function o$2(e,t){if(i$1(e,t),0==t)throw new TypeError(`'${e}' is NULL`)}var s$2={ensureNumber:i$1,ensureString:function(e,t){if(!("string"==typeof t||t instanceof String))throw new TypeError(`'${e}' is not a string`)},ensureBoolean:function(e,t){if("boolean"!=typeof t)throw new TypeError(`'${e}' is not a boolean`)},ensureByteArray:function(e,t){if(!(t instanceof Uint8Array))throw new TypeError(`'${e}' is not an Uint8Array`)},ensureClass:function(e,t,n){if(!(t instanceof n))throw new TypeError(`'${e}' is not an instance of the class ${n.name}`);o$2(e,t.ctxPtr);},ensureNotNull:o$2,ensureImplementInterface:function(e,t,n,r,a){if(o$2(e,t.ctxPtr),!a.isImplemented(t.ctxPtr,r))throw new TypeError(`'${e}' does not implement interface '${n}'`)}};var initPythia = ()=>{const t=new e$1;return new Promise((e,n)=>{t.onRuntimeInitialized=()=>{const n={};n.PythiaError=a$2(),n.Pythia=((e,t)=>{class n{static configure(){const n=e._vscp_pythia_configure();t.PythiaError.handleStatusCode(n);}static cleanup(){e._vscp_pythia_cleanup();}static blindedPasswordBufLen(){return e._vscp_pythia_blinded_password_buf_len()}static deblindedPasswordBufLen(){return e._vscp_pythia_deblinded_password_buf_len()}static blindingSecretBufLen(){return e._vscp_pythia_blinding_secret_buf_len()}static transformationPrivateKeyBufLen(){return e._vscp_pythia_transformation_private_key_buf_len()}static transformationPublicKeyBufLen(){return e._vscp_pythia_transformation_public_key_buf_len()}static transformedPasswordBufLen(){return e._vscp_pythia_transformed_password_buf_len()}static transformedTweakBufLen(){return e._vscp_pythia_transformed_tweak_buf_len()}static proofValueBufLen(){return e._vscp_pythia_proof_value_buf_len()}static passwordUpdateTokenBufLen(){return e._vscp_pythia_password_update_token_buf_len()}static blind(r){s$2.ensureByteArray("password",r);var a=r.length*r.BYTES_PER_ELEMENT;const i=e._malloc(a);e.HEAP8.set(r,i),r=e._vsc_data_ctx_size(),r=e._malloc(r),e._vsc_data(r,i,a),a=n.blindedPasswordBufLen(),a=e._vsc_buffer_new_with_capacity(a);var o=n.blindingSecretBufLen();o=e._vsc_buffer_new_with_capacity(o);try{const n=e._vscp_pythia_blind(r,a,o);t.PythiaError.handleStatusCode(n);const i=e._vsc_buffer_bytes(a),s=e._vsc_buffer_len(a),u=e.HEAPU8.slice(i,i+s),f=e._vsc_buffer_bytes(o),c=e._vsc_buffer_len(o);return {blindedPassword:u,blindingSecret:e.HEAPU8.slice(f,f+c)}}finally{e._free(n),e._free(r),e._vsc_buffer_delete(a),e._vsc_buffer_delete(o);}}static deblind(r,a){s$2.ensureByteArray("transformedPassword",r),s$2.ensureByteArray("blindingSecret",a);var i=r.length*r.BYTES_PER_ELEMENT;const o=e._malloc(i);e.HEAP8.set(r,o),r=e._vsc_data_ctx_size(),r=e._malloc(r),e._vsc_data(r,o,i);var u=a.length*a.BYTES_PER_ELEMENT;i=e._malloc(u),e.HEAP8.set(a,i),a=e._vsc_data_ctx_size(),a=e._malloc(a),e._vsc_data(a,i,u),u=n.deblindedPasswordBufLen(),u=e._vsc_buffer_new_with_capacity(u);try{const n=e._vscp_pythia_deblind(r,a,u);t.PythiaError.handleStatusCode(n);const i=e._vsc_buffer_bytes(u),o=e._vsc_buffer_len(u);return e.HEAPU8.slice(i,i+o)}finally{e._free(i),e._free(r),e._free(n),e._free(a),e._vsc_buffer_delete(u);}}static computeTransformationKeyPair(r,a,i){s$2.ensureByteArray("transformationKeyId",r),s$2.ensureByteArray("pythiaSecret",a),s$2.ensureByteArray("pythiaScopeSecret",i);var o=r.length*r.BYTES_PER_ELEMENT;const u=e._malloc(o);e.HEAP8.set(r,u),r=e._vsc_data_ctx_size(),r=e._malloc(r),e._vsc_data(r,u,o);var f=a.length*a.BYTES_PER_ELEMENT;o=e._malloc(f),e.HEAP8.set(a,o),a=e._vsc_data_ctx_size(),a=e._malloc(a),e._vsc_data(a,o,f);var c=i.length*i.BYTES_PER_ELEMENT;f=e._malloc(c),e.HEAP8.set(i,f),i=e._vsc_data_ctx_size(),i=e._malloc(i),e._vsc_data(i,f,c),c=n.transformationPrivateKeyBufLen(),c=e._vsc_buffer_new_with_capacity(c);var l=n.transformationPublicKeyBufLen();l=e._vsc_buffer_new_with_capacity(l);try{const n=e._vscp_pythia_compute_transformation_key_pair(r,a,i,c,l);t.PythiaError.handleStatusCode(n);const o=e._vsc_buffer_bytes(c),s=e._vsc_buffer_len(c),u=e.HEAPU8.slice(o,o+s),f=e._vsc_buffer_bytes(l),_=e._vsc_buffer_len(l);return {transformationPrivateKey:u,transformationPublicKey:e.HEAPU8.slice(f,f+_)}}finally{e._free(n),e._free(r),e._free(o),e._free(a),e._free(s$2),e._free(i),e._vsc_buffer_delete(c),e._vsc_buffer_delete(l);}}static transform(r,a,i){s$2.ensureByteArray("blindedPassword",r),s$2.ensureByteArray("tweak",a),s$2.ensureByteArray("transformationPrivateKey",i);var o=r.length*r.BYTES_PER_ELEMENT;const u=e._malloc(o);e.HEAP8.set(r,u),r=e._vsc_data_ctx_size(),r=e._malloc(r),e._vsc_data(r,u,o);var f=a.length*a.BYTES_PER_ELEMENT;o=e._malloc(f),e.HEAP8.set(a,o),a=e._vsc_data_ctx_size(),a=e._malloc(a),e._vsc_data(a,o,f);var c=i.length*i.BYTES_PER_ELEMENT;f=e._malloc(c),e.HEAP8.set(i,f),i=e._vsc_data_ctx_size(),i=e._malloc(i),e._vsc_data(i,f,c),c=n.transformedPasswordBufLen(),c=e._vsc_buffer_new_with_capacity(c);var l=n.transformedTweakBufLen();l=e._vsc_buffer_new_with_capacity(l);try{const n=e._vscp_pythia_transform(r,a,i,c,l);t.PythiaError.handleStatusCode(n);const o=e._vsc_buffer_bytes(c),s=e._vsc_buffer_len(c),u=e.HEAPU8.slice(o,o+s),f=e._vsc_buffer_bytes(l),_=e._vsc_buffer_len(l);return {transformedPassword:u,transformedTweak:e.HEAPU8.slice(f,f+_)}}finally{e._free(n),e._free(r),e._free(o),e._free(a),e._free(s$2),e._free(i),e._vsc_buffer_delete(c),e._vsc_buffer_delete(l);}}static prove(r,a,i,o,u){s$2.ensureByteArray("transformedPassword",r),s$2.ensureByteArray("blindedPassword",a),s$2.ensureByteArray("transformedTweak",i),s$2.ensureByteArray("transformationPrivateKey",o),s$2.ensureByteArray("transformationPublicKey",u);var f=r.length*r.BYTES_PER_ELEMENT;const c=e._malloc(f);e.HEAP8.set(r,c),r=e._vsc_data_ctx_size(),r=e._malloc(r),e._vsc_data(r,c,f);var l=a.length*a.BYTES_PER_ELEMENT;f=e._malloc(l),e.HEAP8.set(a,f),a=e._vsc_data_ctx_size(),a=e._malloc(a),e._vsc_data(a,f,l);var _=i.length*i.BYTES_PER_ELEMENT;l=e._malloc(_),e.HEAP8.set(i,l),i=e._vsc_data_ctx_size(),i=e._malloc(i),e._vsc_data(i,l,_);var d=o.length*o.BYTES_PER_ELEMENT;_=e._malloc(d),e.HEAP8.set(o,_),o=e._vsc_data_ctx_size(),o=e._malloc(o),e._vsc_data(o,_,d);var p=u.length*u.BYTES_PER_ELEMENT;d=e._malloc(p),e.HEAP8.set(u,d),u=e._vsc_data_ctx_size(),u=e._malloc(u),e._vsc_data(u,d,p),p=n.proofValueBufLen(),p=e._vsc_buffer_new_with_capacity(p);var y=n.proofValueBufLen();y=e._vsc_buffer_new_with_capacity(y);try{const n=e._vscp_pythia_prove(r,a,i,o,u,p,y);t.PythiaError.handleStatusCode(n);const s=e._vsc_buffer_bytes(p),f=e._vsc_buffer_len(p),c=e.HEAPU8.slice(s,s+f),l=e._vsc_buffer_bytes(y),_=e._vsc_buffer_len(y);return {proofValueC:c,proofValueU:e.HEAPU8.slice(l,l+_)}}finally{e._free(f),e._free(r),e._free(n),e._free(a),e._free(s$2),e._free(i),e._free(l),e._free(o),e._free(_),e._free(u),e._vsc_buffer_delete(p),e._vsc_buffer_delete(y);}}static verify(n,r,a,i,o,u){s$2.ensureByteArray("transformedPassword",n),s$2.ensureByteArray("blindedPassword",r),s$2.ensureByteArray("tweak",a),s$2.ensureByteArray("transformationPublicKey",i),s$2.ensureByteArray("proofValueC",o),s$2.ensureByteArray("proofValueU",u);var f=n.length*n.BYTES_PER_ELEMENT;const c=e._malloc(f);e.HEAP8.set(n,c),n=e._vsc_data_ctx_size(),n=e._malloc(n),e._vsc_data(n,c,f);var l=r.length*r.BYTES_PER_ELEMENT;f=e._malloc(l),e.HEAP8.set(r,f),r=e._vsc_data_ctx_size(),r=e._malloc(r),e._vsc_data(r,f,l);var _=a.length*a.BYTES_PER_ELEMENT;l=e._malloc(_),e.HEAP8.set(a,l),a=e._vsc_data_ctx_size(),a=e._malloc(a),e._vsc_data(a,l,_);var d=i.length*i.BYTES_PER_ELEMENT;_=e._malloc(d),e.HEAP8.set(i,_),i=e._vsc_data_ctx_size(),i=e._malloc(i),e._vsc_data(i,_,d);var p=o.length*o.BYTES_PER_ELEMENT;d=e._malloc(p),e.HEAP8.set(o,d),o=e._vsc_data_ctx_size(),o=e._malloc(o),e._vsc_data(o,d,p);var y=u.length*u.BYTES_PER_ELEMENT;let h;p=e._malloc(y),e.HEAP8.set(u,p),u=e._vsc_data_ctx_size(),u=e._malloc(u),e._vsc_data(u,p,y),y=e._vscp_error_ctx_size(),y=e._malloc(y),e._vscp_error_reset(y);try{h=e._vscp_pythia_verify(n,r,a,i,o,u,y);const s=e._vscp_error_status(y);return t.PythiaError.handleStatusCode(s),!!h}finally{e._free(s$2),e._free(n),e._free(f),e._free(r),e._free(l),e._free(a),e._free(_),e._free(i),e._free(d),e._free(o),e._free(p),e._free(u),e._free(y);}}static getPasswordUpdateToken(r,a){s$2.ensureByteArray("previousTransformationPrivateKey",r),s$2.ensureByteArray("newTransformationPrivateKey",a);var i=r.length*r.BYTES_PER_ELEMENT;const o=e._malloc(i);e.HEAP8.set(r,o),r=e._vsc_data_ctx_size(),r=e._malloc(r),e._vsc_data(r,o,i);var u=a.length*a.BYTES_PER_ELEMENT;i=e._malloc(u),e.HEAP8.set(a,i),a=e._vsc_data_ctx_size(),a=e._malloc(a),e._vsc_data(a,i,u),u=n.passwordUpdateTokenBufLen(),u=e._vsc_buffer_new_with_capacity(u);try{const n=e._vscp_pythia_get_password_update_token(r,a,u);t.PythiaError.handleStatusCode(n);const i=e._vsc_buffer_bytes(u),o=e._vsc_buffer_len(u);return e.HEAPU8.slice(i,i+o)}finally{e._free(i),e._free(r),e._free(n),e._free(a),e._vsc_buffer_delete(u);}}static updateDeblindedWithToken(r,a){s$2.ensureByteArray("deblindedPassword",r),s$2.ensureByteArray("passwordUpdateToken",a);var i=r.length*r.BYTES_PER_ELEMENT;const o=e._malloc(i);e.HEAP8.set(r,o),r=e._vsc_data_ctx_size(),r=e._malloc(r),e._vsc_data(r,o,i);var u=a.length*a.BYTES_PER_ELEMENT;i=e._malloc(u),e.HEAP8.set(a,i),a=e._vsc_data_ctx_size(),a=e._malloc(a),e._vsc_data(a,i,u),u=n.deblindedPasswordBufLen(),u=e._vsc_buffer_new_with_capacity(u);try{const n=e._vscp_pythia_update_deblinded_with_token(r,a,u);t.PythiaError.handleStatusCode(n);const i=e._vsc_buffer_bytes(u),o=e._vsc_buffer_len(u);return e.HEAPU8.slice(i,i+o)}finally{e._free(i),e._free(r),e._free(n),e._free(a),e._vsc_buffer_delete(u);}}}return n})(t,n),e(n);},t.onAbort=e=>{n(Error(e));};})};

            var t$2,e$2,r$3,n$3;r$3=e$2={exports:{}},n$3=function(){var t="undefined"!=typeof document&&document.currentScript?document.currentScript.src:void 0;return function(e){function r(t,e){throw e}function n(t,e,r){var n=e+r;for(r=e;t[r]&&!(r>=n);)++r;if(16<r-e&&t.subarray&&ot)return ot.decode(t.subarray(e,r));for(n="";e<r;){var a=t[e++];if(128&a){var o=63&t[e++];if(192==(224&a))n+=String.fromCharCode((31&a)<<6|o);else{var i=63&t[e++];65536>(a=224==(240&a)?(15&a)<<12|o<<6|i:(7&a)<<18|o<<12|i<<6|63&t[e++])?n+=String.fromCharCode(a):(a-=65536,n+=String.fromCharCode(55296|a>>10,56320|1023&a));}}else n+=String.fromCharCode(a);}return n}function a(t){return 0<t%65536&&(t+=65536-t%65536),t}function o(t){it=t,V.HEAP8=st=new Int8Array(t),V.HEAP16=ut=new Int16Array(t),V.HEAP32=ct=new Int32Array(t),V.HEAPU8=ft=new Uint8Array(t),V.HEAPU16=new Uint16Array(t),V.HEAPU32=new Uint32Array(t),V.HEAPF32=new Float32Array(t),V.HEAPF64=new Float64Array(t);}function i(t){for(;0<t.length;){var e=t.shift();if("function"==typeof e)e();else{var r=e.Jb;"number"==typeof r?void 0===e.gb?V.dynCall_v(r):V.dynCall_vi(r,e.gb):r(void 0===e.gb?null:e.gb);}}}function s(){var t=V.preRun.shift();ht.unshift(t);}function f(t){throw V.onAbort&&V.onAbort(t),q(t),Z(t),at=!0,"abort("+t+"). Build with -s ASSERTIONS=1 for more info."}function u(){var t=Pt;return String.prototype.startsWith?t.startsWith("data:application/octet-stream;base64,"):0===t.indexOf("data:application/octet-stream;base64,")}function c(){try{if(J)return new Uint8Array(J);throw "both async and sync fetching of the wasm failed"}catch(t){f(t);}}function l(t,e){for(var r=0,n=t.length-1;0<=n;n--){var a=t[n];"."===a?t.splice(n,1):".."===a?(t.splice(n,1),r++):r&&(t.splice(n,1),r--);}if(e)for(;r;r--)t.unshift("..");return t}function h(t){var e="/"===t.charAt(0),r="/"===t.substr(-1);return (t=l(t.split("/").filter((function(t){return !!t})),!e).join("/"))||e||(t="."),t&&r&&(t+="/"),(e?"/":"")+t}function p(t){var e=/^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/.exec(t).slice(1);return t=e[0],e=e[1],t||e?(e&&(e=e.substr(0,e.length-1)),t+e):"."}function _(t){if("/"===t)return "/";var e=t.lastIndexOf("/");return -1===e?t:t.substr(e+1)}function d(){for(var t="",e=!1,r=arguments.length-1;-1<=r&&!e;r--){if("string"!=typeof(e=0<=r?arguments[r]:"/"))throw new TypeError("Arguments to path.resolve must be strings");if(!e)return "";t=e+"/"+t,e="/"===e.charAt(0);}return (e?"/":"")+(t=l(t.split("/").filter((function(t){return !!t})),!e).join("/"))||"."}function y(t,e){Rt[t]={input:[],Qa:[],Ya:e},B(t,kt);}function v(t,e){if(e=e||{},!(t=d("/",t)))return {path:"",node:null};var r,n={ob:!0,jb:0};for(r in n)void 0===e[r]&&(e[r]=n[r]);if(8<e.jb)throw new Ft(32);t=l(t.split("/").filter((function(t){return !!t})),!1);var a=It;for(n="/",r=0;r<t.length;r++){var o=r===t.length-1;if(o&&e.parent)break;if(a=m(a,t[r]),n=h(n+"/"+t[r]),a.cb&&(!o||o&&e.ob)&&(a=a.cb.root),!o||e.nb)for(o=0;40960==(61440&a.mode);)if(a=U(n),a=v(n=d(p(n),a),{jb:e.jb}).node,40<o++)throw new Ft(32)}return {path:n,node:a}}function w(t){for(var e;;){if(t===t.parent)return t=t.Ta.rb,e?"/"!==t[t.length-1]?t+"/"+e:t+e:t;e=e?t.name+"/"+e:t.name,t=t.parent;}}function b(t,e){for(var r=0,n=0;n<e.length;n++)r=(r<<5)-r+e.charCodeAt(n)|0;return (t+r>>>0)%Yt.length}function m(t,e){var r;if(r=(r=P(t,"x"))?r:t.Ma.$a?0:2)throw new Ft(r,t);for(r=Yt[b(t.id,e)];r;r=r.Ab){var n=r.name;if(r.parent.id===t.id&&n===e)return r}return t.Ma.$a(t,e)}function g(t,e,r,n){return Mt||((Mt=function(t,e,r,n){t||(t=this),this.parent=t,this.Ta=t.Ta,this.cb=null,this.id=jt++,this.name=e,this.mode=r,this.Ma={},this.Na={},this.eb=n;}).prototype={},Object.defineProperties(Mt.prototype,{read:{get:function(){return 365==(365&this.mode)},set:function(t){t?this.mode|=365:this.mode&=-366;}},write:{get:function(){return 146==(146&this.mode)},set:function(t){t?this.mode|=146:this.mode&=-147;}}})),function(t){var e=b(t.parent.id,t.name);t.Ab=Yt[e],Yt[e]=t;}(t=new Mt(t,e,r,n)),t}function E(t){var e=["r","w","rw"][3&t];return 512&t&&(e+="w"),e}function P(t,e){return Dt?0:(-1===e.indexOf("r")||292&t.mode)&&(-1===e.indexOf("w")||146&t.mode)&&(-1===e.indexOf("x")||73&t.mode)?0:2}function A(t,e){try{return m(t,e),20}catch(t){}return P(t,"wx")}function B(t,e){zt[t]={Na:e};}function T(t,e){var r="/"===e,n=!e;if(r&&It)throw new Ft(10);if(!r&&!n){var a=v(e,{ob:!1});if(e=a.path,(a=a.node).cb)throw new Ft(10);if(16384!=(61440&a.mode))throw new Ft(54)}e={type:t,Qb:{},rb:e,zb:[]},(t=t.Ta(e)).Ta=e,e.root=t,r?It=t:a&&(a.cb=e,a.Ta&&a.Ta.zb.push(e));}function L(t,e,r){var n=v(t,{parent:!0}).node;if(!(t=_(t))||"."===t||".."===t)throw new Ft(28);var a=A(n,t);if(a)throw new Ft(a);if(!n.Ma.bb)throw new Ft(63);return n.Ma.bb(n,t,e,r)}function S(t){L(t,16895,0);}function M(t,e,r){void 0===r&&(r=e,e=438),L(t,8192|e,r);}function x(t,e){if(!d(t))throw new Ft(44);var r=v(e,{parent:!0}).node;if(!r)throw new Ft(44);var n=A(r,e=_(e));if(n)throw new Ft(n);if(!r.Ma.fb)throw new Ft(63);r.Ma.fb(r,e,t);}function U(t){if(!(t=v(t).node))throw new Ft(44);if(!t.Ma.ab)throw new Ft(28);return d(w(t.parent),t.Ma.ab(t))}function R(t,e,r,n){if(""===t)throw new Ft(44);if("string"==typeof e){var a=Vt[e];if(void 0===a)throw Error("Unknown file open mode: "+e);e=a;}if(r=64&e?4095&(void 0===r?438:r)|32768:0,"object"==typeof t)var o=t;else{t=h(t);try{o=v(t,{nb:!(131072&e)}).node;}catch(t){}}if(a=!1,64&e)if(o){if(128&e)throw new Ft(20)}else o=L(t,r,0),a=!0;if(!o)throw new Ft(44);if(8192==(61440&o.mode)&&(e&=-513),65536&e&&16384!=(61440&o.mode))throw new Ft(54);if(!a&&(r=o?40960==(61440&o.mode)?32:16384==(61440&o.mode)&&("r"!==E(e)||512&e)?31:P(o,E(e)):44))throw new Ft(r);if(512&e){var i;if(!(i="string"==typeof(r=o)?v(r,{nb:!0}).node:r).Ma.Sa)throw new Ft(63);if(16384==(61440&i.mode))throw new Ft(31);if(32768!=(61440&i.mode))throw new Ft(28);if(r=P(i,"w"))throw new Ft(r);i.Ma.Sa(i,{size:0,timestamp:Date.now()});}e&=-641,(n=function(t,e){xt||((xt=function(){}).prototype={},Object.defineProperties(xt.prototype,{object:{get:function(){return this.node},set:function(t){this.node=t;}}}));var r,n=new xt;for(r in t)n[r]=t[r];return t=n,e=function(t){for(t=t||0;4096>=t;t++)if(!Ht[t])return t;throw new Ft(33)}(e),t.Va=e,Ht[e]=t}({node:o,path:w(o),flags:e,seekable:!0,position:0,Na:o.Na,Db:[],error:!1},n)).Na.open&&n.Na.open(n),!V.logReadFiles||1&e||(Ut||(Ut={}),t in Ut||(Ut[t]=1,console.log("FS.trackingDelegate error on read file: "+t)));try{Kt.onOpenFile&&(o=0,1!=(2097155&e)&&(o|=1),0!=(2097155&e)&&(o|=2),Kt.onOpenFile(t,o));}catch(e){console.log("FS.trackingDelegate['onOpenFile']('"+t+"', flags) threw an exception: "+e.message);}return n}function k(t,e,r){if(null===t.Va)throw new Ft(8);if(!t.seekable||!t.Na.Xa)throw new Ft(70);if(0!=r&&1!=r&&2!=r)throw new Ft(28);t.position=t.Na.Xa(t,e,r),t.Db=[];}function N(t,e,r,n){var a=st;if(0>r||0>n)throw new Ft(28);if(null===t.Va)throw new Ft(8);if(1==(2097155&t.flags))throw new Ft(8);if(16384==(61440&t.node.mode))throw new Ft(31);if(!t.Na.read)throw new Ft(28);var o=void 0!==n;if(o){if(!t.seekable)throw new Ft(70)}else n=t.position;return e=t.Na.read(t,a,e,r,n),o||(t.position+=e),e}function C(){Ft||((Ft=function(t,e){this.node=e,this.Cb=function(t){this.Ua=t;},this.Cb(t),this.message="FS error";}).prototype=Error(),Ft.prototype.constructor=Ft,[44].forEach((function(t){Wt[t]=new Ft(t),Wt[t].stack="<generic error, no stack>";})));}function O(t,e,r){t=h("/dev/"+t);var n=function(t,e){var r=0;return t&&(r|=365),e&&(r|=146),r}(!!e,!!r);St||(St=64);var a=St++<<8|0;B(a,{open:function(t){t.seekable=!1;},close:function(){r&&r.buffer&&r.buffer.length&&r(10);},read:function(t,r,n,a){for(var o=0,i=0;i<a;i++){try{var s=e();}catch(t){throw new Ft(29)}if(void 0===s&&0===o)throw new Ft(6);if(null==s)break;o++,r[n+i]=s;}return o&&(t.node.timestamp=Date.now()),o},write:function(t,e,n,a){for(var o=0;o<a;o++)try{r(e[n+o]);}catch(t){throw new Ft(29)}return a&&(t.node.timestamp=Date.now()),o}}),M(t,n,a);}function I(){return ct[(Xt+=4)-4>>2]}function z(t){if(t||(t=I()),!(t=Ht[t]))throw new Ft(8);return t}function H(t){try{var e=z(t);if(null===e.Va)throw new Ft(8);e.hb&&(e.hb=null);try{e.Na.close&&e.Na.close(e);}catch(t){throw t}finally{Ht[e.Va]=null;}return e.Va=null,0}catch(t){return void 0!==Qt&&t instanceof Ft||f(t),t.Ua}}function j(t,e,r,n){try{t:{for(var a=z(t),o=t=0;o<r;o++){var i=a,s=ct[e+8*o>>2],u=ct[e+(8*o+4)>>2],c=void 0,l=st;if(0>u||0>c)throw new Ft(28);if(null===i.Va)throw new Ft(8);if(0==(2097155&i.flags))throw new Ft(8);if(16384==(61440&i.node.mode))throw new Ft(31);if(!i.Na.write)throw new Ft(28);1024&i.flags&&k(i,0,2);var h=void 0!==c;if(h){if(!i.seekable)throw new Ft(70)}else c=i.position;var p=i.Na.write(i,l,s,u,c,void 0);h||(i.position+=p);try{i.path&&Kt.onWriteToFile&&Kt.onWriteToFile(i.path);}catch(t){console.log("FS.trackingDelegate['onWriteToFile']('"+i.path+"') threw an exception: "+t.message);}if(0>(i=p)){var _=-1;break t}t+=i;}_=t;}return ct[n>>2]=_,0}catch(t){return void 0!==Qt&&t instanceof Ft||f(t),t.Ua}}function Y(){return st.length}function D(t,e){throw Gt(t,e||1),"longjmp"}function K(){return K.Za||(K.Za=[]),K.Za.push(re()),K.Za.length-1}function F(t){this.name="ExitStatus",this.message="Program terminated with exit("+t+")",this.status=t;}function W(){function t(){if(!te&&(te=!0,!at)){if(V.noFSInit||Lt||(Lt=!0,C(),V.stdin=V.stdin,V.stdout=V.stdout,V.stderr=V.stderr,V.stdin?O("stdin",V.stdin):x("/dev/tty","/dev/stdin"),V.stdout?O("stdout",null,V.stdout):x("/dev/tty","/dev/stdout"),V.stderr?O("stderr",null,V.stderr):x("/dev/tty1","/dev/stderr"),R("/dev/stdin","r"),R("/dev/stdout","w"),R("/dev/stderr","w")),i(pt),Dt=!1,i(_t),V.onRuntimeInitialized&&V.onRuntimeInitialized(),V.postRun)for("function"==typeof V.postRun&&(V.postRun=[V.postRun]);V.postRun.length;){var t=V.postRun.shift();dt.unshift(t);}i(dt);}}if(!(0<mt)){if(V.preRun)for("function"==typeof V.preRun&&(V.preRun=[V.preRun]);V.preRun.length;)s();i(ht),0<mt||(V.setStatus?(V.setStatus("Running..."),setTimeout((function(){setTimeout((function(){V.setStatus("");}),1),t();}),1)):t());}}var V;e=e||{},V||(V=void 0!==e?e:{});var $,Q={};for($ in V)V.hasOwnProperty($)&&(Q[$]=V[$]);var X="";document.currentScript&&(X=document.currentScript.src),t&&(X=t),X=0!==X.indexOf("blob:")?X.substr(0,X.lastIndexOf("/")+1):"";var q=V.print||console.log.bind(console),Z=V.printErr||console.warn.bind(console);for($ in Q)Q.hasOwnProperty($)&&(V[$]=Q[$]);Q=null,V.quit&&(r=V.quit);var J,G,tt={"f64-rem":function(t,e){return t%e},debugger:function(){}},et=0;V.wasmBinary&&(J=V.wasmBinary),V.noExitRuntime&&(G=V.noExitRuntime),"object"!=typeof WebAssembly&&Z("no native wasm support detected");var rt,nt=new WebAssembly.Table({initial:462,maximum:462,element:"anyfunc"}),at=!1,ot="undefined"!=typeof TextDecoder?new TextDecoder("utf8"):void 0;"undefined"!=typeof TextDecoder&&new TextDecoder("utf-16le");var it,st,ft,ut,ct,lt=V.TOTAL_MEMORY||16777216;(rt=V.wasmMemory?V.wasmMemory:new WebAssembly.Memory({initial:lt/65536}))&&(it=rt.buffer),lt=it.byteLength,o(it),ct[15676]=5305792;var ht=[],pt=[],_t=[],dt=[],yt=Math.abs,vt=Math.ceil,wt=Math.floor,bt=Math.min,mt=0,Et=null;V.preloadedImages={},V.preloadedAudios={};var Pt="libpythia.browser.wasm";if(!u()){var At=Pt;Pt=V.locateFile?V.locateFile(At,X):X+At;}V.asm=function(){function t(t){V.asm=t.exports,mt--,V.monitorRunDependencies&&V.monitorRunDependencies(mt),0==mt&&(Et&&(t=Et,Et=null,t()));}function e(e){t(e.instance);}function r(t){return (J||"function"!=typeof fetch?new Promise((function(t){t(c());})):fetch(Pt,{credentials:"same-origin"}).then((function(t){if(!t.ok)throw "failed to load wasm binary file at '"+Pt+"'";return t.arrayBuffer()})).catch((function(){return c()}))).then((function(t){return WebAssembly.instantiate(t,n)})).then(t,(function(t){Z("failed to asynchronously prepare wasm: "+t),f(t);}))}var n={env:qt,wasi_unstable:qt,global:{NaN:NaN,Infinity:1/0},"global.Math":Math,asm2wasm:tt};if(mt++,V.monitorRunDependencies&&V.monitorRunDependencies(mt),V.instantiateWasm)try{return V.instantiateWasm(n,t)}catch(t){return Z("Module.instantiateWasm callback failed with error: "+t),!1}return function(){if(J||"function"!=typeof WebAssembly.instantiateStreaming||u()||"function"!=typeof fetch)return r(e);fetch(Pt,{credentials:"same-origin"}).then((function(t){return WebAssembly.instantiateStreaming(t,n).then(e,(function(t){Z("wasm streaming compile failed: "+t),Z("falling back to ArrayBuffer instantiation"),r(e);}))}));}(),{}};var Bt,Tt,Lt,St,Mt,xt,Ut,Rt=[],kt={open:function(t){var e=Rt[t.node.eb];if(!e)throw new Ft(43);t.Pa=e,t.seekable=!1;},close:function(t){t.Pa.Ya.flush(t.Pa);},flush:function(t){t.Pa.Ya.flush(t.Pa);},read:function(t,e,r,n){if(!t.Pa||!t.Pa.Ya.pb)throw new Ft(60);for(var a=0,o=0;o<n;o++){try{var i=t.Pa.Ya.pb(t.Pa);}catch(t){throw new Ft(29)}if(void 0===i&&0===a)throw new Ft(6);if(null==i)break;a++,e[r+o]=i;}return a&&(t.node.timestamp=Date.now()),a},write:function(t,e,r,n){if(!t.Pa||!t.Pa.Ya.ib)throw new Ft(60);try{for(var a=0;a<n;a++)t.Pa.Ya.ib(t.Pa,e[r+a]);}catch(t){throw new Ft(29)}return n&&(t.node.timestamp=Date.now()),a}},Nt={pb:function(t){if(!t.input.length){var e=null;if("undefined"!=typeof window&&"function"==typeof window.prompt?null!==(e=window.prompt("Input: "))&&(e+="\n"):"function"==typeof readline&&null!==(e=readline())&&(e+="\n"),!e)return null;for(var r=0,n=0;n<e.length;++n){var a=e.charCodeAt(n);55296<=a&&57343>=a&&(a=65536+((1023&a)<<10)|1023&e.charCodeAt(++n)),127>=a?++r:r=2047>=a?r+2:65535>=a?r+3:r+4;}var o=(r=Array(r+1)).length;if(n=0,0<o){a=n,o=n+o-1;for(var i=0;i<e.length;++i){var s=e.charCodeAt(i);if(55296<=s&&57343>=s&&(s=65536+((1023&s)<<10)|1023&e.charCodeAt(++i)),127>=s){if(n>=o)break;r[n++]=s;}else{if(2047>=s){if(n+1>=o)break;r[n++]=192|s>>6;}else{if(65535>=s){if(n+2>=o)break;r[n++]=224|s>>12;}else{if(n+3>=o)break;r[n++]=240|s>>18,r[n++]=128|s>>12&63;}r[n++]=128|s>>6&63;}r[n++]=128|63&s;}}r[n]=0,e=n-a;}else e=0;r.length=e,t.input=r;}return t.input.shift()},ib:function(t,e){null===e||10===e?(q(n(t.Qa,0)),t.Qa=[]):0!=e&&t.Qa.push(e);},flush:function(t){t.Qa&&0<t.Qa.length&&(q(n(t.Qa,0)),t.Qa=[]);}},Ct={ib:function(t,e){null===e||10===e?(Z(n(t.Qa,0)),t.Qa=[]):0!=e&&t.Qa.push(e);},flush:function(t){t.Qa&&0<t.Qa.length&&(Z(n(t.Qa,0)),t.Qa=[]);}},Ot={Ra:null,Ta:function(){return Ot.createNode(null,"/",16895,0)},createNode:function(t,e,r,n){if(24576==(61440&r)||4096==(61440&r))throw new Ft(63);return Ot.Ra||(Ot.Ra={dir:{node:{Wa:Ot.Ma.Wa,Sa:Ot.Ma.Sa,$a:Ot.Ma.$a,bb:Ot.Ma.bb,ub:Ot.Ma.ub,wb:Ot.Ma.wb,vb:Ot.Ma.vb,tb:Ot.Ma.tb,fb:Ot.Ma.fb},stream:{Xa:Ot.Na.Xa}},file:{node:{Wa:Ot.Ma.Wa,Sa:Ot.Ma.Sa},stream:{Xa:Ot.Na.Xa,read:Ot.Na.read,write:Ot.Na.write,kb:Ot.Na.kb,qb:Ot.Na.qb,sb:Ot.Na.sb}},link:{node:{Wa:Ot.Ma.Wa,Sa:Ot.Ma.Sa,ab:Ot.Ma.ab},stream:{}},lb:{node:{Wa:Ot.Ma.Wa,Sa:Ot.Ma.Sa},stream:$t}}),16384==(61440&(r=g(t,e,r,n)).mode)?(r.Ma=Ot.Ra.dir.node,r.Na=Ot.Ra.dir.stream,r.La={}):32768==(61440&r.mode)?(r.Ma=Ot.Ra.file.node,r.Na=Ot.Ra.file.stream,r.Oa=0,r.La=null):40960==(61440&r.mode)?(r.Ma=Ot.Ra.link.node,r.Na=Ot.Ra.link.stream):8192==(61440&r.mode)&&(r.Ma=Ot.Ra.lb.node,r.Na=Ot.Ra.lb.stream),r.timestamp=Date.now(),t&&(t.La[e]=r),r},Kb:function(t){if(t.La&&t.La.subarray){for(var e=[],r=0;r<t.Oa;++r)e.push(t.La[r]);return e}return t.La},Lb:function(t){return t.La?t.La.subarray?t.La.subarray(0,t.Oa):new Uint8Array(t.La):new Uint8Array},mb:function(t,e){var r=t.La?t.La.length:0;r>=e||(e=Math.max(e,r*(1048576>r?2:1.125)|0),0!=r&&(e=Math.max(e,256)),r=t.La,t.La=new Uint8Array(e),0<t.Oa&&t.La.set(r.subarray(0,t.Oa),0));},Bb:function(t,e){if(t.Oa!=e)if(0==e)t.La=null,t.Oa=0;else{if(!t.La||t.La.subarray){var r=t.La;t.La=new Uint8Array(new ArrayBuffer(e)),r&&t.La.set(r.subarray(0,Math.min(e,t.Oa)));}else if(t.La||(t.La=[]),t.La.length>e)t.La.length=e;else for(;t.La.length<e;)t.La.push(0);t.Oa=e;}},Ma:{Wa:function(t){var e={};return e.Ib=8192==(61440&t.mode)?t.id:1,e.Nb=t.id,e.mode=t.mode,e.Pb=1,e.uid=0,e.Mb=0,e.eb=t.eb,16384==(61440&t.mode)?e.size=4096:32768==(61440&t.mode)?e.size=t.Oa:40960==(61440&t.mode)?e.size=t.link.length:e.size=0,e.Fb=new Date(t.timestamp),e.Ob=new Date(t.timestamp),e.Hb=new Date(t.timestamp),e.xb=4096,e.Gb=Math.ceil(e.size/e.xb),e},Sa:function(t,e){void 0!==e.mode&&(t.mode=e.mode),void 0!==e.timestamp&&(t.timestamp=e.timestamp),void 0!==e.size&&Ot.Bb(t,e.size);},$a:function(){throw Wt[44]},bb:function(t,e,r,n){return Ot.createNode(t,e,r,n)},ub:function(t,e,r){if(16384==(61440&t.mode)){try{var n=m(e,r);}catch(t){}if(n)for(var a in n.La)throw new Ft(55)}delete t.parent.La[t.name],t.name=r,e.La[r]=t,t.parent=e;},wb:function(t,e){delete t.La[e];},vb:function(t,e){var r,n=m(t,e);for(r in n.La)throw new Ft(55);delete t.La[e];},tb:function(t){var e,r=[".",".."];for(e in t.La)t.La.hasOwnProperty(e)&&r.push(e);return r},fb:function(t,e,r){return (t=Ot.createNode(t,e,41471,0)).link=r,t},ab:function(t){if(40960!=(61440&t.mode))throw new Ft(28);return t.link}},Na:{read:function(t,e,r,n,a){var o=t.node.La;if(a>=t.node.Oa)return 0;if(8<(t=Math.min(t.node.Oa-a,n))&&o.subarray)e.set(o.subarray(a,a+t),r);else for(n=0;n<t;n++)e[r+n]=o[a+n];return t},write:function(t,e,r,n,a,o){if(o=!1,!n)return 0;if((t=t.node).timestamp=Date.now(),e.subarray&&(!t.La||t.La.subarray)){if(o)return t.La=e.subarray(r,r+n),t.Oa=n;if(0===t.Oa&&0===a)return t.La=new Uint8Array(e.subarray(r,r+n)),t.Oa=n;if(a+n<=t.Oa)return t.La.set(e.subarray(r,r+n),a),n}if(Ot.mb(t,a+n),t.La.subarray&&e.subarray)t.La.set(e.subarray(r,r+n),a);else for(o=0;o<n;o++)t.La[a+o]=e[r+o];return t.Oa=Math.max(t.Oa,a+n),n},Xa:function(t,e,r){if(1===r?e+=t.position:2===r&&32768==(61440&t.node.mode)&&(e+=t.node.Oa),0>e)throw new Ft(28);return e},kb:function(t,e,r){Ot.mb(t.node,e+r),t.node.Oa=Math.max(t.node.Oa,e+r);},qb:function(t,e,r,n,a,o,i){if(32768!=(61440&t.node.mode))throw new Ft(43);if(r=t.node.La,2&i||r.buffer!==e&&r.buffer!==e.buffer){if((0<a||a+n<t.node.Oa)&&(r=r.subarray?r.subarray(a,a+n):Array.prototype.slice.call(r,a,a+n)),t=!0,a=e.buffer==st.buffer,!(n=Jt(n)))throw new Ft(48);(a?st:e).set(r,n);}else t=!1,n=r.byteOffset;return {Rb:n,Eb:t}},sb:function(t,e,r,n,a){if(32768!=(61440&t.node.mode))throw new Ft(43);return 2&a?0:(Ot.Na.write(t,e,0,n,r,!1),0)}}},It=null,zt={},Ht=[],jt=1,Yt=null,Dt=!0,Kt={},Ft=null,Wt={},Vt={r:0,rs:1052672,"r+":2,w:577,wx:705,xw:705,"w+":578,"wx+":706,"xw+":706,a:1089,ax:1217,xa:1217,"a+":1090,"ax+":1218,"xa+":1218},$t={open:function(t){t.Na=zt[t.node.eb].Na,t.Na.open&&t.Na.open(t);},Xa:function(){throw new Ft(70)}},Qt={},Xt=0;C(),Yt=Array(4096),T(Ot,"/"),S("/tmp"),S("/home"),S("/home/web_user"),function(){if(S("/dev"),B(259,{read:function(){return 0},write:function(t,e,r,n){return n}}),M("/dev/null",259),y(1280,Nt),y(1536,Ct),M("/dev/tty",1280),M("/dev/tty1",1536),"object"==typeof crypto&&"function"==typeof crypto.getRandomValues)var t=new Uint8Array(1),e=function(){return crypto.getRandomValues(t),t[0]};e||(e=function(){f("random_device");}),O("random",e),O("urandom",e),S("/dev/shm"),S("/dev/shm/tmp");}(),S("/proc"),S("/proc/self"),S("/proc/self/fd"),T({Ta:function(){var t=g("/proc/self","fd",16895,73);return t.Ma={$a:function(t,e){var r=Ht[+e];if(!r)throw new Ft(8);return (t={parent:null,Ta:{rb:"fake"},Ma:{ab:function(){return r.path}}}).parent=t}},t}},"/proc/self/fd");var qt={u:function(){},J:function(t,e){Xt=e;try{var r=z(),n=I(),a=I(),o=I(),i=I();return -9007199254740992>=(t=4294967296*n+(a>>>0))||9007199254740992<=t?-61:(k(r,t,i),Tt=[r.position>>>0,(Bt=r.position,1<=+yt(Bt)?0<Bt?(0|bt(+wt(Bt/4294967296),4294967295))>>>0:~~+vt((Bt-+(~~Bt>>>0))/4294967296)>>>0:0)],ct[o>>2]=Tt[0],ct[o+4>>2]=Tt[1],r.hb&&0===t&&0===i&&(r.hb=null),0)}catch(t){return void 0!==Qt&&t instanceof Ft||f(t),-t.Ua}},I:function(t,e){Xt=e;try{var r=z(),n=I();t:{var a=I();for(e=t=0;e<a;e++){var o=ct[n+(8*e+4)>>2],i=N(r,ct[n+8*e>>2],o,void 0);if(0>i){var s=-1;break t}if(t+=i,i<o)break}s=t;}return s}catch(t){return void 0!==Qt&&t instanceof Ft||f(t),-t.Ua}},x:function(t,e){Xt=e;try{var r=z();switch(I()){case 0:var n=I();return 0>n?-28:R(r.path,r.flags,0,n).Va;case 1:case 2:return 0;case 3:return r.flags;case 4:return n=I(),r.flags|=n,0;case 12:return n=I(),ut[n+0>>1]=2,0;case 13:case 14:return 0;case 16:case 8:return -28;case 9:return V.___errno_location&&(ct[V.___errno_location()>>2]=28),-1;default:return -28}}catch(t){return void 0!==Qt&&t instanceof Ft||f(t),-t.Ua}},H:function(t,e){Xt=e;try{return N(z(),I(),I())}catch(t){return void 0!==Qt&&t instanceof Ft||f(t),-t.Ua}},w:function(t,e){Xt=e;try{var r=I();return R(r?n(ft,r,void 0):"",I(),I()).Va}catch(t){return void 0!==Qt&&t instanceof Ft||f(t),-t.Ua}},G:function(t,e){Xt=e;try{var r=z(),n=I();switch(n){case 21509:case 21505:return r.Pa?0:-59;case 21510:case 21511:case 21512:case 21506:case 21507:case 21508:return r.Pa?0:-59;case 21519:if(!r.Pa)return -59;var a=I();return ct[a>>2]=0;case 21520:return r.Pa?-28:-59;case 21531:if(t=I(),!r.Na.yb)throw new Ft(59);return r.Na.yb(r,n,t);case 21523:case 21524:return r.Pa?0:-59;default:f("bad ioctl syscall "+n);}}catch(t){return void 0!==Qt&&t instanceof Ft||f(t),-t.Ua}},t:function(){},s:function(){return H.apply(null,arguments)},F:function(){return j.apply(null,arguments)},__memory_base:1024,__table_base:0,E:function(){f();},D:Y,C:function(t,e){D(t,e);},B:function(t,e,r){ft.set(ft.subarray(e,e+r),t);},A:function(t){if(2147418112<t)return !1;for(var e=Math.max(Y(),16777216);e<t;)e=536870912>=e?a(2*e):Math.min(a((3*e+2147483648)/4),2147418112);t:{try{rt.grow(e-it.byteLength+65535>>16),o(rt.buffer),t=1;break t}catch(t){}t=void 0;}return !!t},j:function(t){!G&&(at=!0,V.onExit)&&V.onExit(t),r(t,new F(t));},v:function(t){var e=Date.now();return ct[t>>2]=e/1e3|0,ct[t+4>>2]=e%1e3*1e3|0,0},o:function(t){var e=K.Za[t];K.Za.splice(t,1),ee(e);},q:K,b:D,m:f,a:function(){return et},g:function(t){var e=re();try{return ne(t)}catch(t){if(ee(e),t!==t+0&&"longjmp"!==t)throw t;Gt(1,0);}},i:function(t,e){var r=re();try{return ae(t,e)}catch(t){if(ee(r),t!==t+0&&"longjmp"!==t)throw t;Gt(1,0);}},h:function(t,e,r){var n=re();try{return oe(t,e,r)}catch(t){if(ee(n),t!==t+0&&"longjmp"!==t)throw t;Gt(1,0);}},p:function(t,e,r,n){var a=re();try{return ie(t,e,r,n)}catch(t){if(ee(a),t!==t+0&&"longjmp"!==t)throw t;Gt(1,0);}},z:function(t,e,r,n,a){var o=re();try{return se(t,e,r,n,a)}catch(t){if(ee(o),t!==t+0&&"longjmp"!==t)throw t;Gt(1,0);}},l:function(t){var e=re();try{fe(t);}catch(t){if(ee(e),t!==t+0&&"longjmp"!==t)throw t;Gt(1,0);}},d:function(t,e){var r=re();try{ue(t,e);}catch(t){if(ee(r),t!==t+0&&"longjmp"!==t)throw t;Gt(1,0);}},e:function(t,e,r){var n=re();try{ce(t,e,r);}catch(t){if(ee(n),t!==t+0&&"longjmp"!==t)throw t;Gt(1,0);}},f:function(t,e,r,n){var a=re();try{le(t,e,r,n);}catch(t){if(ee(a),t!==t+0&&"longjmp"!==t)throw t;Gt(1,0);}},k:function(t,e,r,n,a){var o=re();try{he(t,e,r,n,a);}catch(t){if(ee(o),t!==t+0&&"longjmp"!==t)throw t;Gt(1,0);}},r:function(t,e,r,n,a,o){var i=re();try{pe(t,e,r,n,a,o);}catch(t){if(ee(i),t!==t+0&&"longjmp"!==t)throw t;Gt(1,0);}},n:function(t,e,r,n,a,o,i){var s=re();try{_e(t,e,r,n,a,o,i);}catch(t){if(ee(s),t!==t+0&&"longjmp"!==t)throw t;Gt(1,0);}},K:function(t,e,r,n,a,o,i,s){var f=re();try{de(t,e,r,n,a,o,i,s);}catch(t){if(ee(f),t!==t+0&&"longjmp"!==t)throw t;Gt(1,0);}},y:function(t,e,r,n,a,o,i,s,f){var u=re();try{ye(t,e,r,n,a,o,i,s,f);}catch(t){if(ee(u),t!==t+0&&"longjmp"!==t)throw t;Gt(1,0);}},memory:rt,c:function(t){et=t;},table:nt},Zt=V.asm({},qt,it);V.asm=Zt,V.___errno_location=function(){return V.asm.L.apply(null,arguments)},V._free=function(){return V.asm.M.apply(null,arguments)};var Jt=V._malloc=function(){return V.asm.N.apply(null,arguments)},Gt=V._setThrew=function(){return V.asm.O.apply(null,arguments)};V._vsc_buffer_bytes=function(){return V.asm.P.apply(null,arguments)},V._vsc_buffer_data=function(){return V.asm.Q.apply(null,arguments)},V._vsc_buffer_delete=function(){return V.asm.R.apply(null,arguments)},V._vsc_buffer_len=function(){return V.asm.S.apply(null,arguments)},V._vsc_buffer_make_secure=function(){return V.asm.T.apply(null,arguments)},V._vsc_buffer_new=function(){return V.asm.U.apply(null,arguments)},V._vsc_buffer_new_with_capacity=function(){return V.asm.V.apply(null,arguments)},V._vsc_data=function(){return V.asm.W.apply(null,arguments)},V._vsc_data_bytes=function(){return V.asm.X.apply(null,arguments)},V._vsc_data_ctx_size=function(){return V.asm.Y.apply(null,arguments)},V._vsc_data_len=function(){return V.asm.Z.apply(null,arguments)},V._vscp_error_ctx_size=function(){return V.asm._.apply(null,arguments)},V._vscp_error_reset=function(){return V.asm.$.apply(null,arguments)},V._vscp_error_status=function(){return V.asm.aa.apply(null,arguments)},V._vscp_pythia_blind=function(){return V.asm.ba.apply(null,arguments)},V._vscp_pythia_blinded_password_buf_len=function(){return V.asm.ca.apply(null,arguments)},V._vscp_pythia_blinding_secret_buf_len=function(){return V.asm.da.apply(null,arguments)},V._vscp_pythia_cleanup=function(){return V.asm.ea.apply(null,arguments)},V._vscp_pythia_compute_transformation_key_pair=function(){return V.asm.fa.apply(null,arguments)},V._vscp_pythia_configure=function(){return V.asm.ga.apply(null,arguments)},V._vscp_pythia_deblind=function(){return V.asm.ha.apply(null,arguments)},V._vscp_pythia_deblinded_password_buf_len=function(){return V.asm.ia.apply(null,arguments)},V._vscp_pythia_get_password_update_token=function(){return V.asm.ja.apply(null,arguments)},V._vscp_pythia_password_update_token_buf_len=function(){return V.asm.ka.apply(null,arguments)},V._vscp_pythia_proof_value_buf_len=function(){return V.asm.la.apply(null,arguments)},V._vscp_pythia_prove=function(){return V.asm.ma.apply(null,arguments)},V._vscp_pythia_transform=function(){return V.asm.na.apply(null,arguments)},V._vscp_pythia_transformation_private_key_buf_len=function(){return V.asm.oa.apply(null,arguments)},V._vscp_pythia_transformation_public_key_buf_len=function(){return V.asm.pa.apply(null,arguments)},V._vscp_pythia_transformed_password_buf_len=function(){return V.asm.qa.apply(null,arguments)},V._vscp_pythia_transformed_tweak_buf_len=function(){return V.asm.ra.apply(null,arguments)},V._vscp_pythia_update_deblinded_with_token=function(){return V.asm.sa.apply(null,arguments)},V._vscp_pythia_verify=function(){return V.asm.ta.apply(null,arguments)},V.stackAlloc=function(){return V.asm.Ia.apply(null,arguments)};var te,ee=V.stackRestore=function(){return V.asm.Ja.apply(null,arguments)},re=V.stackSave=function(){return V.asm.Ka.apply(null,arguments)},ne=V.dynCall_i=function(){return V.asm.ua.apply(null,arguments)},ae=V.dynCall_ii=function(){return V.asm.va.apply(null,arguments)},oe=V.dynCall_iii=function(){return V.asm.wa.apply(null,arguments)},ie=V.dynCall_iiii=function(){return V.asm.xa.apply(null,arguments)},se=V.dynCall_iiiii=function(){return V.asm.ya.apply(null,arguments)},fe=V.dynCall_v=function(){return V.asm.za.apply(null,arguments)},ue=V.dynCall_vi=function(){return V.asm.Aa.apply(null,arguments)},ce=V.dynCall_vii=function(){return V.asm.Ba.apply(null,arguments)},le=V.dynCall_viii=function(){return V.asm.Ca.apply(null,arguments)},he=V.dynCall_viiii=function(){return V.asm.Da.apply(null,arguments)},pe=V.dynCall_viiiii=function(){return V.asm.Ea.apply(null,arguments)},_e=V.dynCall_viiiiii=function(){return V.asm.Fa.apply(null,arguments)},de=V.dynCall_viiiiiii=function(){return V.asm.Ga.apply(null,arguments)},ye=V.dynCall_viiiiiiii=function(){return V.asm.Ha.apply(null,arguments)};if(V.asm=Zt,V.then=function(t){if(te)t(V);else{var e=V.onRuntimeInitialized;V.onRuntimeInitialized=function(){e&&e(),t(V);};}return V},Et=function t(){te||W(),te||(Et=t);},V.run=W,V.preInit)for("function"==typeof V.preInit&&(V.preInit=[V.preInit]);0<V.preInit.length;)V.preInit.pop()();return G=!0,W(),e}}(),r$3.exports=n$3,t$2=e$2.exports;let u$2;const c$2=t=>{if(u$2)return void console.warn("Pythia modules are already set. Further calls to `setPythiaModules` are ignored.");u$2=t;const{Pythia:e}=u$2;try{e.configure();}catch(t){throw e.cleanup(),t}},l$2=()=>{if(!u$2)throw new Error("You need to call `setPythiaModules` first");return u$2},h$1=()=>void 0!==u$2;for(var _$1=function(t){var e=P$1(t),r=e[0],n=e[1];return 3*(r+n)/4-n},d$1=function(t){var e,r,n=P$1(t),a=n[0],o=n[1],i=new b$1(function(t,e,r){return 3*(e+r)/4-r}(0,a,o)),s=0,f=o>0?a-4:a;for(r=0;r<f;r+=4)e=w$1[t.charCodeAt(r)]<<18|w$1[t.charCodeAt(r+1)]<<12|w$1[t.charCodeAt(r+2)]<<6|w$1[t.charCodeAt(r+3)],i[s++]=e>>16&255,i[s++]=e>>8&255,i[s++]=255&e;2===o&&(e=w$1[t.charCodeAt(r)]<<2|w$1[t.charCodeAt(r+1)]>>4,i[s++]=255&e);1===o&&(e=w$1[t.charCodeAt(r)]<<10|w$1[t.charCodeAt(r+1)]<<4|w$1[t.charCodeAt(r+2)]>>2,i[s++]=e>>8&255,i[s++]=255&e);return i},y$2=function(t){for(var e,r=t.length,n=r%3,a=[],o=0,i=r-n;o<i;o+=16383)a.push(A$1(t,o,o+16383>i?i:o+16383));1===n?(e=t[r-1],a.push(v$3[e>>2]+v$3[e<<4&63]+"==")):2===n&&(e=(t[r-2]<<8)+t[r-1],a.push(v$3[e>>10]+v$3[e>>4&63]+v$3[e<<2&63]+"="));return a.join("")},v$3=[],w$1=[],b$1="undefined"!=typeof Uint8Array?Uint8Array:Array,m$2="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",g$2=0,E$1=m$2.length;g$2<E$1;++g$2)v$3[g$2]=m$2[g$2],w$1[m$2.charCodeAt(g$2)]=g$2;function P$1(t){var e=t.length;if(e%4>0)throw new Error("Invalid string. Length must be a multiple of 4");var r=t.indexOf("=");return -1===r&&(r=e),[r,r===e?0:4-r%4]}function A$1(t,e,r){for(var n,a,o=[],i=e;i<r;i+=3)n=(t[i]<<16&16711680)+(t[i+1]<<8&65280)+(255&t[i+2]),o.push(v$3[(a=n)>>18&63]+v$3[a>>12&63]+v$3[a>>6&63]+v$3[63&a]);return o.join("")}w$1["-".charCodeAt(0)]=62,w$1["_".charCodeAt(0)]=63;var B$1,T$1={byteLength:_$1,toByteArray:d$1,fromByteArray:y$2},L$1={read:function(t,e,r,n,a){var o,i,s=8*a-n-1,f=(1<<s)-1,u=f>>1,c=-7,l=r?a-1:0,h=r?-1:1,p=t[e+l];for(l+=h,o=p&(1<<-c)-1,p>>=-c,c+=s;c>0;o=256*o+t[e+l],l+=h,c-=8);for(i=o&(1<<-c)-1,o>>=-c,c+=n;c>0;i=256*i+t[e+l],l+=h,c-=8);if(0===o)o=1-u;else{if(o===f)return i?NaN:1/0*(p?-1:1);i+=Math.pow(2,n),o-=u;}return (p?-1:1)*i*Math.pow(2,o-n)},write:function(t,e,r,n,a,o){var i,s,f,u=8*o-a-1,c=(1<<u)-1,l=c>>1,h=23===a?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:o-1,_=n?1:-1,d=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(s=isNaN(e)?1:0,i=c):(i=Math.floor(Math.log(e)/Math.LN2),e*(f=Math.pow(2,-i))<1&&(i--,f*=2),(e+=i+l>=1?h/f:h*Math.pow(2,1-l))*f>=2&&(i++,f/=2),i+l>=c?(s=0,i=c):i+l>=1?(s=(e*f-1)*Math.pow(2,a),i+=l):(s=e*Math.pow(2,l-1)*Math.pow(2,a),i=0));a>=8;t[r+p]=255&s,p+=_,s/=256,a-=8);for(i=i<<a|s,u+=a;u>0;t[r+p]=255&i,p+=_,i/=256,u-=8);t[r+p-_]|=128*d;}},S$1=(function(t,e){var r="function"==typeof Symbol&&"function"==typeof Symbol.for?Symbol.for("nodejs.util.inspect.custom"):null;e.Buffer=o,e.SlowBuffer=function(t){return +t!=t&&(t=0),o.alloc(+t)},e.INSPECT_MAX_BYTES=50;var n=2147483647;function a(t){if(t>n)throw new RangeError('The value "'+t+'" is invalid for option "size"');var e=new Uint8Array(t);return Object.setPrototypeOf(e,o.prototype),e}function o(t,e,r){if("number"==typeof t){if("string"==typeof e)throw new TypeError('The "string" argument must be of type string. Received type number');return f(t)}return i(t,e,r)}function i(t,e,r){if("string"==typeof t)return function(t,e){if("string"==typeof e&&""!==e||(e="utf8"),!o.isEncoding(e))throw new TypeError("Unknown encoding: "+e);var r=0|l(t,e),n=a(r),i=n.write(t,e);return i!==r&&(n=n.slice(0,i)),n}(t,e);if(ArrayBuffer.isView(t))return u(t);if(null==t)throw new TypeError("The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type "+typeof t);if(j(t,ArrayBuffer)||t&&j(t.buffer,ArrayBuffer))return function(t,e,r){if(e<0||t.byteLength<e)throw new RangeError('"offset" is outside of buffer bounds');if(t.byteLength<e+(r||0))throw new RangeError('"length" is outside of buffer bounds');var n;return n=void 0===e&&void 0===r?new Uint8Array(t):void 0===r?new Uint8Array(t,e):new Uint8Array(t,e,r),Object.setPrototypeOf(n,o.prototype),n}(t,e,r);if("number"==typeof t)throw new TypeError('The "value" argument must not be of type number. Received type number');var n=t.valueOf&&t.valueOf();if(null!=n&&n!==t)return o.from(n,e,r);var i=function(t){if(o.isBuffer(t)){var e=0|c(t.length),r=a(e);return 0===r.length?r:(t.copy(r,0,0,e),r)}return void 0!==t.length?"number"!=typeof t.length||Y(t.length)?a(0):u(t):"Buffer"===t.type&&Array.isArray(t.data)?u(t.data):void 0}(t);if(i)return i;if("undefined"!=typeof Symbol&&null!=Symbol.toPrimitive&&"function"==typeof t[Symbol.toPrimitive])return o.from(t[Symbol.toPrimitive]("string"),e,r);throw new TypeError("The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type "+typeof t)}function s(t){if("number"!=typeof t)throw new TypeError('"size" argument must be of type number');if(t<0)throw new RangeError('The value "'+t+'" is invalid for option "size"')}function f(t){return s(t),a(t<0?0:0|c(t))}function u(t){for(var e=t.length<0?0:0|c(t.length),r=a(e),n=0;n<e;n+=1)r[n]=255&t[n];return r}function c(t){if(t>=n)throw new RangeError("Attempt to allocate Buffer larger than maximum size: 0x"+n.toString(16)+" bytes");return 0|t}function l(t,e){if(o.isBuffer(t))return t.length;if(ArrayBuffer.isView(t)||j(t,ArrayBuffer))return t.byteLength;if("string"!=typeof t)throw new TypeError('The "string" argument must be one of type string, Buffer, or ArrayBuffer. Received type '+typeof t);var r=t.length,n=arguments.length>2&&!0===arguments[2];if(!n&&0===r)return 0;for(var a=!1;;)switch(e){case"ascii":case"latin1":case"binary":return r;case"utf8":case"utf-8":return I(t).length;case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return 2*r;case"hex":return r>>>1;case"base64":return z(t).length;default:if(a)return n?-1:I(t).length;e=(""+e).toLowerCase(),a=!0;}}function h(t,e,r){var n=!1;if((void 0===e||e<0)&&(e=0),e>this.length)return "";if((void 0===r||r>this.length)&&(r=this.length),r<=0)return "";if((r>>>=0)<=(e>>>=0))return "";for(t||(t="utf8");;)switch(t){case"hex":return M(this,e,r);case"utf8":case"utf-8":return P(this,e,r);case"ascii":return B(this,e,r);case"latin1":case"binary":return S(this,e,r);case"base64":return E(this,e,r);case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return x(this,e,r);default:if(n)throw new TypeError("Unknown encoding: "+t);t=(t+"").toLowerCase(),n=!0;}}function p(t,e,r){var n=t[e];t[e]=t[r],t[r]=n;}function _(t,e,r,n,a){if(0===t.length)return -1;if("string"==typeof r?(n=r,r=0):r>2147483647?r=2147483647:r<-2147483648&&(r=-2147483648),Y(r=+r)&&(r=a?0:t.length-1),r<0&&(r=t.length+r),r>=t.length){if(a)return -1;r=t.length-1;}else if(r<0){if(!a)return -1;r=0;}if("string"==typeof e&&(e=o.from(e,n)),o.isBuffer(e))return 0===e.length?-1:d(t,e,r,n,a);if("number"==typeof e)return e&=255,"function"==typeof Uint8Array.prototype.indexOf?a?Uint8Array.prototype.indexOf.call(t,e,r):Uint8Array.prototype.lastIndexOf.call(t,e,r):d(t,[e],r,n,a);throw new TypeError("val must be string, number or Buffer")}function d(t,e,r,n,a){var o,i=1,s=t.length,f=e.length;if(void 0!==n&&("ucs2"===(n=String(n).toLowerCase())||"ucs-2"===n||"utf16le"===n||"utf-16le"===n)){if(t.length<2||e.length<2)return -1;i=2,s/=2,f/=2,r/=2;}function u(t,e){return 1===i?t[e]:t.readUInt16BE(e*i)}if(a){var c=-1;for(o=r;o<s;o++)if(u(t,o)===u(e,-1===c?0:o-c)){if(-1===c&&(c=o),o-c+1===f)return c*i}else-1!==c&&(o-=o-c),c=-1;}else for(r+f>s&&(r=s-f),o=r;o>=0;o--){for(var l=!0,h=0;h<f;h++)if(u(t,o+h)!==u(e,h)){l=!1;break}if(l)return o}return -1}function y(t,e,r,n){r=Number(r)||0;var a=t.length-r;n?(n=Number(n))>a&&(n=a):n=a;var o=e.length;n>o/2&&(n=o/2);for(var i=0;i<n;++i){var s=parseInt(e.substr(2*i,2),16);if(Y(s))return i;t[r+i]=s;}return i}function v(t,e,r,n){return H(I(e,t.length-r),t,r,n)}function w(t,e,r,n){return H(function(t){for(var e=[],r=0;r<t.length;++r)e.push(255&t.charCodeAt(r));return e}(e),t,r,n)}function b(t,e,r,n){return w(t,e,r,n)}function m(t,e,r,n){return H(z(e),t,r,n)}function g(t,e,r,n){return H(function(t,e){for(var r,n,a,o=[],i=0;i<t.length&&!((e-=2)<0);++i)r=t.charCodeAt(i),n=r>>8,a=r%256,o.push(a),o.push(n);return o}(e,t.length-r),t,r,n)}function E(t,e,r){return 0===e&&r===t.length?T$1.fromByteArray(t):T$1.fromByteArray(t.slice(e,r))}function P(t,e,r){r=Math.min(t.length,r);for(var n=[],a=e;a<r;){var o,i,s,f,u=t[a],c=null,l=u>239?4:u>223?3:u>191?2:1;if(a+l<=r)switch(l){case 1:u<128&&(c=u);break;case 2:128==(192&(o=t[a+1]))&&(f=(31&u)<<6|63&o)>127&&(c=f);break;case 3:o=t[a+1],i=t[a+2],128==(192&o)&&128==(192&i)&&(f=(15&u)<<12|(63&o)<<6|63&i)>2047&&(f<55296||f>57343)&&(c=f);break;case 4:o=t[a+1],i=t[a+2],s=t[a+3],128==(192&o)&&128==(192&i)&&128==(192&s)&&(f=(15&u)<<18|(63&o)<<12|(63&i)<<6|63&s)>65535&&f<1114112&&(c=f);}null===c?(c=65533,l=1):c>65535&&(c-=65536,n.push(c>>>10&1023|55296),c=56320|1023&c),n.push(c),a+=l;}return function(t){var e=t.length;if(e<=A)return String.fromCharCode.apply(String,t);for(var r="",n=0;n<e;)r+=String.fromCharCode.apply(String,t.slice(n,n+=A));return r}(n)}e.kMaxLength=n,o.TYPED_ARRAY_SUPPORT=function(){try{var t=new Uint8Array(1),e={foo:function(){return 42}};return Object.setPrototypeOf(e,Uint8Array.prototype),Object.setPrototypeOf(t,e),42===t.foo()}catch(t){return !1}}(),o.TYPED_ARRAY_SUPPORT||"undefined"==typeof console||"function"!=typeof console.error||console.error("This browser lacks typed array (Uint8Array) support which is required by `buffer` v5.x. Use `buffer` v4.x if you require old browser support."),Object.defineProperty(o.prototype,"parent",{enumerable:!0,get:function(){if(o.isBuffer(this))return this.buffer}}),Object.defineProperty(o.prototype,"offset",{enumerable:!0,get:function(){if(o.isBuffer(this))return this.byteOffset}}),"undefined"!=typeof Symbol&&null!=Symbol.species&&o[Symbol.species]===o&&Object.defineProperty(o,Symbol.species,{value:null,configurable:!0,enumerable:!1,writable:!1}),o.poolSize=8192,o.from=function(t,e,r){return i(t,e,r)},Object.setPrototypeOf(o.prototype,Uint8Array.prototype),Object.setPrototypeOf(o,Uint8Array),o.alloc=function(t,e,r){return function(t,e,r){return s(t),t<=0?a(t):void 0!==e?"string"==typeof r?a(t).fill(e,r):a(t).fill(e):a(t)}(t,e,r)},o.allocUnsafe=function(t){return f(t)},o.allocUnsafeSlow=function(t){return f(t)},o.isBuffer=function(t){return null!=t&&!0===t._isBuffer&&t!==o.prototype},o.compare=function(t,e){if(j(t,Uint8Array)&&(t=o.from(t,t.offset,t.byteLength)),j(e,Uint8Array)&&(e=o.from(e,e.offset,e.byteLength)),!o.isBuffer(t)||!o.isBuffer(e))throw new TypeError('The "buf1", "buf2" arguments must be one of type Buffer or Uint8Array');if(t===e)return 0;for(var r=t.length,n=e.length,a=0,i=Math.min(r,n);a<i;++a)if(t[a]!==e[a]){r=t[a],n=e[a];break}return r<n?-1:n<r?1:0},o.isEncoding=function(t){switch(String(t).toLowerCase()){case"hex":case"utf8":case"utf-8":case"ascii":case"latin1":case"binary":case"base64":case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return !0;default:return !1}},o.concat=function(t,e){if(!Array.isArray(t))throw new TypeError('"list" argument must be an Array of Buffers');if(0===t.length)return o.alloc(0);var r;if(void 0===e)for(e=0,r=0;r<t.length;++r)e+=t[r].length;var n=o.allocUnsafe(e),a=0;for(r=0;r<t.length;++r){var i=t[r];if(j(i,Uint8Array)&&(i=o.from(i)),!o.isBuffer(i))throw new TypeError('"list" argument must be an Array of Buffers');i.copy(n,a),a+=i.length;}return n},o.byteLength=l,o.prototype._isBuffer=!0,o.prototype.swap16=function(){var t=this.length;if(t%2!=0)throw new RangeError("Buffer size must be a multiple of 16-bits");for(var e=0;e<t;e+=2)p(this,e,e+1);return this},o.prototype.swap32=function(){var t=this.length;if(t%4!=0)throw new RangeError("Buffer size must be a multiple of 32-bits");for(var e=0;e<t;e+=4)p(this,e,e+3),p(this,e+1,e+2);return this},o.prototype.swap64=function(){var t=this.length;if(t%8!=0)throw new RangeError("Buffer size must be a multiple of 64-bits");for(var e=0;e<t;e+=8)p(this,e,e+7),p(this,e+1,e+6),p(this,e+2,e+5),p(this,e+3,e+4);return this},o.prototype.toString=function(){var t=this.length;return 0===t?"":0===arguments.length?P(this,0,t):h.apply(this,arguments)},o.prototype.toLocaleString=o.prototype.toString,o.prototype.equals=function(t){if(!o.isBuffer(t))throw new TypeError("Argument must be a Buffer");return this===t||0===o.compare(this,t)},o.prototype.inspect=function(){var t="",r=e.INSPECT_MAX_BYTES;return t=this.toString("hex",0,r).replace(/(.{2})/g,"$1 ").trim(),this.length>r&&(t+=" ... "),"<Buffer "+t+">"},r&&(o.prototype[r]=o.prototype.inspect),o.prototype.compare=function(t,e,r,n,a){if(j(t,Uint8Array)&&(t=o.from(t,t.offset,t.byteLength)),!o.isBuffer(t))throw new TypeError('The "target" argument must be one of type Buffer or Uint8Array. Received type '+typeof t);if(void 0===e&&(e=0),void 0===r&&(r=t?t.length:0),void 0===n&&(n=0),void 0===a&&(a=this.length),e<0||r>t.length||n<0||a>this.length)throw new RangeError("out of range index");if(n>=a&&e>=r)return 0;if(n>=a)return -1;if(e>=r)return 1;if(this===t)return 0;for(var i=(a>>>=0)-(n>>>=0),s=(r>>>=0)-(e>>>=0),f=Math.min(i,s),u=this.slice(n,a),c=t.slice(e,r),l=0;l<f;++l)if(u[l]!==c[l]){i=u[l],s=c[l];break}return i<s?-1:s<i?1:0},o.prototype.includes=function(t,e,r){return -1!==this.indexOf(t,e,r)},o.prototype.indexOf=function(t,e,r){return _(this,t,e,r,!0)},o.prototype.lastIndexOf=function(t,e,r){return _(this,t,e,r,!1)},o.prototype.write=function(t,e,r,n){if(void 0===e)n="utf8",r=this.length,e=0;else if(void 0===r&&"string"==typeof e)n=e,r=this.length,e=0;else{if(!isFinite(e))throw new Error("Buffer.write(string, encoding, offset[, length]) is no longer supported");e>>>=0,isFinite(r)?(r>>>=0,void 0===n&&(n="utf8")):(n=r,r=void 0);}var a=this.length-e;if((void 0===r||r>a)&&(r=a),t.length>0&&(r<0||e<0)||e>this.length)throw new RangeError("Attempt to write outside buffer bounds");n||(n="utf8");for(var o=!1;;)switch(n){case"hex":return y(this,t,e,r);case"utf8":case"utf-8":return v(this,t,e,r);case"ascii":return w(this,t,e,r);case"latin1":case"binary":return b(this,t,e,r);case"base64":return m(this,t,e,r);case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return g(this,t,e,r);default:if(o)throw new TypeError("Unknown encoding: "+n);n=(""+n).toLowerCase(),o=!0;}},o.prototype.toJSON=function(){return {type:"Buffer",data:Array.prototype.slice.call(this._arr||this,0)}};var A=4096;function B(t,e,r){var n="";r=Math.min(t.length,r);for(var a=e;a<r;++a)n+=String.fromCharCode(127&t[a]);return n}function S(t,e,r){var n="";r=Math.min(t.length,r);for(var a=e;a<r;++a)n+=String.fromCharCode(t[a]);return n}function M(t,e,r){var n=t.length;(!e||e<0)&&(e=0),(!r||r<0||r>n)&&(r=n);for(var a="",o=e;o<r;++o)a+=D[t[o]];return a}function x(t,e,r){for(var n=t.slice(e,r),a="",o=0;o<n.length;o+=2)a+=String.fromCharCode(n[o]+256*n[o+1]);return a}function U(t,e,r){if(t%1!=0||t<0)throw new RangeError("offset is not uint");if(t+e>r)throw new RangeError("Trying to access beyond buffer length")}function R(t,e,r,n,a,i){if(!o.isBuffer(t))throw new TypeError('"buffer" argument must be a Buffer instance');if(e>a||e<i)throw new RangeError('"value" argument is out of bounds');if(r+n>t.length)throw new RangeError("Index out of range")}function k(t,e,r,n,a,o){if(r+n>t.length)throw new RangeError("Index out of range");if(r<0)throw new RangeError("Index out of range")}function N(t,e,r,n,a){return e=+e,r>>>=0,a||k(t,0,r,4),L$1.write(t,e,r,n,23,4),r+4}function C(t,e,r,n,a){return e=+e,r>>>=0,a||k(t,0,r,8),L$1.write(t,e,r,n,52,8),r+8}o.prototype.slice=function(t,e){var r=this.length;(t=~~t)<0?(t+=r)<0&&(t=0):t>r&&(t=r),(e=void 0===e?r:~~e)<0?(e+=r)<0&&(e=0):e>r&&(e=r),e<t&&(e=t);var n=this.subarray(t,e);return Object.setPrototypeOf(n,o.prototype),n},o.prototype.readUIntLE=function(t,e,r){t>>>=0,e>>>=0,r||U(t,e,this.length);for(var n=this[t],a=1,o=0;++o<e&&(a*=256);)n+=this[t+o]*a;return n},o.prototype.readUIntBE=function(t,e,r){t>>>=0,e>>>=0,r||U(t,e,this.length);for(var n=this[t+--e],a=1;e>0&&(a*=256);)n+=this[t+--e]*a;return n},o.prototype.readUInt8=function(t,e){return t>>>=0,e||U(t,1,this.length),this[t]},o.prototype.readUInt16LE=function(t,e){return t>>>=0,e||U(t,2,this.length),this[t]|this[t+1]<<8},o.prototype.readUInt16BE=function(t,e){return t>>>=0,e||U(t,2,this.length),this[t]<<8|this[t+1]},o.prototype.readUInt32LE=function(t,e){return t>>>=0,e||U(t,4,this.length),(this[t]|this[t+1]<<8|this[t+2]<<16)+16777216*this[t+3]},o.prototype.readUInt32BE=function(t,e){return t>>>=0,e||U(t,4,this.length),16777216*this[t]+(this[t+1]<<16|this[t+2]<<8|this[t+3])},o.prototype.readIntLE=function(t,e,r){t>>>=0,e>>>=0,r||U(t,e,this.length);for(var n=this[t],a=1,o=0;++o<e&&(a*=256);)n+=this[t+o]*a;return n>=(a*=128)&&(n-=Math.pow(2,8*e)),n},o.prototype.readIntBE=function(t,e,r){t>>>=0,e>>>=0,r||U(t,e,this.length);for(var n=e,a=1,o=this[t+--n];n>0&&(a*=256);)o+=this[t+--n]*a;return o>=(a*=128)&&(o-=Math.pow(2,8*e)),o},o.prototype.readInt8=function(t,e){return t>>>=0,e||U(t,1,this.length),128&this[t]?-1*(255-this[t]+1):this[t]},o.prototype.readInt16LE=function(t,e){t>>>=0,e||U(t,2,this.length);var r=this[t]|this[t+1]<<8;return 32768&r?4294901760|r:r},o.prototype.readInt16BE=function(t,e){t>>>=0,e||U(t,2,this.length);var r=this[t+1]|this[t]<<8;return 32768&r?4294901760|r:r},o.prototype.readInt32LE=function(t,e){return t>>>=0,e||U(t,4,this.length),this[t]|this[t+1]<<8|this[t+2]<<16|this[t+3]<<24},o.prototype.readInt32BE=function(t,e){return t>>>=0,e||U(t,4,this.length),this[t]<<24|this[t+1]<<16|this[t+2]<<8|this[t+3]},o.prototype.readFloatLE=function(t,e){return t>>>=0,e||U(t,4,this.length),L$1.read(this,t,!0,23,4)},o.prototype.readFloatBE=function(t,e){return t>>>=0,e||U(t,4,this.length),L$1.read(this,t,!1,23,4)},o.prototype.readDoubleLE=function(t,e){return t>>>=0,e||U(t,8,this.length),L$1.read(this,t,!0,52,8)},o.prototype.readDoubleBE=function(t,e){return t>>>=0,e||U(t,8,this.length),L$1.read(this,t,!1,52,8)},o.prototype.writeUIntLE=function(t,e,r,n){t=+t,e>>>=0,r>>>=0,n||R(this,t,e,r,Math.pow(2,8*r)-1,0);var a=1,o=0;for(this[e]=255&t;++o<r&&(a*=256);)this[e+o]=t/a&255;return e+r},o.prototype.writeUIntBE=function(t,e,r,n){t=+t,e>>>=0,r>>>=0,n||R(this,t,e,r,Math.pow(2,8*r)-1,0);var a=r-1,o=1;for(this[e+a]=255&t;--a>=0&&(o*=256);)this[e+a]=t/o&255;return e+r},o.prototype.writeUInt8=function(t,e,r){return t=+t,e>>>=0,r||R(this,t,e,1,255,0),this[e]=255&t,e+1},o.prototype.writeUInt16LE=function(t,e,r){return t=+t,e>>>=0,r||R(this,t,e,2,65535,0),this[e]=255&t,this[e+1]=t>>>8,e+2},o.prototype.writeUInt16BE=function(t,e,r){return t=+t,e>>>=0,r||R(this,t,e,2,65535,0),this[e]=t>>>8,this[e+1]=255&t,e+2},o.prototype.writeUInt32LE=function(t,e,r){return t=+t,e>>>=0,r||R(this,t,e,4,4294967295,0),this[e+3]=t>>>24,this[e+2]=t>>>16,this[e+1]=t>>>8,this[e]=255&t,e+4},o.prototype.writeUInt32BE=function(t,e,r){return t=+t,e>>>=0,r||R(this,t,e,4,4294967295,0),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},o.prototype.writeIntLE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var a=Math.pow(2,8*r-1);R(this,t,e,r,a-1,-a);}var o=0,i=1,s=0;for(this[e]=255&t;++o<r&&(i*=256);)t<0&&0===s&&0!==this[e+o-1]&&(s=1),this[e+o]=(t/i>>0)-s&255;return e+r},o.prototype.writeIntBE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var a=Math.pow(2,8*r-1);R(this,t,e,r,a-1,-a);}var o=r-1,i=1,s=0;for(this[e+o]=255&t;--o>=0&&(i*=256);)t<0&&0===s&&0!==this[e+o+1]&&(s=1),this[e+o]=(t/i>>0)-s&255;return e+r},o.prototype.writeInt8=function(t,e,r){return t=+t,e>>>=0,r||R(this,t,e,1,127,-128),t<0&&(t=255+t+1),this[e]=255&t,e+1},o.prototype.writeInt16LE=function(t,e,r){return t=+t,e>>>=0,r||R(this,t,e,2,32767,-32768),this[e]=255&t,this[e+1]=t>>>8,e+2},o.prototype.writeInt16BE=function(t,e,r){return t=+t,e>>>=0,r||R(this,t,e,2,32767,-32768),this[e]=t>>>8,this[e+1]=255&t,e+2},o.prototype.writeInt32LE=function(t,e,r){return t=+t,e>>>=0,r||R(this,t,e,4,2147483647,-2147483648),this[e]=255&t,this[e+1]=t>>>8,this[e+2]=t>>>16,this[e+3]=t>>>24,e+4},o.prototype.writeInt32BE=function(t,e,r){return t=+t,e>>>=0,r||R(this,t,e,4,2147483647,-2147483648),t<0&&(t=4294967295+t+1),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},o.prototype.writeFloatLE=function(t,e,r){return N(this,t,e,!0,r)},o.prototype.writeFloatBE=function(t,e,r){return N(this,t,e,!1,r)},o.prototype.writeDoubleLE=function(t,e,r){return C(this,t,e,!0,r)},o.prototype.writeDoubleBE=function(t,e,r){return C(this,t,e,!1,r)},o.prototype.copy=function(t,e,r,n){if(!o.isBuffer(t))throw new TypeError("argument should be a Buffer");if(r||(r=0),n||0===n||(n=this.length),e>=t.length&&(e=t.length),e||(e=0),n>0&&n<r&&(n=r),n===r)return 0;if(0===t.length||0===this.length)return 0;if(e<0)throw new RangeError("targetStart out of bounds");if(r<0||r>=this.length)throw new RangeError("Index out of range");if(n<0)throw new RangeError("sourceEnd out of bounds");n>this.length&&(n=this.length),t.length-e<n-r&&(n=t.length-e+r);var a=n-r;if(this===t&&"function"==typeof Uint8Array.prototype.copyWithin)this.copyWithin(e,r,n);else if(this===t&&r<e&&e<n)for(var i=a-1;i>=0;--i)t[i+e]=this[i+r];else Uint8Array.prototype.set.call(t,this.subarray(r,n),e);return a},o.prototype.fill=function(t,e,r,n){if("string"==typeof t){if("string"==typeof e?(n=e,e=0,r=this.length):"string"==typeof r&&(n=r,r=this.length),void 0!==n&&"string"!=typeof n)throw new TypeError("encoding must be a string");if("string"==typeof n&&!o.isEncoding(n))throw new TypeError("Unknown encoding: "+n);if(1===t.length){var a=t.charCodeAt(0);("utf8"===n&&a<128||"latin1"===n)&&(t=a);}}else"number"==typeof t?t&=255:"boolean"==typeof t&&(t=Number(t));if(e<0||this.length<e||this.length<r)throw new RangeError("Out of range index");if(r<=e)return this;var i;if(e>>>=0,r=void 0===r?this.length:r>>>0,t||(t=0),"number"==typeof t)for(i=e;i<r;++i)this[i]=t;else{var s=o.isBuffer(t)?t:o.from(t,n),f=s.length;if(0===f)throw new TypeError('The value "'+t+'" is invalid for argument "value"');for(i=0;i<r-e;++i)this[i+e]=s[i%f];}return this};var O=/[^+\/0-9A-Za-z-_]/g;function I(t,e){var r;e=e||1/0;for(var n=t.length,a=null,o=[],i=0;i<n;++i){if((r=t.charCodeAt(i))>55295&&r<57344){if(!a){if(r>56319){(e-=3)>-1&&o.push(239,191,189);continue}if(i+1===n){(e-=3)>-1&&o.push(239,191,189);continue}a=r;continue}if(r<56320){(e-=3)>-1&&o.push(239,191,189),a=r;continue}r=65536+(a-55296<<10|r-56320);}else a&&(e-=3)>-1&&o.push(239,191,189);if(a=null,r<128){if((e-=1)<0)break;o.push(r);}else if(r<2048){if((e-=2)<0)break;o.push(r>>6|192,63&r|128);}else if(r<65536){if((e-=3)<0)break;o.push(r>>12|224,r>>6&63|128,63&r|128);}else{if(!(r<1114112))throw new Error("Invalid code point");if((e-=4)<0)break;o.push(r>>18|240,r>>12&63|128,r>>6&63|128,63&r|128);}}return o}function z(t){return T$1.toByteArray(function(t){if((t=(t=t.split("=")[0]).trim().replace(O,"")).length<2)return "";for(;t.length%4!=0;)t+="=";return t}(t))}function H(t,e,r,n){for(var a=0;a<n&&!(a+r>=e.length||a>=t.length);++a)e[a+r]=t[a];return a}function j(t,e){return t instanceof e||null!=t&&null!=t.constructor&&null!=t.constructor.name&&t.constructor.name===e.name}function Y(t){return t!=t}var D=function(){for(var t=new Array(256),e=0;e<16;++e)for(var r=16*e,n=0;n<16;++n)t[r+n]="0123456789abcdef"[e]+"0123456789abcdef"[n];return t}();}(B$1={exports:{}},B$1.exports),B$1.exports),M$1=S$1.Buffer;S$1.SlowBuffer,S$1.INSPECT_MAX_BYTES,S$1.kMaxLength;const x$2=(t=>(e,r)=>{if("string"==typeof e){if("string"==typeof r&&!t.isEncoding(r))throw new TypeError("Invalid default encoding");return t.from(e,r)}if(e instanceof Uint8Array)return e;if("object"==typeof e&&"string"==typeof e.value&&t.isEncoding(e.encoding))return t.from(e.value,e.encoding);throw new TypeError("Invalid format of Data")})(M$1),U$1=(t=>e=>{let r=t.from(e.buffer);return e.byteLength!==e.buffer.byteLength&&(r=r.slice(e.byteOffset,e.byteOffset+e.byteLength)),r})(M$1);class R$1{blind(t){const{Pythia:e}=l$2(),r=x$2(t,"utf8"),{blindedPassword:n,blindingSecret:a}=e.blind(r);return {blindedPassword:U$1(n),blindingSecret:U$1(a)}}deblind(t){const{Pythia:e}=l$2(),r=x$2(t.transformedPassword,"base64"),n=x$2(t.blindingSecret,"base64"),a=e.deblind(r,n);return U$1(a)}}

            function AbstractIterator$a (db) {
              if (typeof db !== 'object' || db === null) {
                throw new TypeError('First argument must be an abstract-leveldown compliant store')
              }

              this.db = db;
              this._ended = false;
              this._nexting = false;
            }

            AbstractIterator$a.prototype.next = function (callback) {
              var self = this;

              if (typeof callback !== 'function') {
                throw new Error('next() requires a callback argument')
              }

              if (self._ended) {
                nextTick(callback, new Error('cannot call next() after end()'));
                return self
              }

              if (self._nexting) {
                nextTick(callback, new Error('cannot call next() before previous next() has completed'));
                return self
              }

              self._nexting = true;
              self._next(function () {
                self._nexting = false;
                callback.apply(null, arguments);
              });

              return self
            };

            AbstractIterator$a.prototype._next = function (callback) {
              nextTick(callback);
            };

            AbstractIterator$a.prototype.seek = function (target) {
              if (this._ended) {
                throw new Error('cannot call seek() after end()')
              }
              if (this._nexting) {
                throw new Error('cannot call seek() before next() has completed')
              }

              target = this.db._serializeKey(target);
              this._seek(target);
            };

            AbstractIterator$a.prototype._seek = function (target) {};

            AbstractIterator$a.prototype.end = function (callback) {
              if (typeof callback !== 'function') {
                throw new Error('end() requires a callback argument')
              }

              if (this._ended) {
                return nextTick(callback, new Error('end() already called on iterator'))
              }

              this._ended = true;
              this._end(callback);
            };

            AbstractIterator$a.prototype._end = function (callback) {
              nextTick(callback);
            };

            var abstractIterator$4 = AbstractIterator$a;

            function AbstractChainedBatch$8 (db) {
              if (typeof db !== 'object' || db === null) {
                throw new TypeError('First argument must be an abstract-leveldown compliant store')
              }

              this.db = db;
              this._operations = [];
              this._written = false;
            }

            AbstractChainedBatch$8.prototype._checkWritten = function () {
              if (this._written) {
                throw new Error('write() already called on this batch')
              }
            };

            AbstractChainedBatch$8.prototype.put = function (key, value) {
              this._checkWritten();

              var err = this.db._checkKey(key) || this.db._checkValue(value);
              if (err) throw err

              key = this.db._serializeKey(key);
              value = this.db._serializeValue(value);

              this._put(key, value);

              return this
            };

            AbstractChainedBatch$8.prototype._put = function (key, value) {
              this._operations.push({ type: 'put', key: key, value: value });
            };

            AbstractChainedBatch$8.prototype.del = function (key) {
              this._checkWritten();

              var err = this.db._checkKey(key);
              if (err) throw err

              key = this.db._serializeKey(key);
              this._del(key);

              return this
            };

            AbstractChainedBatch$8.prototype._del = function (key) {
              this._operations.push({ type: 'del', key: key });
            };

            AbstractChainedBatch$8.prototype.clear = function () {
              this._checkWritten();
              this._clear();

              return this
            };

            AbstractChainedBatch$8.prototype._clear = function () {
              this._operations = [];
            };

            AbstractChainedBatch$8.prototype.write = function (options, callback) {
              this._checkWritten();

              if (typeof options === 'function') { callback = options; }
              if (typeof callback !== 'function') {
                throw new Error('write() requires a callback argument')
              }
              if (typeof options !== 'object' || options === null) {
                options = {};
              }

              this._written = true;
              this._write(options, callback);
            };

            AbstractChainedBatch$8.prototype._write = function (options, callback) {
              this.db._batch(this._operations, options, callback);
            };

            var abstractChainedBatch$4 = AbstractChainedBatch$8;

            var hasOwnProperty$8 = Object.prototype.hasOwnProperty;
            var rangeOptions$5 = 'start end gt gte lt lte'.split(' ');

            function AbstractLevelDOWN$a (manifest) {
              this.status = 'new';

              // TODO (next major): make this mandatory
              this.supports = levelSupports(manifest, {
                status: true
              });
            }

            AbstractLevelDOWN$a.prototype.open = function (options, callback) {
              var self = this;
              var oldStatus = this.status;

              if (typeof options === 'function') callback = options;

              if (typeof callback !== 'function') {
                throw new Error('open() requires a callback argument')
              }

              if (typeof options !== 'object' || options === null) options = {};

              options.createIfMissing = options.createIfMissing !== false;
              options.errorIfExists = !!options.errorIfExists;

              this.status = 'opening';
              this._open(options, function (err) {
                if (err) {
                  self.status = oldStatus;
                  return callback(err)
                }
                self.status = 'open';
                callback();
              });
            };

            AbstractLevelDOWN$a.prototype._open = function (options, callback) {
              nextTick(callback);
            };

            AbstractLevelDOWN$a.prototype.close = function (callback) {
              var self = this;
              var oldStatus = this.status;

              if (typeof callback !== 'function') {
                throw new Error('close() requires a callback argument')
              }

              this.status = 'closing';
              this._close(function (err) {
                if (err) {
                  self.status = oldStatus;
                  return callback(err)
                }
                self.status = 'closed';
                callback();
              });
            };

            AbstractLevelDOWN$a.prototype._close = function (callback) {
              nextTick(callback);
            };

            AbstractLevelDOWN$a.prototype.get = function (key, options, callback) {
              if (typeof options === 'function') callback = options;

              if (typeof callback !== 'function') {
                throw new Error('get() requires a callback argument')
              }

              var err = this._checkKey(key);
              if (err) return nextTick(callback, err)

              key = this._serializeKey(key);

              if (typeof options !== 'object' || options === null) options = {};

              options.asBuffer = options.asBuffer !== false;

              this._get(key, options, callback);
            };

            AbstractLevelDOWN$a.prototype._get = function (key, options, callback) {
              nextTick(function () { callback(new Error('NotFound')); });
            };

            AbstractLevelDOWN$a.prototype.put = function (key, value, options, callback) {
              if (typeof options === 'function') callback = options;

              if (typeof callback !== 'function') {
                throw new Error('put() requires a callback argument')
              }

              var err = this._checkKey(key) || this._checkValue(value);
              if (err) return nextTick(callback, err)

              key = this._serializeKey(key);
              value = this._serializeValue(value);

              if (typeof options !== 'object' || options === null) options = {};

              this._put(key, value, options, callback);
            };

            AbstractLevelDOWN$a.prototype._put = function (key, value, options, callback) {
              nextTick(callback);
            };

            AbstractLevelDOWN$a.prototype.del = function (key, options, callback) {
              if (typeof options === 'function') callback = options;

              if (typeof callback !== 'function') {
                throw new Error('del() requires a callback argument')
              }

              var err = this._checkKey(key);
              if (err) return nextTick(callback, err)

              key = this._serializeKey(key);

              if (typeof options !== 'object' || options === null) options = {};

              this._del(key, options, callback);
            };

            AbstractLevelDOWN$a.prototype._del = function (key, options, callback) {
              nextTick(callback);
            };

            AbstractLevelDOWN$a.prototype.batch = function (array, options, callback) {
              if (!arguments.length) return this._chainedBatch()

              if (typeof options === 'function') callback = options;

              if (typeof array === 'function') callback = array;

              if (typeof callback !== 'function') {
                throw new Error('batch(array) requires a callback argument')
              }

              if (!Array.isArray(array)) {
                return nextTick(callback, new Error('batch(array) requires an array argument'))
              }

              if (array.length === 0) {
                return nextTick(callback)
              }

              if (typeof options !== 'object' || options === null) options = {};

              var serialized = new Array(array.length);

              for (var i = 0; i < array.length; i++) {
                if (typeof array[i] !== 'object' || array[i] === null) {
                  return nextTick(callback, new Error('batch(array) element must be an object and not `null`'))
                }

                var e = immutable(array[i]);

                if (e.type !== 'put' && e.type !== 'del') {
                  return nextTick(callback, new Error("`type` must be 'put' or 'del'"))
                }

                var err = this._checkKey(e.key);
                if (err) return nextTick(callback, err)

                e.key = this._serializeKey(e.key);

                if (e.type === 'put') {
                  var valueErr = this._checkValue(e.value);
                  if (valueErr) return nextTick(callback, valueErr)

                  e.value = this._serializeValue(e.value);
                }

                serialized[i] = e;
              }

              this._batch(serialized, options, callback);
            };

            AbstractLevelDOWN$a.prototype._batch = function (array, options, callback) {
              nextTick(callback);
            };

            AbstractLevelDOWN$a.prototype.clear = function (options, callback) {
              if (typeof options === 'function') {
                callback = options;
              } else if (typeof callback !== 'function') {
                throw new Error('clear() requires a callback argument')
              }

              options = cleanRangeOptions$4(this, options);
              options.reverse = !!options.reverse;
              options.limit = 'limit' in options ? options.limit : -1;

              this._clear(options, callback);
            };

            AbstractLevelDOWN$a.prototype._clear = function (options, callback) {
              // Avoid setupIteratorOptions, would serialize range options a second time.
              options.keys = true;
              options.values = false;
              options.keyAsBuffer = true;
              options.valueAsBuffer = true;

              var iterator = this._iterator(options);
              var emptyOptions = {};
              var self = this;

              var next = function (err) {
                if (err) {
                  return iterator.end(function () {
                    callback(err);
                  })
                }

                iterator.next(function (err, key) {
                  if (err) return next(err)
                  if (key === undefined) return iterator.end(callback)

                  // This could be optimized by using a batch, but the default _clear
                  // is not meant to be fast. Implementations have more room to optimize
                  // if they override _clear. Note: using _del bypasses key serialization.
                  self._del(key, emptyOptions, next);
                });
              };

              next();
            };

            AbstractLevelDOWN$a.prototype._setupIteratorOptions = function (options) {
              options = cleanRangeOptions$4(this, options);

              options.reverse = !!options.reverse;
              options.keys = options.keys !== false;
              options.values = options.values !== false;
              options.limit = 'limit' in options ? options.limit : -1;
              options.keyAsBuffer = options.keyAsBuffer !== false;
              options.valueAsBuffer = options.valueAsBuffer !== false;

              return options
            };

            function cleanRangeOptions$4 (db, options) {
              var result = {};

              for (var k in options) {
                if (!hasOwnProperty$8.call(options, k)) continue

                var opt = options[k];

                if (isRangeOption$5(k)) {
                  // Note that we don't reject nullish and empty options here. While
                  // those types are invalid as keys, they are valid as range options.
                  opt = db._serializeKey(opt);
                }

                result[k] = opt;
              }

              return result
            }

            function isRangeOption$5 (k) {
              return rangeOptions$5.indexOf(k) !== -1
            }

            AbstractLevelDOWN$a.prototype.iterator = function (options) {
              if (typeof options !== 'object' || options === null) options = {};
              options = this._setupIteratorOptions(options);
              return this._iterator(options)
            };

            AbstractLevelDOWN$a.prototype._iterator = function (options) {
              return new abstractIterator$4(this)
            };

            AbstractLevelDOWN$a.prototype._chainedBatch = function () {
              return new abstractChainedBatch$4(this)
            };

            AbstractLevelDOWN$a.prototype._serializeKey = function (key) {
              return key
            };

            AbstractLevelDOWN$a.prototype._serializeValue = function (value) {
              return value
            };

            AbstractLevelDOWN$a.prototype._checkKey = function (key) {
              if (key === null || key === undefined) {
                return new Error('key cannot be `null` or `undefined`')
              } else if (isBuffer$1(key) && key.length === 0) {
                return new Error('key cannot be an empty Buffer')
              } else if (key === '') {
                return new Error('key cannot be an empty String')
              } else if (Array.isArray(key) && key.length === 0) {
                return new Error('key cannot be an empty Array')
              }
            };

            AbstractLevelDOWN$a.prototype._checkValue = function (value) {
              if (value === null || value === undefined) {
                return new Error('value cannot be `null` or `undefined`')
              }
            };

            var abstractLeveldown$7 = AbstractLevelDOWN$a;

            var AbstractLevelDOWN$b = abstractLeveldown$7;
            var AbstractIterator$b = abstractIterator$4;
            var AbstractChainedBatch$9 = abstractChainedBatch$4;

            var abstractLeveldown$8 = {
            	AbstractLevelDOWN: AbstractLevelDOWN$b,
            	AbstractIterator: AbstractIterator$b,
            	AbstractChainedBatch: AbstractChainedBatch$9
            };

            var ltgt = createCommonjsModule$1(function (module, exports) {
            exports.compare = function (a, b) {

              if(isBuffer$1(a)) {
                var l = Math.min(a.length, b.length);
                for(var i = 0; i < l; i++) {
                  var cmp = a[i] - b[i];
                  if(cmp) return cmp
                }
                return a.length - b.length
              }

              return a < b ? -1 : a > b ? 1 : 0
            };

            // to be compatible with the current abstract-leveldown tests
            // nullish or empty strings.
            // I could use !!val but I want to permit numbers and booleans,
            // if possible.

            function isDef (val) {
              return val !== undefined && val !== ''
            }

            function has (range, name) {
              return Object.hasOwnProperty.call(range, name)
            }

            function hasKey(range, name) {
              return Object.hasOwnProperty.call(range, name) && name
            }

            var lowerBoundKey = exports.lowerBoundKey = function (range) {
                return (
                   hasKey(range, 'gt')
                || hasKey(range, 'gte')
                || hasKey(range, 'min')
                || (range.reverse ? hasKey(range, 'end') : hasKey(range, 'start'))
                || undefined
                )
            };

            var lowerBound = exports.lowerBound = function (range, def) {
              var k = lowerBoundKey(range);
              return k ? range[k] : def
            };

            var lowerBoundInclusive = exports.lowerBoundInclusive = function (range) {
              return has(range, 'gt') ? false : true
            };

            var upperBoundInclusive = exports.upperBoundInclusive =
              function (range) {
                return (has(range, 'lt') /*&& !range.maxEx*/) ? false : true
              };

            var lowerBoundExclusive = exports.lowerBoundExclusive =
              function (range) {
                return !lowerBoundInclusive(range)
              };

            var upperBoundExclusive = exports.upperBoundExclusive =
              function (range) {
                return !upperBoundInclusive(range)
              };

            var upperBoundKey = exports.upperBoundKey = function (range) {
                return (
                   hasKey(range, 'lt')
                || hasKey(range, 'lte')
                || hasKey(range, 'max')
                || (range.reverse ? hasKey(range, 'start') : hasKey(range, 'end'))
                || undefined
                )
            };

            var upperBound = exports.upperBound = function (range, def) {
              var k = upperBoundKey(range);
              return k ? range[k] : def
            };

            exports.start = function (range, def) {
              return range.reverse ? upperBound(range, def) : lowerBound(range, def)
            };
            exports.end = function (range, def) {
              return range.reverse ? lowerBound(range, def) : upperBound(range, def)
            };
            exports.startInclusive = function (range) {
              return (
                range.reverse
              ? upperBoundInclusive(range)
              : lowerBoundInclusive(range)
              )
            };
            exports.endInclusive = function (range) {
              return (
                range.reverse
              ? lowerBoundInclusive(range)
              : upperBoundInclusive(range)
              )
            };

            function id (e) { return e }

            exports.toLtgt = function (range, _range, map, lower, upper) {
              _range = _range || {};
              map = map || id;
              var defaults = arguments.length > 3;
              var lb = exports.lowerBoundKey(range);
              var ub = exports.upperBoundKey(range);
              if(lb) {
                if(lb === 'gt') _range.gt = map(range.gt, false);
                else            _range.gte = map(range[lb], false);
              }
              else if(defaults)
                _range.gte = map(lower, false);

              if(ub) {
                if(ub === 'lt') _range.lt = map(range.lt, true);
                else            _range.lte = map(range[ub], true);
              }
              else if(defaults)
                _range.lte = map(upper, true);

              if(range.reverse != null)
                _range.reverse = !!range.reverse;

              //if range was used mutably
              //(in level-sublevel it's part of an options object
              //that has more properties on it.)
              if(has(_range, 'max'))   delete _range.max;
              if(has(_range, 'min'))   delete _range.min;
              if(has(_range, 'start')) delete _range.start;
              if(has(_range, 'end'))   delete _range.end;

              return _range
            };

            exports.contains = function (range, key, compare) {
              compare = compare || exports.compare;

              var lb = lowerBound(range);
              if(isDef(lb)) {
                var cmp = compare(key, lb);
                if(cmp < 0 || (cmp === 0 && lowerBoundExclusive(range)))
                  return false
              }

              var ub = upperBound(range);
              if(isDef(ub)) {
                var cmp = compare(key, ub);
                if(cmp > 0 || (cmp === 0) && upperBoundExclusive(range))
                  return false
              }

              return true
            };

            exports.filter = function (range, compare) {
              return function (key) {
                return exports.contains(range, key, compare)
              }
            };
            });
            var ltgt_1 = ltgt.compare;
            var ltgt_2 = ltgt.lowerBoundKey;
            var ltgt_3 = ltgt.lowerBound;
            var ltgt_4 = ltgt.lowerBoundInclusive;
            var ltgt_5 = ltgt.upperBoundInclusive;
            var ltgt_6 = ltgt.lowerBoundExclusive;
            var ltgt_7 = ltgt.upperBoundExclusive;
            var ltgt_8 = ltgt.upperBoundKey;
            var ltgt_9 = ltgt.upperBound;
            var ltgt_10 = ltgt.start;
            var ltgt_11 = ltgt.end;
            var ltgt_12 = ltgt.startInclusive;
            var ltgt_13 = ltgt.endInclusive;
            var ltgt_14 = ltgt.toLtgt;
            var ltgt_15 = ltgt.contains;
            var ltgt_16 = ltgt.filter;

            var NONE = {};

            var keyRange = function createKeyRange (options) {
              var lower = ltgt.lowerBound(options, NONE);
              var upper = ltgt.upperBound(options, NONE);
              var lowerOpen = ltgt.lowerBoundExclusive(options, NONE);
              var upperOpen = ltgt.upperBoundExclusive(options, NONE);

              if (lower !== NONE && upper !== NONE) {
                return IDBKeyRange.bound(lower, upper, lowerOpen, upperOpen)
              } else if (lower !== NONE) {
                return IDBKeyRange.lowerBound(lower, lowerOpen)
              } else if (upper !== NONE) {
                return IDBKeyRange.upperBound(upper, upperOpen)
              } else {
                return null
              }
            };

            var ta2str = (function () {
              if (commonjsGlobal$1.TextDecoder) {
                var decoder = new TextDecoder('utf-8');
                return decoder.decode.bind(decoder)
              } else {
                return function ta2str (ta) {
                  return ta2buf(ta).toString()
                }
              }
            })();

            var ab2str = (function () {
              if (commonjsGlobal$1.TextDecoder) {
                var decoder = new TextDecoder('utf-8');
                return decoder.decode.bind(decoder)
              } else {
                return function ab2str (ab) {
                  return Buffer.from(ab).toString()
                }
              }
            })();

            function ta2buf (ta) {
              var buf = Buffer.from(ta.buffer);

              if (ta.byteLength === ta.buffer.byteLength) {
                return buf
              } else {
                return buf.slice(ta.byteOffset, ta.byteOffset + ta.byteLength)
              }
            }

            var deserialize = function (data, asBuffer) {
              if (data instanceof Uint8Array) {
                return asBuffer ? ta2buf(data) : ta2str(data)
              } else if (data instanceof ArrayBuffer) {
                return asBuffer ? Buffer.from(data) : ab2str(data)
              } else {
                return asBuffer ? Buffer.from(String(data)) : String(data)
              }
            };

            //based off rsvp https://github.com/tildeio/rsvp.js
            //license https://github.com/tildeio/rsvp.js/blob/master/LICENSE
            //https://github.com/tildeio/rsvp.js/blob/master/lib/rsvp/asap.js

            var Mutation = commonjsGlobal$1.MutationObserver || commonjsGlobal$1.WebKitMutationObserver;

            var test = function () {
              return Mutation;
            };

            var install = function (handle) {
              var called = 0;
              var observer = new Mutation(handle);
              var element = commonjsGlobal$1.document.createTextNode('');
              observer.observe(element, {
                characterData: true
              });
              return function () {
                element.data = (called = ++called % 2);
              };
            };

            var mutation = {
            	test: test,
            	install: install
            };

            var test$1 = function () {
              if (commonjsGlobal$1.setImmediate) {
                // we can only get here in IE10
                // which doesn't handel postMessage well
                return false;
              }
              return typeof commonjsGlobal$1.MessageChannel !== 'undefined';
            };

            var install$1 = function (func) {
              var channel = new commonjsGlobal$1.MessageChannel();
              channel.port1.onmessage = func;
              return function () {
                channel.port2.postMessage(0);
              };
            };

            var messageChannel = {
            	test: test$1,
            	install: install$1
            };

            var test$2 = function () {
              return 'document' in commonjsGlobal$1 && 'onreadystatechange' in commonjsGlobal$1.document.createElement('script');
            };

            var install$2 = function (handle) {
              return function () {

                // Create a <script> element; its readystatechange event will be fired asynchronously once it is inserted
                // into the document. Do so, thus queuing up the task. Remember to clean up once it's been called.
                var scriptEl = commonjsGlobal$1.document.createElement('script');
                scriptEl.onreadystatechange = function () {
                  handle();

                  scriptEl.onreadystatechange = null;
                  scriptEl.parentNode.removeChild(scriptEl);
                  scriptEl = null;
                };
                commonjsGlobal$1.document.documentElement.appendChild(scriptEl);

                return handle;
              };
            };

            var stateChange = {
            	test: test$2,
            	install: install$2
            };

            var test$3 = function () {
              return true;
            };

            var install$3 = function (t) {
              return function () {
                setTimeout(t, 0);
              };
            };

            var timeout = {
            	test: test$3,
            	install: install$3
            };

            var types = [
              require$$0$1,
              mutation,
              messageChannel,
              stateChange,
              timeout
            ];
            var draining$1;
            var currentQueue$1;
            var queueIndex$1 = -1;
            var queue$1 = [];
            var scheduled = false;
            function cleanUpNextTick$1() {
              if (!draining$1 || !currentQueue$1) {
                return;
              }
              draining$1 = false;
              if (currentQueue$1.length) {
                queue$1 = currentQueue$1.concat(queue$1);
              } else {
                queueIndex$1 = -1;
              }
              if (queue$1.length) {
                nextTick$1();
              }
            }

            //named nextTick for less confusing stack traces
            function nextTick$1() {
              if (draining$1) {
                return;
              }
              scheduled = false;
              draining$1 = true;
              var len = queue$1.length;
              var timeout = setTimeout(cleanUpNextTick$1);
              while (len) {
                currentQueue$1 = queue$1;
                queue$1 = [];
                while (currentQueue$1 && ++queueIndex$1 < len) {
                  currentQueue$1[queueIndex$1].run();
                }
                queueIndex$1 = -1;
                len = queue$1.length;
              }
              currentQueue$1 = null;
              queueIndex$1 = -1;
              draining$1 = false;
              clearTimeout(timeout);
            }
            var scheduleDrain;
            var i$2 = -1;
            var len = types.length;
            while (++i$2 < len) {
              if (types[i$2] && types[i$2].test && types[i$2].test()) {
                scheduleDrain = types[i$2].install(nextTick$1);
                break;
              }
            }
            // v8 likes predictible objects
            function Item$1(fun, array) {
              this.fun = fun;
              this.array = array;
            }
            Item$1.prototype.run = function () {
              var fun = this.fun;
              var array = this.array;
              switch (array.length) {
              case 0:
                return fun();
              case 1:
                return fun(array[0]);
              case 2:
                return fun(array[0], array[1]);
              case 3:
                return fun(array[0], array[1], array[2]);
              default:
                return fun.apply(null, array);
              }

            };
            var lib = immediate;
            function immediate(task) {
              var args = new Array(arguments.length - 1);
              if (arguments.length > 1) {
                for (var i = 1; i < arguments.length; i++) {
                  args[i - 1] = arguments[i];
                }
              }
              queue$1.push(new Item$1(task, args));
              if (!scheduled && !draining$1) {
                scheduled = true;
                scheduleDrain();
              }
            }

            var AbstractIterator$c = abstractLeveldown$8.AbstractIterator;



            var noop$3 = function () {};

            var iterator = Iterator$1;

            function Iterator$1 (db, location, options) {
              AbstractIterator$c.call(this, db);

              this._limit = options.limit;
              this._count = 0;
              this._callback = null;
              this._cache = [];
              this._completed = false;
              this._aborted = false;
              this._error = null;
              this._transaction = null;

              this._keys = options.keys;
              this._values = options.values;
              this._keyAsBuffer = options.keyAsBuffer;
              this._valueAsBuffer = options.valueAsBuffer;

              if (this._limit === 0) {
                this._completed = true;
                return
              }

              try {
                var keyRange$1 = keyRange(options);
              } catch (e) {
                // The lower key is greater than the upper key.
                // IndexedDB throws an error, but we'll just return 0 results.
                this._completed = true;
                return
              }

              this.createIterator(location, keyRange$1, options.reverse);
            }

            inherits_browser(Iterator$1, AbstractIterator$c);

            Iterator$1.prototype.createIterator = function (location, keyRange, reverse) {
              var self = this;
              var transaction = this.db.db.transaction([location], 'readonly');
              var store = transaction.objectStore(location);
              var req = store.openCursor(keyRange, reverse ? 'prev' : 'next');

              req.onsuccess = function (ev) {
                var cursor = ev.target.result;
                if (cursor) self.onItem(cursor);
              };

              this._transaction = transaction;

              // If an error occurs (on the request), the transaction will abort.
              transaction.onabort = function () {
                self.onAbort(self._transaction.error || new Error('aborted by user'));
              };

              transaction.oncomplete = function () {
                self.onComplete();
              };
            };

            Iterator$1.prototype.onItem = function (cursor) {
              this._cache.push(cursor.key, cursor.value);

              if (this._limit <= 0 || ++this._count < this._limit) {
                cursor.continue();
              }

              this.maybeNext();
            };

            Iterator$1.prototype.onAbort = function (err) {
              this._aborted = true;
              this._error = err;
              this.maybeNext();
            };

            Iterator$1.prototype.onComplete = function () {
              this._completed = true;
              this.maybeNext();
            };

            Iterator$1.prototype.maybeNext = function () {
              if (this._callback) {
                this._next(this._callback);
                this._callback = null;
              }
            };

            Iterator$1.prototype._next = function (callback) {
              if (this._aborted) {
                // The error should be picked up by either next() or end().
                var err = this._error;
                this._error = null;

                lib(function () {
                  callback(err);
                });
              } else if (this._cache.length > 0) {
                var key = this._cache.shift();
                var value = this._cache.shift();

                if (this._keys && key !== undefined) {
                  key = this._deserializeKey(key, this._keyAsBuffer);
                } else {
                  key = undefined;
                }

                if (this._values && value !== undefined) {
                  value = this._deserializeValue(value, this._valueAsBuffer);
                } else {
                  value = undefined;
                }

                lib(function () {
                  callback(null, key, value);
                });
              } else if (this._completed) {
                lib(callback);
              } else {
                this._callback = callback;
              }
            };

            // Exposed for the v4 to v5 upgrade utility
            Iterator$1.prototype._deserializeKey = deserialize;
            Iterator$1.prototype._deserializeValue = deserialize;

            Iterator$1.prototype._end = function (callback) {
              if (this._aborted || this._completed) {
                var err = this._error;

                lib(function () {
                  callback(err);
                });

                return
              }

              // Don't advance the cursor anymore, and the transaction will complete
              // on its own in the next tick. This approach is much cleaner than calling
              // transaction.abort() with its unpredictable event order.
              this.onItem = noop$3;
              this.onAbort = callback;
              this.onComplete = callback;
            };

            // Returns either a Uint8Array or Buffer (doesn't matter to
            // IndexedDB, because Buffer is a subclass of Uint8Array)
            var str2bin = (function () {
              if (commonjsGlobal$1.TextEncoder) {
                var encoder = new TextEncoder('utf-8');
                return encoder.encode.bind(encoder)
              } else {
                return Buffer.from
              }
            })();

            var serialize = function (data, asBuffer) {
              if (asBuffer) {
                return isBuffer$1(data) ? data : str2bin(String(data))
              } else {
                return String(data)
              }
            };

            var support = createCommonjsModule$1(function (module, exports) {

            exports.test = function (key) {
              return function test (impl) {
                try {
                  impl.cmp(key, 0);
                  return true
                } catch (err) {
                  return false
                }
              }
            };

            // Detect binary key support (IndexedDB Second Edition)
            exports.bufferKeys = exports.test(Buffer.alloc(0));
            });
            var support_1 = support.test;
            var support_2 = support.bufferKeys;

            var immediateBrowser = {};

            var clear = function clear (db, location, keyRange, options, callback) {
              if (options.limit === 0) return immediateBrowser(callback)

              var transaction = db.db.transaction([location], 'readwrite');
              var store = transaction.objectStore(location);
              var count = 0;

              transaction.oncomplete = function () {
                callback();
              };

              transaction.onabort = function () {
                callback(transaction.error || new Error('aborted by user'));
              };

              // A key cursor is faster (skips reading values) but not supported by IE
              var method = store.openKeyCursor ? 'openKeyCursor' : 'openCursor';
              var direction = options.reverse ? 'prev' : 'next';

              store[method](keyRange, direction).onsuccess = function (ev) {
                var cursor = ev.target.result;

                if (cursor) {
                  // Wait for a request to complete before continuing, saving CPU.
                  store.delete(cursor.key).onsuccess = function () {
                    if (options.limit <= 0 || ++count < options.limit) {
                      cursor.continue();
                    }
                  };
                }
              };
            };

            var levelJs = Level;

            var AbstractLevelDOWN$c = abstractLeveldown$8.AbstractLevelDOWN;









            var DEFAULT_PREFIX = 'level-js-';

            function Level (location, opts) {
              if (!(this instanceof Level)) return new Level(location, opts)

              AbstractLevelDOWN$c.call(this, {
                bufferKeys: support.bufferKeys(indexedDB),
                snapshots: true,
                permanence: true,
                clear: true
              });

              opts = opts || {};

              if (typeof location !== 'string') {
                throw new Error('constructor requires a location string argument')
              }

              this.location = location;
              this.prefix = opts.prefix == null ? DEFAULT_PREFIX : opts.prefix;
              this.version = parseInt(opts.version || 1, 10);
            }

            inherits_browser(Level, AbstractLevelDOWN$c);

            Level.prototype.type = 'level-js';

            Level.prototype._open = function (options, callback) {
              var req = indexedDB.open(this.prefix + this.location, this.version);
              var self = this;

              req.onerror = function () {
                callback(req.error || new Error('unknown error'));
              };

              req.onsuccess = function () {
                self.db = req.result;
                callback();
              };

              req.onupgradeneeded = function (ev) {
                var db = ev.target.result;

                if (!db.objectStoreNames.contains(self.location)) {
                  db.createObjectStore(self.location);
                }
              };
            };

            Level.prototype.store = function (mode) {
              var transaction = this.db.transaction([this.location], mode);
              return transaction.objectStore(this.location)
            };

            Level.prototype.await = function (request, callback) {
              var transaction = request.transaction;

              // Take advantage of the fact that a non-canceled request error aborts
              // the transaction. I.e. no need to listen for "request.onerror".
              transaction.onabort = function () {
                callback(transaction.error || new Error('aborted by user'));
              };

              transaction.oncomplete = function () {
                callback(null, request.result);
              };
            };

            Level.prototype._get = function (key, options, callback) {
              var store = this.store('readonly');

              try {
                var req = store.get(key);
              } catch (err) {
                return lib(function () {
                  callback(err);
                })
              }

              this.await(req, function (err, value) {
                if (err) return callback(err)

                if (value === undefined) {
                  // 'NotFound' error, consistent with LevelDOWN API
                  return callback(new Error('NotFound'))
                }

                callback(null, deserialize(value, options.asBuffer));
              });
            };

            Level.prototype._del = function (key, options, callback) {
              var store = this.store('readwrite');

              try {
                var req = store.delete(key);
              } catch (err) {
                return lib(function () {
                  callback(err);
                })
              }

              this.await(req, callback);
            };

            Level.prototype._put = function (key, value, options, callback) {
              var store = this.store('readwrite');

              try {
                // Will throw a DataError or DataCloneError if the environment
                // does not support serializing the key or value respectively.
                var req = store.put(value, key);
              } catch (err) {
                return lib(function () {
                  callback(err);
                })
              }

              this.await(req, callback);
            };

            Level.prototype._serializeKey = function (key) {
              return serialize(key, this.supports.bufferKeys)
            };

            Level.prototype._serializeValue = function (value) {
              return serialize(value, true)
            };

            Level.prototype._iterator = function (options) {
              return new iterator(this, this.location, options)
            };

            Level.prototype._batch = function (operations, options, callback) {
              if (operations.length === 0) return lib(callback)

              var store = this.store('readwrite');
              var transaction = store.transaction;
              var index = 0;
              var error;

              transaction.onabort = function () {
                callback(error || transaction.error || new Error('aborted by user'));
              };

              transaction.oncomplete = function () {
                callback();
              };

              // Wait for a request to complete before making the next, saving CPU.
              function loop () {
                var op = operations[index++];
                var key = op.key;

                try {
                  var req = op.type === 'del' ? store.delete(key) : store.put(op.value, key);
                } catch (err) {
                  error = err;
                  transaction.abort();
                  return
                }

                if (index < operations.length) {
                  req.onsuccess = loop;
                }
              }

              loop();
            };

            Level.prototype._clear = function (options, callback) {
              try {
                var keyRange$1 = keyRange(options);
              } catch (e) {
                // The lower key is greater than the upper key.
                // IndexedDB throws an error, but we'll just do nothing.
                return lib(callback)
              }

              if (options.limit >= 0) {
                // IDBObjectStore#delete(range) doesn't have such an option.
                // Fall back to cursor-based implementation.
                return clear(this, this.location, keyRange$1, options, callback)
              }

              try {
                var store = this.store('readwrite');
                var req = keyRange$1 ? store.delete(keyRange$1) : store.clear();
              } catch (err) {
                return lib(function () {
                  callback(err);
                })
              }

              this.await(req, callback);
            };

            Level.prototype._close = function (callback) {
              this.db.close();
              lib(callback);
            };

            // NOTE: remove in a next major release
            Level.prototype.upgrade = function (callback) {
              if (this.status !== 'open') {
                return lib(function () {
                  callback(new Error('cannot upgrade() before open()'));
                })
              }

              var it = this.iterator();
              var batchOptions = {};
              var self = this;

              it._deserializeKey = it._deserializeValue = identity;
              next();

              function next (err) {
                if (err) return finish(err)
                it.next(each);
              }

              function each (err, key, value) {
                if (err || key === undefined) {
                  return finish(err)
                }

                var newKey = self._serializeKey(deserialize(key, true));
                var newValue = self._serializeValue(deserialize(value, true));

                // To bypass serialization on the old key, use _batch() instead of batch().
                // NOTE: if we disable snapshotting (#86) this could lead to a loop of
                // inserting and then iterating those same entries, because the new keys
                // possibly sort after the old keys.
                self._batch([
                  { type: 'del', key: key },
                  { type: 'put', key: newKey, value: newValue }
                ], batchOptions, next);
              }

              function finish (err) {
                it.end(function (err2) {
                  callback(err || err2);
                });
              }

              function identity (data) {
                return data
              }
            };

            Level.destroy = function (location, prefix, callback) {
              if (typeof prefix === 'function') {
                callback = prefix;
                prefix = DEFAULT_PREFIX;
              }
              var request = indexedDB.deleteDatabase(prefix + location);
              request.onsuccess = function () {
                callback();
              };
              request.onerror = function (err) {
                callback(err);
              };
            };

            class e$3{constructor(t){if(null==t)throw new Error("`crypto` is required");this.crypto=t;}generateSignature(t,e){return this.crypto.calculateSignature(t,e)}verifySignature(t,e,r){return this.crypto.verifySignature(t,e,r)}exportPublicKey(t){return this.crypto.exportPublicKey(t)}importPublicKey(t){return this.crypto.importPublicKey(t)}generateSha512(t){return this.crypto.calculateHash(t)}}var n$4=function(t,e){return function(t,e){var r,n=(r="undefined"!=typeof document&&document.currentScript?document.currentScript.src:void 0,function(t){var e;t=t||{},e||(e=void 0!==t?t:{});var n,s={};for(n in e)e.hasOwnProperty(n)&&(s[n]=e[n]);var _="";document.currentScript&&(_=document.currentScript.src),r&&(_=r),_=0!==_.indexOf("blob:")?_.substr(0,_.lastIndexOf("/")+1):"";var c=e.print||console.log.bind(console),a=e.printErr||console.warn.bind(console);for(n in s)s.hasOwnProperty(n)&&(e[n]=s[n]);s=null;var i,o={"f64-rem":function(t,e){return t%e},debugger:function(){}};e.wasmBinary&&(i=e.wasmBinary),"object"!=typeof WebAssembly&&a("no native wasm support detected");var l,u,f,p,d,h=new WebAssembly.Table({initial:766,maximum:766,element:"anyfunc"}),y=!1,v="undefined"!=typeof TextDecoder?new TextDecoder("utf8"):void 0;function P(t,e,r){var n=e+r;for(r=e;t[r]&&!(r>=n);)++r;if(16<r-e&&t.subarray&&v)return v.decode(t.subarray(e,r));for(n="";e<r;){var s=t[e++];if(128&s){var _=63&t[e++];if(192==(224&s))n+=String.fromCharCode((31&s)<<6|_);else{var c=63&t[e++];65536>(s=224==(240&s)?(15&s)<<12|_<<6|c:(7&s)<<18|_<<12|c<<6|63&t[e++])?n+=String.fromCharCode(s):(s-=65536,n+=String.fromCharCode(55296|s>>10,56320|1023&s));}}else n+=String.fromCharCode(s);}return n}function m(t){return 0<t%65536&&(t+=65536-t%65536),t}function x(t){u=t,e.HEAP8=f=new Int8Array(t),e.HEAP16=new Int16Array(t),e.HEAP32=d=new Int32Array(t),e.HEAPU8=p=new Uint8Array(t),e.HEAPU16=new Uint16Array(t),e.HEAPU32=new Uint32Array(t),e.HEAPF32=new Float32Array(t),e.HEAPF64=new Float64Array(t);}"undefined"!=typeof TextDecoder&&new TextDecoder("utf-16le");var g=e.TOTAL_MEMORY||16777216;function w(t){for(;0<t.length;){var r=t.shift();if("function"==typeof r)r();else{var n=r.Up;"number"==typeof n?void 0===r.rp?e.dynCall_v(n):e.dynCall_vi(n,r.rp):n(void 0===r.rp?null:r.rp);}}}(l=e.wasmMemory?e.wasmMemory:new WebAssembly.Memory({initial:g/65536}))&&(u=l.buffer),g=u.byteLength,x(u),d[24048]=5339264;var E=[],N=[],I=[],b=[];function A(){var t=e.preRun.shift();E.unshift(t);}var k=Math.abs,C=Math.ceil,T=Math.floor,F=Math.min,S=0,L=null;function R(t){throw e.onAbort&&e.onAbort(t),c(t),a(t),y=!0,new WebAssembly.RuntimeError("abort("+t+"). Build with -s ASSERTIONS=1 for more info.")}function z(){var t=M;return String.prototype.startsWith?t.startsWith("data:application/octet-stream;base64,"):0===t.indexOf("data:application/octet-stream;base64,")}e.preloadedImages={},e.preloadedAudios={};var B,U,M="libfoundation.browser.wasm";if(!z()){var H=M;M=e.locateFile?e.locateFile(H,_):_+H;}function Y(){try{if(i)return new Uint8Array(i);throw "both async and sync fetching of the wasm failed"}catch(t){R(t);}}function D(t,e){for(var r=0,n=t.length-1;0<=n;n--){var s=t[n];"."===s?t.splice(n,1):".."===s?(t.splice(n,1),r++):r&&(t.splice(n,1),r--);}if(e)for(;r;r--)t.unshift("..");return t}function O(t){var e="/"===t.charAt(0),r="/"===t.substr(-1);return (t=D(t.split("/").filter((function(t){return !!t})),!e).join("/"))||e||(t="."),t&&r&&(t+="/"),(e?"/":"")+t}function G(t){var e=/^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/.exec(t).slice(1);return t=e[0],e=e[1],t||e?(e&&(e=e.substr(0,e.length-1)),t+e):"."}function V(t){if("/"===t)return "/";var e=t.lastIndexOf("/");return -1===e?t:t.substr(e+1)}function X(){for(var t="",e=!1,r=arguments.length-1;-1<=r&&!e;r--){if("string"!=typeof(e=0<=r?arguments[r]:"/"))throw new TypeError("Arguments to path.resolve must be strings");if(!e)return "";t=e+"/"+t,e="/"===e.charAt(0);}return (e?"/":"")+(t=D(t.split("/").filter((function(t){return !!t})),!e).join("/"))||"."}e.asm=function(){function t(t){e.asm=t.exports,S--,e.monitorRunDependencies&&e.monitorRunDependencies(S),0==S&&(L&&(t=L,L=null,t()));}function r(e){t(e.instance);}function n(t){return (i||"function"!=typeof fetch?new Promise((function(t){t(Y());})):fetch(M,{credentials:"same-origin"}).then((function(t){if(!t.ok)throw "failed to load wasm binary file at '"+M+"'";return t.arrayBuffer()})).catch((function(){return Y()}))).then((function(t){return WebAssembly.instantiate(t,s)})).then(t,(function(t){a("failed to asynchronously prepare wasm: "+t),R(t);}))}var s={env:Ot,wasi_unstable:Ot,global:{NaN:NaN,Infinity:1/0},"global.Math":Math,asm2wasm:o};if(S++,e.monitorRunDependencies&&e.monitorRunDependencies(S),e.instantiateWasm)try{return e.instantiateWasm(s,t)}catch(t){return a("Module.instantiateWasm callback failed with error: "+t),!1}return function(){if(i||"function"!=typeof WebAssembly.instantiateStreaming||z()||"function"!=typeof fetch)return n(r);fetch(M,{credentials:"same-origin"}).then((function(t){return WebAssembly.instantiateStreaming(t,s).then(r,(function(t){a("wasm streaming compile failed: "+t),a("falling back to ArrayBuffer instantiation"),n(r);}))}));}(),{}};var j=[];function W(t,e){j[t]={input:[],bp:[],kp:e},mt(t,Z);}var Z={open:function(t){var e=j[t.node.pp];if(!e)throw new ct(43);t.ap=e,t.seekable=!1;},close:function(t){t.ap.kp.flush(t.ap);},flush:function(t){t.ap.kp.flush(t.ap);},read:function(t,e,r,n){if(!t.ap||!t.ap.kp.Ap)throw new ct(60);for(var s=0,_=0;_<n;_++){try{var c=t.ap.kp.Ap(t.ap);}catch(t){throw new ct(29)}if(void 0===c&&0===s)throw new ct(6);if(null==c)break;s++,e[r+_]=c;}return s&&(t.node.timestamp=Date.now()),s},write:function(t,e,r,n){if(!t.ap||!t.ap.kp.tp)throw new ct(60);try{for(var s=0;s<n;s++)t.ap.kp.tp(t.ap,e[r+s]);}catch(t){throw new ct(29)}return n&&(t.node.timestamp=Date.now()),s}},$={Ap:function(t){if(!t.input.length){var e=null;if("undefined"!=typeof window&&"function"==typeof window.prompt?null!==(e=window.prompt("Input: "))&&(e+="\n"):"function"==typeof readline&&null!==(e=readline())&&(e+="\n"),!e)return null;for(var r=0,n=0;n<e.length;++n){var s=e.charCodeAt(n);55296<=s&&57343>=s&&(s=65536+((1023&s)<<10)|1023&e.charCodeAt(++n)),127>=s?++r:r=2047>=s?r+2:65535>=s?r+3:r+4;}var _=(r=Array(r+1)).length;if(n=0,0<_){s=n,_=n+_-1;for(var c=0;c<e.length;++c){var a=e.charCodeAt(c);if(55296<=a&&57343>=a&&(a=65536+((1023&a)<<10)|1023&e.charCodeAt(++c)),127>=a){if(n>=_)break;r[n++]=a;}else{if(2047>=a){if(n+1>=_)break;r[n++]=192|a>>6;}else{if(65535>=a){if(n+2>=_)break;r[n++]=224|a>>12;}else{if(n+3>=_)break;r[n++]=240|a>>18,r[n++]=128|a>>12&63;}r[n++]=128|a>>6&63;}r[n++]=128|63&a;}}r[n]=0,e=n-s;}else e=0;r.length=e,t.input=r;}return t.input.shift()},tp:function(t,e){null===e||10===e?(c(P(t.bp,0)),t.bp=[]):0!=e&&t.bp.push(e);},flush:function(t){t.bp&&0<t.bp.length&&(c(P(t.bp,0)),t.bp=[]);}},q={tp:function(t,e){null===e||10===e?(a(P(t.bp,0)),t.bp=[]):0!=e&&t.bp.push(e);},flush:function(t){t.bp&&0<t.bp.length&&(a(P(t.bp,0)),t.bp=[]);}},J={cp:null,fp:function(){return J.createNode(null,"/",16895,0)},createNode:function(t,e,r,n){if(24576==(61440&r)||4096==(61440&r))throw new ct(63);return J.cp||(J.cp={dir:{node:{gp:J.Yo.gp,ep:J.Yo.ep,lp:J.Yo.lp,np:J.Yo.np,Fp:J.Yo.Fp,Hp:J.Yo.Hp,Gp:J.Yo.Gp,Ep:J.Yo.Ep,qp:J.Yo.qp},stream:{ip:J.Zo.ip}},file:{node:{gp:J.Yo.gp,ep:J.Yo.ep},stream:{ip:J.Zo.ip,read:J.Zo.read,write:J.Zo.write,vp:J.Zo.vp,Bp:J.Zo.Bp,Dp:J.Zo.Dp}},link:{node:{gp:J.Yo.gp,ep:J.Yo.ep,mp:J.Yo.mp},stream:{}},wp:{node:{gp:J.Yo.gp,ep:J.Yo.ep},stream:Pt}}),16384==(61440&(r=ft(t,e,r,n)).mode)?(r.Yo=J.cp.dir.node,r.Zo=J.cp.dir.stream,r.Xo={}):32768==(61440&r.mode)?(r.Yo=J.cp.file.node,r.Zo=J.cp.file.stream,r.$o=0,r.Xo=null):40960==(61440&r.mode)?(r.Yo=J.cp.link.node,r.Zo=J.cp.link.stream):8192==(61440&r.mode)&&(r.Yo=J.cp.wp.node,r.Zo=J.cp.wp.stream),r.timestamp=Date.now(),t&&(t.Xo[e]=r),r},Vp:function(t){if(t.Xo&&t.Xo.subarray){for(var e=[],r=0;r<t.$o;++r)e.push(t.Xo[r]);return e}return t.Xo},Wp:function(t){return t.Xo?t.Xo.subarray?t.Xo.subarray(0,t.$o):new Uint8Array(t.Xo):new Uint8Array},xp:function(t,e){var r=t.Xo?t.Xo.length:0;r>=e||(e=Math.max(e,r*(1048576>r?2:1.125)|0),0!=r&&(e=Math.max(e,256)),r=t.Xo,t.Xo=new Uint8Array(e),0<t.$o&&t.Xo.set(r.subarray(0,t.$o),0));},Mp:function(t,e){if(t.$o!=e)if(0==e)t.Xo=null,t.$o=0;else{if(!t.Xo||t.Xo.subarray){var r=t.Xo;t.Xo=new Uint8Array(new ArrayBuffer(e)),r&&t.Xo.set(r.subarray(0,Math.min(e,t.$o)));}else if(t.Xo||(t.Xo=[]),t.Xo.length>e)t.Xo.length=e;else for(;t.Xo.length<e;)t.Xo.push(0);t.$o=e;}},Yo:{gp:function(t){var e={};return e.Tp=8192==(61440&t.mode)?t.id:1,e.Yp=t.id,e.mode=t.mode,e.$p=1,e.uid=0,e.Xp=0,e.pp=t.pp,16384==(61440&t.mode)?e.size=4096:32768==(61440&t.mode)?e.size=t.$o:40960==(61440&t.mode)?e.size=t.link.length:e.size=0,e.Qp=new Date(t.timestamp),e.Zp=new Date(t.timestamp),e.Sp=new Date(t.timestamp),e.Ip=4096,e.Rp=Math.ceil(e.size/e.Ip),e},ep:function(t,e){void 0!==e.mode&&(t.mode=e.mode),void 0!==e.timestamp&&(t.timestamp=e.timestamp),void 0!==e.size&&J.Mp(t,e.size);},lp:function(){throw at[44]},np:function(t,e,r,n){return J.createNode(t,e,r,n)},Fp:function(t,e,r){if(16384==(61440&t.mode)){try{var n=ut(e,r);}catch(t){}if(n)for(var s in n.Xo)throw new ct(55)}delete t.parent.Xo[t.name],t.name=r,e.Xo[r]=t,t.parent=e;},Hp:function(t,e){delete t.Xo[e];},Gp:function(t,e){var r,n=ut(t,e);for(r in n.Xo)throw new ct(55);delete t.Xo[e];},Ep:function(t){var e,r=[".",".."];for(e in t.Xo)t.Xo.hasOwnProperty(e)&&r.push(e);return r},qp:function(t,e,r){return (t=J.createNode(t,e,41471,0)).link=r,t},mp:function(t){if(40960!=(61440&t.mode))throw new ct(28);return t.link}},Zo:{read:function(t,e,r,n,s){var _=t.node.Xo;if(s>=t.node.$o)return 0;if(8<(t=Math.min(t.node.$o-s,n))&&_.subarray)e.set(_.subarray(s,s+t),r);else for(n=0;n<t;n++)e[r+n]=_[s+n];return t},write:function(t,e,r,n,s,_){if(e.buffer===f.buffer&&(_=!1),!n)return 0;if((t=t.node).timestamp=Date.now(),e.subarray&&(!t.Xo||t.Xo.subarray)){if(_)return t.Xo=e.subarray(r,r+n),t.$o=n;if(0===t.$o&&0===s)return t.Xo=new Uint8Array(e.subarray(r,r+n)),t.$o=n;if(s+n<=t.$o)return t.Xo.set(e.subarray(r,r+n),s),n}if(J.xp(t,s+n),t.Xo.subarray&&e.subarray)t.Xo.set(e.subarray(r,r+n),s);else for(_=0;_<n;_++)t.Xo[s+_]=e[r+_];return t.$o=Math.max(t.$o,s+n),n},ip:function(t,e,r){if(1===r?e+=t.position:2===r&&32768==(61440&t.node.mode)&&(e+=t.node.$o),0>e)throw new ct(28);return e},vp:function(t,e,r){J.xp(t.node,e+r),t.node.$o=Math.max(t.node.$o,e+r);},Bp:function(t,e,r,n,s,_,c){if(32768!=(61440&t.node.mode))throw new ct(43);if(r=t.node.Xo,2&c||r.buffer!==e.buffer){if((0<s||s+n<t.node.$o)&&(r=r.subarray?r.subarray(s,s+n):Array.prototype.slice.call(r,s,s+n)),t=!0,s=e.buffer==f.buffer,!(n=Xt(n)))throw new ct(48);(s?f:e).set(r,n);}else t=!1,n=r.byteOffset;return {bq:n,Pp:t}},Dp:function(t,e,r,n,s){if(32768!=(61440&t.node.mode))throw new ct(43);return 2&s?0:(J.Zo.write(t,e,0,n,r,!1),0)}}},Q=null,tt={},et=[],rt=1,nt=null,st=!0,_t={},ct=null,at={};function it(t,e){if(e=e||{},!(t=X("/",t)))return {path:"",node:null};var r,n={zp:!0,up:0};for(r in n)void 0===e[r]&&(e[r]=n[r]);if(8<e.up)throw new ct(32);t=D(t.split("/").filter((function(t){return !!t})),!1);var s=Q;for(n="/",r=0;r<t.length;r++){var _=r===t.length-1;if(_&&e.parent)break;if(s=ut(s,t[r]),n=O(n+"/"+t[r]),s.op&&(!_||_&&e.zp)&&(s=s.op.root),!_||e.yp)for(_=0;40960==(61440&s.mode);)if(s=It(n),s=it(n=X(G(n),s),{up:e.up}).node,40<_++)throw new ct(32)}return {path:n,node:s}}function ot(t){for(var e;;){if(t===t.parent)return t=t.fp.Cp,e?"/"!==t[t.length-1]?t+"/"+e:t+e:t;e=e?t.name+"/"+e:t.name,t=t.parent;}}function lt(t,e){for(var r=0,n=0;n<e.length;n++)r=(r<<5)-r+e.charCodeAt(n)|0;return (t+r>>>0)%nt.length}function ut(t,e){var r;if(r=(r=ht(t,"x"))?r:t.Yo.lp?0:2)throw new ct(r,t);for(r=nt[lt(t.id,e)];r;r=r.Lp){var n=r.name;if(r.parent.id===t.id&&n===e)return r}return t.Yo.lp(t,e)}function ft(t,e,r,n){return Ft||((Ft=function(t,e,r,n){t||(t=this),this.parent=t,this.fp=t.fp,this.op=null,this.id=rt++,this.name=e,this.mode=r,this.Yo={},this.Zo={},this.pp=n;}).prototype={},Object.defineProperties(Ft.prototype,{read:{get:function(){return 365==(365&this.mode)},set:function(t){t?this.mode|=365:this.mode&=-366;}},write:{get:function(){return 146==(146&this.mode)},set:function(t){t?this.mode|=146:this.mode&=-147;}}})),function(t){var e=lt(t.parent.id,t.name);t.Lp=nt[e],nt[e]=t;}(t=new Ft(t,e,r,n)),t}var pt={r:0,rs:1052672,"r+":2,w:577,wx:705,xw:705,"w+":578,"wx+":706,"xw+":706,a:1089,ax:1217,xa:1217,"a+":1090,"ax+":1218,"xa+":1218};function dt(t){var e=["r","w","rw"][3&t];return 512&t&&(e+="w"),e}function ht(t,e){return st?0:(-1===e.indexOf("r")||292&t.mode)&&(-1===e.indexOf("w")||146&t.mode)&&(-1===e.indexOf("x")||73&t.mode)?0:2}function yt(t,e){try{return ut(t,e),20}catch(t){}return ht(t,"wx")}var vt,Pt={open:function(t){t.Zo=tt[t.node.pp].Zo,t.Zo.open&&t.Zo.open(t);},ip:function(){throw new ct(70)}};function mt(t,e){tt[t]={Zo:e};}function xt(t,e){var r="/"===e,n=!e;if(r&&Q)throw new ct(10);if(!r&&!n){var s=it(e,{zp:!1});if(e=s.path,(s=s.node).op)throw new ct(10);if(16384!=(61440&s.mode))throw new ct(54)}e={type:t,aq:{},Cp:e,Kp:[]},(t=t.fp(e)).fp=e,e.root=t,r?Q=t:s&&(s.op=e,s.fp&&s.fp.Kp.push(e));}function gt(t,e,r){var n=it(t,{parent:!0}).node;if(!(t=V(t))||"."===t||".."===t)throw new ct(28);var s=yt(n,t);if(s)throw new ct(s);if(!n.Yo.np)throw new ct(63);return n.Yo.np(n,t,e,r)}function wt(t){gt(t,16895,0);}function Et(t,e,r){void 0===r&&(r=e,e=438),gt(t,8192|e,r);}function Nt(t,e){if(!X(t))throw new ct(44);var r=it(e,{parent:!0}).node;if(!r)throw new ct(44);var n=yt(r,e=V(e));if(n)throw new ct(n);if(!r.Yo.qp)throw new ct(63);r.Yo.qp(r,e,t);}function It(t){if(!(t=it(t).node))throw new ct(44);if(!t.Yo.mp)throw new ct(28);return X(ot(t.parent),t.Yo.mp(t))}function bt(t,r,n){if(""===t)throw new ct(44);if("string"==typeof r){var s=pt[r];if(void 0===s)throw Error("Unknown file open mode: "+r);r=s;}if(n=64&r?4095&(void 0===n?438:n)|32768:0,"object"==typeof t)var _=t;else{t=O(t);try{_=it(t,{yp:!(131072&r)}).node;}catch(t){}}if(s=!1,64&r)if(_){if(128&r)throw new ct(20)}else _=gt(t,n,0),s=!0;if(!_)throw new ct(44);if(8192==(61440&_.mode)&&(r&=-513),65536&r&&16384!=(61440&_.mode))throw new ct(54);if(!s&&(n=_?40960==(61440&_.mode)?32:16384==(61440&_.mode)&&("r"!==dt(r)||512&r)?31:ht(_,dt(r)):44))throw new ct(n);if(512&r){var c;if(!(c="string"==typeof(n=_)?it(n,{yp:!0}).node:n).Yo.ep)throw new ct(63);if(16384==(61440&c.mode))throw new ct(31);if(32768!=(61440&c.mode))throw new ct(28);if(n=ht(c,"w"))throw new ct(n);c.Yo.ep(c,{size:0,timestamp:Date.now()});}r&=-641,(_=function(t){St||((St=function(){}).prototype={},Object.defineProperties(St.prototype,{object:{get:function(){return this.node},set:function(t){this.node=t;}}}));var e,r=new St;for(e in t)r[e]=t[e];return t=r,r=function(){for(var t=0;t<=4096;t++)if(!et[t])return t;throw new ct(33)}(),t.hp=r,et[r]=t}({node:_,path:ot(_),flags:r,seekable:!0,position:0,Zo:_.Zo,Op:[],error:!1})).Zo.open&&_.Zo.open(_),!e.logReadFiles||1&r||(Kt||(Kt={}),t in Kt||(Kt[t]=1,console.log("FS.trackingDelegate error on read file: "+t)));try{_t.onOpenFile&&(c=0,1!=(2097155&r)&&(c|=1),0!=(2097155&r)&&(c|=2),_t.onOpenFile(t,c));}catch(e){console.log("FS.trackingDelegate['onOpenFile']('"+t+"', flags) threw an exception: "+e.message);}return _}function At(t,e,r){if(null===t.hp)throw new ct(8);if(!t.seekable||!t.Zo.ip)throw new ct(70);if(0!=r&&1!=r&&2!=r)throw new ct(28);t.position=t.Zo.ip(t,e,r),t.Op=[];}function kt(){ct||((ct=function(t,e){this.node=e,this.Np=function(t){this.jp=t;},this.Np(t),this.message="FS error";}).prototype=Error(),ct.prototype.constructor=ct,[44].forEach((function(t){at[t]=new ct(t),at[t].stack="<generic error, no stack>";})));}function Ct(t,e,r){t=O("/dev/"+t);var n=function(t,e){var r=0;return t&&(r|=365),e&&(r|=146),r}(!!e,!!r);Tt||(Tt=64);var s=Tt++<<8|0;mt(s,{open:function(t){t.seekable=!1;},close:function(){r&&r.buffer&&r.buffer.length&&r(10);},read:function(t,r,n,s){for(var _=0,c=0;c<s;c++){try{var a=e();}catch(t){throw new ct(29)}if(void 0===a&&0===_)throw new ct(6);if(null==a)break;_++,r[n+c]=a;}return _&&(t.node.timestamp=Date.now()),_},write:function(t,e,n,s){for(var _=0;_<s;_++)try{r(e[n+_]);}catch(t){throw new ct(29)}return s&&(t.node.timestamp=Date.now()),_}}),Et(t,n,s);}var Tt,Ft,St,Kt,Lt={},Rt=0;function zt(){return d[(Rt+=4)-4>>2]}function Bt(t){if(void 0===t&&(t=zt()),!(t=et[t]))throw new ct(8);return t}function Ut(t){try{var e=Bt(t);if(null===e.hp)throw new ct(8);e.sp&&(e.sp=null);try{e.Zo.close&&e.Zo.close(e);}catch(t){throw t}finally{et[e.hp]=null;}return e.hp=null,0}catch(t){return void 0!==Lt&&t instanceof ct||R(t),t.jp}}function Mt(t,e,r,n){try{t:{for(var s=Bt(t),_=t=0;_<r;_++){var c=d[e+(8*_+4)>>2],a=s,i=d[e+8*_>>2],o=c,l=void 0,u=f;if(0>o||0>l)throw new ct(28);if(null===a.hp)throw new ct(8);if(1==(2097155&a.flags))throw new ct(8);if(16384==(61440&a.node.mode))throw new ct(31);if(!a.Zo.read)throw new ct(28);var p=void 0!==l;if(p){if(!a.seekable)throw new ct(70)}else l=a.position;var h=a.Zo.read(a,u,i,o,l);p||(a.position+=h);var y=h;if(0>y){var v=-1;break t}if(t+=y,y<c)break}v=t;}return d[n>>2]=v,0}catch(t){return void 0!==Lt&&t instanceof ct||R(t),t.jp}}function Ht(t,e,r,n,s){try{var _=Bt(t);return -9007199254740992>=(t=4294967296*r+(e>>>0))||9007199254740992<=t?-61:(At(_,t,n),U=[_.position>>>0,(B=_.position,1<=+k(B)?0<B?(0|F(+T(B/4294967296),4294967295))>>>0:~~+C((B-+(~~B>>>0))/4294967296)>>>0:0)],d[s>>2]=U[0],d[s+4>>2]=U[1],_.sp&&0===t&&0===n&&(_.sp=null),0)}catch(t){return void 0!==Lt&&t instanceof ct||R(t),t.jp}}function Yt(t,e,r,n){try{t:{for(var s=Bt(t),_=t=0;_<r;_++){var c=s,a=d[e+8*_>>2],i=d[e+(8*_+4)>>2],o=void 0,l=f;if(0>i||0>o)throw new ct(28);if(null===c.hp)throw new ct(8);if(0==(2097155&c.flags))throw new ct(8);if(16384==(61440&c.node.mode))throw new ct(31);if(!c.Zo.write)throw new ct(28);1024&c.flags&&At(c,0,2);var u=void 0!==o;if(u){if(!c.seekable)throw new ct(70)}else o=c.position;var p=c.Zo.write(c,l,a,i,o,void 0);u||(c.position+=p);try{c.path&&_t.onWriteToFile&&_t.onWriteToFile(c.path);}catch(t){console.log("FS.trackingDelegate['onWriteToFile']('"+c.path+"') threw an exception: "+t.message);}var h=p;if(0>h){var y=-1;break t}t+=h;}y=t;}return d[n>>2]=y,0}catch(t){return void 0!==Lt&&t instanceof ct||R(t),t.jp}}function Dt(){return f.length}kt(),nt=Array(4096),xt(J,"/"),wt("/tmp"),wt("/home"),wt("/home/web_user"),function(){if(wt("/dev"),mt(259,{read:function(){return 0},write:function(t,e,r,n){return n}}),Et("/dev/null",259),W(1280,$),W(1536,q),Et("/dev/tty",1280),Et("/dev/tty1",1536),"object"==typeof crypto&&"function"==typeof crypto.getRandomValues)var t=new Uint8Array(1),e=function(){return crypto.getRandomValues(t),t[0]};e||(e=function(){R("random_device");}),Ct("random",e),Ct("urandom",e),wt("/dev/shm"),wt("/dev/shm/tmp");}(),wt("/proc"),wt("/proc/self"),wt("/proc/self/fd"),xt({fp:function(){var t=ft("/proc/self","fd",16895,73);return t.Yo={lp:function(t,e){var r=et[+e];if(!r)throw new ct(8);return (t={parent:null,fp:{Cp:"fake"},Yo:{mp:function(){return r.path}}}).parent=t}},t}},"/proc/self/fd");var Ot={c:function(){},l:function(t,e){Rt=e;try{var r=zt();return bt(r?P(p,r,void 0):"",zt(),zt()).hp}catch(t){return void 0!==Lt&&t instanceof ct||R(t),-t.jp}},k:function(t,e){Rt=e;try{var r=Bt(),n=zt();switch(n){case 21509:case 21505:return r.ap?0:-59;case 21510:case 21511:case 21512:case 21506:case 21507:case 21508:return r.ap?0:-59;case 21519:if(!r.ap)return -59;var s=zt();return d[s>>2]=0;case 21520:return r.ap?-28:-59;case 21531:if(t=s=zt(),!r.Zo.Jp)throw new ct(59);return r.Zo.Jp(r,n,t);case 21523:case 21524:return r.ap?0:-59;default:R("bad ioctl syscall "+n);}}catch(t){return void 0!==Lt&&t instanceof ct||R(t),-t.jp}},b:function(){},d:function(){return Ut.apply(null,arguments)},j:function(){return Mt.apply(null,arguments)},m:function(){return Ht.apply(null,arguments)},i:function(){return Yt.apply(null,arguments)},__memory_base:1024,__table_base:0,h:function(){R();},g:Dt,o:function(t,e,r){p.set(p.subarray(e,e+r),t);},n:function(t){if(2147418112<t)return !1;for(var e=Math.max(Dt(),16777216);e<t;)e=536870912>=e?m(2*e):Math.min(m((3*e+2147483648)/4),2147418112);t:{try{l.grow(e-u.byteLength+65535>>16),x(l.buffer);var r=1;break t}catch(t){}r=void 0;}return !!r},f:function(t){var e=Date.now();return d[t>>2]=e/1e3|0,d[t+4>>2]=e%1e3*1e3|0,0},a:R,memory:l,e:function(){},table:h},Gt=e.asm({},Ot,u);e.asm=Gt,e.___errno_location=function(){return e.asm.p.apply(null,arguments)},e._free=function(){return e.asm.q.apply(null,arguments)};var Vt,Xt=e._malloc=function(){return e.asm.r.apply(null,arguments)};function jt(){function t(){if(!Vt&&(Vt=!0,!y)){if(e.noFSInit||vt||(vt=!0,kt(),e.stdin=e.stdin,e.stdout=e.stdout,e.stderr=e.stderr,e.stdin?Ct("stdin",e.stdin):Nt("/dev/tty","/dev/stdin"),e.stdout?Ct("stdout",null,e.stdout):Nt("/dev/tty","/dev/stdout"),e.stderr?Ct("stderr",null,e.stderr):Nt("/dev/tty1","/dev/stderr"),bt("/dev/stdin","r"),bt("/dev/stdout","w"),bt("/dev/stderr","w")),w(N),st=!1,w(I),e.onRuntimeInitialized&&e.onRuntimeInitialized(),e.postRun)for("function"==typeof e.postRun&&(e.postRun=[e.postRun]);e.postRun.length;){var t=e.postRun.shift();b.unshift(t);}w(b);}}if(!(0<S)){if(e.preRun)for("function"==typeof e.preRun&&(e.preRun=[e.preRun]);e.preRun.length;)A();w(E),0<S||(e.setStatus?(e.setStatus("Running..."),setTimeout((function(){setTimeout((function(){e.setStatus("");}),1),t();}),1)):t());}}if(e._vsc_buffer_bytes=function(){return e.asm.s.apply(null,arguments)},e._vsc_buffer_data=function(){return e.asm.t.apply(null,arguments)},e._vsc_buffer_delete=function(){return e.asm.u.apply(null,arguments)},e._vsc_buffer_len=function(){return e.asm.v.apply(null,arguments)},e._vsc_buffer_make_secure=function(){return e.asm.w.apply(null,arguments)},e._vsc_buffer_new=function(){return e.asm.x.apply(null,arguments)},e._vsc_buffer_new_with_capacity=function(){return e.asm.y.apply(null,arguments)},e._vsc_data=function(){return e.asm.z.apply(null,arguments)},e._vsc_data_bytes=function(){return e.asm.A.apply(null,arguments)},e._vsc_data_ctx_size=function(){return e.asm.B.apply(null,arguments)},e._vsc_data_len=function(){return e.asm.C.apply(null,arguments)},e._vscf_aes256_cbc_alg_id=function(){return e.asm.D.apply(null,arguments)},e._vscf_aes256_cbc_decrypt=function(){return e.asm.E.apply(null,arguments)},e._vscf_aes256_cbc_decrypted_len=function(){return e.asm.F.apply(null,arguments)},e._vscf_aes256_cbc_decrypted_out_len=function(){return e.asm.G.apply(null,arguments)},e._vscf_aes256_cbc_delete=function(){return e.asm.H.apply(null,arguments)},e._vscf_aes256_cbc_encrypt=function(){return e.asm.I.apply(null,arguments)},e._vscf_aes256_cbc_encrypted_len=function(){return e.asm.J.apply(null,arguments)},e._vscf_aes256_cbc_encrypted_out_len=function(){return e.asm.K.apply(null,arguments)},e._vscf_aes256_cbc_finish=function(){return e.asm.L.apply(null,arguments)},e._vscf_aes256_cbc_new=function(){return e.asm.M.apply(null,arguments)},e._vscf_aes256_cbc_out_len=function(){return e.asm.N.apply(null,arguments)},e._vscf_aes256_cbc_precise_encrypted_len=function(){return e.asm.O.apply(null,arguments)},e._vscf_aes256_cbc_produce_alg_info=function(){return e.asm.P.apply(null,arguments)},e._vscf_aes256_cbc_restore_alg_info=function(){return e.asm.Q.apply(null,arguments)},e._vscf_aes256_cbc_set_key=function(){return e.asm.R.apply(null,arguments)},e._vscf_aes256_cbc_set_nonce=function(){return e.asm.S.apply(null,arguments)},e._vscf_aes256_cbc_shallow_copy=function(){return e.asm.T.apply(null,arguments)},e._vscf_aes256_cbc_start_decryption=function(){return e.asm.U.apply(null,arguments)},e._vscf_aes256_cbc_start_encryption=function(){return e.asm.V.apply(null,arguments)},e._vscf_aes256_cbc_update=function(){return e.asm.W.apply(null,arguments)},e._vscf_aes256_gcm_alg_id=function(){return e.asm.X.apply(null,arguments)},e._vscf_aes256_gcm_auth_decrypt=function(){return e.asm.Y.apply(null,arguments)},e._vscf_aes256_gcm_auth_decrypted_len=function(){return e.asm.Z.apply(null,arguments)},e._vscf_aes256_gcm_auth_encrypt=function(){return e.asm._.apply(null,arguments)},e._vscf_aes256_gcm_auth_encrypted_len=function(){return e.asm.$.apply(null,arguments)},e._vscf_aes256_gcm_decrypt=function(){return e.asm.aa.apply(null,arguments)},e._vscf_aes256_gcm_decrypted_len=function(){return e.asm.ba.apply(null,arguments)},e._vscf_aes256_gcm_decrypted_out_len=function(){return e.asm.ca.apply(null,arguments)},e._vscf_aes256_gcm_delete=function(){return e.asm.da.apply(null,arguments)},e._vscf_aes256_gcm_encrypt=function(){return e.asm.ea.apply(null,arguments)},e._vscf_aes256_gcm_encrypted_len=function(){return e.asm.fa.apply(null,arguments)},e._vscf_aes256_gcm_encrypted_out_len=function(){return e.asm.ga.apply(null,arguments)},e._vscf_aes256_gcm_finish=function(){return e.asm.ha.apply(null,arguments)},e._vscf_aes256_gcm_finish_auth_decryption=function(){return e.asm.ia.apply(null,arguments)},e._vscf_aes256_gcm_finish_auth_encryption=function(){return e.asm.ja.apply(null,arguments)},e._vscf_aes256_gcm_new=function(){return e.asm.ka.apply(null,arguments)},e._vscf_aes256_gcm_out_len=function(){return e.asm.la.apply(null,arguments)},e._vscf_aes256_gcm_precise_encrypted_len=function(){return e.asm.ma.apply(null,arguments)},e._vscf_aes256_gcm_produce_alg_info=function(){return e.asm.na.apply(null,arguments)},e._vscf_aes256_gcm_restore_alg_info=function(){return e.asm.oa.apply(null,arguments)},e._vscf_aes256_gcm_set_auth_data=function(){return e.asm.pa.apply(null,arguments)},e._vscf_aes256_gcm_set_key=function(){return e.asm.qa.apply(null,arguments)},e._vscf_aes256_gcm_set_nonce=function(){return e.asm.ra.apply(null,arguments)},e._vscf_aes256_gcm_shallow_copy=function(){return e.asm.sa.apply(null,arguments)},e._vscf_aes256_gcm_start_decryption=function(){return e.asm.ta.apply(null,arguments)},e._vscf_aes256_gcm_start_encryption=function(){return e.asm.ua.apply(null,arguments)},e._vscf_aes256_gcm_update=function(){return e.asm.va.apply(null,arguments)},e._vscf_alg_factory_create_cipher_from_info=function(){return e.asm.wa.apply(null,arguments)},e._vscf_alg_factory_create_hash_from_info=function(){return e.asm.xa.apply(null,arguments)},e._vscf_alg_factory_create_kdf_from_info=function(){return e.asm.ya.apply(null,arguments)},e._vscf_alg_factory_create_mac_from_info=function(){return e.asm.za.apply(null,arguments)},e._vscf_alg_factory_create_salted_kdf_from_info=function(){return e.asm.Aa.apply(null,arguments)},e._vscf_alg_info_der_deserializer_delete=function(){return e.asm.Ba.apply(null,arguments)},e._vscf_alg_info_der_deserializer_deserialize=function(){return e.asm.Ca.apply(null,arguments)},e._vscf_alg_info_der_deserializer_deserialize_inplace=function(){return e.asm.Da.apply(null,arguments)},e._vscf_alg_info_der_deserializer_new=function(){return e.asm.Ea.apply(null,arguments)},e._vscf_alg_info_der_deserializer_release_asn1_reader=function(){return e.asm.Fa.apply(null,arguments)},e._vscf_alg_info_der_deserializer_setup_defaults=function(){return e.asm.Ga.apply(null,arguments)},e._vscf_alg_info_der_deserializer_shallow_copy=function(){return e.asm.Ha.apply(null,arguments)},e._vscf_alg_info_der_deserializer_use_asn1_reader=function(){return e.asm.Ia.apply(null,arguments)},e._vscf_alg_info_der_serializer_delete=function(){return e.asm.Ja.apply(null,arguments)},e._vscf_alg_info_der_serializer_new=function(){return e.asm.Ka.apply(null,arguments)},e._vscf_alg_info_der_serializer_release_asn1_writer=function(){return e.asm.La.apply(null,arguments)},e._vscf_alg_info_der_serializer_serialize=function(){return e.asm.Ma.apply(null,arguments)},e._vscf_alg_info_der_serializer_serialize_inplace=function(){return e.asm.Na.apply(null,arguments)},e._vscf_alg_info_der_serializer_serialized_len=function(){return e.asm.Oa.apply(null,arguments)},e._vscf_alg_info_der_serializer_setup_defaults=function(){return e.asm.Pa.apply(null,arguments)},e._vscf_alg_info_der_serializer_shallow_copy=function(){return e.asm.Qa.apply(null,arguments)},e._vscf_alg_info_der_serializer_use_asn1_writer=function(){return e.asm.Ra.apply(null,arguments)},e._vscf_asn1rd_delete=function(){return e.asm.Sa.apply(null,arguments)},e._vscf_asn1rd_get_data_len=function(){return e.asm.Ta.apply(null,arguments)},e._vscf_asn1rd_get_len=function(){return e.asm.Ua.apply(null,arguments)},e._vscf_asn1rd_get_tag=function(){return e.asm.Va.apply(null,arguments)},e._vscf_asn1rd_has_error=function(){return e.asm.Wa.apply(null,arguments)},e._vscf_asn1rd_left_len=function(){return e.asm.Xa.apply(null,arguments)},e._vscf_asn1rd_new=function(){return e.asm.Ya.apply(null,arguments)},e._vscf_asn1rd_read_bitstring_as_octet_str=function(){return e.asm.Za.apply(null,arguments)},e._vscf_asn1rd_read_bool=function(){return e.asm._a.apply(null,arguments)},e._vscf_asn1rd_read_context_tag=function(){return e.asm.$a.apply(null,arguments)},e._vscf_asn1rd_read_data=function(){return e.asm.ab.apply(null,arguments)},e._vscf_asn1rd_read_int=function(){return e.asm.bb.apply(null,arguments)},e._vscf_asn1rd_read_int16=function(){return e.asm.cb.apply(null,arguments)},e._vscf_asn1rd_read_int32=function(){return e.asm.db.apply(null,arguments)},e._vscf_asn1rd_read_int64=function(){return e.asm.eb.apply(null,arguments)},e._vscf_asn1rd_read_int8=function(){return e.asm.fb.apply(null,arguments)},e._vscf_asn1rd_read_null=function(){return e.asm.gb.apply(null,arguments)},e._vscf_asn1rd_read_null_optional=function(){return e.asm.hb.apply(null,arguments)},e._vscf_asn1rd_read_octet_str=function(){return e.asm.ib.apply(null,arguments)},e._vscf_asn1rd_read_oid=function(){return e.asm.jb.apply(null,arguments)},e._vscf_asn1rd_read_sequence=function(){return e.asm.kb.apply(null,arguments)},e._vscf_asn1rd_read_set=function(){return e.asm.lb.apply(null,arguments)},e._vscf_asn1rd_read_tag=function(){return e.asm.mb.apply(null,arguments)},e._vscf_asn1rd_read_uint=function(){return e.asm.nb.apply(null,arguments)},e._vscf_asn1rd_read_uint16=function(){return e.asm.ob.apply(null,arguments)},e._vscf_asn1rd_read_uint32=function(){return e.asm.pb.apply(null,arguments)},e._vscf_asn1rd_read_uint64=function(){return e.asm.qb.apply(null,arguments)},e._vscf_asn1rd_read_uint8=function(){return e.asm.rb.apply(null,arguments)},e._vscf_asn1rd_read_utf8_str=function(){return e.asm.sb.apply(null,arguments)},e._vscf_asn1rd_reset=function(){return e.asm.tb.apply(null,arguments)},e._vscf_asn1rd_shallow_copy=function(){return e.asm.ub.apply(null,arguments)},e._vscf_asn1rd_status=function(){return e.asm.vb.apply(null,arguments)},e._vscf_asn1wr_bytes=function(){return e.asm.wb.apply(null,arguments)},e._vscf_asn1wr_delete=function(){return e.asm.xb.apply(null,arguments)},e._vscf_asn1wr_finish=function(){return e.asm.yb.apply(null,arguments)},e._vscf_asn1wr_has_error=function(){return e.asm.zb.apply(null,arguments)},e._vscf_asn1wr_len=function(){return e.asm.Ab.apply(null,arguments)},e._vscf_asn1wr_new=function(){return e.asm.Bb.apply(null,arguments)},e._vscf_asn1wr_reserve=function(){return e.asm.Cb.apply(null,arguments)},e._vscf_asn1wr_reset=function(){return e.asm.Db.apply(null,arguments)},e._vscf_asn1wr_shallow_copy=function(){return e.asm.Eb.apply(null,arguments)},e._vscf_asn1wr_status=function(){return e.asm.Fb.apply(null,arguments)},e._vscf_asn1wr_unwritten_len=function(){return e.asm.Gb.apply(null,arguments)},e._vscf_asn1wr_write_bool=function(){return e.asm.Hb.apply(null,arguments)},e._vscf_asn1wr_write_context_tag=function(){return e.asm.Ib.apply(null,arguments)},e._vscf_asn1wr_write_data=function(){return e.asm.Jb.apply(null,arguments)},e._vscf_asn1wr_write_int=function(){return e.asm.Kb.apply(null,arguments)},e._vscf_asn1wr_write_int16=function(){return e.asm.Lb.apply(null,arguments)},e._vscf_asn1wr_write_int32=function(){return e.asm.Mb.apply(null,arguments)},e._vscf_asn1wr_write_int64=function(){return e.asm.Nb.apply(null,arguments)},e._vscf_asn1wr_write_int8=function(){return e.asm.Ob.apply(null,arguments)},e._vscf_asn1wr_write_len=function(){return e.asm.Pb.apply(null,arguments)},e._vscf_asn1wr_write_null=function(){return e.asm.Qb.apply(null,arguments)},e._vscf_asn1wr_write_octet_str=function(){return e.asm.Rb.apply(null,arguments)},e._vscf_asn1wr_write_octet_str_as_bitstring=function(){return e.asm.Sb.apply(null,arguments)},e._vscf_asn1wr_write_oid=function(){return e.asm.Tb.apply(null,arguments)},e._vscf_asn1wr_write_sequence=function(){return e.asm.Ub.apply(null,arguments)},e._vscf_asn1wr_write_set=function(){return e.asm.Vb.apply(null,arguments)},e._vscf_asn1wr_write_tag=function(){return e.asm.Wb.apply(null,arguments)},e._vscf_asn1wr_write_uint=function(){return e.asm.Xb.apply(null,arguments)},e._vscf_asn1wr_write_uint16=function(){return e.asm.Yb.apply(null,arguments)},e._vscf_asn1wr_write_uint32=function(){return e.asm.Zb.apply(null,arguments)},e._vscf_asn1wr_write_uint64=function(){return e.asm._b.apply(null,arguments)},e._vscf_asn1wr_write_uint8=function(){return e.asm.$b.apply(null,arguments)},e._vscf_asn1wr_write_utf8_str=function(){return e.asm.ac.apply(null,arguments)},e._vscf_asn1wr_written_len=function(){return e.asm.bc.apply(null,arguments)},e._vscf_base64_decode=function(){return e.asm.cc.apply(null,arguments)},e._vscf_base64_decoded_len=function(){return e.asm.dc.apply(null,arguments)},e._vscf_base64_encode=function(){return e.asm.ec.apply(null,arguments)},e._vscf_base64_encoded_len=function(){return e.asm.fc.apply(null,arguments)},e._vscf_brainkey_client_blind=function(){return e.asm.gc.apply(null,arguments)},e._vscf_brainkey_client_deblind=function(){return e.asm.hc.apply(null,arguments)},e._vscf_brainkey_client_delete=function(){return e.asm.ic.apply(null,arguments)},e._vscf_brainkey_client_new=function(){return e.asm.jc.apply(null,arguments)},e._vscf_brainkey_client_release_operation_random=function(){return e.asm.kc.apply(null,arguments)},e._vscf_brainkey_client_release_random=function(){return e.asm.lc.apply(null,arguments)},e._vscf_brainkey_client_setup_defaults=function(){return e.asm.mc.apply(null,arguments)},e._vscf_brainkey_client_shallow_copy=function(){return e.asm.nc.apply(null,arguments)},e._vscf_brainkey_client_use_operation_random=function(){return e.asm.oc.apply(null,arguments)},e._vscf_brainkey_client_use_random=function(){return e.asm.pc.apply(null,arguments)},e._vscf_brainkey_server_delete=function(){return e.asm.qc.apply(null,arguments)},e._vscf_brainkey_server_generate_identity_secret=function(){return e.asm.rc.apply(null,arguments)},e._vscf_brainkey_server_harden=function(){return e.asm.sc.apply(null,arguments)},e._vscf_brainkey_server_new=function(){return e.asm.tc.apply(null,arguments)},e._vscf_brainkey_server_release_operation_random=function(){return e.asm.uc.apply(null,arguments)},e._vscf_brainkey_server_release_random=function(){return e.asm.vc.apply(null,arguments)},e._vscf_brainkey_server_setup_defaults=function(){return e.asm.wc.apply(null,arguments)},e._vscf_brainkey_server_shallow_copy=function(){return e.asm.xc.apply(null,arguments)},e._vscf_brainkey_server_use_operation_random=function(){return e.asm.yc.apply(null,arguments)},e._vscf_brainkey_server_use_random=function(){return e.asm.zc.apply(null,arguments)},e._vscf_cipher_alg_info_alg_id=function(){return e.asm.Ac.apply(null,arguments)},e._vscf_cipher_alg_info_delete=function(){return e.asm.Bc.apply(null,arguments)},e._vscf_cipher_alg_info_new=function(){return e.asm.Cc.apply(null,arguments)},e._vscf_cipher_alg_info_new_with_members=function(){return e.asm.Dc.apply(null,arguments)},e._vscf_cipher_alg_info_nonce=function(){return e.asm.Ec.apply(null,arguments)},e._vscf_cipher_alg_info_shallow_copy=function(){return e.asm.Fc.apply(null,arguments)},e._vscf_ctr_drbg_delete=function(){return e.asm.Gc.apply(null,arguments)},e._vscf_ctr_drbg_enable_prediction_resistance=function(){return e.asm.Hc.apply(null,arguments)},e._vscf_ctr_drbg_new=function(){return e.asm.Ic.apply(null,arguments)},e._vscf_ctr_drbg_random=function(){return e.asm.Jc.apply(null,arguments)},e._vscf_ctr_drbg_release_entropy_source=function(){return e.asm.Kc.apply(null,arguments)},e._vscf_ctr_drbg_reseed=function(){return e.asm.Lc.apply(null,arguments)},e._vscf_ctr_drbg_set_entropy_len=function(){return e.asm.Mc.apply(null,arguments)},e._vscf_ctr_drbg_set_reseed_interval=function(){return e.asm.Nc.apply(null,arguments)},e._vscf_ctr_drbg_setup_defaults=function(){return e.asm.Oc.apply(null,arguments)},e._vscf_ctr_drbg_shallow_copy=function(){return e.asm.Pc.apply(null,arguments)},e._vscf_ctr_drbg_use_entropy_source=function(){return e.asm.Qc.apply(null,arguments)},e._vscf_curve25519_alg_id=function(){return e.asm.Rc.apply(null,arguments)},e._vscf_curve25519_can_decrypt=function(){return e.asm.Sc.apply(null,arguments)},e._vscf_curve25519_can_encrypt=function(){return e.asm.Tc.apply(null,arguments)},e._vscf_curve25519_compute_shared_key=function(){return e.asm.Uc.apply(null,arguments)},e._vscf_curve25519_decrypt=function(){return e.asm.Vc.apply(null,arguments)},e._vscf_curve25519_decrypted_len=function(){return e.asm.Wc.apply(null,arguments)},e._vscf_curve25519_delete=function(){return e.asm.Xc.apply(null,arguments)},e._vscf_curve25519_encrypt=function(){return e.asm.Yc.apply(null,arguments)},e._vscf_curve25519_encrypted_len=function(){return e.asm.Zc.apply(null,arguments)},e._vscf_curve25519_export_private_key=function(){return e.asm._c.apply(null,arguments)},e._vscf_curve25519_export_public_key=function(){return e.asm.$c.apply(null,arguments)},e._vscf_curve25519_generate_ephemeral_key=function(){return e.asm.ad.apply(null,arguments)},e._vscf_curve25519_generate_key=function(){return e.asm.bd.apply(null,arguments)},e._vscf_curve25519_import_private_key=function(){return e.asm.cd.apply(null,arguments)},e._vscf_curve25519_import_public_key=function(){return e.asm.dd.apply(null,arguments)},e._vscf_curve25519_new=function(){return e.asm.ed.apply(null,arguments)},e._vscf_curve25519_produce_alg_info=function(){return e.asm.fd.apply(null,arguments)},e._vscf_curve25519_release_ecies=function(){return e.asm.gd.apply(null,arguments)},e._vscf_curve25519_release_random=function(){return e.asm.hd.apply(null,arguments)},e._vscf_curve25519_restore_alg_info=function(){return e.asm.id.apply(null,arguments)},e._vscf_curve25519_setup_defaults=function(){return e.asm.jd.apply(null,arguments)},e._vscf_curve25519_shallow_copy=function(){return e.asm.kd.apply(null,arguments)},e._vscf_curve25519_shared_key_len=function(){return e.asm.ld.apply(null,arguments)},e._vscf_curve25519_use_ecies=function(){return e.asm.md.apply(null,arguments)},e._vscf_curve25519_use_random=function(){return e.asm.nd.apply(null,arguments)},e._vscf_ecc_alg_id=function(){return e.asm.od.apply(null,arguments)},e._vscf_ecc_alg_info_alg_id=function(){return e.asm.pd.apply(null,arguments)},e._vscf_ecc_alg_info_delete=function(){return e.asm.qd.apply(null,arguments)},e._vscf_ecc_alg_info_domain_id=function(){return e.asm.rd.apply(null,arguments)},e._vscf_ecc_alg_info_key_id=function(){return e.asm.sd.apply(null,arguments)},e._vscf_ecc_alg_info_new=function(){return e.asm.td.apply(null,arguments)},e._vscf_ecc_alg_info_new_with_members=function(){return e.asm.ud.apply(null,arguments)},e._vscf_ecc_alg_info_shallow_copy=function(){return e.asm.vd.apply(null,arguments)},e._vscf_ecc_can_decrypt=function(){return e.asm.wd.apply(null,arguments)},e._vscf_ecc_can_encrypt=function(){return e.asm.xd.apply(null,arguments)},e._vscf_ecc_can_sign=function(){return e.asm.yd.apply(null,arguments)},e._vscf_ecc_can_verify=function(){return e.asm.zd.apply(null,arguments)},e._vscf_ecc_compute_shared_key=function(){return e.asm.Ad.apply(null,arguments)},e._vscf_ecc_decrypt=function(){return e.asm.Bd.apply(null,arguments)},e._vscf_ecc_decrypted_len=function(){return e.asm.Cd.apply(null,arguments)},e._vscf_ecc_delete=function(){return e.asm.Dd.apply(null,arguments)},e._vscf_ecc_encrypt=function(){return e.asm.Ed.apply(null,arguments)},e._vscf_ecc_encrypted_len=function(){return e.asm.Fd.apply(null,arguments)},e._vscf_ecc_export_private_key=function(){return e.asm.Gd.apply(null,arguments)},e._vscf_ecc_export_public_key=function(){return e.asm.Hd.apply(null,arguments)},e._vscf_ecc_generate_ephemeral_key=function(){return e.asm.Id.apply(null,arguments)},e._vscf_ecc_generate_key=function(){return e.asm.Jd.apply(null,arguments)},e._vscf_ecc_import_private_key=function(){return e.asm.Kd.apply(null,arguments)},e._vscf_ecc_import_public_key=function(){return e.asm.Ld.apply(null,arguments)},e._vscf_ecc_new=function(){return e.asm.Md.apply(null,arguments)},e._vscf_ecc_private_key_alg_id=function(){return e.asm.Nd.apply(null,arguments)},e._vscf_ecc_private_key_alg_info=function(){return e.asm.Od.apply(null,arguments)},e._vscf_ecc_private_key_bitlen=function(){return e.asm.Pd.apply(null,arguments)},e._vscf_ecc_private_key_delete=function(){return e.asm.Qd.apply(null,arguments)},e._vscf_ecc_private_key_extract_public_key=function(){return e.asm.Rd.apply(null,arguments)},e._vscf_ecc_private_key_impl_tag=function(){return e.asm.Sd.apply(null,arguments)},e._vscf_ecc_private_key_is_valid=function(){return e.asm.Td.apply(null,arguments)},e._vscf_ecc_private_key_len=function(){return e.asm.Ud.apply(null,arguments)},e._vscf_ecc_private_key_new=function(){return e.asm.Vd.apply(null,arguments)},e._vscf_ecc_private_key_shallow_copy=function(){return e.asm.Wd.apply(null,arguments)},e._vscf_ecc_produce_alg_info=function(){return e.asm.Xd.apply(null,arguments)},e._vscf_ecc_public_key_alg_id=function(){return e.asm.Yd.apply(null,arguments)},e._vscf_ecc_public_key_alg_info=function(){return e.asm.Zd.apply(null,arguments)},e._vscf_ecc_public_key_bitlen=function(){return e.asm._d.apply(null,arguments)},e._vscf_ecc_public_key_delete=function(){return e.asm.$d.apply(null,arguments)},e._vscf_ecc_public_key_impl_tag=function(){return e.asm.ae.apply(null,arguments)},e._vscf_ecc_public_key_is_valid=function(){return e.asm.be.apply(null,arguments)},e._vscf_ecc_public_key_len=function(){return e.asm.ce.apply(null,arguments)},e._vscf_ecc_public_key_new=function(){return e.asm.de.apply(null,arguments)},e._vscf_ecc_public_key_shallow_copy=function(){return e.asm.ee.apply(null,arguments)},e._vscf_ecc_release_ecies=function(){return e.asm.fe.apply(null,arguments)},e._vscf_ecc_release_random=function(){return e.asm.ge.apply(null,arguments)},e._vscf_ecc_restore_alg_info=function(){return e.asm.he.apply(null,arguments)},e._vscf_ecc_setup_defaults=function(){return e.asm.ie.apply(null,arguments)},e._vscf_ecc_shallow_copy=function(){return e.asm.je.apply(null,arguments)},e._vscf_ecc_shared_key_len=function(){return e.asm.ke.apply(null,arguments)},e._vscf_ecc_sign_hash=function(){return e.asm.le.apply(null,arguments)},e._vscf_ecc_signature_len=function(){return e.asm.me.apply(null,arguments)},e._vscf_ecc_use_ecies=function(){return e.asm.ne.apply(null,arguments)},e._vscf_ecc_use_random=function(){return e.asm.oe.apply(null,arguments)},e._vscf_ecc_verify_hash=function(){return e.asm.pe.apply(null,arguments)},e._vscf_ecies_decrypt=function(){return e.asm.qe.apply(null,arguments)},e._vscf_ecies_decrypted_len=function(){return e.asm.re.apply(null,arguments)},e._vscf_ecies_delete=function(){return e.asm.se.apply(null,arguments)},e._vscf_ecies_encrypt=function(){return e.asm.te.apply(null,arguments)},e._vscf_ecies_encrypted_len=function(){return e.asm.ue.apply(null,arguments)},e._vscf_ecies_new=function(){return e.asm.ve.apply(null,arguments)},e._vscf_ecies_release_cipher=function(){return e.asm.we.apply(null,arguments)},e._vscf_ecies_release_ephemeral_key=function(){return e.asm.xe.apply(null,arguments)},e._vscf_ecies_release_kdf=function(){return e.asm.ye.apply(null,arguments)},e._vscf_ecies_release_key_alg=function(){return e.asm.ze.apply(null,arguments)},e._vscf_ecies_release_mac=function(){return e.asm.Ae.apply(null,arguments)},e._vscf_ecies_release_random=function(){return e.asm.Be.apply(null,arguments)},e._vscf_ecies_set_key_alg=function(){return e.asm.Ce.apply(null,arguments)},e._vscf_ecies_setup_defaults=function(){return e.asm.De.apply(null,arguments)},e._vscf_ecies_setup_defaults_no_random=function(){return e.asm.Ee.apply(null,arguments)},e._vscf_ecies_shallow_copy=function(){return e.asm.Fe.apply(null,arguments)},e._vscf_ecies_use_cipher=function(){return e.asm.Ge.apply(null,arguments)},e._vscf_ecies_use_ephemeral_key=function(){return e.asm.He.apply(null,arguments)},e._vscf_ecies_use_kdf=function(){return e.asm.Ie.apply(null,arguments)},e._vscf_ecies_use_mac=function(){return e.asm.Je.apply(null,arguments)},e._vscf_ecies_use_random=function(){return e.asm.Ke.apply(null,arguments)},e._vscf_ed25519_alg_id=function(){return e.asm.Le.apply(null,arguments)},e._vscf_ed25519_can_decrypt=function(){return e.asm.Me.apply(null,arguments)},e._vscf_ed25519_can_encrypt=function(){return e.asm.Ne.apply(null,arguments)},e._vscf_ed25519_can_sign=function(){return e.asm.Oe.apply(null,arguments)},e._vscf_ed25519_can_verify=function(){return e.asm.Pe.apply(null,arguments)},e._vscf_ed25519_compute_shared_key=function(){return e.asm.Qe.apply(null,arguments)},e._vscf_ed25519_decrypt=function(){return e.asm.Re.apply(null,arguments)},e._vscf_ed25519_decrypted_len=function(){return e.asm.Se.apply(null,arguments)},e._vscf_ed25519_delete=function(){return e.asm.Te.apply(null,arguments)},e._vscf_ed25519_encrypt=function(){return e.asm.Ue.apply(null,arguments)},e._vscf_ed25519_encrypted_len=function(){return e.asm.Ve.apply(null,arguments)},e._vscf_ed25519_export_private_key=function(){return e.asm.We.apply(null,arguments)},e._vscf_ed25519_export_public_key=function(){return e.asm.Xe.apply(null,arguments)},e._vscf_ed25519_generate_ephemeral_key=function(){return e.asm.Ye.apply(null,arguments)},e._vscf_ed25519_generate_key=function(){return e.asm.Ze.apply(null,arguments)},e._vscf_ed25519_import_private_key=function(){return e.asm._e.apply(null,arguments)},e._vscf_ed25519_import_public_key=function(){return e.asm.$e.apply(null,arguments)},e._vscf_ed25519_new=function(){return e.asm.af.apply(null,arguments)},e._vscf_ed25519_produce_alg_info=function(){return e.asm.bf.apply(null,arguments)},e._vscf_ed25519_release_ecies=function(){return e.asm.cf.apply(null,arguments)},e._vscf_ed25519_release_random=function(){return e.asm.df.apply(null,arguments)},e._vscf_ed25519_restore_alg_info=function(){return e.asm.ef.apply(null,arguments)},e._vscf_ed25519_setup_defaults=function(){return e.asm.ff.apply(null,arguments)},e._vscf_ed25519_shallow_copy=function(){return e.asm.gf.apply(null,arguments)},e._vscf_ed25519_shared_key_len=function(){return e.asm.hf.apply(null,arguments)},e._vscf_ed25519_sign_hash=function(){return e.asm.jf.apply(null,arguments)},e._vscf_ed25519_signature_len=function(){return e.asm.kf.apply(null,arguments)},e._vscf_ed25519_use_ecies=function(){return e.asm.lf.apply(null,arguments)},e._vscf_ed25519_use_random=function(){return e.asm.mf.apply(null,arguments)},e._vscf_ed25519_verify_hash=function(){return e.asm.nf.apply(null,arguments)},e._vscf_entropy_accumulator_add_source=function(){return e.asm.of.apply(null,arguments)},e._vscf_entropy_accumulator_delete=function(){return e.asm.pf.apply(null,arguments)},e._vscf_entropy_accumulator_gather=function(){return e.asm.qf.apply(null,arguments)},e._vscf_entropy_accumulator_is_strong=function(){return e.asm.rf.apply(null,arguments)},e._vscf_entropy_accumulator_new=function(){return e.asm.sf.apply(null,arguments)},e._vscf_entropy_accumulator_setup_defaults=function(){return e.asm.tf.apply(null,arguments)},e._vscf_entropy_accumulator_shallow_copy=function(){return e.asm.uf.apply(null,arguments)},e._vscf_error_ctx_size=function(){return e.asm.vf.apply(null,arguments)},e._vscf_error_reset=function(){return e.asm.wf.apply(null,arguments)},e._vscf_error_status=function(){return e.asm.xf.apply(null,arguments)},e._vscf_fake_random_delete=function(){return e.asm.yf.apply(null,arguments)},e._vscf_fake_random_gather=function(){return e.asm.zf.apply(null,arguments)},e._vscf_fake_random_is_strong=function(){return e.asm.Af.apply(null,arguments)},e._vscf_fake_random_new=function(){return e.asm.Bf.apply(null,arguments)},e._vscf_fake_random_random=function(){return e.asm.Cf.apply(null,arguments)},e._vscf_fake_random_reseed=function(){return e.asm.Df.apply(null,arguments)},e._vscf_fake_random_setup_source_byte=function(){return e.asm.Ef.apply(null,arguments)},e._vscf_fake_random_setup_source_data=function(){return e.asm.Ff.apply(null,arguments)},e._vscf_fake_random_shallow_copy=function(){return e.asm.Gf.apply(null,arguments)},e._vscf_footer_info_data_size=function(){return e.asm.Hf.apply(null,arguments)},e._vscf_footer_info_delete=function(){return e.asm.If.apply(null,arguments)},e._vscf_footer_info_has_signed_data_info=function(){return e.asm.Jf.apply(null,arguments)},e._vscf_footer_info_new=function(){return e.asm.Kf.apply(null,arguments)},e._vscf_footer_info_set_data_size=function(){return e.asm.Lf.apply(null,arguments)},e._vscf_footer_info_shallow_copy=function(){return e.asm.Mf.apply(null,arguments)},e._vscf_footer_info_signed_data_info=function(){return e.asm.Nf.apply(null,arguments)},e._vscf_group_session_add_epoch=function(){return e.asm.Of.apply(null,arguments)},e._vscf_group_session_create_group_ticket=function(){return e.asm.Pf.apply(null,arguments)},e._vscf_group_session_decrypt=function(){return e.asm.Qf.apply(null,arguments)},e._vscf_group_session_decrypt_len=function(){return e.asm.Rf.apply(null,arguments)},e._vscf_group_session_delete=function(){return e.asm.Sf.apply(null,arguments)},e._vscf_group_session_encrypt=function(){return e.asm.Tf.apply(null,arguments)},e._vscf_group_session_get_current_epoch=function(){return e.asm.Uf.apply(null,arguments)},e._vscf_group_session_get_session_id=function(){return e.asm.Vf.apply(null,arguments)},e._vscf_group_session_message_delete=function(){return e.asm.Wf.apply(null,arguments)},e._vscf_group_session_message_deserialize=function(){return e.asm.Xf.apply(null,arguments)},e._vscf_group_session_message_get_epoch=function(){return e.asm.Yf.apply(null,arguments)},e._vscf_group_session_message_get_session_id=function(){return e.asm.Zf.apply(null,arguments)},e._vscf_group_session_message_get_type=function(){return e.asm._f.apply(null,arguments)},e._vscf_group_session_message_new=function(){return e.asm.$f.apply(null,arguments)},e._vscf_group_session_message_serialize=function(){return e.asm.ag.apply(null,arguments)},e._vscf_group_session_message_serialize_len=function(){return e.asm.bg.apply(null,arguments)},e._vscf_group_session_message_shallow_copy=function(){return e.asm.cg.apply(null,arguments)},e._vscf_group_session_new=function(){return e.asm.dg.apply(null,arguments)},e._vscf_group_session_release_rng=function(){return e.asm.eg.apply(null,arguments)},e._vscf_group_session_setup_defaults=function(){return e.asm.fg.apply(null,arguments)},e._vscf_group_session_shallow_copy=function(){return e.asm.gg.apply(null,arguments)},e._vscf_group_session_ticket_delete=function(){return e.asm.hg.apply(null,arguments)},e._vscf_group_session_ticket_get_ticket_message=function(){return e.asm.ig.apply(null,arguments)},e._vscf_group_session_ticket_new=function(){return e.asm.jg.apply(null,arguments)},e._vscf_group_session_ticket_release_rng=function(){return e.asm.kg.apply(null,arguments)},e._vscf_group_session_ticket_setup_defaults=function(){return e.asm.lg.apply(null,arguments)},e._vscf_group_session_ticket_setup_ticket_as_new=function(){return e.asm.mg.apply(null,arguments)},e._vscf_group_session_ticket_shallow_copy=function(){return e.asm.ng.apply(null,arguments)},e._vscf_group_session_ticket_use_rng=function(){return e.asm.og.apply(null,arguments)},e._vscf_group_session_use_rng=function(){return e.asm.pg.apply(null,arguments)},e._vscf_hash_based_alg_info_alg_id=function(){return e.asm.qg.apply(null,arguments)},e._vscf_hash_based_alg_info_delete=function(){return e.asm.rg.apply(null,arguments)},e._vscf_hash_based_alg_info_hash_alg_info=function(){return e.asm.sg.apply(null,arguments)},e._vscf_hash_based_alg_info_new=function(){return e.asm.tg.apply(null,arguments)},e._vscf_hash_based_alg_info_new_with_members=function(){return e.asm.ug.apply(null,arguments)},e._vscf_hash_based_alg_info_shallow_copy=function(){return e.asm.vg.apply(null,arguments)},e._vscf_hkdf_alg_id=function(){return e.asm.wg.apply(null,arguments)},e._vscf_hkdf_delete=function(){return e.asm.xg.apply(null,arguments)},e._vscf_hkdf_derive=function(){return e.asm.yg.apply(null,arguments)},e._vscf_hkdf_new=function(){return e.asm.zg.apply(null,arguments)},e._vscf_hkdf_produce_alg_info=function(){return e.asm.Ag.apply(null,arguments)},e._vscf_hkdf_release_hash=function(){return e.asm.Bg.apply(null,arguments)},e._vscf_hkdf_reset=function(){return e.asm.Cg.apply(null,arguments)},e._vscf_hkdf_restore_alg_info=function(){return e.asm.Dg.apply(null,arguments)},e._vscf_hkdf_set_info=function(){return e.asm.Eg.apply(null,arguments)},e._vscf_hkdf_shallow_copy=function(){return e.asm.Fg.apply(null,arguments)},e._vscf_hkdf_use_hash=function(){return e.asm.Gg.apply(null,arguments)},e._vscf_hmac_alg_id=function(){return e.asm.Hg.apply(null,arguments)},e._vscf_hmac_delete=function(){return e.asm.Ig.apply(null,arguments)},e._vscf_hmac_digest_len=function(){return e.asm.Jg.apply(null,arguments)},e._vscf_hmac_finish=function(){return e.asm.Kg.apply(null,arguments)},e._vscf_hmac_mac=function(){return e.asm.Lg.apply(null,arguments)},e._vscf_hmac_new=function(){return e.asm.Mg.apply(null,arguments)},e._vscf_hmac_produce_alg_info=function(){return e.asm.Ng.apply(null,arguments)},e._vscf_hmac_release_hash=function(){return e.asm.Og.apply(null,arguments)},e._vscf_hmac_reset=function(){return e.asm.Pg.apply(null,arguments)},e._vscf_hmac_restore_alg_info=function(){return e.asm.Qg.apply(null,arguments)},e._vscf_hmac_shallow_copy=function(){return e.asm.Rg.apply(null,arguments)},e._vscf_hmac_start=function(){return e.asm.Sg.apply(null,arguments)},e._vscf_hmac_update=function(){return e.asm.Tg.apply(null,arguments)},e._vscf_hmac_use_hash=function(){return e.asm.Ug.apply(null,arguments)},e._vscf_impl_api=function(){return e.asm.Vg.apply(null,arguments)},e._vscf_impl_shallow_copy=function(){return e.asm.Wg.apply(null,arguments)},e._vscf_impl_tag=function(){return e.asm.Xg.apply(null,arguments)},e._vscf_kdf1_alg_id=function(){return e.asm.Yg.apply(null,arguments)},e._vscf_kdf1_delete=function(){return e.asm.Zg.apply(null,arguments)},e._vscf_kdf1_derive=function(){return e.asm._g.apply(null,arguments)},e._vscf_kdf1_new=function(){return e.asm.$g.apply(null,arguments)},e._vscf_kdf1_produce_alg_info=function(){return e.asm.ah.apply(null,arguments)},e._vscf_kdf1_release_hash=function(){return e.asm.bh.apply(null,arguments)},e._vscf_kdf1_restore_alg_info=function(){return e.asm.ch.apply(null,arguments)},e._vscf_kdf1_shallow_copy=function(){return e.asm.dh.apply(null,arguments)},e._vscf_kdf1_use_hash=function(){return e.asm.eh.apply(null,arguments)},e._vscf_kdf2_alg_id=function(){return e.asm.fh.apply(null,arguments)},e._vscf_kdf2_delete=function(){return e.asm.gh.apply(null,arguments)},e._vscf_kdf2_derive=function(){return e.asm.hh.apply(null,arguments)},e._vscf_kdf2_new=function(){return e.asm.ih.apply(null,arguments)},e._vscf_kdf2_produce_alg_info=function(){return e.asm.jh.apply(null,arguments)},e._vscf_kdf2_release_hash=function(){return e.asm.kh.apply(null,arguments)},e._vscf_kdf2_restore_alg_info=function(){return e.asm.lh.apply(null,arguments)},e._vscf_kdf2_shallow_copy=function(){return e.asm.mh.apply(null,arguments)},e._vscf_kdf2_use_hash=function(){return e.asm.nh.apply(null,arguments)},e._vscf_key_alg_factory_create_from_alg_id=function(){return e.asm.oh.apply(null,arguments)},e._vscf_key_alg_factory_create_from_key=function(){return e.asm.ph.apply(null,arguments)},e._vscf_key_alg_factory_create_from_raw_private_key=function(){return e.asm.qh.apply(null,arguments)},e._vscf_key_alg_factory_create_from_raw_public_key=function(){return e.asm.rh.apply(null,arguments)},e._vscf_key_asn1_deserializer_delete=function(){return e.asm.sh.apply(null,arguments)},e._vscf_key_asn1_deserializer_deserialize_private_key=function(){return e.asm.th.apply(null,arguments)},e._vscf_key_asn1_deserializer_deserialize_private_key_inplace=function(){return e.asm.uh.apply(null,arguments)},e._vscf_key_asn1_deserializer_deserialize_public_key=function(){return e.asm.vh.apply(null,arguments)},e._vscf_key_asn1_deserializer_deserialize_public_key_inplace=function(){return e.asm.wh.apply(null,arguments)},e._vscf_key_asn1_deserializer_new=function(){return e.asm.xh.apply(null,arguments)},e._vscf_key_asn1_deserializer_release_asn1_reader=function(){return e.asm.yh.apply(null,arguments)},e._vscf_key_asn1_deserializer_setup_defaults=function(){return e.asm.zh.apply(null,arguments)},e._vscf_key_asn1_deserializer_shallow_copy=function(){return e.asm.Ah.apply(null,arguments)},e._vscf_key_asn1_deserializer_use_asn1_reader=function(){return e.asm.Bh.apply(null,arguments)},e._vscf_key_asn1_serializer_delete=function(){return e.asm.Ch.apply(null,arguments)},e._vscf_key_asn1_serializer_new=function(){return e.asm.Dh.apply(null,arguments)},e._vscf_key_asn1_serializer_release_asn1_writer=function(){return e.asm.Eh.apply(null,arguments)},e._vscf_key_asn1_serializer_serialize_private_key=function(){return e.asm.Fh.apply(null,arguments)},e._vscf_key_asn1_serializer_serialize_private_key_inplace=function(){return e.asm.Gh.apply(null,arguments)},e._vscf_key_asn1_serializer_serialize_public_key=function(){return e.asm.Hh.apply(null,arguments)},e._vscf_key_asn1_serializer_serialize_public_key_inplace=function(){return e.asm.Ih.apply(null,arguments)},e._vscf_key_asn1_serializer_serialized_private_key_len=function(){return e.asm.Jh.apply(null,arguments)},e._vscf_key_asn1_serializer_serialized_public_key_len=function(){return e.asm.Kh.apply(null,arguments)},e._vscf_key_asn1_serializer_setup_defaults=function(){return e.asm.Lh.apply(null,arguments)},e._vscf_key_asn1_serializer_shallow_copy=function(){return e.asm.Mh.apply(null,arguments)},e._vscf_key_asn1_serializer_use_asn1_writer=function(){return e.asm.Nh.apply(null,arguments)},e._vscf_key_material_rng_delete=function(){return e.asm.Oh.apply(null,arguments)},e._vscf_key_material_rng_new=function(){return e.asm.Ph.apply(null,arguments)},e._vscf_key_material_rng_random=function(){return e.asm.Qh.apply(null,arguments)},e._vscf_key_material_rng_reseed=function(){return e.asm.Rh.apply(null,arguments)},e._vscf_key_material_rng_reset_key_material=function(){return e.asm.Sh.apply(null,arguments)},e._vscf_key_material_rng_shallow_copy=function(){return e.asm.Th.apply(null,arguments)},e._vscf_key_provider_delete=function(){return e.asm.Uh.apply(null,arguments)},e._vscf_key_provider_export_private_key=function(){return e.asm.Vh.apply(null,arguments)},e._vscf_key_provider_export_public_key=function(){return e.asm.Wh.apply(null,arguments)},e._vscf_key_provider_exported_private_key_len=function(){return e.asm.Xh.apply(null,arguments)},e._vscf_key_provider_exported_public_key_len=function(){return e.asm.Yh.apply(null,arguments)},e._vscf_key_provider_generate_private_key=function(){return e.asm.Zh.apply(null,arguments)},e._vscf_key_provider_import_private_key=function(){return e.asm._h.apply(null,arguments)},e._vscf_key_provider_import_public_key=function(){return e.asm.$h.apply(null,arguments)},e._vscf_key_provider_new=function(){return e.asm.ai.apply(null,arguments)},e._vscf_key_provider_release_ecies=function(){return e.asm.bi.apply(null,arguments)},e._vscf_key_provider_release_random=function(){return e.asm.ci.apply(null,arguments)},e._vscf_key_provider_set_rsa_params=function(){return e.asm.di.apply(null,arguments)},e._vscf_key_provider_setup_defaults=function(){return e.asm.ei.apply(null,arguments)},e._vscf_key_provider_shallow_copy=function(){return e.asm.fi.apply(null,arguments)},e._vscf_key_provider_use_ecies=function(){return e.asm.gi.apply(null,arguments)},e._vscf_key_provider_use_random=function(){return e.asm.hi.apply(null,arguments)},e._vscf_key_recipient_info_delete=function(){return e.asm.ii.apply(null,arguments)},e._vscf_key_recipient_info_encrypted_key=function(){return e.asm.ji.apply(null,arguments)},e._vscf_key_recipient_info_key_encryption_algorithm=function(){return e.asm.ki.apply(null,arguments)},e._vscf_key_recipient_info_list_clear=function(){return e.asm.li.apply(null,arguments)},e._vscf_key_recipient_info_list_delete=function(){return e.asm.mi.apply(null,arguments)},e._vscf_key_recipient_info_list_has_item=function(){return e.asm.ni.apply(null,arguments)},e._vscf_key_recipient_info_list_has_next=function(){return e.asm.oi.apply(null,arguments)},e._vscf_key_recipient_info_list_has_prev=function(){return e.asm.pi.apply(null,arguments)},e._vscf_key_recipient_info_list_item=function(){return e.asm.qi.apply(null,arguments)},e._vscf_key_recipient_info_list_new=function(){return e.asm.ri.apply(null,arguments)},e._vscf_key_recipient_info_list_next=function(){return e.asm.si.apply(null,arguments)},e._vscf_key_recipient_info_list_prev=function(){return e.asm.ti.apply(null,arguments)},e._vscf_key_recipient_info_list_shallow_copy=function(){return e.asm.ui.apply(null,arguments)},e._vscf_key_recipient_info_new=function(){return e.asm.vi.apply(null,arguments)},e._vscf_key_recipient_info_new_with_data=function(){return e.asm.wi.apply(null,arguments)},e._vscf_key_recipient_info_recipient_id=function(){return e.asm.xi.apply(null,arguments)},e._vscf_key_recipient_info_shallow_copy=function(){return e.asm.yi.apply(null,arguments)},e._vscf_message_info_cipher_kdf_alg_info=function(){return e.asm.zi.apply(null,arguments)},e._vscf_message_info_clear=function(){return e.asm.Ai.apply(null,arguments)},e._vscf_message_info_custom_params=function(){return e.asm.Bi.apply(null,arguments)},e._vscf_message_info_custom_params_add_data=function(){return e.asm.Ci.apply(null,arguments)},e._vscf_message_info_custom_params_add_int=function(){return e.asm.Di.apply(null,arguments)},e._vscf_message_info_custom_params_add_string=function(){return e.asm.Ei.apply(null,arguments)},e._vscf_message_info_custom_params_clear=function(){return e.asm.Fi.apply(null,arguments)},e._vscf_message_info_custom_params_delete=function(){return e.asm.Gi.apply(null,arguments)},e._vscf_message_info_custom_params_find_data=function(){return e.asm.Hi.apply(null,arguments)},e._vscf_message_info_custom_params_find_int=function(){return e.asm.Ii.apply(null,arguments)},e._vscf_message_info_custom_params_find_string=function(){return e.asm.Ji.apply(null,arguments)},e._vscf_message_info_custom_params_has_params=function(){return e.asm.Ki.apply(null,arguments)},e._vscf_message_info_custom_params_new=function(){return e.asm.Li.apply(null,arguments)},e._vscf_message_info_custom_params_shallow_copy=function(){return e.asm.Mi.apply(null,arguments)},e._vscf_message_info_data_encryption_alg_info=function(){return e.asm.Ni.apply(null,arguments)},e._vscf_message_info_delete=function(){return e.asm.Oi.apply(null,arguments)},e._vscf_message_info_der_serializer_delete=function(){return e.asm.Pi.apply(null,arguments)},e._vscf_message_info_der_serializer_deserialize=function(){return e.asm.Qi.apply(null,arguments)},e._vscf_message_info_der_serializer_deserialize_footer=function(){return e.asm.Ri.apply(null,arguments)},e._vscf_message_info_der_serializer_new=function(){return e.asm.Si.apply(null,arguments)},e._vscf_message_info_der_serializer_read_prefix=function(){return e.asm.Ti.apply(null,arguments)},e._vscf_message_info_der_serializer_release_asn1_reader=function(){return e.asm.Ui.apply(null,arguments)},e._vscf_message_info_der_serializer_release_asn1_writer=function(){return e.asm.Vi.apply(null,arguments)},e._vscf_message_info_der_serializer_serialize=function(){return e.asm.Wi.apply(null,arguments)},e._vscf_message_info_der_serializer_serialize_footer=function(){return e.asm.Xi.apply(null,arguments)},e._vscf_message_info_der_serializer_serialized_footer_len=function(){return e.asm.Yi.apply(null,arguments)},e._vscf_message_info_der_serializer_serialized_len=function(){return e.asm.Zi.apply(null,arguments)},e._vscf_message_info_der_serializer_setup_defaults=function(){return e.asm._i.apply(null,arguments)},e._vscf_message_info_der_serializer_shallow_copy=function(){return e.asm.$i.apply(null,arguments)},e._vscf_message_info_der_serializer_use_asn1_reader=function(){return e.asm.aj.apply(null,arguments)},e._vscf_message_info_der_serializer_use_asn1_writer=function(){return e.asm.bj.apply(null,arguments)},e._vscf_message_info_editor_add_key_recipient=function(){return e.asm.cj.apply(null,arguments)},e._vscf_message_info_editor_delete=function(){return e.asm.dj.apply(null,arguments)},e._vscf_message_info_editor_new=function(){return e.asm.ej.apply(null,arguments)},e._vscf_message_info_editor_pack=function(){return e.asm.fj.apply(null,arguments)},e._vscf_message_info_editor_packed_len=function(){return e.asm.gj.apply(null,arguments)},e._vscf_message_info_editor_release_random=function(){return e.asm.hj.apply(null,arguments)},e._vscf_message_info_editor_remove_all=function(){return e.asm.ij.apply(null,arguments)},e._vscf_message_info_editor_remove_key_recipient=function(){return e.asm.jj.apply(null,arguments)},e._vscf_message_info_editor_setup_defaults=function(){return e.asm.kj.apply(null,arguments)},e._vscf_message_info_editor_shallow_copy=function(){return e.asm.lj.apply(null,arguments)},e._vscf_message_info_editor_unlock=function(){return e.asm.mj.apply(null,arguments)},e._vscf_message_info_editor_unpack=function(){return e.asm.nj.apply(null,arguments)},e._vscf_message_info_editor_use_random=function(){return e.asm.oj.apply(null,arguments)},e._vscf_message_info_footer_delete=function(){return e.asm.pj.apply(null,arguments)},e._vscf_message_info_footer_has_signer_infos=function(){return e.asm.qj.apply(null,arguments)},e._vscf_message_info_footer_info=function(){return e.asm.rj.apply(null,arguments)},e._vscf_message_info_footer_new=function(){return e.asm.sj.apply(null,arguments)},e._vscf_message_info_footer_shallow_copy=function(){return e.asm.tj.apply(null,arguments)},e._vscf_message_info_footer_signer_digest=function(){return e.asm.uj.apply(null,arguments)},e._vscf_message_info_footer_signer_hash_alg_info=function(){return e.asm.vj.apply(null,arguments)},e._vscf_message_info_footer_signer_infos=function(){return e.asm.wj.apply(null,arguments)},e._vscf_message_info_has_cipher_kdf_alg_info=function(){return e.asm.xj.apply(null,arguments)},e._vscf_message_info_has_custom_params=function(){return e.asm.yj.apply(null,arguments)},e._vscf_message_info_has_footer_info=function(){return e.asm.zj.apply(null,arguments)},e._vscf_message_info_key_recipient_info_list=function(){return e.asm.Aj.apply(null,arguments)},e._vscf_message_info_new=function(){return e.asm.Bj.apply(null,arguments)},e._vscf_message_info_password_recipient_info_list=function(){return e.asm.Cj.apply(null,arguments)},e._vscf_message_info_shallow_copy=function(){return e.asm.Dj.apply(null,arguments)},e._vscf_oid_equal=function(){return e.asm.Ej.apply(null,arguments)},e._vscf_oid_from_alg_id=function(){return e.asm.Fj.apply(null,arguments)},e._vscf_oid_from_id=function(){return e.asm.Gj.apply(null,arguments)},e._vscf_oid_id_to_alg_id=function(){return e.asm.Hj.apply(null,arguments)},e._vscf_oid_to_alg_id=function(){return e.asm.Ij.apply(null,arguments)},e._vscf_oid_to_id=function(){return e.asm.Jj.apply(null,arguments)},e._vscf_password_recipient_info_delete=function(){return e.asm.Kj.apply(null,arguments)},e._vscf_password_recipient_info_encrypted_key=function(){return e.asm.Lj.apply(null,arguments)},e._vscf_password_recipient_info_key_encryption_algorithm=function(){return e.asm.Mj.apply(null,arguments)},e._vscf_password_recipient_info_list_clear=function(){return e.asm.Nj.apply(null,arguments)},e._vscf_password_recipient_info_list_delete=function(){return e.asm.Oj.apply(null,arguments)},e._vscf_password_recipient_info_list_has_item=function(){return e.asm.Pj.apply(null,arguments)},e._vscf_password_recipient_info_list_has_next=function(){return e.asm.Qj.apply(null,arguments)},e._vscf_password_recipient_info_list_has_prev=function(){return e.asm.Rj.apply(null,arguments)},e._vscf_password_recipient_info_list_item=function(){return e.asm.Sj.apply(null,arguments)},e._vscf_password_recipient_info_list_new=function(){return e.asm.Tj.apply(null,arguments)},e._vscf_password_recipient_info_list_next=function(){return e.asm.Uj.apply(null,arguments)},e._vscf_password_recipient_info_list_prev=function(){return e.asm.Vj.apply(null,arguments)},e._vscf_password_recipient_info_list_shallow_copy=function(){return e.asm.Wj.apply(null,arguments)},e._vscf_password_recipient_info_new=function(){return e.asm.Xj.apply(null,arguments)},e._vscf_password_recipient_info_new_with_members=function(){return e.asm.Yj.apply(null,arguments)},e._vscf_password_recipient_info_shallow_copy=function(){return e.asm.Zj.apply(null,arguments)},e._vscf_pbe_alg_info_alg_id=function(){return e.asm._j.apply(null,arguments)},e._vscf_pbe_alg_info_cipher_alg_info=function(){return e.asm.$j.apply(null,arguments)},e._vscf_pbe_alg_info_delete=function(){return e.asm.ak.apply(null,arguments)},e._vscf_pbe_alg_info_kdf_alg_info=function(){return e.asm.bk.apply(null,arguments)},e._vscf_pbe_alg_info_new=function(){return e.asm.ck.apply(null,arguments)},e._vscf_pbe_alg_info_new_with_members=function(){return e.asm.dk.apply(null,arguments)},e._vscf_pbe_alg_info_shallow_copy=function(){return e.asm.ek.apply(null,arguments)},e._vscf_pem_title=function(){return e.asm.fk.apply(null,arguments)},e._vscf_pem_unwrap=function(){return e.asm.gk.apply(null,arguments)},e._vscf_pem_unwrapped_len=function(){return e.asm.hk.apply(null,arguments)},e._vscf_pem_wrap=function(){return e.asm.ik.apply(null,arguments)},e._vscf_pem_wrapped_len=function(){return e.asm.jk.apply(null,arguments)},e._vscf_pkcs5_pbes2_alg_id=function(){return e.asm.kk.apply(null,arguments)},e._vscf_pkcs5_pbes2_decrypt=function(){return e.asm.lk.apply(null,arguments)},e._vscf_pkcs5_pbes2_decrypted_len=function(){return e.asm.mk.apply(null,arguments)},e._vscf_pkcs5_pbes2_delete=function(){return e.asm.nk.apply(null,arguments)},e._vscf_pkcs5_pbes2_encrypt=function(){return e.asm.ok.apply(null,arguments)},e._vscf_pkcs5_pbes2_encrypted_len=function(){return e.asm.pk.apply(null,arguments)},e._vscf_pkcs5_pbes2_new=function(){return e.asm.qk.apply(null,arguments)},e._vscf_pkcs5_pbes2_precise_encrypted_len=function(){return e.asm.rk.apply(null,arguments)},e._vscf_pkcs5_pbes2_produce_alg_info=function(){return e.asm.sk.apply(null,arguments)},e._vscf_pkcs5_pbes2_release_cipher=function(){return e.asm.tk.apply(null,arguments)},e._vscf_pkcs5_pbes2_release_kdf=function(){return e.asm.uk.apply(null,arguments)},e._vscf_pkcs5_pbes2_reset=function(){return e.asm.vk.apply(null,arguments)},e._vscf_pkcs5_pbes2_restore_alg_info=function(){return e.asm.wk.apply(null,arguments)},e._vscf_pkcs5_pbes2_shallow_copy=function(){return e.asm.xk.apply(null,arguments)},e._vscf_pkcs5_pbes2_use_cipher=function(){return e.asm.yk.apply(null,arguments)},e._vscf_pkcs5_pbes2_use_kdf=function(){return e.asm.zk.apply(null,arguments)},e._vscf_pkcs5_pbkdf2_alg_id=function(){return e.asm.Ak.apply(null,arguments)},e._vscf_pkcs5_pbkdf2_delete=function(){return e.asm.Bk.apply(null,arguments)},e._vscf_pkcs5_pbkdf2_derive=function(){return e.asm.Ck.apply(null,arguments)},e._vscf_pkcs5_pbkdf2_new=function(){return e.asm.Dk.apply(null,arguments)},e._vscf_pkcs5_pbkdf2_produce_alg_info=function(){return e.asm.Ek.apply(null,arguments)},e._vscf_pkcs5_pbkdf2_release_hmac=function(){return e.asm.Fk.apply(null,arguments)},e._vscf_pkcs5_pbkdf2_reset=function(){return e.asm.Gk.apply(null,arguments)},e._vscf_pkcs5_pbkdf2_restore_alg_info=function(){return e.asm.Hk.apply(null,arguments)},e._vscf_pkcs5_pbkdf2_set_info=function(){return e.asm.Ik.apply(null,arguments)},e._vscf_pkcs5_pbkdf2_setup_defaults=function(){return e.asm.Jk.apply(null,arguments)},e._vscf_pkcs5_pbkdf2_shallow_copy=function(){return e.asm.Kk.apply(null,arguments)},e._vscf_pkcs5_pbkdf2_use_hmac=function(){return e.asm.Lk.apply(null,arguments)},e._vscf_pkcs8_serializer_delete=function(){return e.asm.Mk.apply(null,arguments)},e._vscf_pkcs8_serializer_new=function(){return e.asm.Nk.apply(null,arguments)},e._vscf_pkcs8_serializer_release_asn1_writer=function(){return e.asm.Ok.apply(null,arguments)},e._vscf_pkcs8_serializer_serialize_private_key=function(){return e.asm.Pk.apply(null,arguments)},e._vscf_pkcs8_serializer_serialize_private_key_inplace=function(){return e.asm.Qk.apply(null,arguments)},e._vscf_pkcs8_serializer_serialize_public_key=function(){return e.asm.Rk.apply(null,arguments)},e._vscf_pkcs8_serializer_serialize_public_key_inplace=function(){return e.asm.Sk.apply(null,arguments)},e._vscf_pkcs8_serializer_serialized_private_key_len=function(){return e.asm.Tk.apply(null,arguments)},e._vscf_pkcs8_serializer_serialized_public_key_len=function(){return e.asm.Uk.apply(null,arguments)},e._vscf_pkcs8_serializer_setup_defaults=function(){return e.asm.Vk.apply(null,arguments)},e._vscf_pkcs8_serializer_shallow_copy=function(){return e.asm.Wk.apply(null,arguments)},e._vscf_pkcs8_serializer_use_asn1_writer=function(){return e.asm.Xk.apply(null,arguments)},e._vscf_raw_private_key_alg_id=function(){return e.asm.Yk.apply(null,arguments)},e._vscf_raw_private_key_alg_info=function(){return e.asm.Zk.apply(null,arguments)},e._vscf_raw_private_key_bitlen=function(){return e.asm._k.apply(null,arguments)},e._vscf_raw_private_key_data=function(){return e.asm.$k.apply(null,arguments)},e._vscf_raw_private_key_delete=function(){return e.asm.al.apply(null,arguments)},e._vscf_raw_private_key_extract_public_key=function(){return e.asm.bl.apply(null,arguments)},e._vscf_raw_private_key_get_public_key=function(){return e.asm.cl.apply(null,arguments)},e._vscf_raw_private_key_has_public_key=function(){return e.asm.dl.apply(null,arguments)},e._vscf_raw_private_key_impl_tag=function(){return e.asm.el.apply(null,arguments)},e._vscf_raw_private_key_is_valid=function(){return e.asm.fl.apply(null,arguments)},e._vscf_raw_private_key_len=function(){return e.asm.gl.apply(null,arguments)},e._vscf_raw_private_key_new=function(){return e.asm.hl.apply(null,arguments)},e._vscf_raw_private_key_set_public_key=function(){return e.asm.il.apply(null,arguments)},e._vscf_raw_private_key_shallow_copy=function(){return e.asm.jl.apply(null,arguments)},e._vscf_raw_public_key_alg_id=function(){return e.asm.kl.apply(null,arguments)},e._vscf_raw_public_key_alg_info=function(){return e.asm.ll.apply(null,arguments)},e._vscf_raw_public_key_bitlen=function(){return e.asm.ml.apply(null,arguments)},e._vscf_raw_public_key_data=function(){return e.asm.nl.apply(null,arguments)},e._vscf_raw_public_key_delete=function(){return e.asm.ol.apply(null,arguments)},e._vscf_raw_public_key_impl_tag=function(){return e.asm.pl.apply(null,arguments)},e._vscf_raw_public_key_is_valid=function(){return e.asm.ql.apply(null,arguments)},e._vscf_raw_public_key_len=function(){return e.asm.rl.apply(null,arguments)},e._vscf_raw_public_key_new=function(){return e.asm.sl.apply(null,arguments)},e._vscf_raw_public_key_shallow_copy=function(){return e.asm.tl.apply(null,arguments)},e._vscf_recipient_cipher_add_key_recipient=function(){return e.asm.ul.apply(null,arguments)},e._vscf_recipient_cipher_add_signer=function(){return e.asm.vl.apply(null,arguments)},e._vscf_recipient_cipher_clear_recipients=function(){return e.asm.wl.apply(null,arguments)},e._vscf_recipient_cipher_clear_signers=function(){return e.asm.xl.apply(null,arguments)},e._vscf_recipient_cipher_custom_params=function(){return e.asm.yl.apply(null,arguments)},e._vscf_recipient_cipher_decryption_out_len=function(){return e.asm.zl.apply(null,arguments)},e._vscf_recipient_cipher_delete=function(){return e.asm.Al.apply(null,arguments)},e._vscf_recipient_cipher_encryption_out_len=function(){return e.asm.Bl.apply(null,arguments)},e._vscf_recipient_cipher_finish_decryption=function(){return e.asm.Cl.apply(null,arguments)},e._vscf_recipient_cipher_finish_encryption=function(){return e.asm.Dl.apply(null,arguments)},e._vscf_recipient_cipher_has_key_recipient=function(){return e.asm.El.apply(null,arguments)},e._vscf_recipient_cipher_is_data_signed=function(){return e.asm.Fl.apply(null,arguments)},e._vscf_recipient_cipher_message_info_footer_len=function(){return e.asm.Gl.apply(null,arguments)},e._vscf_recipient_cipher_message_info_len=function(){return e.asm.Hl.apply(null,arguments)},e._vscf_recipient_cipher_new=function(){return e.asm.Il.apply(null,arguments)},e._vscf_recipient_cipher_pack_message_info=function(){return e.asm.Jl.apply(null,arguments)},e._vscf_recipient_cipher_pack_message_info_footer=function(){return e.asm.Kl.apply(null,arguments)},e._vscf_recipient_cipher_process_decryption=function(){return e.asm.Ll.apply(null,arguments)},e._vscf_recipient_cipher_process_encryption=function(){return e.asm.Ml.apply(null,arguments)},e._vscf_recipient_cipher_release_encryption_cipher=function(){return e.asm.Nl.apply(null,arguments)},e._vscf_recipient_cipher_release_random=function(){return e.asm.Ol.apply(null,arguments)},e._vscf_recipient_cipher_release_signer_hash=function(){return e.asm.Pl.apply(null,arguments)},e._vscf_recipient_cipher_shallow_copy=function(){return e.asm.Ql.apply(null,arguments)},e._vscf_recipient_cipher_signer_infos=function(){return e.asm.Rl.apply(null,arguments)},e._vscf_recipient_cipher_start_decryption_with_key=function(){return e.asm.Sl.apply(null,arguments)},e._vscf_recipient_cipher_start_encryption=function(){return e.asm.Tl.apply(null,arguments)},e._vscf_recipient_cipher_start_signed_encryption=function(){return e.asm.Ul.apply(null,arguments)},e._vscf_recipient_cipher_start_verified_decryption_with_key=function(){return e.asm.Vl.apply(null,arguments)},e._vscf_recipient_cipher_use_encryption_cipher=function(){return e.asm.Wl.apply(null,arguments)},e._vscf_recipient_cipher_use_random=function(){return e.asm.Xl.apply(null,arguments)},e._vscf_recipient_cipher_use_signer_hash=function(){return e.asm.Yl.apply(null,arguments)},e._vscf_recipient_cipher_verify_signer_info=function(){return e.asm.Zl.apply(null,arguments)},e._vscf_rsa_alg_id=function(){return e.asm._l.apply(null,arguments)},e._vscf_rsa_can_decrypt=function(){return e.asm.$l.apply(null,arguments)},e._vscf_rsa_can_encrypt=function(){return e.asm.am.apply(null,arguments)},e._vscf_rsa_can_sign=function(){return e.asm.bm.apply(null,arguments)},e._vscf_rsa_can_verify=function(){return e.asm.cm.apply(null,arguments)},e._vscf_rsa_decrypt=function(){return e.asm.dm.apply(null,arguments)},e._vscf_rsa_decrypted_len=function(){return e.asm.em.apply(null,arguments)},e._vscf_rsa_delete=function(){return e.asm.fm.apply(null,arguments)},e._vscf_rsa_encrypt=function(){return e.asm.gm.apply(null,arguments)},e._vscf_rsa_encrypted_len=function(){return e.asm.hm.apply(null,arguments)},e._vscf_rsa_export_private_key=function(){return e.asm.im.apply(null,arguments)},e._vscf_rsa_export_public_key=function(){return e.asm.jm.apply(null,arguments)},e._vscf_rsa_generate_ephemeral_key=function(){return e.asm.km.apply(null,arguments)},e._vscf_rsa_generate_key=function(){return e.asm.lm.apply(null,arguments)},e._vscf_rsa_import_private_key=function(){return e.asm.mm.apply(null,arguments)},e._vscf_rsa_import_public_key=function(){return e.asm.nm.apply(null,arguments)},e._vscf_rsa_new=function(){return e.asm.om.apply(null,arguments)},e._vscf_rsa_private_key_alg_id=function(){return e.asm.pm.apply(null,arguments)},e._vscf_rsa_private_key_alg_info=function(){return e.asm.qm.apply(null,arguments)},e._vscf_rsa_private_key_bitlen=function(){return e.asm.rm.apply(null,arguments)},e._vscf_rsa_private_key_delete=function(){return e.asm.sm.apply(null,arguments)},e._vscf_rsa_private_key_extract_public_key=function(){return e.asm.tm.apply(null,arguments)},e._vscf_rsa_private_key_impl_tag=function(){return e.asm.um.apply(null,arguments)},e._vscf_rsa_private_key_is_valid=function(){return e.asm.vm.apply(null,arguments)},e._vscf_rsa_private_key_len=function(){return e.asm.wm.apply(null,arguments)},e._vscf_rsa_private_key_new=function(){return e.asm.xm.apply(null,arguments)},e._vscf_rsa_private_key_shallow_copy=function(){return e.asm.ym.apply(null,arguments)},e._vscf_rsa_produce_alg_info=function(){return e.asm.zm.apply(null,arguments)},e._vscf_rsa_public_key_alg_id=function(){return e.asm.Am.apply(null,arguments)},e._vscf_rsa_public_key_alg_info=function(){return e.asm.Bm.apply(null,arguments)},e._vscf_rsa_public_key_bitlen=function(){return e.asm.Cm.apply(null,arguments)},e._vscf_rsa_public_key_delete=function(){return e.asm.Dm.apply(null,arguments)},e._vscf_rsa_public_key_impl_tag=function(){return e.asm.Em.apply(null,arguments)},e._vscf_rsa_public_key_is_valid=function(){return e.asm.Fm.apply(null,arguments)},e._vscf_rsa_public_key_key_exponent=function(){return e.asm.Gm.apply(null,arguments)},e._vscf_rsa_public_key_len=function(){return e.asm.Hm.apply(null,arguments)},e._vscf_rsa_public_key_new=function(){return e.asm.Im.apply(null,arguments)},e._vscf_rsa_public_key_shallow_copy=function(){return e.asm.Jm.apply(null,arguments)},e._vscf_rsa_release_random=function(){return e.asm.Km.apply(null,arguments)},e._vscf_rsa_restore_alg_info=function(){return e.asm.Lm.apply(null,arguments)},e._vscf_rsa_setup_defaults=function(){return e.asm.Mm.apply(null,arguments)},e._vscf_rsa_shallow_copy=function(){return e.asm.Nm.apply(null,arguments)},e._vscf_rsa_sign_hash=function(){return e.asm.Om.apply(null,arguments)},e._vscf_rsa_signature_len=function(){return e.asm.Pm.apply(null,arguments)},e._vscf_rsa_use_random=function(){return e.asm.Qm.apply(null,arguments)},e._vscf_rsa_verify_hash=function(){return e.asm.Rm.apply(null,arguments)},e._vscf_salted_kdf_alg_info_alg_id=function(){return e.asm.Sm.apply(null,arguments)},e._vscf_salted_kdf_alg_info_delete=function(){return e.asm.Tm.apply(null,arguments)},e._vscf_salted_kdf_alg_info_hash_alg_info=function(){return e.asm.Um.apply(null,arguments)},e._vscf_salted_kdf_alg_info_iteration_count=function(){return e.asm.Vm.apply(null,arguments)},e._vscf_salted_kdf_alg_info_new=function(){return e.asm.Wm.apply(null,arguments)},e._vscf_salted_kdf_alg_info_new_with_members=function(){return e.asm.Xm.apply(null,arguments)},e._vscf_salted_kdf_alg_info_salt=function(){return e.asm.Ym.apply(null,arguments)},e._vscf_salted_kdf_alg_info_shallow_copy=function(){return e.asm.Zm.apply(null,arguments)},e._vscf_sec1_serializer_delete=function(){return e.asm._m.apply(null,arguments)},e._vscf_sec1_serializer_new=function(){return e.asm.$m.apply(null,arguments)},e._vscf_sec1_serializer_release_asn1_writer=function(){return e.asm.an.apply(null,arguments)},e._vscf_sec1_serializer_serialize_private_key=function(){return e.asm.bn.apply(null,arguments)},e._vscf_sec1_serializer_serialize_private_key_inplace=function(){return e.asm.cn.apply(null,arguments)},e._vscf_sec1_serializer_serialize_public_key=function(){return e.asm.dn.apply(null,arguments)},e._vscf_sec1_serializer_serialize_public_key_inplace=function(){return e.asm.en.apply(null,arguments)},e._vscf_sec1_serializer_serialized_private_key_len=function(){return e.asm.fn.apply(null,arguments)},e._vscf_sec1_serializer_serialized_public_key_len=function(){return e.asm.gn.apply(null,arguments)},e._vscf_sec1_serializer_setup_defaults=function(){return e.asm.hn.apply(null,arguments)},e._vscf_sec1_serializer_shallow_copy=function(){return e.asm.jn.apply(null,arguments)},e._vscf_sec1_serializer_use_asn1_writer=function(){return e.asm.kn.apply(null,arguments)},e._vscf_seed_entropy_source_delete=function(){return e.asm.ln.apply(null,arguments)},e._vscf_seed_entropy_source_gather=function(){return e.asm.mn.apply(null,arguments)},e._vscf_seed_entropy_source_is_strong=function(){return e.asm.nn.apply(null,arguments)},e._vscf_seed_entropy_source_new=function(){return e.asm.on.apply(null,arguments)},e._vscf_seed_entropy_source_reset_seed=function(){return e.asm.pn.apply(null,arguments)},e._vscf_seed_entropy_source_shallow_copy=function(){return e.asm.qn.apply(null,arguments)},e._vscf_sha224_alg_id=function(){return e.asm.rn.apply(null,arguments)},e._vscf_sha224_delete=function(){return e.asm.sn.apply(null,arguments)},e._vscf_sha224_finish=function(){return e.asm.tn.apply(null,arguments)},e._vscf_sha224_hash=function(){return e.asm.un.apply(null,arguments)},e._vscf_sha224_new=function(){return e.asm.vn.apply(null,arguments)},e._vscf_sha224_produce_alg_info=function(){return e.asm.wn.apply(null,arguments)},e._vscf_sha224_restore_alg_info=function(){return e.asm.xn.apply(null,arguments)},e._vscf_sha224_shallow_copy=function(){return e.asm.yn.apply(null,arguments)},e._vscf_sha224_start=function(){return e.asm.zn.apply(null,arguments)},e._vscf_sha224_update=function(){return e.asm.An.apply(null,arguments)},e._vscf_sha256_alg_id=function(){return e.asm.Bn.apply(null,arguments)},e._vscf_sha256_delete=function(){return e.asm.Cn.apply(null,arguments)},e._vscf_sha256_finish=function(){return e.asm.Dn.apply(null,arguments)},e._vscf_sha256_hash=function(){return e.asm.En.apply(null,arguments)},e._vscf_sha256_new=function(){return e.asm.Fn.apply(null,arguments)},e._vscf_sha256_produce_alg_info=function(){return e.asm.Gn.apply(null,arguments)},e._vscf_sha256_restore_alg_info=function(){return e.asm.Hn.apply(null,arguments)},e._vscf_sha256_shallow_copy=function(){return e.asm.In.apply(null,arguments)},e._vscf_sha256_start=function(){return e.asm.Jn.apply(null,arguments)},e._vscf_sha256_update=function(){return e.asm.Kn.apply(null,arguments)},e._vscf_sha384_alg_id=function(){return e.asm.Ln.apply(null,arguments)},e._vscf_sha384_delete=function(){return e.asm.Mn.apply(null,arguments)},e._vscf_sha384_finish=function(){return e.asm.Nn.apply(null,arguments)},e._vscf_sha384_hash=function(){return e.asm.On.apply(null,arguments)},e._vscf_sha384_new=function(){return e.asm.Pn.apply(null,arguments)},e._vscf_sha384_produce_alg_info=function(){return e.asm.Qn.apply(null,arguments)},e._vscf_sha384_restore_alg_info=function(){return e.asm.Rn.apply(null,arguments)},e._vscf_sha384_shallow_copy=function(){return e.asm.Sn.apply(null,arguments)},e._vscf_sha384_start=function(){return e.asm.Tn.apply(null,arguments)},e._vscf_sha384_update=function(){return e.asm.Un.apply(null,arguments)},e._vscf_sha512_alg_id=function(){return e.asm.Vn.apply(null,arguments)},e._vscf_sha512_delete=function(){return e.asm.Wn.apply(null,arguments)},e._vscf_sha512_finish=function(){return e.asm.Xn.apply(null,arguments)},e._vscf_sha512_hash=function(){return e.asm.Yn.apply(null,arguments)},e._vscf_sha512_new=function(){return e.asm.Zn.apply(null,arguments)},e._vscf_sha512_produce_alg_info=function(){return e.asm._n.apply(null,arguments)},e._vscf_sha512_restore_alg_info=function(){return e.asm.$n.apply(null,arguments)},e._vscf_sha512_shallow_copy=function(){return e.asm.ao.apply(null,arguments)},e._vscf_sha512_start=function(){return e.asm.bo.apply(null,arguments)},e._vscf_sha512_update=function(){return e.asm.co.apply(null,arguments)},e._vscf_signed_data_info_delete=function(){return e.asm.eo.apply(null,arguments)},e._vscf_signed_data_info_hash_alg_info=function(){return e.asm.fo.apply(null,arguments)},e._vscf_signed_data_info_new=function(){return e.asm.go.apply(null,arguments)},e._vscf_signed_data_info_set_hash_alg_info=function(){return e.asm.ho.apply(null,arguments)},e._vscf_signed_data_info_shallow_copy=function(){return e.asm.io.apply(null,arguments)},e._vscf_signer_append_data=function(){return e.asm.jo.apply(null,arguments)},e._vscf_signer_delete=function(){return e.asm.ko.apply(null,arguments)},e._vscf_signer_info_delete=function(){return e.asm.lo.apply(null,arguments)},e._vscf_signer_info_list_clear=function(){return e.asm.mo.apply(null,arguments)},e._vscf_signer_info_list_delete=function(){return e.asm.no.apply(null,arguments)},e._vscf_signer_info_list_has_item=function(){return e.asm.oo.apply(null,arguments)},e._vscf_signer_info_list_has_next=function(){return e.asm.po.apply(null,arguments)},e._vscf_signer_info_list_has_prev=function(){return e.asm.qo.apply(null,arguments)},e._vscf_signer_info_list_item=function(){return e.asm.ro.apply(null,arguments)},e._vscf_signer_info_list_new=function(){return e.asm.so.apply(null,arguments)},e._vscf_signer_info_list_next=function(){return e.asm.to.apply(null,arguments)},e._vscf_signer_info_list_prev=function(){return e.asm.uo.apply(null,arguments)},e._vscf_signer_info_list_shallow_copy=function(){return e.asm.vo.apply(null,arguments)},e._vscf_signer_info_new=function(){return e.asm.wo.apply(null,arguments)},e._vscf_signer_info_shallow_copy=function(){return e.asm.xo.apply(null,arguments)},e._vscf_signer_info_signature=function(){return e.asm.yo.apply(null,arguments)},e._vscf_signer_info_signer_alg_info=function(){return e.asm.zo.apply(null,arguments)},e._vscf_signer_info_signer_id=function(){return e.asm.Ao.apply(null,arguments)},e._vscf_signer_new=function(){return e.asm.Bo.apply(null,arguments)},e._vscf_signer_release_hash=function(){return e.asm.Co.apply(null,arguments)},e._vscf_signer_release_random=function(){return e.asm.Do.apply(null,arguments)},e._vscf_signer_reset=function(){return e.asm.Eo.apply(null,arguments)},e._vscf_signer_shallow_copy=function(){return e.asm.Fo.apply(null,arguments)},e._vscf_signer_sign=function(){return e.asm.Go.apply(null,arguments)},e._vscf_signer_signature_len=function(){return e.asm.Ho.apply(null,arguments)},e._vscf_signer_use_hash=function(){return e.asm.Io.apply(null,arguments)},e._vscf_signer_use_random=function(){return e.asm.Jo.apply(null,arguments)},e._vscf_simple_alg_info_alg_id=function(){return e.asm.Ko.apply(null,arguments)},e._vscf_simple_alg_info_delete=function(){return e.asm.Lo.apply(null,arguments)},e._vscf_simple_alg_info_new=function(){return e.asm.Mo.apply(null,arguments)},e._vscf_simple_alg_info_new_with_alg_id=function(){return e.asm.No.apply(null,arguments)},e._vscf_simple_alg_info_shallow_copy=function(){return e.asm.Oo.apply(null,arguments)},e._vscf_verifier_append_data=function(){return e.asm.Po.apply(null,arguments)},e._vscf_verifier_delete=function(){return e.asm.Qo.apply(null,arguments)},e._vscf_verifier_new=function(){return e.asm.Ro.apply(null,arguments)},e._vscf_verifier_reset=function(){return e.asm.So.apply(null,arguments)},e._vscf_verifier_shallow_copy=function(){return e.asm.To.apply(null,arguments)},e._vscf_verifier_verify=function(){return e.asm.Uo.apply(null,arguments)},e.stackAlloc=function(){return e.asm.Wo.apply(null,arguments)},e.dynCall_vi=function(){return e.asm.Vo.apply(null,arguments)},e.asm=Gt,e.then=function(t){if(Vt)t(e);else{var r=e.onRuntimeInitialized;e.onRuntimeInitialized=function(){r&&r(),t(e);};}return e},L=function t(){Vt||jt(),Vt||(L=t);},e.run=jt,e.preInit)for("function"==typeof e.preInit&&(e.preInit=[e.preInit]);0<e.preInit.length;)e.preInit.pop()();return jt(),t});t.exports=n;}(e={exports:{}}),e.exports}(),s$3=(t,e)=>{class r extends Error{constructor(t){super(t),this.name="FoundationError",this.message=t;}static handleStatusCode(t){if(0!=t){if(-1==t)throw new r("This error should not be returned if assertions is enabled.");if(-2==t)throw new r("Can be used to define that not all context prerequisites are satisfied. Note, this error should not be returned if assertions is enabled.");if(-3==t)throw new r("Define that error code from one of third-party module was not handled. Note, this error should not be returned if assertions is enabled.");if(-101==t)throw new r("Buffer capacity is not enough to hold result.");if(-200==t)throw new r("Unsupported algorithm.");if(-201==t)throw new r("Authentication failed during decryption.");if(-202==t)throw new r("Attempt to read data out of buffer bounds.");if(-203==t)throw new r("ASN.1 encoded data is corrupted.");if(-204==t)throw new r("Attempt to read ASN.1 type that is bigger then requested C type.");if(-205==t)throw new r("ASN.1 representation of PKCS#1 public key is corrupted.");if(-206==t)throw new r("ASN.1 representation of PKCS#1 private key is corrupted.");if(-207==t)throw new r("ASN.1 representation of PKCS#8 public key is corrupted.");if(-208==t)throw new r("ASN.1 representation of PKCS#8 private key is corrupted.");if(-209==t)throw new r("Encrypted data is corrupted.");if(-210==t)throw new r("Underlying random operation returns error.");if(-211==t)throw new r("Generation of the private or secret key failed.");if(-212==t)throw new r("One of the entropy sources failed.");if(-213==t)throw new r("Requested data to be generated is too big.");if(-214==t)throw new r("Base64 encoded string contains invalid characters.");if(-215==t)throw new r("PEM data is corrupted.");if(-216==t)throw new r("Exchange key return zero.");if(-217==t)throw new r("Ed25519 public key is corrupted.");if(-218==t)throw new r("Ed25519 private key is corrupted.");if(-219==t)throw new r("CURVE25519 public key is corrupted.");if(-220==t)throw new r("CURVE25519 private key is corrupted.");if(-221==t)throw new r("Elliptic curve public key format is corrupted see RFC 5480.");if(-222==t)throw new r("Elliptic curve public key format is corrupted see RFC 5915.");if(-223==t)throw new r("ASN.1 representation of a public key is corrupted.");if(-224==t)throw new r("ASN.1 representation of a private key is corrupted.");if(-225==t)throw new r("Key algorithm does not accept given type of public key.");if(-226==t)throw new r("Key algorithm does not accept given type of private key.");if(-301==t)throw new r("Decryption failed, because message info was not given explicitly, and was not part of an encrypted message.");if(-302==t)throw new r("Message Info is corrupted.");if(-303==t)throw new r("Recipient defined with id is not found within message info during data decryption.");if(-304==t)throw new r("Content encryption key can not be decrypted with a given private key.");if(-305==t)throw new r("Content encryption key can not be decrypted with a given password.");if(-306==t)throw new r("Custom parameter with a given key is not found within message info.");if(-307==t)throw new r("A custom parameter with a given key is found, but the requested value type does not correspond to the actual type.");if(-308==t)throw new r("Signature format is corrupted.");if(-309==t)throw new r("Message Info footer is corrupted.");if(-401==t)throw new r("Brainkey password length is out of range.");if(-402==t)throw new r("Brainkey number length should be 32 byte.");if(-403==t)throw new r("Brainkey point length should be 65 bytes.");if(-404==t)throw new r("Brainkey name is out of range.");if(-405==t)throw new r("Brainkey internal error.");if(-406==t)throw new r("Brainkey point is invalid.");if(-407==t)throw new r("Brainkey number buffer length capacity should be >= 32 byte.");if(-408==t)throw new r("Brainkey point buffer length capacity should be >= 32 byte.");if(-409==t)throw new r("Brainkey seed buffer length capacity should be >= 32 byte.");if(-410==t)throw new r("Brainkey identity secret is invalid.");if(-501==t)throw new r("Invalid padding.");if(-601==t)throw new r("Protobuf error.");if(-701==t)throw new r("Session id doesnt match.");if(-702==t)throw new r("Epoch not found.");if(-703==t)throw new r("Wrong key type.");if(-704==t)throw new r("Invalid signature.");if(-705==t)throw new r("Ed25519 error.");if(-706==t)throw new r("Duplicate epoch.");if(-707==t)throw new r("Plain text too long.");throw new r("Unexpected status code:"+t)}}}return r};function _$2(t,e){if(!("number"==typeof e||e instanceof Number))throw new TypeError(`'${t}' is not a number`);if(Number.isNaN(e))throw new TypeError(`'${t}' is NaN`);if(e===1/0)throw new TypeError(`'${t}' is Infinity`);if(e===-1/0)throw new TypeError(`'${t}' is -Infinity`)}function c$3(t,e){if(_$2(t,e),0==e)throw new TypeError(`'${t}' is NULL`)}var a$3={ensureNumber:_$2,ensureString:function(t,e){if(!("string"==typeof e||e instanceof String))throw new TypeError(`'${t}' is not a string`)},ensureBoolean:function(t,e){if("boolean"!=typeof e)throw new TypeError(`'${t}' is not a boolean`)},ensureByteArray:function(t,e){if(!(e instanceof Uint8Array))throw new TypeError(`'${t}' is not an Uint8Array`)},ensureClass:function(t,e,r){if(!(e instanceof r))throw new TypeError(`'${t}' is not an instance of the class ${r.name}`);c$3(t,e.ctxPtr);},ensureNotNull:c$3,ensureImplementInterface:function(t,e,r,n,s){if(c$3(t,e.ctxPtr),!s.isImplemented(e.ctxPtr,n))throw new TypeError(`'${t}' does not implement interface '${r}'`)}},i$3=(t,e)=>{class r{constructor(e){this.name="MessageInfo",this.ctxPtr=void 0===e?t._vscf_message_info_new():e;}static newAndUseCContext(e){return new r(t._vscf_message_info_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_message_info_delete(this.ctxPtr),this.ctxPtr=null);}dataEncryptionAlgInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_message_info_data_encryption_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}keyRecipientInfoList(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_message_info_key_recipient_info_list(this.ctxPtr),e.KeyRecipientInfoList.newAndUseCContext(r)}passwordRecipientInfoList(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_message_info_password_recipient_info_list(this.ctxPtr),e.PasswordRecipientInfoList.newAndUseCContext(r)}hasCustomParams(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_message_info_has_custom_params(this.ctxPtr))}customParams(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_message_info_custom_params(this.ctxPtr),e.MessageInfoCustomParams.newAndUseCContext(r)}hasCipherKdfAlgInfo(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_message_info_has_cipher_kdf_alg_info(this.ctxPtr))}cipherKdfAlgInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_message_info_cipher_kdf_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}hasFooterInfo(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_message_info_has_footer_info(this.ctxPtr))}footerInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_message_info_footer_info(this.ctxPtr),e.FooterInfo.newAndUseCContext(r)}clear(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_message_info_clear(this.ctxPtr);}}return r},o$3=(t,e)=>{class r{constructor(e){this.name="KeyRecipientInfo",this.ctxPtr=void 0===e?t._vscf_key_recipient_info_new():e;}static newAndUseCContext(e){return new r(t._vscf_key_recipient_info_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_key_recipient_info_delete(this.ctxPtr),this.ctxPtr=null);}static newWithData(n,s,_){a$3.ensureByteArray("recipientId",n),a$3.ensureImplementInterface("keyEncryptionAlgorithm",s,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),a$3.ensureByteArray("encryptedKey",_);const c=n.length*n.BYTES_PER_ELEMENT,i=t._malloc(c);t.HEAP8.set(n,i);const o=t._vsc_data_ctx_size(),l=t._malloc(o);t._vsc_data(l,i,c);const u=_.length*_.BYTES_PER_ELEMENT,f=t._malloc(u);t.HEAP8.set(_,f);const p=t._vsc_data_ctx_size(),d=t._malloc(p);let h;t._vsc_data(d,f,u);try{return h=t._vscf_key_recipient_info_new_with_data(l,s.ctxPtr,d),r.newAndTakeCContext(h)}finally{t._free(i),t._free(l),t._free(f),t._free(d);}}recipientId(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=t._vsc_data_ctx_size(),r=t._malloc(e);try{t._vscf_key_recipient_info_recipient_id(r,this.ctxPtr);const e=t._vsc_data_len(r),n=t._vsc_data_bytes(r);return t.HEAPU8.slice(n,n+e)}finally{t._free(r);}}keyEncryptionAlgorithm(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_key_recipient_info_key_encryption_algorithm(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}encryptedKey(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=t._vsc_data_ctx_size(),r=t._malloc(e);try{t._vscf_key_recipient_info_encrypted_key(r,this.ctxPtr);const e=t._vsc_data_len(r),n=t._vsc_data_bytes(r);return t.HEAPU8.slice(n,n+e)}finally{t._free(r);}}}return r},l$3=(t,e)=>{class r{constructor(e){this.name="KeyRecipientInfoList",this.ctxPtr=void 0===e?t._vscf_key_recipient_info_list_new():e;}static newAndUseCContext(e){return new r(t._vscf_key_recipient_info_list_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_key_recipient_info_list_delete(this.ctxPtr),this.ctxPtr=null);}hasItem(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_key_recipient_info_list_has_item(this.ctxPtr))}item(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_key_recipient_info_list_item(this.ctxPtr),e.KeyRecipientInfo.newAndUseCContext(r)}hasNext(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_key_recipient_info_list_has_next(this.ctxPtr))}next(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),e=t._vscf_key_recipient_info_list_next(this.ctxPtr),r.newAndTakeCContext(e)}hasPrev(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_key_recipient_info_list_has_prev(this.ctxPtr))}prev(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),e=t._vscf_key_recipient_info_list_prev(this.ctxPtr),r.newAndTakeCContext(e)}clear(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_key_recipient_info_list_clear(this.ctxPtr);}}return r},u$3=(t,e)=>{class r{constructor(e){this.name="PasswordRecipientInfo",this.ctxPtr=void 0===e?t._vscf_password_recipient_info_new():e;}static newAndUseCContext(e){return new r(t._vscf_password_recipient_info_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_password_recipient_info_delete(this.ctxPtr),this.ctxPtr=null);}static newWithMembers(n,s){a$3.ensureImplementInterface("keyEncryptionAlgorithm",n,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),a$3.ensureByteArray("encryptedKey",s);const _=s.length*s.BYTES_PER_ELEMENT,c=t._malloc(_);t.HEAP8.set(s,c);const i=t._vsc_data_ctx_size(),o=t._malloc(i);let l;t._vsc_data(o,c,_);try{return l=t._vscf_password_recipient_info_new_with_members(n.ctxPtr,o),r.newAndTakeCContext(l)}finally{t._free(c),t._free(o);}}keyEncryptionAlgorithm(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_password_recipient_info_key_encryption_algorithm(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}encryptedKey(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=t._vsc_data_ctx_size(),r=t._malloc(e);try{t._vscf_password_recipient_info_encrypted_key(r,this.ctxPtr);const e=t._vsc_data_len(r),n=t._vsc_data_bytes(r);return t.HEAPU8.slice(n,n+e)}finally{t._free(r);}}}return r},f$2=(t,e)=>{class r{constructor(e){this.name="PasswordRecipientInfoList",this.ctxPtr=void 0===e?t._vscf_password_recipient_info_list_new():e;}static newAndUseCContext(e){return new r(t._vscf_password_recipient_info_list_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_password_recipient_info_list_delete(this.ctxPtr),this.ctxPtr=null);}hasItem(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_password_recipient_info_list_has_item(this.ctxPtr))}item(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_password_recipient_info_list_item(this.ctxPtr),e.PasswordRecipientInfo.newAndUseCContext(r)}hasNext(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_password_recipient_info_list_has_next(this.ctxPtr))}next(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),e=t._vscf_password_recipient_info_list_next(this.ctxPtr),r.newAndTakeCContext(e)}hasPrev(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_password_recipient_info_list_has_prev(this.ctxPtr))}prev(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),e=t._vscf_password_recipient_info_list_prev(this.ctxPtr),r.newAndTakeCContext(e)}clear(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_password_recipient_info_list_clear(this.ctxPtr);}}return r},p$2=(t,e)=>{class r{constructor(e){this.name="Ecies",this.ctxPtr=void 0===e?t._vscf_ecies_new():e;}static newAndUseCContext(e){return new r(t._vscf_ecies_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_ecies_delete(this.ctxPtr),this.ctxPtr=null);}set random(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("random",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_ecies_release_random(this.ctxPtr),t._vscf_ecies_use_random(this.ctxPtr,r.ctxPtr);}set cipher(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("cipher",r,"Foundation.Cipher",e.FoundationInterfaceTag.CIPHER,e.FoundationInterface),t._vscf_ecies_release_cipher(this.ctxPtr),t._vscf_ecies_use_cipher(this.ctxPtr,r.ctxPtr);}set mac(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("mac",r,"Foundation.Mac",e.FoundationInterfaceTag.MAC,e.FoundationInterface),t._vscf_ecies_release_mac(this.ctxPtr),t._vscf_ecies_use_mac(this.ctxPtr,r.ctxPtr);}set kdf(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("kdf",r,"Foundation.Kdf",e.FoundationInterfaceTag.KDF,e.FoundationInterface),t._vscf_ecies_release_kdf(this.ctxPtr),t._vscf_ecies_use_kdf(this.ctxPtr,r.ctxPtr);}set ephemeralKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("ephemeralKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),t._vscf_ecies_release_ephemeral_key(this.ctxPtr),t._vscf_ecies_use_ephemeral_key(this.ctxPtr,r.ctxPtr);}setKeyAlg(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("keyAlg",r,"Foundation.KeyAlg",e.FoundationInterfaceTag.KEY_ALG,e.FoundationInterface),t._vscf_ecies_set_key_alg(this.ctxPtr,r.ctxPtr);}releaseKeyAlg(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecies_release_key_alg(this.ctxPtr);}setupDefaults(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_ecies_setup_defaults(this.ctxPtr);e.FoundationError.handleStatusCode(r);}setupDefaultsNoRandom(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecies_setup_defaults_no_random(this.ctxPtr);}encryptedLen(r,n){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$3.ensureNumber("dataLen",n),t._vscf_ecies_encrypted_len(this.ctxPtr,r.ctxPtr,n)}encrypt(r,n){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$3.ensureByteArray("data",n);const s=n.length*n.BYTES_PER_ELEMENT,_=t._malloc(s);t.HEAP8.set(n,_);const c=t._vsc_data_ctx_size(),i=t._malloc(c);t._vsc_data(i,_,s);const o=this.encryptedLen(r,n.length),l=t._vsc_buffer_new_with_capacity(o);try{const n=t._vscf_ecies_encrypt(this.ctxPtr,r.ctxPtr,i,l);e.FoundationError.handleStatusCode(n);const s=t._vsc_buffer_bytes(l),c=t._vsc_buffer_len(l);return t.HEAPU8.slice(s,s+c)}finally{t._free(_),t._free(i),t._vsc_buffer_delete(l);}}decryptedLen(r,n){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$3.ensureNumber("dataLen",n),t._vscf_ecies_decrypted_len(this.ctxPtr,r.ctxPtr,n)}decrypt(r,n){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$3.ensureByteArray("data",n);const s=n.length*n.BYTES_PER_ELEMENT,_=t._malloc(s);t.HEAP8.set(n,_);const c=t._vsc_data_ctx_size(),i=t._malloc(c);t._vsc_data(i,_,s);const o=this.decryptedLen(r,n.length),l=t._vsc_buffer_new_with_capacity(o);try{const n=t._vscf_ecies_decrypt(this.ctxPtr,r.ctxPtr,i,l);e.FoundationError.handleStatusCode(n);const s=t._vsc_buffer_bytes(l),c=t._vsc_buffer_len(l);return t.HEAPU8.slice(s,s+c)}finally{t._free(_),t._free(i),t._vsc_buffer_delete(l);}}}return r},d$2=(t,e)=>{class r{constructor(e){this.name="RecipientCipher",this.ctxPtr=void 0===e?t._vscf_recipient_cipher_new():e;}static newAndUseCContext(e){return new r(t._vscf_recipient_cipher_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_recipient_cipher_delete(this.ctxPtr),this.ctxPtr=null);}set random(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("random",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_recipient_cipher_release_random(this.ctxPtr),t._vscf_recipient_cipher_use_random(this.ctxPtr,r.ctxPtr);}set encryptionCipher(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("encryptionCipher",r,"Foundation.Cipher",e.FoundationInterfaceTag.CIPHER,e.FoundationInterface),t._vscf_recipient_cipher_release_encryption_cipher(this.ctxPtr),t._vscf_recipient_cipher_use_encryption_cipher(this.ctxPtr,r.ctxPtr);}set signerHash(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("signerHash",r,"Foundation.Hash",e.FoundationInterfaceTag.HASH,e.FoundationInterface),t._vscf_recipient_cipher_release_signer_hash(this.ctxPtr),t._vscf_recipient_cipher_use_signer_hash(this.ctxPtr,r.ctxPtr);}hasKeyRecipient(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("recipientId",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);let c;t._vsc_data(_,n,r);try{return !!(c=t._vscf_recipient_cipher_has_key_recipient(this.ctxPtr,_))}finally{t._free(n),t._free(_);}}addKeyRecipient(r,n){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("recipientId",r),a$3.ensureImplementInterface("publicKey",n,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface);const s=r.length*r.BYTES_PER_ELEMENT,_=t._malloc(s);t.HEAP8.set(r,_);const c=t._vsc_data_ctx_size(),i=t._malloc(c);t._vsc_data(i,_,s);try{t._vscf_recipient_cipher_add_key_recipient(this.ctxPtr,i,n.ctxPtr);}finally{t._free(_),t._free(i);}}clearRecipients(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_recipient_cipher_clear_recipients(this.ctxPtr);}addSigner(r,n){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("signerId",r),a$3.ensureImplementInterface("privateKey",n,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface);const s=r.length*r.BYTES_PER_ELEMENT,_=t._malloc(s);t.HEAP8.set(r,_);const c=t._vsc_data_ctx_size(),i=t._malloc(c);t._vsc_data(i,_,s);try{const r=t._vscf_recipient_cipher_add_signer(this.ctxPtr,i,n.ctxPtr);e.FoundationError.handleStatusCode(r);}finally{t._free(_),t._free(i);}}clearSigners(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_recipient_cipher_clear_signers(this.ctxPtr);}customParams(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_recipient_cipher_custom_params(this.ctxPtr),e.MessageInfoCustomParams.newAndUseCContext(r)}startEncryption(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_recipient_cipher_start_encryption(this.ctxPtr);e.FoundationError.handleStatusCode(r);}startSignedEncryption(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("dataSize",r);const n=t._vscf_recipient_cipher_start_signed_encryption(this.ctxPtr,r);e.FoundationError.handleStatusCode(n);}messageInfoLen(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_recipient_cipher_message_info_len(this.ctxPtr)}packMessageInfo(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=this.messageInfoLen(),r=t._vsc_buffer_new_with_capacity(e);try{t._vscf_recipient_cipher_pack_message_info(this.ctxPtr,r);const e=t._vsc_buffer_bytes(r),n=t._vsc_buffer_len(r);return t.HEAPU8.slice(e,e+n)}finally{t._vsc_buffer_delete(r);}}encryptionOutLen(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("dataLen",e),t._vscf_recipient_cipher_encryption_out_len(this.ctxPtr,e)}processEncryption(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",r);const n=r.length*r.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(r,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=this.encryptionOutLen(r.length),o=t._vsc_buffer_new_with_capacity(i);try{const r=t._vscf_recipient_cipher_process_encryption(this.ctxPtr,c,o);e.FoundationError.handleStatusCode(r);const n=t._vsc_buffer_bytes(o),_=t._vsc_buffer_len(o);return t.HEAPU8.slice(n,n+_)}finally{t._free(s),t._free(c),t._vsc_buffer_delete(o);}}finishEncryption(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=this.encryptionOutLen(0),n=t._vsc_buffer_new_with_capacity(r);try{const r=t._vscf_recipient_cipher_finish_encryption(this.ctxPtr,n);e.FoundationError.handleStatusCode(r);const s=t._vsc_buffer_bytes(n),_=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+_)}finally{t._vsc_buffer_delete(n);}}startDecryptionWithKey(r,n,s){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("recipientId",r),a$3.ensureImplementInterface("privateKey",n,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$3.ensureByteArray("messageInfo",s);const _=r.length*r.BYTES_PER_ELEMENT,c=t._malloc(_);t.HEAP8.set(r,c);const i=t._vsc_data_ctx_size(),o=t._malloc(i);t._vsc_data(o,c,_);const l=s.length*s.BYTES_PER_ELEMENT,u=t._malloc(l);t.HEAP8.set(s,u);const f=t._vsc_data_ctx_size(),p=t._malloc(f);t._vsc_data(p,u,l);try{const r=t._vscf_recipient_cipher_start_decryption_with_key(this.ctxPtr,o,n.ctxPtr,p);e.FoundationError.handleStatusCode(r);}finally{t._free(c),t._free(o),t._free(u),t._free(p);}}startVerifiedDecryptionWithKey(r,n,s,_){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("recipientId",r),a$3.ensureImplementInterface("privateKey",n,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$3.ensureByteArray("messageInfo",s),a$3.ensureByteArray("messageInfoFooter",_);const c=r.length*r.BYTES_PER_ELEMENT,i=t._malloc(c);t.HEAP8.set(r,i);const o=t._vsc_data_ctx_size(),l=t._malloc(o);t._vsc_data(l,i,c);const u=s.length*s.BYTES_PER_ELEMENT,f=t._malloc(u);t.HEAP8.set(s,f);const p=t._vsc_data_ctx_size(),d=t._malloc(p);t._vsc_data(d,f,u);const h=_.length*_.BYTES_PER_ELEMENT,y=t._malloc(h);t.HEAP8.set(_,y);const v=t._vsc_data_ctx_size(),P=t._malloc(v);t._vsc_data(P,y,h);try{const r=t._vscf_recipient_cipher_start_verified_decryption_with_key(this.ctxPtr,l,n.ctxPtr,d,P);e.FoundationError.handleStatusCode(r);}finally{t._free(i),t._free(l),t._free(f),t._free(d),t._free(y),t._free(P);}}decryptionOutLen(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("dataLen",e),t._vscf_recipient_cipher_decryption_out_len(this.ctxPtr,e)}processDecryption(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",r);const n=r.length*r.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(r,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=this.decryptionOutLen(r.length),o=t._vsc_buffer_new_with_capacity(i);try{const r=t._vscf_recipient_cipher_process_decryption(this.ctxPtr,c,o);e.FoundationError.handleStatusCode(r);const n=t._vsc_buffer_bytes(o),_=t._vsc_buffer_len(o);return t.HEAPU8.slice(n,n+_)}finally{t._free(s),t._free(c),t._vsc_buffer_delete(o);}}finishDecryption(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=this.decryptionOutLen(0),n=t._vsc_buffer_new_with_capacity(r);try{const r=t._vscf_recipient_cipher_finish_decryption(this.ctxPtr,n);e.FoundationError.handleStatusCode(r);const s=t._vsc_buffer_bytes(n),_=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+_)}finally{t._vsc_buffer_delete(n);}}isDataSigned(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_recipient_cipher_is_data_signed(this.ctxPtr))}signerInfos(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_recipient_cipher_signer_infos(this.ctxPtr),e.SignerInfoList.newAndUseCContext(r)}verifySignerInfo(r,n){let s;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("signerInfo",r,e.SignerInfo),a$3.ensureImplementInterface("publicKey",n,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),!!(s=t._vscf_recipient_cipher_verify_signer_info(this.ctxPtr,r.ctxPtr,n.ctxPtr))}messageInfoFooterLen(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_recipient_cipher_message_info_footer_len(this.ctxPtr)}packMessageInfoFooter(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=this.messageInfoFooterLen(),n=t._vsc_buffer_new_with_capacity(r);try{const r=t._vscf_recipient_cipher_pack_message_info_footer(this.ctxPtr,n);e.FoundationError.handleStatusCode(r);const s=t._vsc_buffer_bytes(n),_=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+_)}finally{t._vsc_buffer_delete(n);}}}return r},h$2=(t,e)=>{class r{constructor(e){this.name="MessageInfoCustomParams",this.ctxPtr=void 0===e?t._vscf_message_info_custom_params_new():e;}static newAndUseCContext(e){return new r(t._vscf_message_info_custom_params_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_message_info_custom_params_delete(this.ctxPtr),this.ctxPtr=null);}addInt(e,r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("key",e),a$3.ensureNumber("value",r);const n=e.length*e.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(e,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);try{t._vscf_message_info_custom_params_add_int(this.ctxPtr,c,r);}finally{t._free(s),t._free(c);}}addString(e,r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("key",e),a$3.ensureByteArray("value",r);const n=e.length*e.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(e,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=r.length*r.BYTES_PER_ELEMENT,o=t._malloc(i);t.HEAP8.set(r,o);const l=t._vsc_data_ctx_size(),u=t._malloc(l);t._vsc_data(u,o,i);try{t._vscf_message_info_custom_params_add_string(this.ctxPtr,c,u);}finally{t._free(s),t._free(c),t._free(o),t._free(u);}}addData(e,r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("key",e),a$3.ensureByteArray("value",r);const n=e.length*e.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(e,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=r.length*r.BYTES_PER_ELEMENT,o=t._malloc(i);t.HEAP8.set(r,o);const l=t._vsc_data_ctx_size(),u=t._malloc(l);t._vsc_data(u,o,i);try{t._vscf_message_info_custom_params_add_data(this.ctxPtr,c,u);}finally{t._free(s),t._free(c),t._free(o),t._free(u);}}clear(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_message_info_custom_params_clear(this.ctxPtr);}findInt(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("key",r);const n=r.length*r.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(r,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=t._vscf_error_ctx_size(),o=t._malloc(i);let l;t._vscf_error_reset(o);try{l=t._vscf_message_info_custom_params_find_int(this.ctxPtr,c,o);const r=t._vscf_error_status(o);return e.FoundationError.handleStatusCode(r),l}finally{t._free(s),t._free(c),t._free(o);}}findString(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("key",r);const n=r.length*r.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(r,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=t._vscf_error_ctx_size(),o=t._malloc(i);t._vscf_error_reset(o);const l=t._vsc_data_ctx_size(),u=t._malloc(l);try{t._vscf_message_info_custom_params_find_string(u,this.ctxPtr,c,o);const r=t._vscf_error_status(o);e.FoundationError.handleStatusCode(r);const n=t._vsc_data_len(u),_=t._vsc_data_bytes(u);return t.HEAPU8.slice(_,_+n)}finally{t._free(s),t._free(c),t._free(o),t._free(u);}}findData(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("key",r);const n=r.length*r.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(r,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=t._vscf_error_ctx_size(),o=t._malloc(i);t._vscf_error_reset(o);const l=t._vsc_data_ctx_size(),u=t._malloc(l);try{t._vscf_message_info_custom_params_find_data(u,this.ctxPtr,c,o);const r=t._vscf_error_status(o);e.FoundationError.handleStatusCode(r);const n=t._vsc_data_len(u),_=t._vsc_data_bytes(u);return t.HEAPU8.slice(_,_+n)}finally{t._free(s),t._free(c),t._free(o),t._free(u);}}hasParams(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_message_info_custom_params_has_params(this.ctxPtr))}}return r},y$3=(t,e)=>{class r{constructor(e){this.name="KeyProvider",this.ctxPtr=void 0===e?t._vscf_key_provider_new():e;}static newAndUseCContext(e){return new r(t._vscf_key_provider_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_key_provider_delete(this.ctxPtr),this.ctxPtr=null);}set random(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("random",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_key_provider_release_random(this.ctxPtr),t._vscf_key_provider_use_random(this.ctxPtr,r.ctxPtr);}set ecies(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("ecies",r,e.Ecies),t._vscf_key_provider_release_ecies(this.ctxPtr),t._vscf_key_provider_use_ecies(this.ctxPtr,r.ctxPtr);}setupDefaults(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_key_provider_setup_defaults(this.ctxPtr);e.FoundationError.handleStatusCode(r);}setRsaParams(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("bitlen",e),t._vscf_key_provider_set_rsa_params(this.ctxPtr,e);}generatePrivateKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("algId",r);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_key_provider_generate_private_key(this.ctxPtr,r,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(s);}}importPrivateKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("keyData",r);const n=r.length*r.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(r,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=t._vscf_error_ctx_size(),o=t._malloc(i);let l;t._vscf_error_reset(o);try{l=t._vscf_key_provider_import_private_key(this.ctxPtr,c,o);const r=t._vscf_error_status(o);return e.FoundationError.handleStatusCode(r),e.FoundationInterface.newAndTakeCContext(l)}finally{t._free(s),t._free(c),t._free(o);}}importPublicKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("keyData",r);const n=r.length*r.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(r,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=t._vscf_error_ctx_size(),o=t._malloc(i);let l;t._vscf_error_reset(o);try{l=t._vscf_key_provider_import_public_key(this.ctxPtr,c,o);const r=t._vscf_error_status(o);return e.FoundationError.handleStatusCode(r),e.FoundationInterface.newAndTakeCContext(l)}finally{t._free(s),t._free(c),t._free(o);}}exportedPublicKeyLen(r){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),t._vscf_key_provider_exported_public_key_len(this.ctxPtr,r.ctxPtr)}exportPublicKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface);const n=this.exportedPublicKeyLen(r),s=t._vsc_buffer_new_with_capacity(n);try{const n=t._vscf_key_provider_export_public_key(this.ctxPtr,r.ctxPtr,s);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(s),c=t._vsc_buffer_len(s);return t.HEAPU8.slice(_,_+c)}finally{t._vsc_buffer_delete(s);}}exportedPrivateKeyLen(r){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),t._vscf_key_provider_exported_private_key_len(this.ctxPtr,r.ctxPtr)}exportPrivateKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface);const n=this.exportedPrivateKeyLen(r),s=t._vsc_buffer_new_with_capacity(n);try{const n=t._vscf_key_provider_export_private_key(this.ctxPtr,r.ctxPtr,s);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(s),c=t._vsc_buffer_len(s);return t.HEAPU8.slice(_,_+c)}finally{t._vsc_buffer_delete(s);}}}return r},v$4=(t,e)=>{class r{constructor(e){this.name="Signer",this.ctxPtr=void 0===e?t._vscf_signer_new():e;}static newAndUseCContext(e){return new r(t._vscf_signer_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_signer_delete(this.ctxPtr),this.ctxPtr=null);}set hash(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("hash",r,"Foundation.Hash",e.FoundationInterfaceTag.HASH,e.FoundationInterface),t._vscf_signer_release_hash(this.ctxPtr),t._vscf_signer_use_hash(this.ctxPtr,r.ctxPtr);}set random(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("random",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_signer_release_random(this.ctxPtr),t._vscf_signer_use_random(this.ctxPtr,r.ctxPtr);}reset(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_signer_reset(this.ctxPtr);}appendData(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);t._vsc_data(_,n,r);try{t._vscf_signer_append_data(this.ctxPtr,_);}finally{t._free(n),t._free(_);}}signatureLen(r){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),t._vscf_signer_signature_len(this.ctxPtr,r.ctxPtr)}sign(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface);const n=this.signatureLen(r),s=t._vsc_buffer_new_with_capacity(n);try{const n=t._vscf_signer_sign(this.ctxPtr,r.ctxPtr,s);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(s),c=t._vsc_buffer_len(s);return t.HEAPU8.slice(_,_+c)}finally{t._vsc_buffer_delete(s);}}}return r},P$2=(t,e)=>{class r{constructor(e){this.name="Verifier",this.ctxPtr=void 0===e?t._vscf_verifier_new():e;}static newAndUseCContext(e){return new r(t._vscf_verifier_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_verifier_delete(this.ctxPtr),this.ctxPtr=null);}reset(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("signature",r);const n=r.length*r.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(r,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);try{const r=t._vscf_verifier_reset(this.ctxPtr,c);e.FoundationError.handleStatusCode(r);}finally{t._free(s),t._free(c);}}appendData(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);t._vsc_data(_,n,r);try{t._vscf_verifier_append_data(this.ctxPtr,_);}finally{t._free(n),t._free(_);}}verify(r){let n;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),!!(n=t._vscf_verifier_verify(this.ctxPtr,r.ctxPtr))}}return r},m$3=(t,e)=>{class r{static get POINT_LEN(){return 65}get POINT_LEN(){return r.POINT_LEN}static get MPI_LEN(){return 32}get MPI_LEN(){return r.MPI_LEN}static get SEED_LEN(){return 32}get SEED_LEN(){return r.SEED_LEN}static get MAX_PASSWORD_LEN(){return 128}get MAX_PASSWORD_LEN(){return r.MAX_PASSWORD_LEN}static get MAX_KEY_NAME_LEN(){return 128}get MAX_KEY_NAME_LEN(){return r.MAX_KEY_NAME_LEN}constructor(e){this.name="BrainkeyClient",this.ctxPtr=void 0===e?t._vscf_brainkey_client_new():e;}static newAndUseCContext(e){return new r(t._vscf_brainkey_client_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_brainkey_client_delete(this.ctxPtr),this.ctxPtr=null);}set random(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("random",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_brainkey_client_release_random(this.ctxPtr),t._vscf_brainkey_client_use_random(this.ctxPtr,r.ctxPtr);}set operationRandom(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("operationRandom",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_brainkey_client_release_operation_random(this.ctxPtr),t._vscf_brainkey_client_use_operation_random(this.ctxPtr,r.ctxPtr);}setupDefaults(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_brainkey_client_setup_defaults(this.ctxPtr);e.FoundationError.handleStatusCode(r);}blind(n){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("password",n);const s=n.length*n.BYTES_PER_ELEMENT,_=t._malloc(s);t.HEAP8.set(n,_);const c=t._vsc_data_ctx_size(),i=t._malloc(c);t._vsc_data(i,_,s);const o=r.MPI_LEN,l=t._vsc_buffer_new_with_capacity(o),u=r.POINT_LEN,f=t._vsc_buffer_new_with_capacity(u);try{const r=t._vscf_brainkey_client_blind(this.ctxPtr,i,l,f);e.FoundationError.handleStatusCode(r);const n=t._vsc_buffer_bytes(l),s=t._vsc_buffer_len(l),c=t.HEAPU8.slice(n,n+s),a=t._vsc_buffer_bytes(f),o=t._vsc_buffer_len(f);return {deblindFactor:c,blindedPoint:t.HEAPU8.slice(a,a+o)}}finally{t._free(_),t._free(i),t._vsc_buffer_delete(l),t._vsc_buffer_delete(f);}}deblind(n,s,_,c){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("password",n),a$3.ensureByteArray("hardenedPoint",s),a$3.ensureByteArray("deblindFactor",_),a$3.ensureByteArray("keyName",c);const i=n.length*n.BYTES_PER_ELEMENT,o=t._malloc(i);t.HEAP8.set(n,o);const l=t._vsc_data_ctx_size(),u=t._malloc(l);t._vsc_data(u,o,i);const f=s.length*s.BYTES_PER_ELEMENT,p=t._malloc(f);t.HEAP8.set(s,p);const d=t._vsc_data_ctx_size(),h=t._malloc(d);t._vsc_data(h,p,f);const y=_.length*_.BYTES_PER_ELEMENT,v=t._malloc(y);t.HEAP8.set(_,v);const P=t._vsc_data_ctx_size(),m=t._malloc(P);t._vsc_data(m,v,y);const x=c.length*c.BYTES_PER_ELEMENT,g=t._malloc(x);t.HEAP8.set(c,g);const w=t._vsc_data_ctx_size(),E=t._malloc(w);t._vsc_data(E,g,x);const N=r.POINT_LEN,I=t._vsc_buffer_new_with_capacity(N);try{const r=t._vscf_brainkey_client_deblind(this.ctxPtr,u,h,m,E,I);e.FoundationError.handleStatusCode(r);const n=t._vsc_buffer_bytes(I),s=t._vsc_buffer_len(I);return t.HEAPU8.slice(n,n+s)}finally{t._free(o),t._free(u),t._free(p),t._free(h),t._free(v),t._free(m),t._free(g),t._free(E),t._vsc_buffer_delete(I);}}}return r},x$3=(t,e)=>{class r{static get POINT_LEN(){return 65}get POINT_LEN(){return r.POINT_LEN}static get MPI_LEN(){return 32}get MPI_LEN(){return r.MPI_LEN}constructor(e){this.name="BrainkeyServer",this.ctxPtr=void 0===e?t._vscf_brainkey_server_new():e;}static newAndUseCContext(e){return new r(t._vscf_brainkey_server_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_brainkey_server_delete(this.ctxPtr),this.ctxPtr=null);}set random(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("random",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_brainkey_server_release_random(this.ctxPtr),t._vscf_brainkey_server_use_random(this.ctxPtr,r.ctxPtr);}set operationRandom(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("operationRandom",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_brainkey_server_release_operation_random(this.ctxPtr),t._vscf_brainkey_server_use_operation_random(this.ctxPtr,r.ctxPtr);}setupDefaults(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_brainkey_server_setup_defaults(this.ctxPtr);e.FoundationError.handleStatusCode(r);}generateIdentitySecret(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const n=r.MPI_LEN,s=t._vsc_buffer_new_with_capacity(n);try{const r=t._vscf_brainkey_server_generate_identity_secret(this.ctxPtr,s);e.FoundationError.handleStatusCode(r);const n=t._vsc_buffer_bytes(s),_=t._vsc_buffer_len(s);return t.HEAPU8.slice(n,n+_)}finally{t._vsc_buffer_delete(s);}}harden(n,s){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("identitySecret",n),a$3.ensureByteArray("blindedPoint",s);const _=n.length*n.BYTES_PER_ELEMENT,c=t._malloc(_);t.HEAP8.set(n,c);const i=t._vsc_data_ctx_size(),o=t._malloc(i);t._vsc_data(o,c,_);const l=s.length*s.BYTES_PER_ELEMENT,u=t._malloc(l);t.HEAP8.set(s,u);const f=t._vsc_data_ctx_size(),p=t._malloc(f);t._vsc_data(p,u,l);const d=r.POINT_LEN,h=t._vsc_buffer_new_with_capacity(d);try{const r=t._vscf_brainkey_server_harden(this.ctxPtr,o,p,h);e.FoundationError.handleStatusCode(r);const n=t._vsc_buffer_bytes(h),s=t._vsc_buffer_len(h);return t.HEAPU8.slice(n,n+s)}finally{t._free(c),t._free(o),t._free(u),t._free(p),t._vsc_buffer_delete(h);}}}return r},g$3=(t,e)=>{class r{static get MAX_MESSAGE_LEN(){return 30188}get MAX_MESSAGE_LEN(){return r.MAX_MESSAGE_LEN}static get MESSAGE_VERSION(){return 1}get MESSAGE_VERSION(){return r.MESSAGE_VERSION}constructor(e){this.name="GroupSessionMessage",this.ctxPtr=void 0===e?t._vscf_group_session_message_new():e;}static newAndUseCContext(e){return new r(t._vscf_group_session_message_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_group_session_message_delete(this.ctxPtr),this.ctxPtr=null);}getType(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_group_session_message_get_type(this.ctxPtr)}getSessionId(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=t._vsc_data_ctx_size(),r=t._malloc(e);try{t._vscf_group_session_message_get_session_id(r,this.ctxPtr);const e=t._vsc_data_len(r),n=t._vsc_data_bytes(r);return t.HEAPU8.slice(n,n+e)}finally{t._free(r);}}getEpoch(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_group_session_message_get_epoch(this.ctxPtr)}serializeLen(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_group_session_message_serialize_len(this.ctxPtr)}serialize(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=this.serializeLen(),r=t._vsc_buffer_new_with_capacity(e);try{t._vscf_group_session_message_serialize(this.ctxPtr,r);const e=t._vsc_buffer_bytes(r),n=t._vsc_buffer_len(r);return t.HEAPU8.slice(e,e+n)}finally{t._vsc_buffer_delete(r);}}static deserialize(n){a$3.ensureByteArray("input",n);const s=n.length*n.BYTES_PER_ELEMENT,_=t._malloc(s);t.HEAP8.set(n,_);const c=t._vsc_data_ctx_size(),i=t._malloc(c);t._vsc_data(i,_,s);const o=t._vscf_error_ctx_size(),l=t._malloc(o);let u;t._vscf_error_reset(l);try{u=t._vscf_group_session_message_deserialize(i,l);const n=t._vscf_error_status(l);return e.FoundationError.handleStatusCode(n),r.newAndTakeCContext(u)}finally{t._free(_),t._free(i),t._free(l);}}}return r},w$2=(t,e)=>{class r{constructor(e){this.name="GroupSessionTicket",this.ctxPtr=void 0===e?t._vscf_group_session_ticket_new():e;}static newAndUseCContext(e){return new r(t._vscf_group_session_ticket_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_group_session_ticket_delete(this.ctxPtr),this.ctxPtr=null);}set rng(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("rng",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_group_session_ticket_release_rng(this.ctxPtr),t._vscf_group_session_ticket_use_rng(this.ctxPtr,r.ctxPtr);}setupDefaults(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_group_session_ticket_setup_defaults(this.ctxPtr);e.FoundationError.handleStatusCode(r);}setupTicketAsNew(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("sessionId",r);const n=r.length*r.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(r,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);try{const r=t._vscf_group_session_ticket_setup_ticket_as_new(this.ctxPtr,c);e.FoundationError.handleStatusCode(r);}finally{t._free(s),t._free(c);}}getTicketMessage(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_group_session_ticket_get_ticket_message(this.ctxPtr),e.GroupSessionMessage.newAndUseCContext(r)}}return r},E$2=(t,e)=>{class r{static get SENDER_ID_LEN(){return 32}get SENDER_ID_LEN(){return r.SENDER_ID_LEN}static get MAX_PLAIN_TEXT_LEN(){return 3e4}get MAX_PLAIN_TEXT_LEN(){return r.MAX_PLAIN_TEXT_LEN}static get MAX_EPOCHS_COUNT(){return 50}get MAX_EPOCHS_COUNT(){return r.MAX_EPOCHS_COUNT}static get SALT_SIZE(){return 32}get SALT_SIZE(){return r.SALT_SIZE}constructor(e){this.name="GroupSession",this.ctxPtr=void 0===e?t._vscf_group_session_new():e;}static newAndUseCContext(e){return new r(t._vscf_group_session_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_group_session_delete(this.ctxPtr),this.ctxPtr=null);}set rng(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("rng",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_group_session_release_rng(this.ctxPtr),t._vscf_group_session_use_rng(this.ctxPtr,r.ctxPtr);}getCurrentEpoch(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_group_session_get_current_epoch(this.ctxPtr)}setupDefaults(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_group_session_setup_defaults(this.ctxPtr);e.FoundationError.handleStatusCode(r);}getSessionId(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=t._vsc_data_ctx_size(),r=t._malloc(e);try{t._vscf_group_session_get_session_id(r,this.ctxPtr);const e=t._vsc_data_len(r),n=t._vsc_data_bytes(r);return t.HEAPU8.slice(n,n+e)}finally{t._free(r);}}addEpoch(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("message",r,e.GroupSessionMessage);const n=t._vscf_group_session_add_epoch(this.ctxPtr,r.ctxPtr);e.FoundationError.handleStatusCode(n);}encrypt(r,n){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("plainText",r),a$3.ensureImplementInterface("privateKey",n,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface);const s=r.length*r.BYTES_PER_ELEMENT,_=t._malloc(s);t.HEAP8.set(r,_);const c=t._vsc_data_ctx_size(),i=t._malloc(c);t._vsc_data(i,_,s);const o=t._vscf_error_ctx_size(),l=t._malloc(o);let u;t._vscf_error_reset(l);try{u=t._vscf_group_session_encrypt(this.ctxPtr,i,n.ctxPtr,l);const r=t._vscf_error_status(l);return e.FoundationError.handleStatusCode(r),e.GroupSessionMessage.newAndTakeCContext(u)}finally{t._free(_),t._free(i),t._free(l);}}decryptLen(r){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("message",r,e.GroupSessionMessage),t._vscf_group_session_decrypt_len(this.ctxPtr,r.ctxPtr)}decrypt(r,n){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("message",r,e.GroupSessionMessage),a$3.ensureImplementInterface("publicKey",n,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface);const s=this.decryptLen(r),_=t._vsc_buffer_new_with_capacity(s);try{const s=t._vscf_group_session_decrypt(this.ctxPtr,r.ctxPtr,n.ctxPtr,_);e.FoundationError.handleStatusCode(s);const c=t._vsc_buffer_bytes(_),a=t._vsc_buffer_len(_);return t.HEAPU8.slice(c,c+a)}finally{t._vsc_buffer_delete(_);}}createGroupTicket(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_error_ctx_size(),n=t._malloc(r);let s;t._vscf_error_reset(n);try{s=t._vscf_group_session_create_group_ticket(this.ctxPtr,n);const r=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(r),e.GroupSessionTicket.newAndTakeCContext(s)}finally{t._free(n);}}}return r},N$1=(t,e)=>{class r{constructor(e){this.name="MessageInfoEditor",this.ctxPtr=void 0===e?t._vscf_message_info_editor_new():e;}static newAndUseCContext(e){return new r(t._vscf_message_info_editor_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_message_info_editor_delete(this.ctxPtr),this.ctxPtr=null);}set random(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("random",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_message_info_editor_release_random(this.ctxPtr),t._vscf_message_info_editor_use_random(this.ctxPtr,r.ctxPtr);}setupDefaults(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_message_info_editor_setup_defaults(this.ctxPtr);e.FoundationError.handleStatusCode(r);}unpack(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("messageInfoData",r);const n=r.length*r.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(r,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);try{const r=t._vscf_message_info_editor_unpack(this.ctxPtr,c);e.FoundationError.handleStatusCode(r);}finally{t._free(s),t._free(c);}}unlock(r,n){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("ownerRecipientId",r),a$3.ensureImplementInterface("ownerPrivateKey",n,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface);const s=r.length*r.BYTES_PER_ELEMENT,_=t._malloc(s);t.HEAP8.set(r,_);const c=t._vsc_data_ctx_size(),i=t._malloc(c);t._vsc_data(i,_,s);try{const r=t._vscf_message_info_editor_unlock(this.ctxPtr,i,n.ctxPtr);e.FoundationError.handleStatusCode(r);}finally{t._free(_),t._free(i);}}addKeyRecipient(r,n){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("recipientId",r),a$3.ensureImplementInterface("publicKey",n,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface);const s=r.length*r.BYTES_PER_ELEMENT,_=t._malloc(s);t.HEAP8.set(r,_);const c=t._vsc_data_ctx_size(),i=t._malloc(c);t._vsc_data(i,_,s);try{const r=t._vscf_message_info_editor_add_key_recipient(this.ctxPtr,i,n.ctxPtr);e.FoundationError.handleStatusCode(r);}finally{t._free(_),t._free(i);}}removeKeyRecipient(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("recipientId",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);let c;t._vsc_data(_,n,r);try{return !!(c=t._vscf_message_info_editor_remove_key_recipient(this.ctxPtr,_))}finally{t._free(n),t._free(_);}}removeAll(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_message_info_editor_remove_all(this.ctxPtr);}packedLen(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_message_info_editor_packed_len(this.ctxPtr)}pack(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=this.packedLen(),r=t._vsc_buffer_new_with_capacity(e);try{t._vscf_message_info_editor_pack(this.ctxPtr,r);const e=t._vsc_buffer_bytes(r),n=t._vsc_buffer_len(r);return t.HEAPU8.slice(e,e+n)}finally{t._vsc_buffer_delete(r);}}}return r},I$1=(t,e)=>{class r{constructor(e){this.name="SignerInfo",this.ctxPtr=void 0===e?t._vscf_signer_info_new():e;}static newAndUseCContext(e){return new r(t._vscf_signer_info_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_signer_info_delete(this.ctxPtr),this.ctxPtr=null);}signerId(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=t._vsc_data_ctx_size(),r=t._malloc(e);try{t._vscf_signer_info_signer_id(r,this.ctxPtr);const e=t._vsc_data_len(r),n=t._vsc_data_bytes(r);return t.HEAPU8.slice(n,n+e)}finally{t._free(r);}}signerAlgInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_signer_info_signer_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}signature(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=t._vsc_data_ctx_size(),r=t._malloc(e);try{t._vscf_signer_info_signature(r,this.ctxPtr);const e=t._vsc_data_len(r),n=t._vsc_data_bytes(r);return t.HEAPU8.slice(n,n+e)}finally{t._free(r);}}}return r},b$2=(t,e)=>{class r{constructor(e){this.name="SignerInfoList",this.ctxPtr=void 0===e?t._vscf_signer_info_list_new():e;}static newAndUseCContext(e){return new r(t._vscf_signer_info_list_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_signer_info_list_delete(this.ctxPtr),this.ctxPtr=null);}hasItem(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_signer_info_list_has_item(this.ctxPtr))}item(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_signer_info_list_item(this.ctxPtr),e.SignerInfo.newAndUseCContext(r)}hasNext(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_signer_info_list_has_next(this.ctxPtr))}next(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),e=t._vscf_signer_info_list_next(this.ctxPtr),r.newAndTakeCContext(e)}hasPrev(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_signer_info_list_has_prev(this.ctxPtr))}prev(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),e=t._vscf_signer_info_list_prev(this.ctxPtr),r.newAndTakeCContext(e)}clear(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_signer_info_list_clear(this.ctxPtr);}}return r},A$2=(t,e)=>{class r{constructor(e){this.name="MessageInfoFooter",this.ctxPtr=void 0===e?t._vscf_message_info_footer_new():e;}static newAndUseCContext(e){return new r(t._vscf_message_info_footer_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_message_info_footer_delete(this.ctxPtr),this.ctxPtr=null);}hasSignerInfos(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_message_info_footer_has_signer_infos(this.ctxPtr))}signerInfos(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_message_info_footer_signer_infos(this.ctxPtr),e.SignerInfoList.newAndUseCContext(r)}signerHashAlgInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_message_info_footer_signer_hash_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}signerDigest(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=t._vsc_data_ctx_size(),r=t._malloc(e);try{t._vscf_message_info_footer_signer_digest(r,this.ctxPtr);const e=t._vsc_data_len(r),n=t._vsc_data_bytes(r);return t.HEAPU8.slice(n,n+e)}finally{t._free(r);}}}return r},k$2=(t,e)=>{class r{constructor(e){this.name="SignedDataInfo",this.ctxPtr=void 0===e?t._vscf_signed_data_info_new():e;}static newAndUseCContext(e){return new r(t._vscf_signed_data_info_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_signed_data_info_delete(this.ctxPtr),this.ctxPtr=null);}setHashAlgInfo(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("hashAlgInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),t._vscf_signed_data_info_set_hash_alg_info(this.ctxPtr,r.ctxPtr);}hashAlgInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_signed_data_info_hash_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}}return r},C$1=(t,e)=>{class r{constructor(e){this.name="FooterInfo",this.ctxPtr=void 0===e?t._vscf_footer_info_new():e;}static newAndUseCContext(e){return new r(t._vscf_footer_info_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_footer_info_delete(this.ctxPtr),this.ctxPtr=null);}hasSignedDataInfo(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_footer_info_has_signed_data_info(this.ctxPtr))}signedDataInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_footer_info_signed_data_info(this.ctxPtr),e.SignedDataInfo.newAndUseCContext(r)}setDataSize(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("dataSize",e),t._vscf_footer_info_set_data_size(this.ctxPtr,e);}dataSize(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_footer_info_data_size(this.ctxPtr)}}return r},T$2=(t,e)=>{class r{static get DIGEST_LEN(){return 28}get DIGEST_LEN(){return r.DIGEST_LEN}static get BLOCK_LEN(){return 64}get BLOCK_LEN(){return r.BLOCK_LEN}constructor(e){this.name="Sha224",this.ctxPtr=void 0===e?t._vscf_sha224_new():e;}static newAndUseCContext(e){return new r(t._vscf_sha224_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_sha224_delete(this.ctxPtr),this.ctxPtr=null);}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_sha224_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_sha224_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface);const n=t._vscf_sha224_restore_alg_info(this.ctxPtr,r.ctxPtr);e.FoundationError.handleStatusCode(n);}hash(e){a$3.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);t._vsc_data(_,n,r);const c=this.DIGEST_LEN,i=t._vsc_buffer_new_with_capacity(c);try{t._vscf_sha224_hash(_,i);const e=t._vsc_buffer_bytes(i),r=t._vsc_buffer_len(i);return t.HEAPU8.slice(e,e+r)}finally{t._free(n),t._free(_),t._vsc_buffer_delete(i);}}start(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_sha224_start(this.ctxPtr);}update(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);t._vsc_data(_,n,r);try{t._vscf_sha224_update(this.ctxPtr,_);}finally{t._free(n),t._free(_);}}finish(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=this.DIGEST_LEN,r=t._vsc_buffer_new_with_capacity(e);try{t._vscf_sha224_finish(this.ctxPtr,r);const e=t._vsc_buffer_bytes(r),n=t._vsc_buffer_len(r);return t.HEAPU8.slice(e,e+n)}finally{t._vsc_buffer_delete(r);}}}return r},F$1=(t,e)=>{class r{static get DIGEST_LEN(){return 32}get DIGEST_LEN(){return r.DIGEST_LEN}static get BLOCK_LEN(){return 64}get BLOCK_LEN(){return r.BLOCK_LEN}constructor(e){this.name="Sha256",this.ctxPtr=void 0===e?t._vscf_sha256_new():e;}static newAndUseCContext(e){return new r(t._vscf_sha256_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_sha256_delete(this.ctxPtr),this.ctxPtr=null);}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_sha256_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_sha256_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface);const n=t._vscf_sha256_restore_alg_info(this.ctxPtr,r.ctxPtr);e.FoundationError.handleStatusCode(n);}hash(e){a$3.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);t._vsc_data(_,n,r);const c=this.DIGEST_LEN,i=t._vsc_buffer_new_with_capacity(c);try{t._vscf_sha256_hash(_,i);const e=t._vsc_buffer_bytes(i),r=t._vsc_buffer_len(i);return t.HEAPU8.slice(e,e+r)}finally{t._free(n),t._free(_),t._vsc_buffer_delete(i);}}start(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_sha256_start(this.ctxPtr);}update(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);t._vsc_data(_,n,r);try{t._vscf_sha256_update(this.ctxPtr,_);}finally{t._free(n),t._free(_);}}finish(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=this.DIGEST_LEN,r=t._vsc_buffer_new_with_capacity(e);try{t._vscf_sha256_finish(this.ctxPtr,r);const e=t._vsc_buffer_bytes(r),n=t._vsc_buffer_len(r);return t.HEAPU8.slice(e,e+n)}finally{t._vsc_buffer_delete(r);}}}return r},S$2=(t,e)=>{class r{static get DIGEST_LEN(){return 48}get DIGEST_LEN(){return r.DIGEST_LEN}static get BLOCK_LEN(){return 128}get BLOCK_LEN(){return r.BLOCK_LEN}constructor(e){this.name="Sha384",this.ctxPtr=void 0===e?t._vscf_sha384_new():e;}static newAndUseCContext(e){return new r(t._vscf_sha384_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_sha384_delete(this.ctxPtr),this.ctxPtr=null);}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_sha384_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_sha384_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface);const n=t._vscf_sha384_restore_alg_info(this.ctxPtr,r.ctxPtr);e.FoundationError.handleStatusCode(n);}hash(e){a$3.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);t._vsc_data(_,n,r);const c=this.DIGEST_LEN,i=t._vsc_buffer_new_with_capacity(c);try{t._vscf_sha384_hash(_,i);const e=t._vsc_buffer_bytes(i),r=t._vsc_buffer_len(i);return t.HEAPU8.slice(e,e+r)}finally{t._free(n),t._free(_),t._vsc_buffer_delete(i);}}start(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_sha384_start(this.ctxPtr);}update(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);t._vsc_data(_,n,r);try{t._vscf_sha384_update(this.ctxPtr,_);}finally{t._free(n),t._free(_);}}finish(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=this.DIGEST_LEN,r=t._vsc_buffer_new_with_capacity(e);try{t._vscf_sha384_finish(this.ctxPtr,r);const e=t._vsc_buffer_bytes(r),n=t._vsc_buffer_len(r);return t.HEAPU8.slice(e,e+n)}finally{t._vsc_buffer_delete(r);}}}return r},K$2=(t,e)=>{class r{static get DIGEST_LEN(){return 64}get DIGEST_LEN(){return r.DIGEST_LEN}static get BLOCK_LEN(){return 128}get BLOCK_LEN(){return r.BLOCK_LEN}constructor(e){this.name="Sha512",this.ctxPtr=void 0===e?t._vscf_sha512_new():e;}static newAndUseCContext(e){return new r(t._vscf_sha512_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_sha512_delete(this.ctxPtr),this.ctxPtr=null);}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_sha512_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_sha512_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface);const n=t._vscf_sha512_restore_alg_info(this.ctxPtr,r.ctxPtr);e.FoundationError.handleStatusCode(n);}hash(e){a$3.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);t._vsc_data(_,n,r);const c=this.DIGEST_LEN,i=t._vsc_buffer_new_with_capacity(c);try{t._vscf_sha512_hash(_,i);const e=t._vsc_buffer_bytes(i),r=t._vsc_buffer_len(i);return t.HEAPU8.slice(e,e+r)}finally{t._free(n),t._free(_),t._vsc_buffer_delete(i);}}start(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_sha512_start(this.ctxPtr);}update(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);t._vsc_data(_,n,r);try{t._vscf_sha512_update(this.ctxPtr,_);}finally{t._free(n),t._free(_);}}finish(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=this.DIGEST_LEN,r=t._vsc_buffer_new_with_capacity(e);try{t._vscf_sha512_finish(this.ctxPtr,r);const e=t._vsc_buffer_bytes(r),n=t._vsc_buffer_len(r);return t.HEAPU8.slice(e,e+n)}finally{t._vsc_buffer_delete(r);}}}return r},L$2=(t,e)=>{class r{static get NONCE_LEN(){return 12}get NONCE_LEN(){return r.NONCE_LEN}static get KEY_LEN(){return 32}get KEY_LEN(){return r.KEY_LEN}static get KEY_BITLEN(){return 256}get KEY_BITLEN(){return r.KEY_BITLEN}static get BLOCK_LEN(){return 16}get BLOCK_LEN(){return r.BLOCK_LEN}static get AUTH_TAG_LEN(){return 16}get AUTH_TAG_LEN(){return r.AUTH_TAG_LEN}constructor(e){this.name="Aes256Gcm",this.ctxPtr=void 0===e?t._vscf_aes256_gcm_new():e;}static newAndUseCContext(e){return new r(t._vscf_aes256_gcm_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_aes256_gcm_delete(this.ctxPtr),this.ctxPtr=null);}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_aes256_gcm_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_aes256_gcm_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface);const n=t._vscf_aes256_gcm_restore_alg_info(this.ctxPtr,r.ctxPtr);e.FoundationError.handleStatusCode(n);}encrypt(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",r);const n=r.length*r.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(r,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=this.encryptedLen(r.length),o=t._vsc_buffer_new_with_capacity(i);try{const r=t._vscf_aes256_gcm_encrypt(this.ctxPtr,c,o);e.FoundationError.handleStatusCode(r);const n=t._vsc_buffer_bytes(o),_=t._vsc_buffer_len(o);return t.HEAPU8.slice(n,n+_)}finally{t._free(s),t._free(c),t._vsc_buffer_delete(o);}}encryptedLen(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("dataLen",e),t._vscf_aes256_gcm_encrypted_len(this.ctxPtr,e)}preciseEncryptedLen(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("dataLen",e),t._vscf_aes256_gcm_precise_encrypted_len(this.ctxPtr,e)}decrypt(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",r);const n=r.length*r.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(r,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=this.decryptedLen(r.length),o=t._vsc_buffer_new_with_capacity(i);try{const r=t._vscf_aes256_gcm_decrypt(this.ctxPtr,c,o);e.FoundationError.handleStatusCode(r);const n=t._vsc_buffer_bytes(o),_=t._vsc_buffer_len(o);return t.HEAPU8.slice(n,n+_)}finally{t._free(s),t._free(c),t._vsc_buffer_delete(o);}}decryptedLen(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("dataLen",e),t._vscf_aes256_gcm_decrypted_len(this.ctxPtr,e)}setNonce(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("nonce",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);t._vsc_data(_,n,r);try{t._vscf_aes256_gcm_set_nonce(this.ctxPtr,_);}finally{t._free(n),t._free(_);}}setKey(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("key",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);t._vsc_data(_,n,r);try{t._vscf_aes256_gcm_set_key(this.ctxPtr,_);}finally{t._free(n),t._free(_);}}startEncryption(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_aes256_gcm_start_encryption(this.ctxPtr);}startDecryption(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_aes256_gcm_start_decryption(this.ctxPtr);}update(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);t._vsc_data(_,n,r);const c=this.outLen(e.length),i=t._vsc_buffer_new_with_capacity(c);try{t._vscf_aes256_gcm_update(this.ctxPtr,_,i);const e=t._vsc_buffer_bytes(i),r=t._vsc_buffer_len(i);return t.HEAPU8.slice(e,e+r)}finally{t._free(n),t._free(_),t._vsc_buffer_delete(i);}}outLen(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("dataLen",e),t._vscf_aes256_gcm_out_len(this.ctxPtr,e)}encryptedOutLen(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("dataLen",e),t._vscf_aes256_gcm_encrypted_out_len(this.ctxPtr,e)}decryptedOutLen(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("dataLen",e),t._vscf_aes256_gcm_decrypted_out_len(this.ctxPtr,e)}finish(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=this.outLen(0),n=t._vsc_buffer_new_with_capacity(r);try{const r=t._vscf_aes256_gcm_finish(this.ctxPtr,n);e.FoundationError.handleStatusCode(r);const s=t._vsc_buffer_bytes(n),_=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+_)}finally{t._vsc_buffer_delete(n);}}authEncrypt(r,n){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",r),a$3.ensureByteArray("authData",n);const s=r.length*r.BYTES_PER_ELEMENT,_=t._malloc(s);t.HEAP8.set(r,_);const c=t._vsc_data_ctx_size(),i=t._malloc(c);t._vsc_data(i,_,s);const o=n.length*n.BYTES_PER_ELEMENT,l=t._malloc(o);t.HEAP8.set(n,l);const u=t._vsc_data_ctx_size(),f=t._malloc(u);t._vsc_data(f,l,o);const p=this.authEncryptedLen(r.length),d=t._vsc_buffer_new_with_capacity(p),h=this.AUTH_TAG_LEN,y=t._vsc_buffer_new_with_capacity(h);try{const r=t._vscf_aes256_gcm_auth_encrypt(this.ctxPtr,i,f,d,y);e.FoundationError.handleStatusCode(r);const n=t._vsc_buffer_bytes(d),s=t._vsc_buffer_len(d),c=t.HEAPU8.slice(n,n+s),a=t._vsc_buffer_bytes(y),o=t._vsc_buffer_len(y);return {out:c,tag:t.HEAPU8.slice(a,a+o)}}finally{t._free(_),t._free(i),t._free(l),t._free(f),t._vsc_buffer_delete(d),t._vsc_buffer_delete(y);}}authEncryptedLen(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("dataLen",e),t._vscf_aes256_gcm_auth_encrypted_len(this.ctxPtr,e)}authDecrypt(r,n,s){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",r),a$3.ensureByteArray("authData",n),a$3.ensureByteArray("tag",s);const _=r.length*r.BYTES_PER_ELEMENT,c=t._malloc(_);t.HEAP8.set(r,c);const i=t._vsc_data_ctx_size(),o=t._malloc(i);t._vsc_data(o,c,_);const l=n.length*n.BYTES_PER_ELEMENT,u=t._malloc(l);t.HEAP8.set(n,u);const f=t._vsc_data_ctx_size(),p=t._malloc(f);t._vsc_data(p,u,l);const d=s.length*s.BYTES_PER_ELEMENT,h=t._malloc(d);t.HEAP8.set(s,h);const y=t._vsc_data_ctx_size(),v=t._malloc(y);t._vsc_data(v,h,d);const P=this.authDecryptedLen(r.length),m=t._vsc_buffer_new_with_capacity(P);try{const r=t._vscf_aes256_gcm_auth_decrypt(this.ctxPtr,o,p,v,m);e.FoundationError.handleStatusCode(r);const n=t._vsc_buffer_bytes(m),s=t._vsc_buffer_len(m);return t.HEAPU8.slice(n,n+s)}finally{t._free(c),t._free(o),t._free(u),t._free(p),t._free(h),t._free(v),t._vsc_buffer_delete(m);}}authDecryptedLen(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("dataLen",e),t._vscf_aes256_gcm_auth_decrypted_len(this.ctxPtr,e)}setAuthData(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("authData",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);t._vsc_data(_,n,r);try{t._vscf_aes256_gcm_set_auth_data(this.ctxPtr,_);}finally{t._free(n),t._free(_);}}finishAuthEncryption(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=this.outLen(0),n=t._vsc_buffer_new_with_capacity(r),s=this.AUTH_TAG_LEN,_=t._vsc_buffer_new_with_capacity(s);try{const r=t._vscf_aes256_gcm_finish_auth_encryption(this.ctxPtr,n,_);e.FoundationError.handleStatusCode(r);const s=t._vsc_buffer_bytes(n),c=t._vsc_buffer_len(n),a=t.HEAPU8.slice(s,s+c),i=t._vsc_buffer_bytes(_),o=t._vsc_buffer_len(_);return {out:a,tag:t.HEAPU8.slice(i,i+o)}}finally{t._vsc_buffer_delete(n),t._vsc_buffer_delete(_);}}finishAuthDecryption(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("tag",r);const n=r.length*r.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(r,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=this.outLen(0),o=t._vsc_buffer_new_with_capacity(i);try{const r=t._vscf_aes256_gcm_finish_auth_decryption(this.ctxPtr,c,o);e.FoundationError.handleStatusCode(r);const n=t._vsc_buffer_bytes(o),_=t._vsc_buffer_len(o);return t.HEAPU8.slice(n,n+_)}finally{t._free(s),t._free(c),t._vsc_buffer_delete(o);}}}return r},R$2=(t,e)=>{class r{static get NONCE_LEN(){return 16}get NONCE_LEN(){return r.NONCE_LEN}static get KEY_LEN(){return 32}get KEY_LEN(){return r.KEY_LEN}static get KEY_BITLEN(){return 256}get KEY_BITLEN(){return r.KEY_BITLEN}static get BLOCK_LEN(){return 16}get BLOCK_LEN(){return r.BLOCK_LEN}constructor(e){this.name="Aes256Cbc",this.ctxPtr=void 0===e?t._vscf_aes256_cbc_new():e;}static newAndUseCContext(e){return new r(t._vscf_aes256_cbc_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_aes256_cbc_delete(this.ctxPtr),this.ctxPtr=null);}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_aes256_cbc_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_aes256_cbc_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface);const n=t._vscf_aes256_cbc_restore_alg_info(this.ctxPtr,r.ctxPtr);e.FoundationError.handleStatusCode(n);}encrypt(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",r);const n=r.length*r.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(r,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=this.encryptedLen(r.length),o=t._vsc_buffer_new_with_capacity(i);try{const r=t._vscf_aes256_cbc_encrypt(this.ctxPtr,c,o);e.FoundationError.handleStatusCode(r);const n=t._vsc_buffer_bytes(o),_=t._vsc_buffer_len(o);return t.HEAPU8.slice(n,n+_)}finally{t._free(s),t._free(c),t._vsc_buffer_delete(o);}}encryptedLen(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("dataLen",e),t._vscf_aes256_cbc_encrypted_len(this.ctxPtr,e)}preciseEncryptedLen(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("dataLen",e),t._vscf_aes256_cbc_precise_encrypted_len(this.ctxPtr,e)}decrypt(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",r);const n=r.length*r.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(r,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=this.decryptedLen(r.length),o=t._vsc_buffer_new_with_capacity(i);try{const r=t._vscf_aes256_cbc_decrypt(this.ctxPtr,c,o);e.FoundationError.handleStatusCode(r);const n=t._vsc_buffer_bytes(o),_=t._vsc_buffer_len(o);return t.HEAPU8.slice(n,n+_)}finally{t._free(s),t._free(c),t._vsc_buffer_delete(o);}}decryptedLen(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("dataLen",e),t._vscf_aes256_cbc_decrypted_len(this.ctxPtr,e)}setNonce(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("nonce",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);t._vsc_data(_,n,r);try{t._vscf_aes256_cbc_set_nonce(this.ctxPtr,_);}finally{t._free(n),t._free(_);}}setKey(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("key",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);t._vsc_data(_,n,r);try{t._vscf_aes256_cbc_set_key(this.ctxPtr,_);}finally{t._free(n),t._free(_);}}startEncryption(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_aes256_cbc_start_encryption(this.ctxPtr);}startDecryption(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_aes256_cbc_start_decryption(this.ctxPtr);}update(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);t._vsc_data(_,n,r);const c=this.outLen(e.length),i=t._vsc_buffer_new_with_capacity(c);try{t._vscf_aes256_cbc_update(this.ctxPtr,_,i);const e=t._vsc_buffer_bytes(i),r=t._vsc_buffer_len(i);return t.HEAPU8.slice(e,e+r)}finally{t._free(n),t._free(_),t._vsc_buffer_delete(i);}}outLen(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("dataLen",e),t._vscf_aes256_cbc_out_len(this.ctxPtr,e)}encryptedOutLen(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("dataLen",e),t._vscf_aes256_cbc_encrypted_out_len(this.ctxPtr,e)}decryptedOutLen(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("dataLen",e),t._vscf_aes256_cbc_decrypted_out_len(this.ctxPtr,e)}finish(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=this.outLen(0),n=t._vsc_buffer_new_with_capacity(r);try{const r=t._vscf_aes256_cbc_finish(this.ctxPtr,n);e.FoundationError.handleStatusCode(r);const s=t._vsc_buffer_bytes(n),_=t._vsc_buffer_len(n);return t.HEAPU8.slice(s,s+_)}finally{t._vsc_buffer_delete(n);}}}return r},z$1=(t,e)=>{class r{constructor(e){this.name="Asn1rd",this.ctxPtr=void 0===e?t._vscf_asn1rd_new():e;}static newAndUseCContext(e){return new r(t._vscf_asn1rd_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_asn1rd_delete(this.ctxPtr),this.ctxPtr=null);}reset(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);t._vsc_data(_,n,r);try{t._vscf_asn1rd_reset(this.ctxPtr,_);}finally{t._free(n),t._free(_);}}leftLen(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_left_len(this.ctxPtr)}hasError(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_asn1rd_has_error(this.ctxPtr))}status(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_asn1rd_status(this.ctxPtr);e.FoundationError.handleStatusCode(r);}getTag(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_get_tag(this.ctxPtr)}getLen(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_get_len(this.ctxPtr)}getDataLen(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_get_data_len(this.ctxPtr)}readTag(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("tag",e),t._vscf_asn1rd_read_tag(this.ctxPtr,e)}readContextTag(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("tag",e),t._vscf_asn1rd_read_context_tag(this.ctxPtr,e)}readInt(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_int(this.ctxPtr)}readInt8(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_int8(this.ctxPtr)}readInt16(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_int16(this.ctxPtr)}readInt32(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_int32(this.ctxPtr)}readInt64(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_int64(this.ctxPtr)}readUint(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_uint(this.ctxPtr)}readUint8(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_uint8(this.ctxPtr)}readUint16(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_uint16(this.ctxPtr)}readUint32(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_uint32(this.ctxPtr)}readUint64(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_uint64(this.ctxPtr)}readBool(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_asn1rd_read_bool(this.ctxPtr))}readNull(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_null(this.ctxPtr);}readNullOptional(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_null_optional(this.ctxPtr);}readOctetStr(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=t._vsc_data_ctx_size(),r=t._malloc(e);try{t._vscf_asn1rd_read_octet_str(r,this.ctxPtr);const e=t._vsc_data_len(r),n=t._vsc_data_bytes(r);return t.HEAPU8.slice(n,n+e)}finally{t._free(r);}}readBitstringAsOctetStr(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=t._vsc_data_ctx_size(),r=t._malloc(e);try{t._vscf_asn1rd_read_bitstring_as_octet_str(r,this.ctxPtr);const e=t._vsc_data_len(r),n=t._vsc_data_bytes(r);return t.HEAPU8.slice(n,n+e)}finally{t._free(r);}}readUtf8Str(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=t._vsc_data_ctx_size(),r=t._malloc(e);try{t._vscf_asn1rd_read_utf8_str(r,this.ctxPtr);const e=t._vsc_data_len(r),n=t._vsc_data_bytes(r);return t.HEAPU8.slice(n,n+e)}finally{t._free(r);}}readOid(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=t._vsc_data_ctx_size(),r=t._malloc(e);try{t._vscf_asn1rd_read_oid(r,this.ctxPtr);const e=t._vsc_data_len(r),n=t._vsc_data_bytes(r);return t.HEAPU8.slice(n,n+e)}finally{t._free(r);}}readData(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("len",e);const r=t._vsc_data_ctx_size(),n=t._malloc(r);try{t._vscf_asn1rd_read_data(n,this.ctxPtr,e);const r=t._vsc_data_len(n),s=t._vsc_data_bytes(n);return t.HEAPU8.slice(s,s+r)}finally{t._free(n);}}readSequence(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_sequence(this.ctxPtr)}readSet(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1rd_read_set(this.ctxPtr)}}return r},B$2=(t,e)=>{class r{constructor(e){this.name="Asn1wr",this.ctxPtr=void 0===e?t._vscf_asn1wr_new():e;}static newAndUseCContext(e){return new r(t._vscf_asn1wr_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_asn1wr_delete(this.ctxPtr),this.ctxPtr=null);}reset(e,r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("out",e),a$3.ensureNumber("outLen",r),t._vscf_asn1wr_reset(this.ctxPtr,e,r);}finish(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureBoolean("doNotAdjust",e),t._vscf_asn1wr_finish(this.ctxPtr,e)}bytes(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1wr_bytes(this.ctxPtr)}len(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1wr_len(this.ctxPtr)}writtenLen(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1wr_written_len(this.ctxPtr)}unwrittenLen(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1wr_unwritten_len(this.ctxPtr)}hasError(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_asn1wr_has_error(this.ctxPtr))}status(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_asn1wr_status(this.ctxPtr);e.FoundationError.handleStatusCode(r);}reserve(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("len",e),t._vscf_asn1wr_reserve(this.ctxPtr,e)}writeTag(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("tag",e),t._vscf_asn1wr_write_tag(this.ctxPtr,e)}writeContextTag(e,r){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("tag",e),a$3.ensureNumber("len",r),t._vscf_asn1wr_write_context_tag(this.ctxPtr,e,r)}writeLen(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("len",e),t._vscf_asn1wr_write_len(this.ctxPtr,e)}writeInt(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("value",e),t._vscf_asn1wr_write_int(this.ctxPtr,e)}writeInt8(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("value",e),t._vscf_asn1wr_write_int8(this.ctxPtr,e)}writeInt16(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("value",e),t._vscf_asn1wr_write_int16(this.ctxPtr,e)}writeInt32(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("value",e),t._vscf_asn1wr_write_int32(this.ctxPtr,e)}writeInt64(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("value",e),t._vscf_asn1wr_write_int64(this.ctxPtr,e)}writeUint(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("value",e),t._vscf_asn1wr_write_uint(this.ctxPtr,e)}writeUint8(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("value",e),t._vscf_asn1wr_write_uint8(this.ctxPtr,e)}writeUint16(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("value",e),t._vscf_asn1wr_write_uint16(this.ctxPtr,e)}writeUint32(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("value",e),t._vscf_asn1wr_write_uint32(this.ctxPtr,e)}writeUint64(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("value",e),t._vscf_asn1wr_write_uint64(this.ctxPtr,e)}writeBool(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureBoolean("value",e),t._vscf_asn1wr_write_bool(this.ctxPtr,e)}writeNull(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_asn1wr_write_null(this.ctxPtr)}writeOctetStr(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("value",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);let c;t._vsc_data(_,n,r);try{return c=t._vscf_asn1wr_write_octet_str(this.ctxPtr,_)}finally{t._free(n),t._free(_);}}writeOctetStrAsBitstring(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("value",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);let c;t._vsc_data(_,n,r);try{return c=t._vscf_asn1wr_write_octet_str_as_bitstring(this.ctxPtr,_)}finally{t._free(n),t._free(_);}}writeData(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);let c;t._vsc_data(_,n,r);try{return c=t._vscf_asn1wr_write_data(this.ctxPtr,_)}finally{t._free(n),t._free(_);}}writeUtf8Str(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("value",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);let c;t._vsc_data(_,n,r);try{return c=t._vscf_asn1wr_write_utf8_str(this.ctxPtr,_)}finally{t._free(n),t._free(_);}}writeOid(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("value",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);let c;t._vsc_data(_,n,r);try{return c=t._vscf_asn1wr_write_oid(this.ctxPtr,_)}finally{t._free(n),t._free(_);}}writeSequence(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("len",e),t._vscf_asn1wr_write_sequence(this.ctxPtr,e)}writeSet(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("len",e),t._vscf_asn1wr_write_set(this.ctxPtr,e)}}return r},U$2=(t,e)=>{class r{constructor(e){this.name="RsaPublicKey",this.ctxPtr=void 0===e?t._vscf_rsa_public_key_new():e;}static newAndUseCContext(e){return new r(t._vscf_rsa_public_key_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_rsa_public_key_delete(this.ctxPtr),this.ctxPtr=null);}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_rsa_public_key_alg_id(this.ctxPtr)}algInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_rsa_public_key_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}len(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_rsa_public_key_len(this.ctxPtr)}bitlen(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_rsa_public_key_bitlen(this.ctxPtr)}implTag(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_rsa_public_key_impl_tag(this.ctxPtr)}isValid(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_rsa_public_key_is_valid(this.ctxPtr))}keyExponent(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_rsa_public_key_key_exponent(this.ctxPtr)}}return r},M$2=(t,e)=>{class r{constructor(e){this.name="RsaPrivateKey",this.ctxPtr=void 0===e?t._vscf_rsa_private_key_new():e;}static newAndUseCContext(e){return new r(t._vscf_rsa_private_key_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_rsa_private_key_delete(this.ctxPtr),this.ctxPtr=null);}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_rsa_private_key_alg_id(this.ctxPtr)}algInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_rsa_private_key_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}len(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_rsa_private_key_len(this.ctxPtr)}bitlen(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_rsa_private_key_bitlen(this.ctxPtr)}implTag(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_rsa_private_key_impl_tag(this.ctxPtr)}isValid(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_rsa_private_key_is_valid(this.ctxPtr))}extractPublicKey(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_rsa_private_key_extract_public_key(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}}return r},H$1=(t,e)=>{class r{static get CAN_IMPORT_PUBLIC_KEY(){return !0}get CAN_IMPORT_PUBLIC_KEY(){return r.CAN_IMPORT_PUBLIC_KEY}static get CAN_EXPORT_PUBLIC_KEY(){return !0}get CAN_EXPORT_PUBLIC_KEY(){return r.CAN_EXPORT_PUBLIC_KEY}static get CAN_IMPORT_PRIVATE_KEY(){return !0}get CAN_IMPORT_PRIVATE_KEY(){return r.CAN_IMPORT_PRIVATE_KEY}static get CAN_EXPORT_PRIVATE_KEY(){return !0}get CAN_EXPORT_PRIVATE_KEY(){return r.CAN_EXPORT_PRIVATE_KEY}constructor(e){this.name="Rsa",this.ctxPtr=void 0===e?t._vscf_rsa_new():e;}static newAndUseCContext(e){return new r(t._vscf_rsa_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_rsa_delete(this.ctxPtr),this.ctxPtr=null);}set random(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("random",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_rsa_release_random(this.ctxPtr),t._vscf_rsa_use_random(this.ctxPtr,r.ctxPtr);}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_rsa_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_rsa_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface);const n=t._vscf_rsa_restore_alg_info(this.ctxPtr,r.ctxPtr);e.FoundationError.handleStatusCode(n);}generateEphemeralKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("key",r,"Foundation.Key",e.FoundationInterfaceTag.KEY,e.FoundationInterface);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_rsa_generate_ephemeral_key(this.ctxPtr,r.ctxPtr,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(s);}}importPublicKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("rawKey",r,e.RawPublicKey);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_rsa_import_public_key(this.ctxPtr,r.ctxPtr,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(s);}}exportPublicKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_rsa_export_public_key(this.ctxPtr,r.ctxPtr,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),e.RawPublicKey.newAndTakeCContext(_)}finally{t._free(s);}}importPrivateKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("rawKey",r,e.RawPrivateKey);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_rsa_import_private_key(this.ctxPtr,r.ctxPtr,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(s);}}exportPrivateKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_rsa_export_private_key(this.ctxPtr,r.ctxPtr,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),e.RawPrivateKey.newAndTakeCContext(_)}finally{t._free(s);}}canEncrypt(r,n){let s;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$3.ensureNumber("dataLen",n),!!(s=t._vscf_rsa_can_encrypt(this.ctxPtr,r.ctxPtr,n))}encryptedLen(r,n){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$3.ensureNumber("dataLen",n),t._vscf_rsa_encrypted_len(this.ctxPtr,r.ctxPtr,n)}encrypt(r,n){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$3.ensureByteArray("data",n);const s=n.length*n.BYTES_PER_ELEMENT,_=t._malloc(s);t.HEAP8.set(n,_);const c=t._vsc_data_ctx_size(),i=t._malloc(c);t._vsc_data(i,_,s);const o=this.encryptedLen(r,n.length),l=t._vsc_buffer_new_with_capacity(o);try{const n=t._vscf_rsa_encrypt(this.ctxPtr,r.ctxPtr,i,l);e.FoundationError.handleStatusCode(n);const s=t._vsc_buffer_bytes(l),c=t._vsc_buffer_len(l);return t.HEAPU8.slice(s,s+c)}finally{t._free(_),t._free(i),t._vsc_buffer_delete(l);}}canDecrypt(r,n){let s;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$3.ensureNumber("dataLen",n),!!(s=t._vscf_rsa_can_decrypt(this.ctxPtr,r.ctxPtr,n))}decryptedLen(r,n){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$3.ensureNumber("dataLen",n),t._vscf_rsa_decrypted_len(this.ctxPtr,r.ctxPtr,n)}decrypt(r,n){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$3.ensureByteArray("data",n);const s=n.length*n.BYTES_PER_ELEMENT,_=t._malloc(s);t.HEAP8.set(n,_);const c=t._vsc_data_ctx_size(),i=t._malloc(c);t._vsc_data(i,_,s);const o=this.decryptedLen(r,n.length),l=t._vsc_buffer_new_with_capacity(o);try{const n=t._vscf_rsa_decrypt(this.ctxPtr,r.ctxPtr,i,l);e.FoundationError.handleStatusCode(n);const s=t._vsc_buffer_bytes(l),c=t._vsc_buffer_len(l);return t.HEAPU8.slice(s,s+c)}finally{t._free(_),t._free(i),t._vsc_buffer_delete(l);}}canSign(r){let n;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),!!(n=t._vscf_rsa_can_sign(this.ctxPtr,r.ctxPtr))}signatureLen(r){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("key",r,"Foundation.Key",e.FoundationInterfaceTag.KEY,e.FoundationInterface),t._vscf_rsa_signature_len(this.ctxPtr,r.ctxPtr)}signHash(r,n,s){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$3.ensureNumber("hashId",n),a$3.ensureByteArray("digest",s);const _=s.length*s.BYTES_PER_ELEMENT,c=t._malloc(_);t.HEAP8.set(s,c);const i=t._vsc_data_ctx_size(),o=t._malloc(i);t._vsc_data(o,c,_);const l=this.signatureLen(r),u=t._vsc_buffer_new_with_capacity(l);try{const s=t._vscf_rsa_sign_hash(this.ctxPtr,r.ctxPtr,n,o,u);e.FoundationError.handleStatusCode(s);const _=t._vsc_buffer_bytes(u),a=t._vsc_buffer_len(u);return t.HEAPU8.slice(_,_+a)}finally{t._free(c),t._free(o),t._vsc_buffer_delete(u);}}canVerify(r){let n;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),!!(n=t._vscf_rsa_can_verify(this.ctxPtr,r.ctxPtr))}verifyHash(r,n,s,_){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$3.ensureNumber("hashId",n),a$3.ensureByteArray("digest",s),a$3.ensureByteArray("signature",_);const c=s.length*s.BYTES_PER_ELEMENT,i=t._malloc(c);t.HEAP8.set(s,i);const o=t._vsc_data_ctx_size(),l=t._malloc(o);t._vsc_data(l,i,c);const u=_.length*_.BYTES_PER_ELEMENT,f=t._malloc(u);t.HEAP8.set(_,f);const p=t._vsc_data_ctx_size(),d=t._malloc(p);let h;t._vsc_data(d,f,u);try{return !!(h=t._vscf_rsa_verify_hash(this.ctxPtr,r.ctxPtr,n,l,d))}finally{t._free(i),t._free(l),t._free(f),t._free(d);}}setupDefaults(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_rsa_setup_defaults(this.ctxPtr);e.FoundationError.handleStatusCode(r);}generateKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("bitlen",r);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_rsa_generate_key(this.ctxPtr,r,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(s);}}}return r},Y$1=(t,e)=>{class r{constructor(e){this.name="EccPublicKey",this.ctxPtr=void 0===e?t._vscf_ecc_public_key_new():e;}static newAndUseCContext(e){return new r(t._vscf_ecc_public_key_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_ecc_public_key_delete(this.ctxPtr),this.ctxPtr=null);}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecc_public_key_alg_id(this.ctxPtr)}algInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_ecc_public_key_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}len(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecc_public_key_len(this.ctxPtr)}bitlen(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecc_public_key_bitlen(this.ctxPtr)}implTag(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecc_public_key_impl_tag(this.ctxPtr)}isValid(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_ecc_public_key_is_valid(this.ctxPtr))}}return r},D$1=(t,e)=>{class r{constructor(e){this.name="EccPrivateKey",this.ctxPtr=void 0===e?t._vscf_ecc_private_key_new():e;}static newAndUseCContext(e){return new r(t._vscf_ecc_private_key_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_ecc_private_key_delete(this.ctxPtr),this.ctxPtr=null);}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecc_private_key_alg_id(this.ctxPtr)}algInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_ecc_private_key_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}len(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecc_private_key_len(this.ctxPtr)}bitlen(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecc_private_key_bitlen(this.ctxPtr)}implTag(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecc_private_key_impl_tag(this.ctxPtr)}isValid(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_ecc_private_key_is_valid(this.ctxPtr))}extractPublicKey(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_ecc_private_key_extract_public_key(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}}return r},O$1=(t,e)=>{class r{static get CAN_IMPORT_PUBLIC_KEY(){return !0}get CAN_IMPORT_PUBLIC_KEY(){return r.CAN_IMPORT_PUBLIC_KEY}static get CAN_EXPORT_PUBLIC_KEY(){return !0}get CAN_EXPORT_PUBLIC_KEY(){return r.CAN_EXPORT_PUBLIC_KEY}static get CAN_IMPORT_PRIVATE_KEY(){return !0}get CAN_IMPORT_PRIVATE_KEY(){return r.CAN_IMPORT_PRIVATE_KEY}static get CAN_EXPORT_PRIVATE_KEY(){return !0}get CAN_EXPORT_PRIVATE_KEY(){return r.CAN_EXPORT_PRIVATE_KEY}constructor(e){this.name="Ecc",this.ctxPtr=void 0===e?t._vscf_ecc_new():e;}static newAndUseCContext(e){return new r(t._vscf_ecc_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_ecc_delete(this.ctxPtr),this.ctxPtr=null);}set random(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("random",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_ecc_release_random(this.ctxPtr),t._vscf_ecc_use_random(this.ctxPtr,r.ctxPtr);}set ecies(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("ecies",r,e.Ecies),t._vscf_ecc_release_ecies(this.ctxPtr),t._vscf_ecc_use_ecies(this.ctxPtr,r.ctxPtr);}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecc_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_ecc_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface);const n=t._vscf_ecc_restore_alg_info(this.ctxPtr,r.ctxPtr);e.FoundationError.handleStatusCode(n);}generateEphemeralKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("key",r,"Foundation.Key",e.FoundationInterfaceTag.KEY,e.FoundationInterface);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_ecc_generate_ephemeral_key(this.ctxPtr,r.ctxPtr,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(s);}}importPublicKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("rawKey",r,e.RawPublicKey);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_ecc_import_public_key(this.ctxPtr,r.ctxPtr,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(s);}}exportPublicKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_ecc_export_public_key(this.ctxPtr,r.ctxPtr,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),e.RawPublicKey.newAndTakeCContext(_)}finally{t._free(s);}}importPrivateKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("rawKey",r,e.RawPrivateKey);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_ecc_import_private_key(this.ctxPtr,r.ctxPtr,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(s);}}exportPrivateKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_ecc_export_private_key(this.ctxPtr,r.ctxPtr,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),e.RawPrivateKey.newAndTakeCContext(_)}finally{t._free(s);}}canEncrypt(r,n){let s;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$3.ensureNumber("dataLen",n),!!(s=t._vscf_ecc_can_encrypt(this.ctxPtr,r.ctxPtr,n))}encryptedLen(r,n){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$3.ensureNumber("dataLen",n),t._vscf_ecc_encrypted_len(this.ctxPtr,r.ctxPtr,n)}encrypt(r,n){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$3.ensureByteArray("data",n);const s=n.length*n.BYTES_PER_ELEMENT,_=t._malloc(s);t.HEAP8.set(n,_);const c=t._vsc_data_ctx_size(),i=t._malloc(c);t._vsc_data(i,_,s);const o=this.encryptedLen(r,n.length),l=t._vsc_buffer_new_with_capacity(o);try{const n=t._vscf_ecc_encrypt(this.ctxPtr,r.ctxPtr,i,l);e.FoundationError.handleStatusCode(n);const s=t._vsc_buffer_bytes(l),c=t._vsc_buffer_len(l);return t.HEAPU8.slice(s,s+c)}finally{t._free(_),t._free(i),t._vsc_buffer_delete(l);}}canDecrypt(r,n){let s;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$3.ensureNumber("dataLen",n),!!(s=t._vscf_ecc_can_decrypt(this.ctxPtr,r.ctxPtr,n))}decryptedLen(r,n){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$3.ensureNumber("dataLen",n),t._vscf_ecc_decrypted_len(this.ctxPtr,r.ctxPtr,n)}decrypt(r,n){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$3.ensureByteArray("data",n);const s=n.length*n.BYTES_PER_ELEMENT,_=t._malloc(s);t.HEAP8.set(n,_);const c=t._vsc_data_ctx_size(),i=t._malloc(c);t._vsc_data(i,_,s);const o=this.decryptedLen(r,n.length),l=t._vsc_buffer_new_with_capacity(o);try{const n=t._vscf_ecc_decrypt(this.ctxPtr,r.ctxPtr,i,l);e.FoundationError.handleStatusCode(n);const s=t._vsc_buffer_bytes(l),c=t._vsc_buffer_len(l);return t.HEAPU8.slice(s,s+c)}finally{t._free(_),t._free(i),t._vsc_buffer_delete(l);}}canSign(r){let n;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),!!(n=t._vscf_ecc_can_sign(this.ctxPtr,r.ctxPtr))}signatureLen(r){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("key",r,"Foundation.Key",e.FoundationInterfaceTag.KEY,e.FoundationInterface),t._vscf_ecc_signature_len(this.ctxPtr,r.ctxPtr)}signHash(r,n,s){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$3.ensureNumber("hashId",n),a$3.ensureByteArray("digest",s);const _=s.length*s.BYTES_PER_ELEMENT,c=t._malloc(_);t.HEAP8.set(s,c);const i=t._vsc_data_ctx_size(),o=t._malloc(i);t._vsc_data(o,c,_);const l=this.signatureLen(r),u=t._vsc_buffer_new_with_capacity(l);try{const s=t._vscf_ecc_sign_hash(this.ctxPtr,r.ctxPtr,n,o,u);e.FoundationError.handleStatusCode(s);const _=t._vsc_buffer_bytes(u),a=t._vsc_buffer_len(u);return t.HEAPU8.slice(_,_+a)}finally{t._free(c),t._free(o),t._vsc_buffer_delete(u);}}canVerify(r){let n;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),!!(n=t._vscf_ecc_can_verify(this.ctxPtr,r.ctxPtr))}verifyHash(r,n,s,_){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$3.ensureNumber("hashId",n),a$3.ensureByteArray("digest",s),a$3.ensureByteArray("signature",_);const c=s.length*s.BYTES_PER_ELEMENT,i=t._malloc(c);t.HEAP8.set(s,i);const o=t._vsc_data_ctx_size(),l=t._malloc(o);t._vsc_data(l,i,c);const u=_.length*_.BYTES_PER_ELEMENT,f=t._malloc(u);t.HEAP8.set(_,f);const p=t._vsc_data_ctx_size(),d=t._malloc(p);let h;t._vsc_data(d,f,u);try{return !!(h=t._vscf_ecc_verify_hash(this.ctxPtr,r.ctxPtr,n,l,d))}finally{t._free(i),t._free(l),t._free(f),t._free(d);}}computeSharedKey(r,n){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$3.ensureImplementInterface("privateKey",n,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface);const s=this.sharedKeyLen(n),_=t._vsc_buffer_new_with_capacity(s);try{const s=t._vscf_ecc_compute_shared_key(this.ctxPtr,r.ctxPtr,n.ctxPtr,_);e.FoundationError.handleStatusCode(s);const c=t._vsc_buffer_bytes(_),a=t._vsc_buffer_len(_);return t.HEAPU8.slice(c,c+a)}finally{t._vsc_buffer_delete(_);}}sharedKeyLen(r){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("key",r,"Foundation.Key",e.FoundationInterfaceTag.KEY,e.FoundationInterface),t._vscf_ecc_shared_key_len(this.ctxPtr,r.ctxPtr)}setupDefaults(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_ecc_setup_defaults(this.ctxPtr);e.FoundationError.handleStatusCode(r);}generateKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("algId",r);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_ecc_generate_key(this.ctxPtr,r,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(s);}}}return r},G$1=(t,e)=>{class r{static get SOURCES_MAX(){return 15}get SOURCES_MAX(){return r.SOURCES_MAX}constructor(e){this.name="EntropyAccumulator",this.ctxPtr=void 0===e?t._vscf_entropy_accumulator_new():e;}static newAndUseCContext(e){return new r(t._vscf_entropy_accumulator_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_entropy_accumulator_delete(this.ctxPtr),this.ctxPtr=null);}isStrong(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_entropy_accumulator_is_strong(this.ctxPtr))}gather(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("len",r);const n=r,s=t._vsc_buffer_new_with_capacity(n);try{const n=t._vscf_entropy_accumulator_gather(this.ctxPtr,r,s);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(s),c=t._vsc_buffer_len(s);return t.HEAPU8.slice(_,_+c)}finally{t._vsc_buffer_delete(s);}}setupDefaults(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_entropy_accumulator_setup_defaults(this.ctxPtr);}addSource(r,n){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("source",r,"Foundation.EntropySource",e.FoundationInterfaceTag.ENTROPY_SOURCE,e.FoundationInterface),a$3.ensureNumber("threshold",n),t._vscf_entropy_accumulator_add_source(this.ctxPtr,r.ctxPtr,n);}}return r},V$1=(t,e)=>{class r{static get RESEED_INTERVAL(){return 1e4}get RESEED_INTERVAL(){return r.RESEED_INTERVAL}static get ENTROPY_LEN(){return 48}get ENTROPY_LEN(){return r.ENTROPY_LEN}constructor(e){this.name="CtrDrbg",this.ctxPtr=void 0===e?t._vscf_ctr_drbg_new():e;}static newAndUseCContext(e){return new r(t._vscf_ctr_drbg_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_ctr_drbg_delete(this.ctxPtr),this.ctxPtr=null);}set entropySource(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("entropySource",r,"Foundation.EntropySource",e.FoundationInterfaceTag.ENTROPY_SOURCE,e.FoundationInterface),t._vscf_ctr_drbg_release_entropy_source(this.ctxPtr);const n=t._vscf_ctr_drbg_use_entropy_source(this.ctxPtr,r.ctxPtr);e.FoundationError.handleStatusCode(n);}random(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("dataLen",r);const n=r,s=t._vsc_buffer_new_with_capacity(n);try{const n=t._vscf_ctr_drbg_random(this.ctxPtr,r,s);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(s),c=t._vsc_buffer_len(s);return t.HEAPU8.slice(_,_+c)}finally{t._vsc_buffer_delete(s);}}reseed(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_ctr_drbg_reseed(this.ctxPtr);e.FoundationError.handleStatusCode(r);}setupDefaults(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_ctr_drbg_setup_defaults(this.ctxPtr);e.FoundationError.handleStatusCode(r);}enablePredictionResistance(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ctr_drbg_enable_prediction_resistance(this.ctxPtr);}setReseedInterval(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("interval",e),t._vscf_ctr_drbg_set_reseed_interval(this.ctxPtr,e);}setEntropyLen(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("len",e),t._vscf_ctr_drbg_set_entropy_len(this.ctxPtr,e);}}return r},X$1=(t,e)=>{class r{constructor(e){this.name="Hmac",this.ctxPtr=void 0===e?t._vscf_hmac_new():e;}static newAndUseCContext(e){return new r(t._vscf_hmac_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_hmac_delete(this.ctxPtr),this.ctxPtr=null);}set hash(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("hash",r,"Foundation.Hash",e.FoundationInterfaceTag.HASH,e.FoundationInterface),t._vscf_hmac_release_hash(this.ctxPtr),t._vscf_hmac_use_hash(this.ctxPtr,r.ctxPtr);}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_hmac_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_hmac_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface);const n=t._vscf_hmac_restore_alg_info(this.ctxPtr,r.ctxPtr);e.FoundationError.handleStatusCode(n);}digestLen(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_hmac_digest_len(this.ctxPtr)}mac(e,r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("key",e),a$3.ensureByteArray("data",r);const n=e.length*e.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(e,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=r.length*r.BYTES_PER_ELEMENT,o=t._malloc(i);t.HEAP8.set(r,o);const l=t._vsc_data_ctx_size(),u=t._malloc(l);t._vsc_data(u,o,i);const f=this.digestLen(),p=t._vsc_buffer_new_with_capacity(f);try{t._vscf_hmac_mac(this.ctxPtr,c,u,p);const e=t._vsc_buffer_bytes(p),r=t._vsc_buffer_len(p);return t.HEAPU8.slice(e,e+r)}finally{t._free(s),t._free(c),t._free(o),t._free(u),t._vsc_buffer_delete(p);}}start(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("key",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);t._vsc_data(_,n,r);try{t._vscf_hmac_start(this.ctxPtr,_);}finally{t._free(n),t._free(_);}}update(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);t._vsc_data(_,n,r);try{t._vscf_hmac_update(this.ctxPtr,_);}finally{t._free(n),t._free(_);}}finish(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=this.digestLen(),r=t._vsc_buffer_new_with_capacity(e);try{t._vscf_hmac_finish(this.ctxPtr,r);const e=t._vsc_buffer_bytes(r),n=t._vsc_buffer_len(r);return t.HEAPU8.slice(e,e+n)}finally{t._vsc_buffer_delete(r);}}reset(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_hmac_reset(this.ctxPtr);}}return r},j$1=(t,e)=>{class r{constructor(e){this.name="Hkdf",this.ctxPtr=void 0===e?t._vscf_hkdf_new():e;}static newAndUseCContext(e){return new r(t._vscf_hkdf_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_hkdf_delete(this.ctxPtr),this.ctxPtr=null);}set hash(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("hash",r,"Foundation.Hash",e.FoundationInterfaceTag.HASH,e.FoundationInterface),t._vscf_hkdf_release_hash(this.ctxPtr),t._vscf_hkdf_use_hash(this.ctxPtr,r.ctxPtr);}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_hkdf_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_hkdf_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface);const n=t._vscf_hkdf_restore_alg_info(this.ctxPtr,r.ctxPtr);e.FoundationError.handleStatusCode(n);}derive(e,r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",e),a$3.ensureNumber("keyLen",r);const n=e.length*e.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(e,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=r,o=t._vsc_buffer_new_with_capacity(i);try{t._vscf_hkdf_derive(this.ctxPtr,c,r,o);const e=t._vsc_buffer_bytes(o),n=t._vsc_buffer_len(o);return t.HEAPU8.slice(e,e+n)}finally{t._free(s),t._free(c),t._vsc_buffer_delete(o);}}reset(e,r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("salt",e),a$3.ensureNumber("iterationCount",r);const n=e.length*e.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(e,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);try{t._vscf_hkdf_reset(this.ctxPtr,c,r);}finally{t._free(s),t._free(c);}}setInfo(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("info",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);t._vsc_data(_,n,r);try{t._vscf_hkdf_set_info(this.ctxPtr,_);}finally{t._free(n),t._free(_);}}}return r},W$1=(t,e)=>{class r{constructor(e){this.name="Kdf1",this.ctxPtr=void 0===e?t._vscf_kdf1_new():e;}static newAndUseCContext(e){return new r(t._vscf_kdf1_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_kdf1_delete(this.ctxPtr),this.ctxPtr=null);}set hash(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("hash",r,"Foundation.Hash",e.FoundationInterfaceTag.HASH,e.FoundationInterface),t._vscf_kdf1_release_hash(this.ctxPtr),t._vscf_kdf1_use_hash(this.ctxPtr,r.ctxPtr);}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_kdf1_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_kdf1_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface);const n=t._vscf_kdf1_restore_alg_info(this.ctxPtr,r.ctxPtr);e.FoundationError.handleStatusCode(n);}derive(e,r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",e),a$3.ensureNumber("keyLen",r);const n=e.length*e.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(e,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=r,o=t._vsc_buffer_new_with_capacity(i);try{t._vscf_kdf1_derive(this.ctxPtr,c,r,o);const e=t._vsc_buffer_bytes(o),n=t._vsc_buffer_len(o);return t.HEAPU8.slice(e,e+n)}finally{t._free(s),t._free(c),t._vsc_buffer_delete(o);}}}return r},Z$1=(t,e)=>{class r{constructor(e){this.name="Kdf2",this.ctxPtr=void 0===e?t._vscf_kdf2_new():e;}static newAndUseCContext(e){return new r(t._vscf_kdf2_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_kdf2_delete(this.ctxPtr),this.ctxPtr=null);}set hash(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("hash",r,"Foundation.Hash",e.FoundationInterfaceTag.HASH,e.FoundationInterface),t._vscf_kdf2_release_hash(this.ctxPtr),t._vscf_kdf2_use_hash(this.ctxPtr,r.ctxPtr);}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_kdf2_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_kdf2_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface);const n=t._vscf_kdf2_restore_alg_info(this.ctxPtr,r.ctxPtr);e.FoundationError.handleStatusCode(n);}derive(e,r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",e),a$3.ensureNumber("keyLen",r);const n=e.length*e.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(e,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=r,o=t._vsc_buffer_new_with_capacity(i);try{t._vscf_kdf2_derive(this.ctxPtr,c,r,o);const e=t._vsc_buffer_bytes(o),n=t._vsc_buffer_len(o);return t.HEAPU8.slice(e,e+n)}finally{t._free(s),t._free(c),t._vsc_buffer_delete(o);}}}return r},$$1=(t,e)=>{class r{constructor(e){this.name="FakeRandom",this.ctxPtr=void 0===e?t._vscf_fake_random_new():e;}static newAndUseCContext(e){return new r(t._vscf_fake_random_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_fake_random_delete(this.ctxPtr),this.ctxPtr=null);}random(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("dataLen",r);const n=r,s=t._vsc_buffer_new_with_capacity(n);try{const n=t._vscf_fake_random_random(this.ctxPtr,r,s);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(s),c=t._vsc_buffer_len(s);return t.HEAPU8.slice(_,_+c)}finally{t._vsc_buffer_delete(s);}}reseed(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_fake_random_reseed(this.ctxPtr);e.FoundationError.handleStatusCode(r);}isStrong(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_fake_random_is_strong(this.ctxPtr))}gather(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("len",r);const n=r,s=t._vsc_buffer_new_with_capacity(n);try{const n=t._vscf_fake_random_gather(this.ctxPtr,r,s);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(s),c=t._vsc_buffer_len(s);return t.HEAPU8.slice(_,_+c)}finally{t._vsc_buffer_delete(s);}}setupSourceByte(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("byteSource",e),t._vscf_fake_random_setup_source_byte(this.ctxPtr,e);}setupSourceData(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("dataSource",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);t._vsc_data(_,n,r);try{t._vscf_fake_random_setup_source_data(this.ctxPtr,_);}finally{t._free(n),t._free(_);}}}return r},q$1=(t,e)=>{class r{constructor(e){this.name="Pkcs5Pbkdf2",this.ctxPtr=void 0===e?t._vscf_pkcs5_pbkdf2_new():e;}static newAndUseCContext(e){return new r(t._vscf_pkcs5_pbkdf2_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_pkcs5_pbkdf2_delete(this.ctxPtr),this.ctxPtr=null);}set hmac(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("hmac",r,"Foundation.Mac",e.FoundationInterfaceTag.MAC,e.FoundationInterface),t._vscf_pkcs5_pbkdf2_release_hmac(this.ctxPtr),t._vscf_pkcs5_pbkdf2_use_hmac(this.ctxPtr,r.ctxPtr);}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_pkcs5_pbkdf2_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_pkcs5_pbkdf2_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface);const n=t._vscf_pkcs5_pbkdf2_restore_alg_info(this.ctxPtr,r.ctxPtr);e.FoundationError.handleStatusCode(n);}derive(e,r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",e),a$3.ensureNumber("keyLen",r);const n=e.length*e.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(e,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=r,o=t._vsc_buffer_new_with_capacity(i);try{t._vscf_pkcs5_pbkdf2_derive(this.ctxPtr,c,r,o);const e=t._vsc_buffer_bytes(o),n=t._vsc_buffer_len(o);return t.HEAPU8.slice(e,e+n)}finally{t._free(s),t._free(c),t._vsc_buffer_delete(o);}}reset(e,r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("salt",e),a$3.ensureNumber("iterationCount",r);const n=e.length*e.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(e,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);try{t._vscf_pkcs5_pbkdf2_reset(this.ctxPtr,c,r);}finally{t._free(s),t._free(c);}}setInfo(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("info",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);t._vsc_data(_,n,r);try{t._vscf_pkcs5_pbkdf2_set_info(this.ctxPtr,_);}finally{t._free(n),t._free(_);}}setupDefaults(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_pkcs5_pbkdf2_setup_defaults(this.ctxPtr);}}return r},J$1=(t,e)=>{class r{constructor(e){this.name="Pkcs5Pbes2",this.ctxPtr=void 0===e?t._vscf_pkcs5_pbes2_new():e;}static newAndUseCContext(e){return new r(t._vscf_pkcs5_pbes2_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_pkcs5_pbes2_delete(this.ctxPtr),this.ctxPtr=null);}set kdf(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("kdf",r,"Foundation.SaltedKdf",e.FoundationInterfaceTag.SALTED_KDF,e.FoundationInterface),t._vscf_pkcs5_pbes2_release_kdf(this.ctxPtr),t._vscf_pkcs5_pbes2_use_kdf(this.ctxPtr,r.ctxPtr);}set cipher(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("cipher",r,"Foundation.Cipher",e.FoundationInterfaceTag.CIPHER,e.FoundationInterface),t._vscf_pkcs5_pbes2_release_cipher(this.ctxPtr),t._vscf_pkcs5_pbes2_use_cipher(this.ctxPtr,r.ctxPtr);}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_pkcs5_pbes2_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_pkcs5_pbes2_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface);const n=t._vscf_pkcs5_pbes2_restore_alg_info(this.ctxPtr,r.ctxPtr);e.FoundationError.handleStatusCode(n);}encrypt(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",r);const n=r.length*r.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(r,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=this.encryptedLen(r.length),o=t._vsc_buffer_new_with_capacity(i);try{const r=t._vscf_pkcs5_pbes2_encrypt(this.ctxPtr,c,o);e.FoundationError.handleStatusCode(r);const n=t._vsc_buffer_bytes(o),_=t._vsc_buffer_len(o);return t.HEAPU8.slice(n,n+_)}finally{t._free(s),t._free(c),t._vsc_buffer_delete(o);}}encryptedLen(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("dataLen",e),t._vscf_pkcs5_pbes2_encrypted_len(this.ctxPtr,e)}preciseEncryptedLen(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("dataLen",e),t._vscf_pkcs5_pbes2_precise_encrypted_len(this.ctxPtr,e)}decrypt(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",r);const n=r.length*r.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(r,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=this.decryptedLen(r.length),o=t._vsc_buffer_new_with_capacity(i);try{const r=t._vscf_pkcs5_pbes2_decrypt(this.ctxPtr,c,o);e.FoundationError.handleStatusCode(r);const n=t._vsc_buffer_bytes(o),_=t._vsc_buffer_len(o);return t.HEAPU8.slice(n,n+_)}finally{t._free(s),t._free(c),t._vsc_buffer_delete(o);}}decryptedLen(e){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("dataLen",e),t._vscf_pkcs5_pbes2_decrypted_len(this.ctxPtr,e)}reset(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("pwd",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);t._vsc_data(_,n,r);try{t._vscf_pkcs5_pbes2_reset(this.ctxPtr,_);}finally{t._free(n),t._free(_);}}}return r},Q$1=(t,e)=>{class r{constructor(e){this.name="SeedEntropySource",this.ctxPtr=void 0===e?t._vscf_seed_entropy_source_new():e;}static newAndUseCContext(e){return new r(t._vscf_seed_entropy_source_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_seed_entropy_source_delete(this.ctxPtr),this.ctxPtr=null);}isStrong(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_seed_entropy_source_is_strong(this.ctxPtr))}gather(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("len",r);const n=r,s=t._vsc_buffer_new_with_capacity(n);try{const n=t._vscf_seed_entropy_source_gather(this.ctxPtr,r,s);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(s),c=t._vsc_buffer_len(s);return t.HEAPU8.slice(_,_+c)}finally{t._vsc_buffer_delete(s);}}resetSeed(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("seed",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);t._vsc_data(_,n,r);try{t._vscf_seed_entropy_source_reset_seed(this.ctxPtr,_);}finally{t._free(n),t._free(_);}}}return r},tt$1=(t,e)=>{class r{static get KEY_MATERIAL_LEN_MIN(){return 32}get KEY_MATERIAL_LEN_MIN(){return r.KEY_MATERIAL_LEN_MIN}static get KEY_MATERIAL_LEN_MAX(){return 512}get KEY_MATERIAL_LEN_MAX(){return r.KEY_MATERIAL_LEN_MAX}constructor(e){this.name="KeyMaterialRng",this.ctxPtr=void 0===e?t._vscf_key_material_rng_new():e;}static newAndUseCContext(e){return new r(t._vscf_key_material_rng_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_key_material_rng_delete(this.ctxPtr),this.ctxPtr=null);}random(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureNumber("dataLen",r);const n=r,s=t._vsc_buffer_new_with_capacity(n);try{const n=t._vscf_key_material_rng_random(this.ctxPtr,r,s);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(s),c=t._vsc_buffer_len(s);return t.HEAPU8.slice(_,_+c)}finally{t._vsc_buffer_delete(s);}}reseed(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_key_material_rng_reseed(this.ctxPtr);e.FoundationError.handleStatusCode(r);}resetKeyMaterial(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("keyMaterial",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);t._vsc_data(_,n,r);try{t._vscf_key_material_rng_reset_key_material(this.ctxPtr,_);}finally{t._free(n),t._free(_);}}}return r},et$1=(t,e)=>{class r{constructor(e){this.name="RawPublicKey",this.ctxPtr=void 0===e?t._vscf_raw_public_key_new():e;}static newAndUseCContext(e){return new r(t._vscf_raw_public_key_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_raw_public_key_delete(this.ctxPtr),this.ctxPtr=null);}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_raw_public_key_alg_id(this.ctxPtr)}algInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_raw_public_key_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}len(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_raw_public_key_len(this.ctxPtr)}bitlen(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_raw_public_key_bitlen(this.ctxPtr)}implTag(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_raw_public_key_impl_tag(this.ctxPtr)}isValid(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_raw_public_key_is_valid(this.ctxPtr))}data(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=t._vsc_data_ctx_size(),r=t._malloc(e);try{t._vscf_raw_public_key_data(r,this.ctxPtr);const e=t._vsc_data_len(r),n=t._vsc_data_bytes(r);return t.HEAPU8.slice(n,n+e)}finally{t._free(r);}}}return r},rt$1=(t,e)=>{class r{constructor(e){this.name="RawPrivateKey",this.ctxPtr=void 0===e?t._vscf_raw_private_key_new():e;}static newAndUseCContext(e){return new r(t._vscf_raw_private_key_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_raw_private_key_delete(this.ctxPtr),this.ctxPtr=null);}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_raw_private_key_alg_id(this.ctxPtr)}algInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_raw_private_key_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}len(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_raw_private_key_len(this.ctxPtr)}bitlen(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_raw_private_key_bitlen(this.ctxPtr)}implTag(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_raw_private_key_impl_tag(this.ctxPtr)}isValid(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_raw_private_key_is_valid(this.ctxPtr))}extractPublicKey(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_raw_private_key_extract_public_key(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}data(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=t._vsc_data_ctx_size(),r=t._malloc(e);try{t._vscf_raw_private_key_data(r,this.ctxPtr);const e=t._vsc_data_len(r),n=t._vsc_data_bytes(r);return t.HEAPU8.slice(n,n+e)}finally{t._free(r);}}hasPublicKey(){let e;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),!!(e=t._vscf_raw_private_key_has_public_key(this.ctxPtr))}setPublicKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("rawPublicKey",r,e.RawPublicKey),t._vscf_raw_private_key_set_public_key(this.ctxPtr,r.ctxPtr);}getPublicKey(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_raw_private_key_get_public_key(this.ctxPtr),e.RawPublicKey.newAndUseCContext(r)}}return r},nt$1=(t,e)=>{class r{constructor(e){this.name="Pkcs8Serializer",this.ctxPtr=void 0===e?t._vscf_pkcs8_serializer_new():e;}static newAndUseCContext(e){return new r(t._vscf_pkcs8_serializer_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_pkcs8_serializer_delete(this.ctxPtr),this.ctxPtr=null);}set asn1Writer(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("asn1Writer",r,"Foundation.Asn1Writer",e.FoundationInterfaceTag.ASN1_WRITER,e.FoundationInterface),t._vscf_pkcs8_serializer_release_asn1_writer(this.ctxPtr),t._vscf_pkcs8_serializer_use_asn1_writer(this.ctxPtr,r.ctxPtr);}serializedPublicKeyLen(r){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("publicKey",r,e.RawPublicKey),t._vscf_pkcs8_serializer_serialized_public_key_len(this.ctxPtr,r.ctxPtr)}serializePublicKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("publicKey",r,e.RawPublicKey);const n=this.serializedPublicKeyLen(r),s=t._vsc_buffer_new_with_capacity(n);try{const n=t._vscf_pkcs8_serializer_serialize_public_key(this.ctxPtr,r.ctxPtr,s);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(s),c=t._vsc_buffer_len(s);return t.HEAPU8.slice(_,_+c)}finally{t._vsc_buffer_delete(s);}}serializedPrivateKeyLen(r){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("privateKey",r,e.RawPrivateKey),t._vscf_pkcs8_serializer_serialized_private_key_len(this.ctxPtr,r.ctxPtr)}serializePrivateKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("privateKey",r,e.RawPrivateKey);const n=this.serializedPrivateKeyLen(r),s=t._vsc_buffer_new_with_capacity(n);try{const n=t._vscf_pkcs8_serializer_serialize_private_key(this.ctxPtr,r.ctxPtr,s);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(s),c=t._vsc_buffer_len(s);return t.HEAPU8.slice(_,_+c)}finally{t._vsc_buffer_delete(s);}}setupDefaults(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_pkcs8_serializer_setup_defaults(this.ctxPtr);}serializePublicKeyInplace(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("publicKey",r,e.RawPublicKey);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_pkcs8_serializer_serialize_public_key_inplace(this.ctxPtr,r.ctxPtr,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),_}finally{t._free(s);}}serializePrivateKeyInplace(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("privateKey",r,e.RawPrivateKey);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_pkcs8_serializer_serialize_private_key_inplace(this.ctxPtr,r.ctxPtr,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),_}finally{t._free(s);}}}return r},st$1=(t,e)=>{class r{constructor(e){this.name="Sec1Serializer",this.ctxPtr=void 0===e?t._vscf_sec1_serializer_new():e;}static newAndUseCContext(e){return new r(t._vscf_sec1_serializer_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_sec1_serializer_delete(this.ctxPtr),this.ctxPtr=null);}set asn1Writer(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("asn1Writer",r,"Foundation.Asn1Writer",e.FoundationInterfaceTag.ASN1_WRITER,e.FoundationInterface),t._vscf_sec1_serializer_release_asn1_writer(this.ctxPtr),t._vscf_sec1_serializer_use_asn1_writer(this.ctxPtr,r.ctxPtr);}serializedPublicKeyLen(r){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("publicKey",r,e.RawPublicKey),t._vscf_sec1_serializer_serialized_public_key_len(this.ctxPtr,r.ctxPtr)}serializePublicKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("publicKey",r,e.RawPublicKey);const n=this.serializedPublicKeyLen(r),s=t._vsc_buffer_new_with_capacity(n);try{const n=t._vscf_sec1_serializer_serialize_public_key(this.ctxPtr,r.ctxPtr,s);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(s),c=t._vsc_buffer_len(s);return t.HEAPU8.slice(_,_+c)}finally{t._vsc_buffer_delete(s);}}serializedPrivateKeyLen(r){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("privateKey",r,e.RawPrivateKey),t._vscf_sec1_serializer_serialized_private_key_len(this.ctxPtr,r.ctxPtr)}serializePrivateKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("privateKey",r,e.RawPrivateKey);const n=this.serializedPrivateKeyLen(r),s=t._vsc_buffer_new_with_capacity(n);try{const n=t._vscf_sec1_serializer_serialize_private_key(this.ctxPtr,r.ctxPtr,s);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(s),c=t._vsc_buffer_len(s);return t.HEAPU8.slice(_,_+c)}finally{t._vsc_buffer_delete(s);}}setupDefaults(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_sec1_serializer_setup_defaults(this.ctxPtr);}serializePublicKeyInplace(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("publicKey",r,e.RawPublicKey);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_sec1_serializer_serialize_public_key_inplace(this.ctxPtr,r.ctxPtr,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),_}finally{t._free(s);}}serializePrivateKeyInplace(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("privateKey",r,e.RawPrivateKey);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_sec1_serializer_serialize_private_key_inplace(this.ctxPtr,r.ctxPtr,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),_}finally{t._free(s);}}}return r},_t$1=(t,e)=>{class r{constructor(e){this.name="KeyAsn1Serializer",this.ctxPtr=void 0===e?t._vscf_key_asn1_serializer_new():e;}static newAndUseCContext(e){return new r(t._vscf_key_asn1_serializer_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_key_asn1_serializer_delete(this.ctxPtr),this.ctxPtr=null);}set asn1Writer(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("asn1Writer",r,"Foundation.Asn1Writer",e.FoundationInterfaceTag.ASN1_WRITER,e.FoundationInterface),t._vscf_key_asn1_serializer_release_asn1_writer(this.ctxPtr),t._vscf_key_asn1_serializer_use_asn1_writer(this.ctxPtr,r.ctxPtr);}serializedPublicKeyLen(r){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("publicKey",r,e.RawPublicKey),t._vscf_key_asn1_serializer_serialized_public_key_len(this.ctxPtr,r.ctxPtr)}serializePublicKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("publicKey",r,e.RawPublicKey);const n=this.serializedPublicKeyLen(r),s=t._vsc_buffer_new_with_capacity(n);try{const n=t._vscf_key_asn1_serializer_serialize_public_key(this.ctxPtr,r.ctxPtr,s);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(s),c=t._vsc_buffer_len(s);return t.HEAPU8.slice(_,_+c)}finally{t._vsc_buffer_delete(s);}}serializedPrivateKeyLen(r){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("privateKey",r,e.RawPrivateKey),t._vscf_key_asn1_serializer_serialized_private_key_len(this.ctxPtr,r.ctxPtr)}serializePrivateKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("privateKey",r,e.RawPrivateKey);const n=this.serializedPrivateKeyLen(r),s=t._vsc_buffer_new_with_capacity(n);try{const n=t._vscf_key_asn1_serializer_serialize_private_key(this.ctxPtr,r.ctxPtr,s);e.FoundationError.handleStatusCode(n);const _=t._vsc_buffer_bytes(s),c=t._vsc_buffer_len(s);return t.HEAPU8.slice(_,_+c)}finally{t._vsc_buffer_delete(s);}}setupDefaults(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_key_asn1_serializer_setup_defaults(this.ctxPtr);}serializePublicKeyInplace(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("publicKey",r,e.RawPublicKey);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_key_asn1_serializer_serialize_public_key_inplace(this.ctxPtr,r.ctxPtr,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),_}finally{t._free(s);}}serializePrivateKeyInplace(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("privateKey",r,e.RawPrivateKey);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_key_asn1_serializer_serialize_private_key_inplace(this.ctxPtr,r.ctxPtr,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),_}finally{t._free(s);}}}return r},ct$1=(t,e)=>{class r{constructor(e){this.name="KeyAsn1Deserializer",this.ctxPtr=void 0===e?t._vscf_key_asn1_deserializer_new():e;}static newAndUseCContext(e){return new r(t._vscf_key_asn1_deserializer_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_key_asn1_deserializer_delete(this.ctxPtr),this.ctxPtr=null);}set asn1Reader(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("asn1Reader",r,"Foundation.Asn1Reader",e.FoundationInterfaceTag.ASN1_READER,e.FoundationInterface),t._vscf_key_asn1_deserializer_release_asn1_reader(this.ctxPtr),t._vscf_key_asn1_deserializer_use_asn1_reader(this.ctxPtr,r.ctxPtr);}deserializePublicKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("publicKeyData",r);const n=r.length*r.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(r,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=t._vscf_error_ctx_size(),o=t._malloc(i);let l;t._vscf_error_reset(o);try{l=t._vscf_key_asn1_deserializer_deserialize_public_key(this.ctxPtr,c,o);const r=t._vscf_error_status(o);return e.FoundationError.handleStatusCode(r),e.RawPublicKey.newAndTakeCContext(l)}finally{t._free(s),t._free(c),t._free(o);}}deserializePrivateKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("privateKeyData",r);const n=r.length*r.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(r,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=t._vscf_error_ctx_size(),o=t._malloc(i);let l;t._vscf_error_reset(o);try{l=t._vscf_key_asn1_deserializer_deserialize_private_key(this.ctxPtr,c,o);const r=t._vscf_error_status(o);return e.FoundationError.handleStatusCode(r),e.RawPrivateKey.newAndTakeCContext(l)}finally{t._free(s),t._free(c),t._free(o);}}setupDefaults(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_key_asn1_deserializer_setup_defaults(this.ctxPtr);}deserializePublicKeyInplace(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_error_ctx_size(),n=t._malloc(r);let s;t._vscf_error_reset(n);try{s=t._vscf_key_asn1_deserializer_deserialize_public_key_inplace(this.ctxPtr,n);const r=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(r),e.RawPublicKey.newAndTakeCContext(s)}finally{t._free(n);}}deserializePrivateKeyInplace(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_error_ctx_size(),n=t._malloc(r);let s;t._vscf_error_reset(n);try{s=t._vscf_key_asn1_deserializer_deserialize_private_key_inplace(this.ctxPtr,n);const r=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(r),e.RawPrivateKey.newAndTakeCContext(s)}finally{t._free(n);}}}return r},at$1=(t,e)=>{class r{static get CAN_IMPORT_PUBLIC_KEY(){return !0}get CAN_IMPORT_PUBLIC_KEY(){return r.CAN_IMPORT_PUBLIC_KEY}static get CAN_EXPORT_PUBLIC_KEY(){return !0}get CAN_EXPORT_PUBLIC_KEY(){return r.CAN_EXPORT_PUBLIC_KEY}static get CAN_IMPORT_PRIVATE_KEY(){return !0}get CAN_IMPORT_PRIVATE_KEY(){return r.CAN_IMPORT_PRIVATE_KEY}static get CAN_EXPORT_PRIVATE_KEY(){return !0}get CAN_EXPORT_PRIVATE_KEY(){return r.CAN_EXPORT_PRIVATE_KEY}constructor(e){this.name="Ed25519",this.ctxPtr=void 0===e?t._vscf_ed25519_new():e;}static newAndUseCContext(e){return new r(t._vscf_ed25519_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_ed25519_delete(this.ctxPtr),this.ctxPtr=null);}set random(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("random",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_ed25519_release_random(this.ctxPtr),t._vscf_ed25519_use_random(this.ctxPtr,r.ctxPtr);}set ecies(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("ecies",r,e.Ecies),t._vscf_ed25519_release_ecies(this.ctxPtr),t._vscf_ed25519_use_ecies(this.ctxPtr,r.ctxPtr);}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ed25519_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_ed25519_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface);const n=t._vscf_ed25519_restore_alg_info(this.ctxPtr,r.ctxPtr);e.FoundationError.handleStatusCode(n);}generateEphemeralKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("key",r,"Foundation.Key",e.FoundationInterfaceTag.KEY,e.FoundationInterface);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_ed25519_generate_ephemeral_key(this.ctxPtr,r.ctxPtr,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(s);}}importPublicKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("rawKey",r,e.RawPublicKey);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_ed25519_import_public_key(this.ctxPtr,r.ctxPtr,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(s);}}exportPublicKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_ed25519_export_public_key(this.ctxPtr,r.ctxPtr,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),e.RawPublicKey.newAndTakeCContext(_)}finally{t._free(s);}}importPrivateKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("rawKey",r,e.RawPrivateKey);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_ed25519_import_private_key(this.ctxPtr,r.ctxPtr,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(s);}}exportPrivateKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_ed25519_export_private_key(this.ctxPtr,r.ctxPtr,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),e.RawPrivateKey.newAndTakeCContext(_)}finally{t._free(s);}}canEncrypt(r,n){let s;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$3.ensureNumber("dataLen",n),!!(s=t._vscf_ed25519_can_encrypt(this.ctxPtr,r.ctxPtr,n))}encryptedLen(r,n){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$3.ensureNumber("dataLen",n),t._vscf_ed25519_encrypted_len(this.ctxPtr,r.ctxPtr,n)}encrypt(r,n){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$3.ensureByteArray("data",n);const s=n.length*n.BYTES_PER_ELEMENT,_=t._malloc(s);t.HEAP8.set(n,_);const c=t._vsc_data_ctx_size(),i=t._malloc(c);t._vsc_data(i,_,s);const o=this.encryptedLen(r,n.length),l=t._vsc_buffer_new_with_capacity(o);try{const n=t._vscf_ed25519_encrypt(this.ctxPtr,r.ctxPtr,i,l);e.FoundationError.handleStatusCode(n);const s=t._vsc_buffer_bytes(l),c=t._vsc_buffer_len(l);return t.HEAPU8.slice(s,s+c)}finally{t._free(_),t._free(i),t._vsc_buffer_delete(l);}}canDecrypt(r,n){let s;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$3.ensureNumber("dataLen",n),!!(s=t._vscf_ed25519_can_decrypt(this.ctxPtr,r.ctxPtr,n))}decryptedLen(r,n){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$3.ensureNumber("dataLen",n),t._vscf_ed25519_decrypted_len(this.ctxPtr,r.ctxPtr,n)}decrypt(r,n){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$3.ensureByteArray("data",n);const s=n.length*n.BYTES_PER_ELEMENT,_=t._malloc(s);t.HEAP8.set(n,_);const c=t._vsc_data_ctx_size(),i=t._malloc(c);t._vsc_data(i,_,s);const o=this.decryptedLen(r,n.length),l=t._vsc_buffer_new_with_capacity(o);try{const n=t._vscf_ed25519_decrypt(this.ctxPtr,r.ctxPtr,i,l);e.FoundationError.handleStatusCode(n);const s=t._vsc_buffer_bytes(l),c=t._vsc_buffer_len(l);return t.HEAPU8.slice(s,s+c)}finally{t._free(_),t._free(i),t._vsc_buffer_delete(l);}}canSign(r){let n;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),!!(n=t._vscf_ed25519_can_sign(this.ctxPtr,r.ctxPtr))}signatureLen(r){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("key",r,"Foundation.Key",e.FoundationInterfaceTag.KEY,e.FoundationInterface),t._vscf_ed25519_signature_len(this.ctxPtr,r.ctxPtr)}signHash(r,n,s){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$3.ensureNumber("hashId",n),a$3.ensureByteArray("digest",s);const _=s.length*s.BYTES_PER_ELEMENT,c=t._malloc(_);t.HEAP8.set(s,c);const i=t._vsc_data_ctx_size(),o=t._malloc(i);t._vsc_data(o,c,_);const l=this.signatureLen(r),u=t._vsc_buffer_new_with_capacity(l);try{const s=t._vscf_ed25519_sign_hash(this.ctxPtr,r.ctxPtr,n,o,u);e.FoundationError.handleStatusCode(s);const _=t._vsc_buffer_bytes(u),a=t._vsc_buffer_len(u);return t.HEAPU8.slice(_,_+a)}finally{t._free(c),t._free(o),t._vsc_buffer_delete(u);}}canVerify(r){let n;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),!!(n=t._vscf_ed25519_can_verify(this.ctxPtr,r.ctxPtr))}verifyHash(r,n,s,_){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$3.ensureNumber("hashId",n),a$3.ensureByteArray("digest",s),a$3.ensureByteArray("signature",_);const c=s.length*s.BYTES_PER_ELEMENT,i=t._malloc(c);t.HEAP8.set(s,i);const o=t._vsc_data_ctx_size(),l=t._malloc(o);t._vsc_data(l,i,c);const u=_.length*_.BYTES_PER_ELEMENT,f=t._malloc(u);t.HEAP8.set(_,f);const p=t._vsc_data_ctx_size(),d=t._malloc(p);let h;t._vsc_data(d,f,u);try{return !!(h=t._vscf_ed25519_verify_hash(this.ctxPtr,r.ctxPtr,n,l,d))}finally{t._free(i),t._free(l),t._free(f),t._free(d);}}computeSharedKey(r,n){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$3.ensureImplementInterface("privateKey",n,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface);const s=this.sharedKeyLen(n),_=t._vsc_buffer_new_with_capacity(s);try{const s=t._vscf_ed25519_compute_shared_key(this.ctxPtr,r.ctxPtr,n.ctxPtr,_);e.FoundationError.handleStatusCode(s);const c=t._vsc_buffer_bytes(_),a=t._vsc_buffer_len(_);return t.HEAPU8.slice(c,c+a)}finally{t._vsc_buffer_delete(_);}}sharedKeyLen(r){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("key",r,"Foundation.Key",e.FoundationInterfaceTag.KEY,e.FoundationInterface),t._vscf_ed25519_shared_key_len(this.ctxPtr,r.ctxPtr)}setupDefaults(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_ed25519_setup_defaults(this.ctxPtr);e.FoundationError.handleStatusCode(r);}generateKey(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_error_ctx_size(),n=t._malloc(r);let s;t._vscf_error_reset(n);try{s=t._vscf_ed25519_generate_key(this.ctxPtr,n);const r=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(r),e.FoundationInterface.newAndTakeCContext(s)}finally{t._free(n);}}}return r},it$1=(t,e)=>{class r{static get CAN_IMPORT_PUBLIC_KEY(){return !0}get CAN_IMPORT_PUBLIC_KEY(){return r.CAN_IMPORT_PUBLIC_KEY}static get CAN_EXPORT_PUBLIC_KEY(){return !0}get CAN_EXPORT_PUBLIC_KEY(){return r.CAN_EXPORT_PUBLIC_KEY}static get CAN_IMPORT_PRIVATE_KEY(){return !0}get CAN_IMPORT_PRIVATE_KEY(){return r.CAN_IMPORT_PRIVATE_KEY}static get CAN_EXPORT_PRIVATE_KEY(){return !0}get CAN_EXPORT_PRIVATE_KEY(){return r.CAN_EXPORT_PRIVATE_KEY}constructor(e){this.name="Curve25519",this.ctxPtr=void 0===e?t._vscf_curve25519_new():e;}static newAndUseCContext(e){return new r(t._vscf_curve25519_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_curve25519_delete(this.ctxPtr),this.ctxPtr=null);}set random(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("random",r,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface),t._vscf_curve25519_release_random(this.ctxPtr),t._vscf_curve25519_use_random(this.ctxPtr,r.ctxPtr);}set ecies(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("ecies",r,e.Ecies),t._vscf_curve25519_release_ecies(this.ctxPtr),t._vscf_curve25519_use_ecies(this.ctxPtr,r.ctxPtr);}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_curve25519_alg_id(this.ctxPtr)}produceAlgInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_curve25519_produce_alg_info(this.ctxPtr),e.FoundationInterface.newAndTakeCContext(r)}restoreAlgInfo(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface);const n=t._vscf_curve25519_restore_alg_info(this.ctxPtr,r.ctxPtr);e.FoundationError.handleStatusCode(n);}generateEphemeralKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("key",r,"Foundation.Key",e.FoundationInterfaceTag.KEY,e.FoundationInterface);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_curve25519_generate_ephemeral_key(this.ctxPtr,r.ctxPtr,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(s);}}importPublicKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("rawKey",r,e.RawPublicKey);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_curve25519_import_public_key(this.ctxPtr,r.ctxPtr,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(s);}}exportPublicKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_curve25519_export_public_key(this.ctxPtr,r.ctxPtr,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),e.RawPublicKey.newAndTakeCContext(_)}finally{t._free(s);}}importPrivateKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("rawKey",r,e.RawPrivateKey);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_curve25519_import_private_key(this.ctxPtr,r.ctxPtr,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),e.FoundationInterface.newAndTakeCContext(_)}finally{t._free(s);}}exportPrivateKey(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface);const n=t._vscf_error_ctx_size(),s=t._malloc(n);let _;t._vscf_error_reset(s);try{_=t._vscf_curve25519_export_private_key(this.ctxPtr,r.ctxPtr,s);const n=t._vscf_error_status(s);return e.FoundationError.handleStatusCode(n),e.RawPrivateKey.newAndTakeCContext(_)}finally{t._free(s);}}canEncrypt(r,n){let s;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$3.ensureNumber("dataLen",n),!!(s=t._vscf_curve25519_can_encrypt(this.ctxPtr,r.ctxPtr,n))}encryptedLen(r,n){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$3.ensureNumber("dataLen",n),t._vscf_curve25519_encrypted_len(this.ctxPtr,r.ctxPtr,n)}encrypt(r,n){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$3.ensureByteArray("data",n);const s=n.length*n.BYTES_PER_ELEMENT,_=t._malloc(s);t.HEAP8.set(n,_);const c=t._vsc_data_ctx_size(),i=t._malloc(c);t._vsc_data(i,_,s);const o=this.encryptedLen(r,n.length),l=t._vsc_buffer_new_with_capacity(o);try{const n=t._vscf_curve25519_encrypt(this.ctxPtr,r.ctxPtr,i,l);e.FoundationError.handleStatusCode(n);const s=t._vsc_buffer_bytes(l),c=t._vsc_buffer_len(l);return t.HEAPU8.slice(s,s+c)}finally{t._free(_),t._free(i),t._vsc_buffer_delete(l);}}canDecrypt(r,n){let s;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$3.ensureNumber("dataLen",n),!!(s=t._vscf_curve25519_can_decrypt(this.ctxPtr,r.ctxPtr,n))}decryptedLen(r,n){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$3.ensureNumber("dataLen",n),t._vscf_curve25519_decrypted_len(this.ctxPtr,r.ctxPtr,n)}decrypt(r,n){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("privateKey",r,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface),a$3.ensureByteArray("data",n);const s=n.length*n.BYTES_PER_ELEMENT,_=t._malloc(s);t.HEAP8.set(n,_);const c=t._vsc_data_ctx_size(),i=t._malloc(c);t._vsc_data(i,_,s);const o=this.decryptedLen(r,n.length),l=t._vsc_buffer_new_with_capacity(o);try{const n=t._vscf_curve25519_decrypt(this.ctxPtr,r.ctxPtr,i,l);e.FoundationError.handleStatusCode(n);const s=t._vsc_buffer_bytes(l),c=t._vsc_buffer_len(l);return t.HEAPU8.slice(s,s+c)}finally{t._free(_),t._free(i),t._vsc_buffer_delete(l);}}computeSharedKey(r,n){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("publicKey",r,"Foundation.PublicKey",e.FoundationInterfaceTag.PUBLIC_KEY,e.FoundationInterface),a$3.ensureImplementInterface("privateKey",n,"Foundation.PrivateKey",e.FoundationInterfaceTag.PRIVATE_KEY,e.FoundationInterface);const s=this.sharedKeyLen(n),_=t._vsc_buffer_new_with_capacity(s);try{const s=t._vscf_curve25519_compute_shared_key(this.ctxPtr,r.ctxPtr,n.ctxPtr,_);e.FoundationError.handleStatusCode(s);const c=t._vsc_buffer_bytes(_),a=t._vsc_buffer_len(_);return t.HEAPU8.slice(c,c+a)}finally{t._vsc_buffer_delete(_);}}sharedKeyLen(r){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("key",r,"Foundation.Key",e.FoundationInterfaceTag.KEY,e.FoundationInterface),t._vscf_curve25519_shared_key_len(this.ctxPtr,r.ctxPtr)}setupDefaults(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_curve25519_setup_defaults(this.ctxPtr);e.FoundationError.handleStatusCode(r);}generateKey(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_error_ctx_size(),n=t._malloc(r);let s;t._vscf_error_reset(n);try{s=t._vscf_curve25519_generate_key(this.ctxPtr,n);const r=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(r),e.FoundationInterface.newAndTakeCContext(s)}finally{t._free(n);}}}return r},ot$1=(t,e)=>{class r{constructor(e){this.name="SimpleAlgInfo",this.ctxPtr=void 0===e?t._vscf_simple_alg_info_new():e;}static newAndUseCContext(e){return new r(t._vscf_simple_alg_info_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_simple_alg_info_delete(this.ctxPtr),this.ctxPtr=null);}static newWithAlgId(e){let n;return a$3.ensureNumber("algId",e),n=t._vscf_simple_alg_info_new_with_alg_id(e),r.newAndTakeCContext(n)}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_simple_alg_info_alg_id(this.ctxPtr)}}return r},lt$1=(t,e)=>{class r{constructor(e){this.name="HashBasedAlgInfo",this.ctxPtr=void 0===e?t._vscf_hash_based_alg_info_new():e;}static newAndUseCContext(e){return new r(t._vscf_hash_based_alg_info_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_hash_based_alg_info_delete(this.ctxPtr),this.ctxPtr=null);}static newWithMembers(n,s){let _;return a$3.ensureNumber("algId",n),a$3.ensureImplementInterface("hashAlgInfo",s,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),_=t._vscf_hash_based_alg_info_new_with_members(n,s.ctxPtr),r.newAndTakeCContext(_)}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_hash_based_alg_info_alg_id(this.ctxPtr)}hashAlgInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_hash_based_alg_info_hash_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}}return r},ut$1=(t,e)=>{class r{constructor(e){this.name="CipherAlgInfo",this.ctxPtr=void 0===e?t._vscf_cipher_alg_info_new():e;}static newAndUseCContext(e){return new r(t._vscf_cipher_alg_info_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_cipher_alg_info_delete(this.ctxPtr),this.ctxPtr=null);}static newWithMembers(e,n){a$3.ensureNumber("algId",e),a$3.ensureByteArray("nonce",n);const s=n.length*n.BYTES_PER_ELEMENT,_=t._malloc(s);t.HEAP8.set(n,_);const c=t._vsc_data_ctx_size(),i=t._malloc(c);let o;t._vsc_data(i,_,s);try{return o=t._vscf_cipher_alg_info_new_with_members(e,i),r.newAndTakeCContext(o)}finally{t._free(_),t._free(i);}}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_cipher_alg_info_alg_id(this.ctxPtr)}nonce(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=t._vsc_data_ctx_size(),r=t._malloc(e);try{t._vscf_cipher_alg_info_nonce(r,this.ctxPtr);const e=t._vsc_data_len(r),n=t._vsc_data_bytes(r);return t.HEAPU8.slice(n,n+e)}finally{t._free(r);}}}return r},ft$1=(t,e)=>{class r{constructor(e){this.name="SaltedKdfAlgInfo",this.ctxPtr=void 0===e?t._vscf_salted_kdf_alg_info_new():e;}static newAndUseCContext(e){return new r(t._vscf_salted_kdf_alg_info_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_salted_kdf_alg_info_delete(this.ctxPtr),this.ctxPtr=null);}static newWithMembers(n,s,_,c){a$3.ensureNumber("algId",n),a$3.ensureImplementInterface("hashAlgInfo",s,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),a$3.ensureByteArray("salt",_),a$3.ensureNumber("iterationCount",c);const i=_.length*_.BYTES_PER_ELEMENT,o=t._malloc(i);t.HEAP8.set(_,o);const l=t._vsc_data_ctx_size(),u=t._malloc(l);let f;t._vsc_data(u,o,i);try{return f=t._vscf_salted_kdf_alg_info_new_with_members(n,s.ctxPtr,u,c),r.newAndTakeCContext(f)}finally{t._free(o),t._free(u);}}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_salted_kdf_alg_info_alg_id(this.ctxPtr)}hashAlgInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_salted_kdf_alg_info_hash_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}salt(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const e=t._vsc_data_ctx_size(),r=t._malloc(e);try{t._vscf_salted_kdf_alg_info_salt(r,this.ctxPtr);const e=t._vsc_data_len(r),n=t._vsc_data_bytes(r);return t.HEAPU8.slice(n,n+e)}finally{t._free(r);}}iterationCount(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_salted_kdf_alg_info_iteration_count(this.ctxPtr)}}return r},pt$1=(t,e)=>{class r{constructor(e){this.name="PbeAlgInfo",this.ctxPtr=void 0===e?t._vscf_pbe_alg_info_new():e;}static newAndUseCContext(e){return new r(t._vscf_pbe_alg_info_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_pbe_alg_info_delete(this.ctxPtr),this.ctxPtr=null);}static newWithMembers(n,s,_){let c;return a$3.ensureNumber("algId",n),a$3.ensureImplementInterface("kdfAlgInfo",s,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),a$3.ensureImplementInterface("cipherAlgInfo",_,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),c=t._vscf_pbe_alg_info_new_with_members(n,s.ctxPtr,_.ctxPtr),r.newAndTakeCContext(c)}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_pbe_alg_info_alg_id(this.ctxPtr)}kdfAlgInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_pbe_alg_info_kdf_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}cipherAlgInfo(){let r;return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),r=t._vscf_pbe_alg_info_cipher_alg_info(this.ctxPtr),e.FoundationInterface.newAndUseCContext(r)}}return r},dt$1=(t,e)=>{class r{constructor(e){this.name="EccAlgInfo",this.ctxPtr=void 0===e?t._vscf_ecc_alg_info_new():e;}static newAndUseCContext(e){return new r(t._vscf_ecc_alg_info_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_ecc_alg_info_delete(this.ctxPtr),this.ctxPtr=null);}static newWithMembers(e,n,s){let _;return a$3.ensureNumber("algId",e),a$3.ensureNumber("keyId",n),a$3.ensureNumber("domainId",s),_=t._vscf_ecc_alg_info_new_with_members(e,n,s),r.newAndTakeCContext(_)}algId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecc_alg_info_alg_id(this.ctxPtr)}keyId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecc_alg_info_key_id(this.ctxPtr)}domainId(){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_ecc_alg_info_domain_id(this.ctxPtr)}}return r},ht$1=(t,e)=>{class r{constructor(e){this.name="AlgInfoDerSerializer",this.ctxPtr=void 0===e?t._vscf_alg_info_der_serializer_new():e;}static newAndUseCContext(e){return new r(t._vscf_alg_info_der_serializer_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_alg_info_der_serializer_delete(this.ctxPtr),this.ctxPtr=null);}set asn1Writer(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("asn1Writer",r,"Foundation.Asn1Writer",e.FoundationInterfaceTag.ASN1_WRITER,e.FoundationInterface),t._vscf_alg_info_der_serializer_release_asn1_writer(this.ctxPtr),t._vscf_alg_info_der_serializer_use_asn1_writer(this.ctxPtr,r.ctxPtr);}serializedLen(r){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),t._vscf_alg_info_der_serializer_serialized_len(this.ctxPtr,r.ctxPtr)}serialize(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface);const n=this.serializedLen(r),s=t._vsc_buffer_new_with_capacity(n);try{t._vscf_alg_info_der_serializer_serialize(this.ctxPtr,r.ctxPtr,s);const e=t._vsc_buffer_bytes(s),n=t._vsc_buffer_len(s);return t.HEAPU8.slice(e,e+n)}finally{t._vsc_buffer_delete(s);}}setupDefaults(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_alg_info_der_serializer_setup_defaults(this.ctxPtr);}serializeInplace(r){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),t._vscf_alg_info_der_serializer_serialize_inplace(this.ctxPtr,r.ctxPtr)}}return r},yt$1=(t,e)=>{class r{constructor(e){this.name="AlgInfoDerDeserializer",this.ctxPtr=void 0===e?t._vscf_alg_info_der_deserializer_new():e;}static newAndUseCContext(e){return new r(t._vscf_alg_info_der_deserializer_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_alg_info_der_deserializer_delete(this.ctxPtr),this.ctxPtr=null);}set asn1Reader(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("asn1Reader",r,"Foundation.Asn1Reader",e.FoundationInterfaceTag.ASN1_READER,e.FoundationInterface),t._vscf_alg_info_der_deserializer_release_asn1_reader(this.ctxPtr),t._vscf_alg_info_der_deserializer_use_asn1_reader(this.ctxPtr,r.ctxPtr);}deserialize(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",r);const n=r.length*r.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(r,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=t._vscf_error_ctx_size(),o=t._malloc(i);let l;t._vscf_error_reset(o);try{l=t._vscf_alg_info_der_deserializer_deserialize(this.ctxPtr,c,o);const r=t._vscf_error_status(o);return e.FoundationError.handleStatusCode(r),e.FoundationInterface.newAndTakeCContext(l)}finally{t._free(s),t._free(c),t._free(o);}}setupDefaults(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_alg_info_der_deserializer_setup_defaults(this.ctxPtr);}deserializeInplace(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr);const r=t._vscf_error_ctx_size(),n=t._malloc(r);let s;t._vscf_error_reset(n);try{s=t._vscf_alg_info_der_deserializer_deserialize_inplace(this.ctxPtr,n);const r=t._vscf_error_status(n);return e.FoundationError.handleStatusCode(r),e.FoundationInterface.newAndTakeCContext(s)}finally{t._free(n);}}}return r},vt$1=(t,e)=>{class r{static get PREFIX_LEN(){return 32}get PREFIX_LEN(){return r.PREFIX_LEN}constructor(e){this.name="MessageInfoDerSerializer",this.ctxPtr=void 0===e?t._vscf_message_info_der_serializer_new():e;}static newAndUseCContext(e){return new r(t._vscf_message_info_der_serializer_shallow_copy(e))}static newAndTakeCContext(t){return new r(t)}delete(){void 0!==this.ctxPtr&&null!==this.ctxPtr&&(t._vscf_message_info_der_serializer_delete(this.ctxPtr),this.ctxPtr=null);}set asn1Reader(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("asn1Reader",r,"Foundation.Asn1Reader",e.FoundationInterfaceTag.ASN1_READER,e.FoundationInterface),t._vscf_message_info_der_serializer_release_asn1_reader(this.ctxPtr),t._vscf_message_info_der_serializer_use_asn1_reader(this.ctxPtr,r.ctxPtr);}set asn1Writer(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureImplementInterface("asn1Writer",r,"Foundation.Asn1Writer",e.FoundationInterfaceTag.ASN1_WRITER,e.FoundationInterface),t._vscf_message_info_der_serializer_release_asn1_writer(this.ctxPtr),t._vscf_message_info_der_serializer_use_asn1_writer(this.ctxPtr,r.ctxPtr);}serializedLen(r){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("messageInfo",r,e.MessageInfo),t._vscf_message_info_der_serializer_serialized_len(this.ctxPtr,r.ctxPtr)}serialize(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("messageInfo",r,e.MessageInfo);const n=this.serializedLen(r),s=t._vsc_buffer_new_with_capacity(n);try{t._vscf_message_info_der_serializer_serialize(this.ctxPtr,r.ctxPtr,s);const e=t._vsc_buffer_bytes(s),n=t._vsc_buffer_len(s);return t.HEAPU8.slice(e,e+n)}finally{t._vsc_buffer_delete(s);}}readPrefix(e){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);let c;t._vsc_data(_,n,r);try{return c=t._vscf_message_info_der_serializer_read_prefix(this.ctxPtr,_)}finally{t._free(n),t._free(_);}}deserialize(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",r);const n=r.length*r.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(r,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=t._vscf_error_ctx_size(),o=t._malloc(i);let l;t._vscf_error_reset(o);try{l=t._vscf_message_info_der_serializer_deserialize(this.ctxPtr,c,o);const r=t._vscf_error_status(o);return e.FoundationError.handleStatusCode(r),e.MessageInfo.newAndTakeCContext(l)}finally{t._free(s),t._free(c),t._free(o);}}serializedFooterLen(r){return a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("messageInfoFooter",r,e.MessageInfoFooter),t._vscf_message_info_der_serializer_serialized_footer_len(this.ctxPtr,r.ctxPtr)}serializeFooter(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureClass("messageInfoFooter",r,e.MessageInfoFooter);const n=this.serializedFooterLen(r),s=t._vsc_buffer_new_with_capacity(n);try{t._vscf_message_info_der_serializer_serialize_footer(this.ctxPtr,r.ctxPtr,s);const e=t._vsc_buffer_bytes(s),n=t._vsc_buffer_len(s);return t.HEAPU8.slice(e,e+n)}finally{t._vsc_buffer_delete(s);}}deserializeFooter(r){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),a$3.ensureByteArray("data",r);const n=r.length*r.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(r,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=t._vscf_error_ctx_size(),o=t._malloc(i);let l;t._vscf_error_reset(o);try{l=t._vscf_message_info_der_serializer_deserialize_footer(this.ctxPtr,c,o);const r=t._vscf_error_status(o);return e.FoundationError.handleStatusCode(r),e.MessageInfoFooter.newAndTakeCContext(l)}finally{t._free(s),t._free(c),t._free(o);}}setupDefaults(){a$3.ensureNotNull("this.ctxPtr",this.ctxPtr),t._vscf_message_info_der_serializer_setup_defaults(this.ctxPtr);}}return r};class Pt extends Error{constructor(){super("Module already exists."),Object.setPrototypeOf(this,Pt.prototype),this.name="ModuleAlreadyExistsError";}}class mt extends Error{constructor(){super("Module not found."),Object.setPrototypeOf(this,mt.prototype),this.name="ModuleNotFoundError";}}const xt=new class{constructor(){this.initFns=new Map,this.initPromises=new Map,this.modules=new Map,this.addModule=(t,e)=>{if(this.initFns.has(t))throw new Pt;this.loadModulesPromise=void 0,this.initFns.set(t,e);},this.getModule=t=>{if(!this.modules.has(t))throw new mt;return this.modules.get(t)},this.hasModule=t=>this.modules.has(t),this.setModule=(t,e)=>{this.modules.set(t,e);},this.removeModule=t=>{this.initFns.delete(t),this.initPromises.delete(t),this.modules.delete(t);},this.loadModule=(t,...e)=>{if(!this.initFns.has(t))throw new mt;if(this.initPromises.has(t))return this.initPromises.get(t);const r=this.initFns.get(t)(...e).then(e=>(this.modules.set(t,e),Promise.resolve()));return this.initPromises.set(t,r),r},this.loadModules=t=>{if(this.loadModulesPromise)return this.loadModulesPromise;const e=t||{},r=Array.from(this.initFns.keys()).map(t=>e[t]?this.loadModule(t,...e[t]):this.loadModule(t));return this.loadModulesPromise=Promise.all(r).then(()=>Promise.resolve()),this.loadModulesPromise};}};xt.addModule("foundation",()=>{const t=new n$4;return new Promise((e,r)=>{t.onRuntimeInitialized=()=>{const r={};r.FoundationInterfaceTag=((t,e)=>Object.freeze({ALG:1,ALG_INFO:2,ALG_INFO_DESERIALIZER:3,ALG_INFO_SERIALIZER:4,ASN1_READER:5,ASN1_WRITER:6,AUTH_DECRYPT:7,AUTH_ENCRYPT:8,CIPHER:9,CIPHER_AUTH:10,CIPHER_AUTH_INFO:11,CIPHER_INFO:12,COMPUTE_SHARED_KEY:13,DECRYPT:14,ENCRYPT:15,ENTROPY_SOURCE:16,HASH:17,KDF:18,KEY:19,KEY_ALG:20,KEY_CIPHER:21,KEY_DESERIALIZER:22,KEY_SERIALIZER:23,KEY_SIGNER:24,MAC:25,MESSAGE_INFO_FOOTER_SERIALIZER:26,MESSAGE_INFO_SERIALIZER:27,PRIVATE_KEY:28,PUBLIC_KEY:29,RANDOM:30,SALTED_KDF:31}))(),r.FoundationInterface=((t,e)=>(class{static newAndTakeCContext(r){const n=t._vscf_impl_tag(r);switch(n){case e.FoundationImplTag.SHA224:return e.Sha224.newAndTakeCContext(r);case e.FoundationImplTag.SHA256:return e.Sha256.newAndTakeCContext(r);case e.FoundationImplTag.SHA384:return e.Sha384.newAndTakeCContext(r);case e.FoundationImplTag.SHA512:return e.Sha512.newAndTakeCContext(r);case e.FoundationImplTag.AES256_GCM:return e.Aes256Gcm.newAndTakeCContext(r);case e.FoundationImplTag.AES256_CBC:return e.Aes256Cbc.newAndTakeCContext(r);case e.FoundationImplTag.ASN1RD:return e.Asn1rd.newAndTakeCContext(r);case e.FoundationImplTag.ASN1WR:return e.Asn1wr.newAndTakeCContext(r);case e.FoundationImplTag.RSA_PUBLIC_KEY:return e.RsaPublicKey.newAndTakeCContext(r);case e.FoundationImplTag.RSA_PRIVATE_KEY:return e.RsaPrivateKey.newAndTakeCContext(r);case e.FoundationImplTag.RSA:return e.Rsa.newAndTakeCContext(r);case e.FoundationImplTag.ECC_PUBLIC_KEY:return e.EccPublicKey.newAndTakeCContext(r);case e.FoundationImplTag.ECC_PRIVATE_KEY:return e.EccPrivateKey.newAndTakeCContext(r);case e.FoundationImplTag.ECC:return e.Ecc.newAndTakeCContext(r);case e.FoundationImplTag.ENTROPY_ACCUMULATOR:return e.EntropyAccumulator.newAndTakeCContext(r);case e.FoundationImplTag.CTR_DRBG:return e.CtrDrbg.newAndTakeCContext(r);case e.FoundationImplTag.HMAC:return e.Hmac.newAndTakeCContext(r);case e.FoundationImplTag.HKDF:return e.Hkdf.newAndTakeCContext(r);case e.FoundationImplTag.KDF1:return e.Kdf1.newAndTakeCContext(r);case e.FoundationImplTag.KDF2:return e.Kdf2.newAndTakeCContext(r);case e.FoundationImplTag.FAKE_RANDOM:return e.FakeRandom.newAndTakeCContext(r);case e.FoundationImplTag.PKCS5_PBKDF2:return e.Pkcs5Pbkdf2.newAndTakeCContext(r);case e.FoundationImplTag.PKCS5_PBES2:return e.Pkcs5Pbes2.newAndTakeCContext(r);case e.FoundationImplTag.SEED_ENTROPY_SOURCE:return e.SeedEntropySource.newAndTakeCContext(r);case e.FoundationImplTag.KEY_MATERIAL_RNG:return e.KeyMaterialRng.newAndTakeCContext(r);case e.FoundationImplTag.RAW_PUBLIC_KEY:return e.RawPublicKey.newAndTakeCContext(r);case e.FoundationImplTag.RAW_PRIVATE_KEY:return e.RawPrivateKey.newAndTakeCContext(r);case e.FoundationImplTag.PKCS8_SERIALIZER:return e.Pkcs8Serializer.newAndTakeCContext(r);case e.FoundationImplTag.SEC1_SERIALIZER:return e.Sec1Serializer.newAndTakeCContext(r);case e.FoundationImplTag.KEY_ASN1_SERIALIZER:return e.KeyAsn1Serializer.newAndTakeCContext(r);case e.FoundationImplTag.KEY_ASN1_DESERIALIZER:return e.KeyAsn1Deserializer.newAndTakeCContext(r);case e.FoundationImplTag.ED25519:return e.Ed25519.newAndTakeCContext(r);case e.FoundationImplTag.CURVE25519:return e.Curve25519.newAndTakeCContext(r);case e.FoundationImplTag.SIMPLE_ALG_INFO:return e.SimpleAlgInfo.newAndTakeCContext(r);case e.FoundationImplTag.HASH_BASED_ALG_INFO:return e.HashBasedAlgInfo.newAndTakeCContext(r);case e.FoundationImplTag.CIPHER_ALG_INFO:return e.CipherAlgInfo.newAndTakeCContext(r);case e.FoundationImplTag.SALTED_KDF_ALG_INFO:return e.SaltedKdfAlgInfo.newAndTakeCContext(r);case e.FoundationImplTag.PBE_ALG_INFO:return e.PbeAlgInfo.newAndTakeCContext(r);case e.FoundationImplTag.ECC_ALG_INFO:return e.EccAlgInfo.newAndTakeCContext(r);case e.FoundationImplTag.ALG_INFO_DER_SERIALIZER:return e.AlgInfoDerSerializer.newAndTakeCContext(r);case e.FoundationImplTag.ALG_INFO_DER_DESERIALIZER:return e.AlgInfoDerDeserializer.newAndTakeCContext(r);case e.FoundationImplTag.MESSAGE_INFO_DER_SERIALIZER:return e.MessageInfoDerSerializer.newAndTakeCContext(r);default:throw new Error("Unexpected implementation tag found: "+n)}}static newAndUseCContext(r){return new e.FoundationInterface.newAndTakeCContext(t._vscf_impl_shallow_copy(r))}static isImplemented(e,r){return 0!=t._vscf_impl_api(e,r)}}))(t,r),r.FoundationImplTag=((t,e)=>Object.freeze({AES256_CBC:1,AES256_GCM:2,ALG_INFO_DER_DESERIALIZER:3,ALG_INFO_DER_SERIALIZER:4,ASN1RD:5,ASN1WR:6,CIPHER_ALG_INFO:7,CTR_DRBG:8,CURVE25519:9,ECC:10,ECC_ALG_INFO:11,ECC_PRIVATE_KEY:12,ECC_PUBLIC_KEY:13,ED25519:14,ENTROPY_ACCUMULATOR:15,FAKE_RANDOM:16,HASH_BASED_ALG_INFO:17,HKDF:18,HMAC:19,KDF1:20,KDF2:21,KEY_ASN1_DESERIALIZER:22,KEY_ASN1_SERIALIZER:23,KEY_MATERIAL_RNG:24,MESSAGE_INFO_DER_SERIALIZER:25,PBE_ALG_INFO:26,PKCS5_PBES2:27,PKCS5_PBKDF2:28,PKCS8_SERIALIZER:29,RAW_PRIVATE_KEY:30,RAW_PUBLIC_KEY:31,RSA:32,RSA_PRIVATE_KEY:33,RSA_PUBLIC_KEY:34,SALTED_KDF_ALG_INFO:35,SEC1_SERIALIZER:36,SEED_ENTROPY_SOURCE:37,SHA224:38,SHA256:39,SHA384:40,SHA512:41,SIMPLE_ALG_INFO:42}))(),r.FoundationError=s$3(),r.Asn1Tag=((t,e)=>Object.freeze({BOOLEAN:0,INTEGER:1,BIT_STRING:2,OCTET_STRING:3,NULL:4,OID:5,UTF8_STRING:6,SEQUENCE:7,SET:8,PRINTABLE_STRING:9,T61_STRING:10,IA5_STRING:11,UTC_TIME:12,GENERALIZED_TIME:13,UNIVERSAL_STRING:14,BMP_STRING:15,PRIMITIVE:16,CONSTRUCTED:17,CONTEXT_SPECIFIC:18}))(),r.AlgId=((t,e)=>Object.freeze({NONE:0,SHA224:1,SHA256:2,SHA384:3,SHA512:4,KDF1:5,KDF2:6,RSA:7,ECC:8,ED25519:9,CURVE25519:10,SECP256R1:11,AES256_GCM:12,AES256_CBC:13,HMAC:14,HKDF:15,PKCS5_PBKDF2:16,PKCS5_PBES2:17}))(),r.OidId=((t,e)=>Object.freeze({NONE:0,RSA:1,ED25519:2,CURVE25519:3,SHA224:4,SHA256:5,SHA384:6,SHA512:7,KDF1:8,KDF2:9,AES256_GCM:10,AES256_CBC:11,PKCS5_PBKDF2:12,PKCS5_PBES2:13,CMS_DATA:14,CMS_ENVELOPED_DATA:15,HKDF_WITH_SHA256:16,HKDF_WITH_SHA384:17,HKDF_WITH_SHA512:18,HMAC_WITH_SHA224:19,HMAC_WITH_SHA256:20,HMAC_WITH_SHA384:21,HMAC_WITH_SHA512:22,EC_GENERIC_KEY:23,EC_DOMAIN_SECP256R1:24}))(),r.GroupMsgType=((t,e)=>Object.freeze({GROUP_INFO:0,REGULAR:1}))(),r.Oid=((t,e)=>(class{static fromAlgId(e){a$3.ensureNumber("algId",e);const r=t._vsc_data_ctx_size(),n=t._malloc(r);try{t._vscf_oid_from_alg_id(n,e);const r=t._vsc_data_len(n),s=t._vsc_data_bytes(n);return t.HEAPU8.slice(s,s+r)}finally{t._free(n);}}static toAlgId(e){a$3.ensureByteArray("oid",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);let c;t._vsc_data(_,n,r);try{return c=t._vscf_oid_to_alg_id(_)}finally{t._free(n),t._free(_);}}static fromId(e){a$3.ensureNumber("oidId",e);const r=t._vsc_data_ctx_size(),n=t._malloc(r);try{t._vscf_oid_from_id(n,e);const r=t._vsc_data_len(n),s=t._vsc_data_bytes(n);return t.HEAPU8.slice(s,s+r)}finally{t._free(n);}}static toId(e){a$3.ensureByteArray("oid",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);let c;t._vsc_data(_,n,r);try{return c=t._vscf_oid_to_id(_)}finally{t._free(n),t._free(_);}}static idToAlgId(e){return a$3.ensureNumber("oidId",e),t._vscf_oid_id_to_alg_id(e)}static equal(e,r){a$3.ensureByteArray("lhs",e),a$3.ensureByteArray("rhs",r);const n=e.length*e.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(e,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=r.length*r.BYTES_PER_ELEMENT,o=t._malloc(i);t.HEAP8.set(r,o);const l=t._vsc_data_ctx_size(),u=t._malloc(l);let f;t._vsc_data(u,o,i);try{return !!(f=t._vscf_oid_equal(c,u))}finally{t._free(s),t._free(c),t._free(o),t._free(u);}}}))(t),r.Base64=((t,e)=>{class r{static encodedLen(e){return a$3.ensureNumber("dataLen",e),t._vscf_base64_encoded_len(e)}static encode(e){a$3.ensureByteArray("data",e);const n=e.length*e.BYTES_PER_ELEMENT,s=t._malloc(n);t.HEAP8.set(e,s);const _=t._vsc_data_ctx_size(),c=t._malloc(_);t._vsc_data(c,s,n);const i=r.encodedLen(e.length),o=t._vsc_buffer_new_with_capacity(i);try{t._vscf_base64_encode(c,o);const e=t._vsc_buffer_bytes(o),r=t._vsc_buffer_len(o);return t.HEAPU8.slice(e,e+r)}finally{t._free(s),t._free(c),t._vsc_buffer_delete(o);}}static decodedLen(e){return a$3.ensureNumber("strLen",e),t._vscf_base64_decoded_len(e)}static decode(n){a$3.ensureByteArray("str",n);const s=n.length*n.BYTES_PER_ELEMENT,_=t._malloc(s);t.HEAP8.set(n,_);const c=t._vsc_data_ctx_size(),i=t._malloc(c);t._vsc_data(i,_,s);const o=r.decodedLen(n.length),l=t._vsc_buffer_new_with_capacity(o);try{const r=t._vscf_base64_decode(i,l);e.FoundationError.handleStatusCode(r);const n=t._vsc_buffer_bytes(l),s=t._vsc_buffer_len(l);return t.HEAPU8.slice(n,n+s)}finally{t._free(_),t._free(i),t._vsc_buffer_delete(l);}}}return r})(t,r),r.Pem=((t,e)=>{class r{static wrappedLen(e,r){return a$3.ensureNumber("title",e),a$3.ensureNumber("dataLen",r),t._vscf_pem_wrapped_len(e,r)}static wrap(e,n){a$3.ensureNumber("title",e),a$3.ensureByteArray("data",n);const s=n.length*n.BYTES_PER_ELEMENT,_=t._malloc(s);t.HEAP8.set(n,_);const c=t._vsc_data_ctx_size(),i=t._malloc(c);t._vsc_data(i,_,s);const o=r.wrappedLen(e,n.length),l=t._vsc_buffer_new_with_capacity(o);try{t._vscf_pem_wrap(e,i,l);const r=t._vsc_buffer_bytes(l),n=t._vsc_buffer_len(l);return t.HEAPU8.slice(r,r+n)}finally{t._free(_),t._free(i),t._vsc_buffer_delete(l);}}static unwrappedLen(e){return a$3.ensureNumber("pemLen",e),t._vscf_pem_unwrapped_len(e)}static unwrap(n){a$3.ensureByteArray("pem",n);const s=n.length*n.BYTES_PER_ELEMENT,_=t._malloc(s);t.HEAP8.set(n,_);const c=t._vsc_data_ctx_size(),i=t._malloc(c);t._vsc_data(i,_,s);const o=r.unwrappedLen(n.length),l=t._vsc_buffer_new_with_capacity(o);try{const r=t._vscf_pem_unwrap(i,l);e.FoundationError.handleStatusCode(r);const n=t._vsc_buffer_bytes(l),s=t._vsc_buffer_len(l);return t.HEAPU8.slice(n,n+s)}finally{t._free(_),t._free(i),t._vsc_buffer_delete(l);}}static title(e){a$3.ensureByteArray("pem",e);const r=e.length*e.BYTES_PER_ELEMENT,n=t._malloc(r);t.HEAP8.set(e,n);const s=t._vsc_data_ctx_size(),_=t._malloc(s);t._vsc_data(_,n,r);const c=t._vsc_data_ctx_size(),i=t._malloc(c);try{t._vscf_pem_title(i,_);const e=t._vsc_data_len(i),r=t._vsc_data_bytes(i);return t.HEAPU8.slice(r,r+e)}finally{t._free(n),t._free(_),t._free(i);}}}return r})(t,r),r.MessageInfo=i$3(t,r),r.KeyRecipientInfo=o$3(t,r),r.KeyRecipientInfoList=l$3(t,r),r.PasswordRecipientInfo=u$3(t,r),r.PasswordRecipientInfoList=f$2(t,r),r.AlgFactory=((t,e)=>(class{static createHashFromInfo(r){let n;return a$3.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),n=t._vscf_alg_factory_create_hash_from_info(r.ctxPtr),e.FoundationInterface.newAndTakeCContext(n)}static createMacFromInfo(r){let n;return a$3.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),n=t._vscf_alg_factory_create_mac_from_info(r.ctxPtr),e.FoundationInterface.newAndTakeCContext(n)}static createKdfFromInfo(r){let n;return a$3.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),n=t._vscf_alg_factory_create_kdf_from_info(r.ctxPtr),e.FoundationInterface.newAndTakeCContext(n)}static createSaltedKdfFromInfo(r){let n;return a$3.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),n=t._vscf_alg_factory_create_salted_kdf_from_info(r.ctxPtr),e.FoundationInterface.newAndTakeCContext(n)}static createCipherFromInfo(r){let n;return a$3.ensureImplementInterface("algInfo",r,"Foundation.AlgInfo",e.FoundationInterfaceTag.ALG_INFO,e.FoundationInterface),n=t._vscf_alg_factory_create_cipher_from_info(r.ctxPtr),e.FoundationInterface.newAndTakeCContext(n)}}))(t,r),r.KeyAlgFactory=((t,e)=>(class{static createFromAlgId(r,n){a$3.ensureNumber("algId",r),a$3.ensureImplementInterface("random",n,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface);const s=t._vscf_error_ctx_size(),_=t._malloc(s);let c;t._vscf_error_reset(_);try{c=t._vscf_key_alg_factory_create_from_alg_id(r,n.ctxPtr,_);const s=t._vscf_error_status(_);return e.FoundationError.handleStatusCode(s),e.FoundationInterface.newAndTakeCContext(c)}finally{t._free(_);}}static createFromKey(r,n){a$3.ensureImplementInterface("key",r,"Foundation.Key",e.FoundationInterfaceTag.KEY,e.FoundationInterface),a$3.ensureImplementInterface("random",n,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface);const s=t._vscf_error_ctx_size(),_=t._malloc(s);let c;t._vscf_error_reset(_);try{c=t._vscf_key_alg_factory_create_from_key(r.ctxPtr,n.ctxPtr,_);const s=t._vscf_error_status(_);return e.FoundationError.handleStatusCode(s),e.FoundationInterface.newAndTakeCContext(c)}finally{t._free(_);}}static createFromRawPublicKey(r,n){a$3.ensureClass("publicKey",r,e.RawPublicKey),a$3.ensureImplementInterface("random",n,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface);const s=t._vscf_error_ctx_size(),_=t._malloc(s);let c;t._vscf_error_reset(_);try{c=t._vscf_key_alg_factory_create_from_raw_public_key(r.ctxPtr,n.ctxPtr,_);const s=t._vscf_error_status(_);return e.FoundationError.handleStatusCode(s),e.FoundationInterface.newAndTakeCContext(c)}finally{t._free(_);}}static createFromRawPrivateKey(r,n){a$3.ensureClass("privateKey",r,e.RawPrivateKey),a$3.ensureImplementInterface("random",n,"Foundation.Random",e.FoundationInterfaceTag.RANDOM,e.FoundationInterface);const s=t._vscf_error_ctx_size(),_=t._malloc(s);let c;t._vscf_error_reset(_);try{c=t._vscf_key_alg_factory_create_from_raw_private_key(r.ctxPtr,n.ctxPtr,_);const s=t._vscf_error_status(_);return e.FoundationError.handleStatusCode(s),e.FoundationInterface.newAndTakeCContext(c)}finally{t._free(_);}}}))(t,r),r.Ecies=p$2(t,r),r.RecipientCipher=d$2(t,r),r.MessageInfoCustomParams=h$2(t,r),r.KeyProvider=y$3(t,r),r.Signer=v$4(t,r),r.Verifier=P$2(t,r),r.BrainkeyClient=m$3(t,r),r.BrainkeyServer=x$3(t,r),r.GroupSessionMessage=g$3(t,r),r.GroupSessionTicket=w$2(t,r),r.GroupSession=E$2(t,r),r.MessageInfoEditor=N$1(t,r),r.SignerInfo=I$1(t,r),r.SignerInfoList=b$2(t,r),r.MessageInfoFooter=A$2(t,r),r.SignedDataInfo=k$2(t,r),r.FooterInfo=C$1(t,r),r.Sha224=T$2(t,r),r.Sha256=F$1(t,r),r.Sha384=S$2(t,r),r.Sha512=K$2(t,r),r.Aes256Gcm=L$2(t,r),r.Aes256Cbc=R$2(t,r),r.Asn1rd=z$1(t,r),r.Asn1wr=B$2(t,r),r.RsaPublicKey=U$2(t,r),r.RsaPrivateKey=M$2(t,r),r.Rsa=H$1(t,r),r.EccPublicKey=Y$1(t,r),r.EccPrivateKey=D$1(t,r),r.Ecc=O$1(t,r),r.EntropyAccumulator=G$1(t,r),r.CtrDrbg=V$1(t,r),r.Hmac=X$1(t,r),r.Hkdf=j$1(t,r),r.Kdf1=W$1(t,r),r.Kdf2=Z$1(t,r),r.FakeRandom=$$1(t,r),r.Pkcs5Pbkdf2=q$1(t,r),r.Pkcs5Pbes2=J$1(t,r),r.SeedEntropySource=Q$1(t,r),r.KeyMaterialRng=tt$1(t,r),r.RawPublicKey=et$1(t,r),r.RawPrivateKey=rt$1(t,r),r.Pkcs8Serializer=nt$1(t,r),r.Sec1Serializer=st$1(t,r),r.KeyAsn1Serializer=_t$1(t,r),r.KeyAsn1Deserializer=ct$1(t,r),r.Ed25519=at$1(t,r),r.Curve25519=it$1(t,r),r.SimpleAlgInfo=ot$1(t),r.HashBasedAlgInfo=lt$1(t,r),r.CipherAlgInfo=ut$1(t),r.SaltedKdfAlgInfo=ft$1(t,r),r.PbeAlgInfo=pt$1(t,r),r.EccAlgInfo=dt$1(t),r.AlgInfoDerSerializer=ht$1(t,r),r.AlgInfoDerDeserializer=yt$1(t,r),r.MessageInfoDerSerializer=vt$1(t,r),e(r);},t.onAbort=t=>{r(new Error(t));};})});const gt=()=>xt.hasModule("foundation"),wt=()=>xt.getModule("foundation"),Et=t=>{xt.setModule("foundation",t);},It=(t,e)=>{Object.defineProperty(t,e,{configurable:!1,enumerable:!0,get:()=>{const{AlgId:t}=wt();return t[e]}});},bt={};It(bt,"SHA224"),It(bt,"SHA256"),It(bt,"SHA384"),It(bt,"SHA512");const At=(t,e,r,n)=>{Object.defineProperty(t,e,{configurable:!1,enumerable:!0,get:()=>{const{AlgId:t}=xt.getModule("foundation");return {bitlen:n,algId:t[r]}}});},kt={};At(kt,"Default","ED25519"),At(kt,"ED25519","ED25519"),At(kt,"CURVE25519","CURVE25519"),At(kt,"SECP256R1","SECP256R1"),At(kt,"RSA_2048","RSA",2048),At(kt,"RSA_3072","RSA",3072),At(kt,"RSA_4096","RSA",4096),At(kt,"RSA_8192","RSA",8192);for(var Ct=function(t){var e=Ut(t),r=e[0],n=e[1];return 3*(r+n)/4-n},Tt=function(t){var e,r,n=Ut(t),s=n[0],_=n[1],c=new Lt(function(t,e,r){return 3*(e+r)/4-r}(0,s,_)),a=0,i=_>0?s-4:s;for(r=0;r<i;r+=4)e=Kt[t.charCodeAt(r)]<<18|Kt[t.charCodeAt(r+1)]<<12|Kt[t.charCodeAt(r+2)]<<6|Kt[t.charCodeAt(r+3)],c[a++]=e>>16&255,c[a++]=e>>8&255,c[a++]=255&e;2===_&&(e=Kt[t.charCodeAt(r)]<<2|Kt[t.charCodeAt(r+1)]>>4,c[a++]=255&e);1===_&&(e=Kt[t.charCodeAt(r)]<<10|Kt[t.charCodeAt(r+1)]<<4|Kt[t.charCodeAt(r+2)]>>2,c[a++]=e>>8&255,c[a++]=255&e);return c},Ft=function(t){for(var e,r=t.length,n=r%3,s=[],_=0,c=r-n;_<c;_+=16383)s.push(Mt(t,_,_+16383>c?c:_+16383));1===n?(e=t[r-1],s.push(St[e>>2]+St[e<<4&63]+"==")):2===n&&(e=(t[r-2]<<8)+t[r-1],s.push(St[e>>10]+St[e>>4&63]+St[e<<2&63]+"="));return s.join("")},St=[],Kt=[],Lt="undefined"!=typeof Uint8Array?Uint8Array:Array,Rt="ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/",zt=0,Bt=Rt.length;zt<Bt;++zt)St[zt]=Rt[zt],Kt[Rt.charCodeAt(zt)]=zt;function Ut(t){var e=t.length;if(e%4>0)throw new Error("Invalid string. Length must be a multiple of 4");var r=t.indexOf("=");return -1===r&&(r=e),[r,r===e?0:4-r%4]}function Mt(t,e,r){for(var n,s,_=[],c=e;c<r;c+=3)n=(t[c]<<16&16711680)+(t[c+1]<<8&65280)+(255&t[c+2]),_.push(St[(s=n)>>18&63]+St[s>>12&63]+St[s>>6&63]+St[63&s]);return _.join("")}Kt["-".charCodeAt(0)]=62,Kt["_".charCodeAt(0)]=63;var Ht,Yt={byteLength:Ct,toByteArray:Tt,fromByteArray:Ft},Dt={read:function(t,e,r,n,s){var _,c,a=8*s-n-1,i=(1<<a)-1,o=i>>1,l=-7,u=r?s-1:0,f=r?-1:1,p=t[e+u];for(u+=f,_=p&(1<<-l)-1,p>>=-l,l+=a;l>0;_=256*_+t[e+u],u+=f,l-=8);for(c=_&(1<<-l)-1,_>>=-l,l+=n;l>0;c=256*c+t[e+u],u+=f,l-=8);if(0===_)_=1-o;else{if(_===i)return c?NaN:1/0*(p?-1:1);c+=Math.pow(2,n),_-=o;}return (p?-1:1)*c*Math.pow(2,_-n)},write:function(t,e,r,n,s,_){var c,a,i,o=8*_-s-1,l=(1<<o)-1,u=l>>1,f=23===s?Math.pow(2,-24)-Math.pow(2,-77):0,p=n?0:_-1,d=n?1:-1,h=e<0||0===e&&1/e<0?1:0;for(e=Math.abs(e),isNaN(e)||e===1/0?(a=isNaN(e)?1:0,c=l):(c=Math.floor(Math.log(e)/Math.LN2),e*(i=Math.pow(2,-c))<1&&(c--,i*=2),(e+=c+u>=1?f/i:f*Math.pow(2,1-u))*i>=2&&(c++,i/=2),c+u>=l?(a=0,c=l):c+u>=1?(a=(e*i-1)*Math.pow(2,s),c+=u):(a=e*Math.pow(2,u-1)*Math.pow(2,s),c=0));s>=8;t[r+p]=255&a,p+=d,a/=256,s-=8);for(c=c<<s|a,o+=s;o>0;t[r+p]=255&c,p+=d,c/=256,o-=8);t[r+p-d]|=128*h;}},Ot=(function(t,e){var r="function"==typeof Symbol&&"function"==typeof Symbol.for?Symbol.for("nodejs.util.inspect.custom"):null;e.Buffer=_,e.SlowBuffer=function(t){return +t!=t&&(t=0),_.alloc(+t)},e.INSPECT_MAX_BYTES=50;var n=2147483647;function s(t){if(t>n)throw new RangeError('The value "'+t+'" is invalid for option "size"');var e=new Uint8Array(t);return Object.setPrototypeOf(e,_.prototype),e}function _(t,e,r){if("number"==typeof t){if("string"==typeof e)throw new TypeError('The "string" argument must be of type string. Received type number');return i(t)}return c(t,e,r)}function c(t,e,r){if("string"==typeof t)return function(t,e){if("string"==typeof e&&""!==e||(e="utf8"),!_.isEncoding(e))throw new TypeError("Unknown encoding: "+e);var r=0|u(t,e),n=s(r),c=n.write(t,e);return c!==r&&(n=n.slice(0,c)),n}(t,e);if(ArrayBuffer.isView(t))return o(t);if(null==t)throw new TypeError("The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type "+typeof t);if(U(t,ArrayBuffer)||t&&U(t.buffer,ArrayBuffer))return function(t,e,r){if(e<0||t.byteLength<e)throw new RangeError('"offset" is outside of buffer bounds');if(t.byteLength<e+(r||0))throw new RangeError('"length" is outside of buffer bounds');var n;return n=void 0===e&&void 0===r?new Uint8Array(t):void 0===r?new Uint8Array(t,e):new Uint8Array(t,e,r),Object.setPrototypeOf(n,_.prototype),n}(t,e,r);if("number"==typeof t)throw new TypeError('The "value" argument must not be of type number. Received type number');var n=t.valueOf&&t.valueOf();if(null!=n&&n!==t)return _.from(n,e,r);var c=function(t){if(_.isBuffer(t)){var e=0|l(t.length),r=s(e);return 0===r.length?r:(t.copy(r,0,0,e),r)}return void 0!==t.length?"number"!=typeof t.length||M(t.length)?s(0):o(t):"Buffer"===t.type&&Array.isArray(t.data)?o(t.data):void 0}(t);if(c)return c;if("undefined"!=typeof Symbol&&null!=Symbol.toPrimitive&&"function"==typeof t[Symbol.toPrimitive])return _.from(t[Symbol.toPrimitive]("string"),e,r);throw new TypeError("The first argument must be one of type string, Buffer, ArrayBuffer, Array, or Array-like Object. Received type "+typeof t)}function a(t){if("number"!=typeof t)throw new TypeError('"size" argument must be of type number');if(t<0)throw new RangeError('The value "'+t+'" is invalid for option "size"')}function i(t){return a(t),s(t<0?0:0|l(t))}function o(t){for(var e=t.length<0?0:0|l(t.length),r=s(e),n=0;n<e;n+=1)r[n]=255&t[n];return r}function l(t){if(t>=n)throw new RangeError("Attempt to allocate Buffer larger than maximum size: 0x"+n.toString(16)+" bytes");return 0|t}function u(t,e){if(_.isBuffer(t))return t.length;if(ArrayBuffer.isView(t)||U(t,ArrayBuffer))return t.byteLength;if("string"!=typeof t)throw new TypeError('The "string" argument must be one of type string, Buffer, or ArrayBuffer. Received type '+typeof t);var r=t.length,n=arguments.length>2&&!0===arguments[2];if(!n&&0===r)return 0;for(var s=!1;;)switch(e){case"ascii":case"latin1":case"binary":return r;case"utf8":case"utf-8":return R(t).length;case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return 2*r;case"hex":return r>>>1;case"base64":return z(t).length;default:if(s)return n?-1:R(t).length;e=(""+e).toLowerCase(),s=!0;}}function f(t,e,r){var n=!1;if((void 0===e||e<0)&&(e=0),e>this.length)return "";if((void 0===r||r>this.length)&&(r=this.length),r<=0)return "";if((r>>>=0)<=(e>>>=0))return "";for(t||(t="utf8");;)switch(t){case"hex":return A(this,e,r);case"utf8":case"utf-8":return E(this,e,r);case"ascii":return I(this,e,r);case"latin1":case"binary":return b(this,e,r);case"base64":return w(this,e,r);case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return k(this,e,r);default:if(n)throw new TypeError("Unknown encoding: "+t);t=(t+"").toLowerCase(),n=!0;}}function p(t,e,r){var n=t[e];t[e]=t[r],t[r]=n;}function d(t,e,r,n,s){if(0===t.length)return -1;if("string"==typeof r?(n=r,r=0):r>2147483647?r=2147483647:r<-2147483648&&(r=-2147483648),M(r=+r)&&(r=s?0:t.length-1),r<0&&(r=t.length+r),r>=t.length){if(s)return -1;r=t.length-1;}else if(r<0){if(!s)return -1;r=0;}if("string"==typeof e&&(e=_.from(e,n)),_.isBuffer(e))return 0===e.length?-1:h(t,e,r,n,s);if("number"==typeof e)return e&=255,"function"==typeof Uint8Array.prototype.indexOf?s?Uint8Array.prototype.indexOf.call(t,e,r):Uint8Array.prototype.lastIndexOf.call(t,e,r):h(t,[e],r,n,s);throw new TypeError("val must be string, number or Buffer")}function h(t,e,r,n,s){var _,c=1,a=t.length,i=e.length;if(void 0!==n&&("ucs2"===(n=String(n).toLowerCase())||"ucs-2"===n||"utf16le"===n||"utf-16le"===n)){if(t.length<2||e.length<2)return -1;c=2,a/=2,i/=2,r/=2;}function o(t,e){return 1===c?t[e]:t.readUInt16BE(e*c)}if(s){var l=-1;for(_=r;_<a;_++)if(o(t,_)===o(e,-1===l?0:_-l)){if(-1===l&&(l=_),_-l+1===i)return l*c}else-1!==l&&(_-=_-l),l=-1;}else for(r+i>a&&(r=a-i),_=r;_>=0;_--){for(var u=!0,f=0;f<i;f++)if(o(t,_+f)!==o(e,f)){u=!1;break}if(u)return _}return -1}function y(t,e,r,n){r=Number(r)||0;var s=t.length-r;n?(n=Number(n))>s&&(n=s):n=s;var _=e.length;n>_/2&&(n=_/2);for(var c=0;c<n;++c){var a=parseInt(e.substr(2*c,2),16);if(M(a))return c;t[r+c]=a;}return c}function v(t,e,r,n){return B(R(e,t.length-r),t,r,n)}function P(t,e,r,n){return B(function(t){for(var e=[],r=0;r<t.length;++r)e.push(255&t.charCodeAt(r));return e}(e),t,r,n)}function m(t,e,r,n){return P(t,e,r,n)}function x(t,e,r,n){return B(z(e),t,r,n)}function g(t,e,r,n){return B(function(t,e){for(var r,n,s,_=[],c=0;c<t.length&&!((e-=2)<0);++c)r=t.charCodeAt(c),n=r>>8,s=r%256,_.push(s),_.push(n);return _}(e,t.length-r),t,r,n)}function w(t,e,r){return 0===e&&r===t.length?Yt.fromByteArray(t):Yt.fromByteArray(t.slice(e,r))}function E(t,e,r){r=Math.min(t.length,r);for(var n=[],s=e;s<r;){var _,c,a,i,o=t[s],l=null,u=o>239?4:o>223?3:o>191?2:1;if(s+u<=r)switch(u){case 1:o<128&&(l=o);break;case 2:128==(192&(_=t[s+1]))&&(i=(31&o)<<6|63&_)>127&&(l=i);break;case 3:_=t[s+1],c=t[s+2],128==(192&_)&&128==(192&c)&&(i=(15&o)<<12|(63&_)<<6|63&c)>2047&&(i<55296||i>57343)&&(l=i);break;case 4:_=t[s+1],c=t[s+2],a=t[s+3],128==(192&_)&&128==(192&c)&&128==(192&a)&&(i=(15&o)<<18|(63&_)<<12|(63&c)<<6|63&a)>65535&&i<1114112&&(l=i);}null===l?(l=65533,u=1):l>65535&&(l-=65536,n.push(l>>>10&1023|55296),l=56320|1023&l),n.push(l),s+=u;}return function(t){var e=t.length;if(e<=N)return String.fromCharCode.apply(String,t);for(var r="",n=0;n<e;)r+=String.fromCharCode.apply(String,t.slice(n,n+=N));return r}(n)}e.kMaxLength=n,_.TYPED_ARRAY_SUPPORT=function(){try{var t=new Uint8Array(1),e={foo:function(){return 42}};return Object.setPrototypeOf(e,Uint8Array.prototype),Object.setPrototypeOf(t,e),42===t.foo()}catch(t){return !1}}(),_.TYPED_ARRAY_SUPPORT||"undefined"==typeof console||"function"!=typeof console.error||console.error("This browser lacks typed array (Uint8Array) support which is required by `buffer` v5.x. Use `buffer` v4.x if you require old browser support."),Object.defineProperty(_.prototype,"parent",{enumerable:!0,get:function(){if(_.isBuffer(this))return this.buffer}}),Object.defineProperty(_.prototype,"offset",{enumerable:!0,get:function(){if(_.isBuffer(this))return this.byteOffset}}),"undefined"!=typeof Symbol&&null!=Symbol.species&&_[Symbol.species]===_&&Object.defineProperty(_,Symbol.species,{value:null,configurable:!0,enumerable:!1,writable:!1}),_.poolSize=8192,_.from=function(t,e,r){return c(t,e,r)},Object.setPrototypeOf(_.prototype,Uint8Array.prototype),Object.setPrototypeOf(_,Uint8Array),_.alloc=function(t,e,r){return function(t,e,r){return a(t),t<=0?s(t):void 0!==e?"string"==typeof r?s(t).fill(e,r):s(t).fill(e):s(t)}(t,e,r)},_.allocUnsafe=function(t){return i(t)},_.allocUnsafeSlow=function(t){return i(t)},_.isBuffer=function(t){return null!=t&&!0===t._isBuffer&&t!==_.prototype},_.compare=function(t,e){if(U(t,Uint8Array)&&(t=_.from(t,t.offset,t.byteLength)),U(e,Uint8Array)&&(e=_.from(e,e.offset,e.byteLength)),!_.isBuffer(t)||!_.isBuffer(e))throw new TypeError('The "buf1", "buf2" arguments must be one of type Buffer or Uint8Array');if(t===e)return 0;for(var r=t.length,n=e.length,s=0,c=Math.min(r,n);s<c;++s)if(t[s]!==e[s]){r=t[s],n=e[s];break}return r<n?-1:n<r?1:0},_.isEncoding=function(t){switch(String(t).toLowerCase()){case"hex":case"utf8":case"utf-8":case"ascii":case"latin1":case"binary":case"base64":case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return !0;default:return !1}},_.concat=function(t,e){if(!Array.isArray(t))throw new TypeError('"list" argument must be an Array of Buffers');if(0===t.length)return _.alloc(0);var r;if(void 0===e)for(e=0,r=0;r<t.length;++r)e+=t[r].length;var n=_.allocUnsafe(e),s=0;for(r=0;r<t.length;++r){var c=t[r];if(U(c,Uint8Array)&&(c=_.from(c)),!_.isBuffer(c))throw new TypeError('"list" argument must be an Array of Buffers');c.copy(n,s),s+=c.length;}return n},_.byteLength=u,_.prototype._isBuffer=!0,_.prototype.swap16=function(){var t=this.length;if(t%2!=0)throw new RangeError("Buffer size must be a multiple of 16-bits");for(var e=0;e<t;e+=2)p(this,e,e+1);return this},_.prototype.swap32=function(){var t=this.length;if(t%4!=0)throw new RangeError("Buffer size must be a multiple of 32-bits");for(var e=0;e<t;e+=4)p(this,e,e+3),p(this,e+1,e+2);return this},_.prototype.swap64=function(){var t=this.length;if(t%8!=0)throw new RangeError("Buffer size must be a multiple of 64-bits");for(var e=0;e<t;e+=8)p(this,e,e+7),p(this,e+1,e+6),p(this,e+2,e+5),p(this,e+3,e+4);return this},_.prototype.toString=function(){var t=this.length;return 0===t?"":0===arguments.length?E(this,0,t):f.apply(this,arguments)},_.prototype.toLocaleString=_.prototype.toString,_.prototype.equals=function(t){if(!_.isBuffer(t))throw new TypeError("Argument must be a Buffer");return this===t||0===_.compare(this,t)},_.prototype.inspect=function(){var t="",r=e.INSPECT_MAX_BYTES;return t=this.toString("hex",0,r).replace(/(.{2})/g,"$1 ").trim(),this.length>r&&(t+=" ... "),"<Buffer "+t+">"},r&&(_.prototype[r]=_.prototype.inspect),_.prototype.compare=function(t,e,r,n,s){if(U(t,Uint8Array)&&(t=_.from(t,t.offset,t.byteLength)),!_.isBuffer(t))throw new TypeError('The "target" argument must be one of type Buffer or Uint8Array. Received type '+typeof t);if(void 0===e&&(e=0),void 0===r&&(r=t?t.length:0),void 0===n&&(n=0),void 0===s&&(s=this.length),e<0||r>t.length||n<0||s>this.length)throw new RangeError("out of range index");if(n>=s&&e>=r)return 0;if(n>=s)return -1;if(e>=r)return 1;if(this===t)return 0;for(var c=(s>>>=0)-(n>>>=0),a=(r>>>=0)-(e>>>=0),i=Math.min(c,a),o=this.slice(n,s),l=t.slice(e,r),u=0;u<i;++u)if(o[u]!==l[u]){c=o[u],a=l[u];break}return c<a?-1:a<c?1:0},_.prototype.includes=function(t,e,r){return -1!==this.indexOf(t,e,r)},_.prototype.indexOf=function(t,e,r){return d(this,t,e,r,!0)},_.prototype.lastIndexOf=function(t,e,r){return d(this,t,e,r,!1)},_.prototype.write=function(t,e,r,n){if(void 0===e)n="utf8",r=this.length,e=0;else if(void 0===r&&"string"==typeof e)n=e,r=this.length,e=0;else{if(!isFinite(e))throw new Error("Buffer.write(string, encoding, offset[, length]) is no longer supported");e>>>=0,isFinite(r)?(r>>>=0,void 0===n&&(n="utf8")):(n=r,r=void 0);}var s=this.length-e;if((void 0===r||r>s)&&(r=s),t.length>0&&(r<0||e<0)||e>this.length)throw new RangeError("Attempt to write outside buffer bounds");n||(n="utf8");for(var _=!1;;)switch(n){case"hex":return y(this,t,e,r);case"utf8":case"utf-8":return v(this,t,e,r);case"ascii":return P(this,t,e,r);case"latin1":case"binary":return m(this,t,e,r);case"base64":return x(this,t,e,r);case"ucs2":case"ucs-2":case"utf16le":case"utf-16le":return g(this,t,e,r);default:if(_)throw new TypeError("Unknown encoding: "+n);n=(""+n).toLowerCase(),_=!0;}},_.prototype.toJSON=function(){return {type:"Buffer",data:Array.prototype.slice.call(this._arr||this,0)}};var N=4096;function I(t,e,r){var n="";r=Math.min(t.length,r);for(var s=e;s<r;++s)n+=String.fromCharCode(127&t[s]);return n}function b(t,e,r){var n="";r=Math.min(t.length,r);for(var s=e;s<r;++s)n+=String.fromCharCode(t[s]);return n}function A(t,e,r){var n=t.length;(!e||e<0)&&(e=0),(!r||r<0||r>n)&&(r=n);for(var s="",_=e;_<r;++_)s+=H[t[_]];return s}function k(t,e,r){for(var n=t.slice(e,r),s="",_=0;_<n.length;_+=2)s+=String.fromCharCode(n[_]+256*n[_+1]);return s}function C(t,e,r){if(t%1!=0||t<0)throw new RangeError("offset is not uint");if(t+e>r)throw new RangeError("Trying to access beyond buffer length")}function T(t,e,r,n,s,c){if(!_.isBuffer(t))throw new TypeError('"buffer" argument must be a Buffer instance');if(e>s||e<c)throw new RangeError('"value" argument is out of bounds');if(r+n>t.length)throw new RangeError("Index out of range")}function F(t,e,r,n,s,_){if(r+n>t.length)throw new RangeError("Index out of range");if(r<0)throw new RangeError("Index out of range")}function S(t,e,r,n,s){return e=+e,r>>>=0,s||F(t,0,r,4),Dt.write(t,e,r,n,23,4),r+4}function K(t,e,r,n,s){return e=+e,r>>>=0,s||F(t,0,r,8),Dt.write(t,e,r,n,52,8),r+8}_.prototype.slice=function(t,e){var r=this.length;(t=~~t)<0?(t+=r)<0&&(t=0):t>r&&(t=r),(e=void 0===e?r:~~e)<0?(e+=r)<0&&(e=0):e>r&&(e=r),e<t&&(e=t);var n=this.subarray(t,e);return Object.setPrototypeOf(n,_.prototype),n},_.prototype.readUIntLE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t],s=1,_=0;++_<e&&(s*=256);)n+=this[t+_]*s;return n},_.prototype.readUIntBE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t+--e],s=1;e>0&&(s*=256);)n+=this[t+--e]*s;return n},_.prototype.readUInt8=function(t,e){return t>>>=0,e||C(t,1,this.length),this[t]},_.prototype.readUInt16LE=function(t,e){return t>>>=0,e||C(t,2,this.length),this[t]|this[t+1]<<8},_.prototype.readUInt16BE=function(t,e){return t>>>=0,e||C(t,2,this.length),this[t]<<8|this[t+1]},_.prototype.readUInt32LE=function(t,e){return t>>>=0,e||C(t,4,this.length),(this[t]|this[t+1]<<8|this[t+2]<<16)+16777216*this[t+3]},_.prototype.readUInt32BE=function(t,e){return t>>>=0,e||C(t,4,this.length),16777216*this[t]+(this[t+1]<<16|this[t+2]<<8|this[t+3])},_.prototype.readIntLE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=this[t],s=1,_=0;++_<e&&(s*=256);)n+=this[t+_]*s;return n>=(s*=128)&&(n-=Math.pow(2,8*e)),n},_.prototype.readIntBE=function(t,e,r){t>>>=0,e>>>=0,r||C(t,e,this.length);for(var n=e,s=1,_=this[t+--n];n>0&&(s*=256);)_+=this[t+--n]*s;return _>=(s*=128)&&(_-=Math.pow(2,8*e)),_},_.prototype.readInt8=function(t,e){return t>>>=0,e||C(t,1,this.length),128&this[t]?-1*(255-this[t]+1):this[t]},_.prototype.readInt16LE=function(t,e){t>>>=0,e||C(t,2,this.length);var r=this[t]|this[t+1]<<8;return 32768&r?4294901760|r:r},_.prototype.readInt16BE=function(t,e){t>>>=0,e||C(t,2,this.length);var r=this[t+1]|this[t]<<8;return 32768&r?4294901760|r:r},_.prototype.readInt32LE=function(t,e){return t>>>=0,e||C(t,4,this.length),this[t]|this[t+1]<<8|this[t+2]<<16|this[t+3]<<24},_.prototype.readInt32BE=function(t,e){return t>>>=0,e||C(t,4,this.length),this[t]<<24|this[t+1]<<16|this[t+2]<<8|this[t+3]},_.prototype.readFloatLE=function(t,e){return t>>>=0,e||C(t,4,this.length),Dt.read(this,t,!0,23,4)},_.prototype.readFloatBE=function(t,e){return t>>>=0,e||C(t,4,this.length),Dt.read(this,t,!1,23,4)},_.prototype.readDoubleLE=function(t,e){return t>>>=0,e||C(t,8,this.length),Dt.read(this,t,!0,52,8)},_.prototype.readDoubleBE=function(t,e){return t>>>=0,e||C(t,8,this.length),Dt.read(this,t,!1,52,8)},_.prototype.writeUIntLE=function(t,e,r,n){t=+t,e>>>=0,r>>>=0,n||T(this,t,e,r,Math.pow(2,8*r)-1,0);var s=1,_=0;for(this[e]=255&t;++_<r&&(s*=256);)this[e+_]=t/s&255;return e+r},_.prototype.writeUIntBE=function(t,e,r,n){t=+t,e>>>=0,r>>>=0,n||T(this,t,e,r,Math.pow(2,8*r)-1,0);var s=r-1,_=1;for(this[e+s]=255&t;--s>=0&&(_*=256);)this[e+s]=t/_&255;return e+r},_.prototype.writeUInt8=function(t,e,r){return t=+t,e>>>=0,r||T(this,t,e,1,255,0),this[e]=255&t,e+1},_.prototype.writeUInt16LE=function(t,e,r){return t=+t,e>>>=0,r||T(this,t,e,2,65535,0),this[e]=255&t,this[e+1]=t>>>8,e+2},_.prototype.writeUInt16BE=function(t,e,r){return t=+t,e>>>=0,r||T(this,t,e,2,65535,0),this[e]=t>>>8,this[e+1]=255&t,e+2},_.prototype.writeUInt32LE=function(t,e,r){return t=+t,e>>>=0,r||T(this,t,e,4,4294967295,0),this[e+3]=t>>>24,this[e+2]=t>>>16,this[e+1]=t>>>8,this[e]=255&t,e+4},_.prototype.writeUInt32BE=function(t,e,r){return t=+t,e>>>=0,r||T(this,t,e,4,4294967295,0),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},_.prototype.writeIntLE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var s=Math.pow(2,8*r-1);T(this,t,e,r,s-1,-s);}var _=0,c=1,a=0;for(this[e]=255&t;++_<r&&(c*=256);)t<0&&0===a&&0!==this[e+_-1]&&(a=1),this[e+_]=(t/c>>0)-a&255;return e+r},_.prototype.writeIntBE=function(t,e,r,n){if(t=+t,e>>>=0,!n){var s=Math.pow(2,8*r-1);T(this,t,e,r,s-1,-s);}var _=r-1,c=1,a=0;for(this[e+_]=255&t;--_>=0&&(c*=256);)t<0&&0===a&&0!==this[e+_+1]&&(a=1),this[e+_]=(t/c>>0)-a&255;return e+r},_.prototype.writeInt8=function(t,e,r){return t=+t,e>>>=0,r||T(this,t,e,1,127,-128),t<0&&(t=255+t+1),this[e]=255&t,e+1},_.prototype.writeInt16LE=function(t,e,r){return t=+t,e>>>=0,r||T(this,t,e,2,32767,-32768),this[e]=255&t,this[e+1]=t>>>8,e+2},_.prototype.writeInt16BE=function(t,e,r){return t=+t,e>>>=0,r||T(this,t,e,2,32767,-32768),this[e]=t>>>8,this[e+1]=255&t,e+2},_.prototype.writeInt32LE=function(t,e,r){return t=+t,e>>>=0,r||T(this,t,e,4,2147483647,-2147483648),this[e]=255&t,this[e+1]=t>>>8,this[e+2]=t>>>16,this[e+3]=t>>>24,e+4},_.prototype.writeInt32BE=function(t,e,r){return t=+t,e>>>=0,r||T(this,t,e,4,2147483647,-2147483648),t<0&&(t=4294967295+t+1),this[e]=t>>>24,this[e+1]=t>>>16,this[e+2]=t>>>8,this[e+3]=255&t,e+4},_.prototype.writeFloatLE=function(t,e,r){return S(this,t,e,!0,r)},_.prototype.writeFloatBE=function(t,e,r){return S(this,t,e,!1,r)},_.prototype.writeDoubleLE=function(t,e,r){return K(this,t,e,!0,r)},_.prototype.writeDoubleBE=function(t,e,r){return K(this,t,e,!1,r)},_.prototype.copy=function(t,e,r,n){if(!_.isBuffer(t))throw new TypeError("argument should be a Buffer");if(r||(r=0),n||0===n||(n=this.length),e>=t.length&&(e=t.length),e||(e=0),n>0&&n<r&&(n=r),n===r)return 0;if(0===t.length||0===this.length)return 0;if(e<0)throw new RangeError("targetStart out of bounds");if(r<0||r>=this.length)throw new RangeError("Index out of range");if(n<0)throw new RangeError("sourceEnd out of bounds");n>this.length&&(n=this.length),t.length-e<n-r&&(n=t.length-e+r);var s=n-r;if(this===t&&"function"==typeof Uint8Array.prototype.copyWithin)this.copyWithin(e,r,n);else if(this===t&&r<e&&e<n)for(var c=s-1;c>=0;--c)t[c+e]=this[c+r];else Uint8Array.prototype.set.call(t,this.subarray(r,n),e);return s},_.prototype.fill=function(t,e,r,n){if("string"==typeof t){if("string"==typeof e?(n=e,e=0,r=this.length):"string"==typeof r&&(n=r,r=this.length),void 0!==n&&"string"!=typeof n)throw new TypeError("encoding must be a string");if("string"==typeof n&&!_.isEncoding(n))throw new TypeError("Unknown encoding: "+n);if(1===t.length){var s=t.charCodeAt(0);("utf8"===n&&s<128||"latin1"===n)&&(t=s);}}else"number"==typeof t?t&=255:"boolean"==typeof t&&(t=Number(t));if(e<0||this.length<e||this.length<r)throw new RangeError("Out of range index");if(r<=e)return this;var c;if(e>>>=0,r=void 0===r?this.length:r>>>0,t||(t=0),"number"==typeof t)for(c=e;c<r;++c)this[c]=t;else{var a=_.isBuffer(t)?t:_.from(t,n),i=a.length;if(0===i)throw new TypeError('The value "'+t+'" is invalid for argument "value"');for(c=0;c<r-e;++c)this[c+e]=a[c%i];}return this};var L=/[^+/0-9A-Za-z-_]/g;function R(t,e){var r;e=e||1/0;for(var n=t.length,s=null,_=[],c=0;c<n;++c){if((r=t.charCodeAt(c))>55295&&r<57344){if(!s){if(r>56319){(e-=3)>-1&&_.push(239,191,189);continue}if(c+1===n){(e-=3)>-1&&_.push(239,191,189);continue}s=r;continue}if(r<56320){(e-=3)>-1&&_.push(239,191,189),s=r;continue}r=65536+(s-55296<<10|r-56320);}else s&&(e-=3)>-1&&_.push(239,191,189);if(s=null,r<128){if((e-=1)<0)break;_.push(r);}else if(r<2048){if((e-=2)<0)break;_.push(r>>6|192,63&r|128);}else if(r<65536){if((e-=3)<0)break;_.push(r>>12|224,r>>6&63|128,63&r|128);}else{if(!(r<1114112))throw new Error("Invalid code point");if((e-=4)<0)break;_.push(r>>18|240,r>>12&63|128,r>>6&63|128,63&r|128);}}return _}function z(t){return Yt.toByteArray(function(t){if((t=(t=t.split("=")[0]).trim().replace(L,"")).length<2)return "";for(;t.length%4!=0;)t+="=";return t}(t))}function B(t,e,r,n){for(var s=0;s<n&&!(s+r>=e.length||s>=t.length);++s)e[s+r]=t[s];return s}function U(t,e){return t instanceof e||null!=t&&null!=t.constructor&&null!=t.constructor.name&&t.constructor.name===e.name}function M(t){return t!=t}var H=function(){for(var t=new Array(256),e=0;e<16;++e)for(var r=16*e,n=0;n<16;++n)t[r+n]="0123456789abcdef"[e]+"0123456789abcdef"[n];return t}();}(Ht={exports:{}},Ht.exports),Ht.exports),Gt=Ot.Buffer;Ot.SlowBuffer,Ot.INSPECT_MAX_BYTES,Ot.kMaxLength;const Vt=(Xt=Gt,(t,e)=>{if("string"==typeof t){if("string"==typeof e&&!Xt.isEncoding(e))throw new TypeError("Invalid default encoding");return Xt.from(t,e)}if(t instanceof Uint8Array)return t;if("object"==typeof t&&"string"==typeof t.value&&Xt.isEncoding(t.encoding))return Xt.from(t.value,t.encoding);throw new TypeError("Invalid format of Data")});var Xt;const jt=(t=>e=>{let r=t.from(e.buffer);return e.byteLength!==e.buffer.byteLength&&(r=r.slice(e.byteOffset,e.byteOffset+e.byteLength)),r})(Gt);function Wt(t,e="privateKey"){if(null==t||!(t.identifier instanceof Uint8Array)||"object"!=typeof t.lowLevelPrivateKey||"boolean"!=typeof t.isDisposed)throw new TypeError(`\`${e}\` is not a VirgilPrivateKey.`);if(t.isDisposed)throw new Error(`Cannot use \`${e}\` after it was disposed.`)}function Zt(t,e="publicKey"){if(null==t||!(t.identifier instanceof Uint8Array)||"object"!=typeof t.lowLevelPublicKey||"boolean"!=typeof t.isDisposed)throw new TypeError(`\`${e}\` is not a VirgilPublicKey.`);if(t.isDisposed)throw new Error(`Cannot use \`${e}\` after is was disposed.`)}function $t(t,e="publicKeys"){if(0===t.length)throw new TypeError(`\`${e}\` array must not be empty.`);t.forEach(t=>Zt(t));}const qt=(()=>{let t;return ()=>{if(!t){const e=wt();t=new e.CtrDrbg;try{t.setupDefaults();}catch(e){throw t.delete(),t=void 0,e}}return t}})();function Jt(t){const e=wt().GroupSessionMessage.deserialize(t),r={epochNumber:e.getEpoch(),sessionId:jt(e.getSessionId()).toString("hex"),data:jt(t).toString("base64")};return e.delete(),r}function Qt(t){const e=wt().GroupSessionMessage.deserialize(t),r=e.getEpoch();return e.delete(),r}function te(t){const e=new(wt().GroupSession);e.rng=qt();const r=[];try{for(const n of t){const t=wt().GroupSessionMessage.deserialize(n);r.push(t),e.addEpoch(t);}return e}finally{for(;r.length;){const t=r.pop();t&&t.delete();}}}function ee(t){const e=new(wt().Sha512);try{return e.hash(t).subarray(0,32)}finally{e.delete();}}function re(t){return t=t.slice().sort((t,e)=>Qt(t)-Qt(e)),{getSessionId(){const e=te(t),r=e.getSessionId();return e.delete(),jt(r).toString("hex")},getCurrentEpochNumber:()=>Qt(t[t.length-1]),encrypt(e,r){const n=Vt(e,"utf8");let s;Wt(r);try{s=te(t);const e=s.encrypt(n,r.lowLevelPrivateKey),_=e.serialize();return e.delete(),jt(_)}finally{s&&s.delete();}},decrypt(e,r){const n=Vt(e,"base64");let s,_;Zt(r);try{return s=te(t),_=wt().GroupSessionMessage.deserialize(n),jt(s.decrypt(_,r.lowLevelPublicKey))}finally{_&&_.delete(),s&&s.delete();}},addNewEpoch(){const e=te(t);try{const r=e.createGroupTicket(),n=r.getTicketMessage(),s=n.serialize();return t.push(s),n.delete(),r.delete(),Jt(s)}finally{e.delete();}},export:()=>t.map(jt),parseMessage:t=>Jt(Vt(t,"base64"))}}const ne=Gt.from("VIRGIL-DATA-SIGNATURE","utf8"),se=Gt.from("VIRGIL-DATA-SIGNER-ID","utf8"),_e=t=>null==t?[]:Array.isArray(t)?t:[t];class ce{constructor(t,e){this.identifier=t,this.lowLevelPrivateKey=e,this._isDisposed=!1;}get isDisposed(){return this._isDisposed}dispose(){this.lowLevelPrivateKey.delete(),this._isDisposed=!0;}}class ae{constructor(t,e){this.identifier=t,this.lowLevelPublicKey=e,this._isDisposed=!1;}get isDisposed(){return this._isDisposed}get key(){const t=new(wt().KeyAsn1Serializer);try{return t.setupDefaults(),t.serializePublicKey(this.lowLevelPublicKey)}finally{t.delete();}}dispose(){this.lowLevelPublicKey.delete(),this._isDisposed=!0;}}class ie{constructor(t,e){this._isFinished=!1,this.isRunning=!1,this.isDisposed=!1;const r=wt();this.publicKeys=_e(t),$t(this.publicKeys),this.ctrDrbg=new r.CtrDrbg;try{this.ctrDrbg.setupDefaults();}catch(t){throw this.ctrDrbg.delete(),t}if(this.recipientCipher=new r.RecipientCipher,this.aes256Gcm=new r.Aes256Gcm,this.recipientCipher.encryptionCipher=this.aes256Gcm,this.recipientCipher.random=this.ctrDrbg,this.publicKeys.forEach(({identifier:t},e)=>{this.recipientCipher.addKeyRecipient(t,this.publicKeys[e].lowLevelPublicKey);}),e){const t=Vt(e,"base64");this.messageInfoCustomParams=this.recipientCipher.customParams(),this.messageInfoCustomParams.addData(ne,t);}}get isFinished(){return this._isFinished}start(){return this.ensureLegalState(),this.recipientCipher.startEncryption(),this.isRunning=!0,jt(this.recipientCipher.packMessageInfo())}update(t){this.ensureLegalState(),this.ensureIsRunning();const e=Vt(t,"utf8");return jt(this.recipientCipher.processEncryption(e))}final(t=!0){this.ensureLegalState(),this.ensureIsRunning();try{return jt(this.recipientCipher.finishEncryption())}finally{this._isFinished=!0,this.isRunning=!1,t&&this.dispose();}}dispose(){this.recipientCipher.delete(),this.aes256Gcm.delete(),this.ctrDrbg.delete(),this.messageInfoCustomParams&&this.messageInfoCustomParams.delete(),this.isDisposed=!0;}ensureLegalState(){if(this._isFinished)throw new Error("Illegal state. Cannot use cipher after the `final` method has been called.");if(this.isDisposed)throw new Error("Illegal state. Cannot use cipher after the `dispose` method has been called.")}ensureIsRunning(){if(!this.isRunning)throw new Error("Illegal state. Cannot use cipher before the `start` method.")}}class oe{constructor(t){this._isFinished=!1,this.isDisposed=!1;const e=wt();Wt(t),this.privateKey=t,this.recipientCipher=new e.RecipientCipher;try{this.recipientCipher.startDecryptionWithKey(t.identifier,this.privateKey.lowLevelPrivateKey,new Uint8Array(0));}catch(t){throw this.recipientCipher.delete(),t}}get isFinished(){return this._isFinished}getSignature(){if(!this._isFinished)throw new Error("Illegal state. Cannot get signature before the `final` method has been called.");if(this.isDisposed)throw new Error("Illegal state. Cannot get signature after the `dispose` method has been called.");const t=this.recipientCipher.customParams();try{return jt(t.findData(ne))}finally{t.delete();}}update(t){this.ensureLegalState();const e=Vt(t,"utf8");return jt(this.recipientCipher.processDecryption(e))}final(t=!0){this.ensureLegalState();try{return jt(this.recipientCipher.finishDecryption())}finally{this._isFinished=!0,t&&this.dispose();}}dispose(){this.recipientCipher.delete(),this.isDisposed=!0;}ensureLegalState(){if(this._isFinished)throw new Error("Illegal state. Cannot use cipher after the `final` method has been called.");if(this.isDisposed)throw new Error("Illegal state. Cannot use cipher after the `dispose` method has been called.")}}class le{constructor(){this.isDisposed=!1;const t=wt();this.signer=new t.Signer,this.sha512=new t.Sha512,this.signer.hash=this.sha512,this.signer.reset();}update(t){if(this.isDisposed)throw new Error("Illegal state. Cannot use signer after the `dispose` method has been called.");const e=Vt(t,"utf8");return this.signer.appendData(e),this}sign(t,e=!0){if(this.isDisposed)throw new Error("Illegal state. The VirgilStreamSigner has been disposed. Pass `false` as the second argument to the `sign` method if you need to generate more than one signature.");Wt(t);const r=this.signer.sign(t.lowLevelPrivateKey);return e&&this.dispose(),jt(r)}dispose(){this.signer.delete(),this.sha512.delete();}}class ue{constructor(t){this.isDisposed=!1;const e=wt(),r=Vt(t,"base64");this.verifier=new e.Verifier;try{this.verifier.reset(r);}catch(t){throw this.verifier.delete(),t}}update(t){if(this.isDisposed)throw new Error("Illegal state. Cannot use signer after the `dispose` method has been called.");const e=Vt(t,"utf8");return this.verifier.appendData(e),this}verify(t,e=!0){if(this.isDisposed)throw new Error("Illegal state. The VirgilStreamVerifier has been disposed. Pass `false` as the second argument to the `verify` method if you need to verify with more than one public key.");Zt(t);const r=this.verifier.verify(t.lowLevelPublicKey);return e&&this.dispose(),r}dispose(){this.verifier.delete(),this.isDisposed=!0;}}const fe=10;class pe{constructor(t={}){this.hashAlgorithm=bt,this.keyPairType=kt;const e=wt();this.keyProvider=new e.KeyProvider;try{this.keyProvider.setupDefaults();}catch(t){throw this.keyProvider.delete(),t}this.random=new e.CtrDrbg;try{this.random.setupDefaults();}catch(t){throw this.random.delete(),this.keyProvider.delete(),t}this.defaultKeyPairType=t.defaultKeyPairType||kt.Default,this.useSha256Identifiers=t.useSha256Identifiers||!1,this._isDisposed=!1;}get isDisposed(){return this._isDisposed}dispose(){this.keyProvider.delete(),this.random.delete(),this._isDisposed=!0;}generateKeys(t){this.throwIfDisposed();const e=t||this.defaultKeyPairType,r=wt(),n=new r.KeyProvider;try{n.setupDefaults();}catch(t){throw n.delete(),t}let s;e.algId===r.AlgId.RSA&&n.setRsaParams(e.bitlen);try{s=n.generatePrivateKey(e.algId);}catch(t){throw n.delete(),t}const _=s.extractPublicKey();try{const t=this.keyProvider.exportPublicKey(_),e=this.calculateKeypairIdentifier(t,this.useSha256Identifiers);return {privateKey:new ce(e,s),publicKey:new ae(e,_)}}finally{n.delete();}}generateKeysFromKeyMaterial(t,e){this.throwIfDisposed();const r=e||this.defaultKeyPairType,n=Vt(t,"base64"),s=wt(),_=new s.KeyMaterialRng;_.resetKeyMaterial(n);const c=new s.KeyProvider;try{c.setupDefaults();}catch(t){throw _.delete(),c.delete(),t}let a;c.random=_,r.algId===s.AlgId.RSA&&c.setRsaParams(r.bitlen);try{a=c.generatePrivateKey(r.algId);}catch(t){throw _.delete(),c.delete(),t}const i=a.extractPublicKey();try{const t=this.keyProvider.exportPublicKey(i),e=this.calculateKeypairIdentifier(t,this.useSha256Identifiers);return {privateKey:new ce(e,a),publicKey:new ae(e,i)}}finally{_.delete(),c.delete();}}importPrivateKey(t){this.throwIfDisposed();const e=Vt(t,"base64"),r=this.keyProvider.importPrivateKey(e),n=r.extractPublicKey();try{const t=this.keyProvider.exportPublicKey(n),e=this.calculateKeypairIdentifier(t,this.useSha256Identifiers);return new ce(e,r)}finally{n.delete();}}exportPrivateKey(t){return this.throwIfDisposed(),Wt(t),jt(this.keyProvider.exportPrivateKey(t.lowLevelPrivateKey))}importPublicKey(t){this.throwIfDisposed();const e=Vt(t,"base64"),r=this.keyProvider.importPublicKey(e),n=this.calculateKeypairIdentifier(e,this.useSha256Identifiers);return new ae(n,r)}exportPublicKey(t){return this.throwIfDisposed(),jt(this.keyProvider.exportPublicKey(t.lowLevelPublicKey))}encrypt(t,e){this.throwIfDisposed();const r=Vt(t,"utf8"),n=_e(e);$t(n);const s=wt(),_=new s.RecipientCipher,c=new s.Aes256Gcm;_.encryptionCipher=c,_.random=this.random,n.forEach(({identifier:t},e)=>{_.addKeyRecipient(t,n[e].lowLevelPublicKey);});try{_.startEncryption();const t=_.packMessageInfo(),e=_.processEncryption(r),n=_.finishEncryption();return Gt.concat([t,e,n])}finally{_.delete(),c.delete();}}decrypt(t,e){this.throwIfDisposed();const r=Vt(t,"base64");Wt(e);const n=new(wt().RecipientCipher);n.random=this.random;try{n.startDecryptionWithKey(e.identifier,e.lowLevelPrivateKey,new Uint8Array(0));const t=n.processDecryption(r),s=n.finishDecryption();return Gt.concat([t,s])}finally{n.delete();}}calculateHash(t,e=bt.SHA512){const r=Vt(t,"utf8");let n;switch(e){case bt.SHA224:n=this.createHash(r,wt().Sha224);break;case bt.SHA256:n=this.createHash(r,wt().Sha256);break;case bt.SHA384:n=this.createHash(r,wt().Sha384);break;case bt.SHA512:n=this.createHash(r,wt().Sha512);break;default:throw new TypeError("Unknown hash algorithm")}return jt(n)}extractPublicKey(t){this.throwIfDisposed(),Wt(t);const e=t.lowLevelPrivateKey.extractPublicKey();return new ae(t.identifier,e)}calculateSignature(t,e){this.throwIfDisposed();const r=Vt(t,"utf8");Wt(e);const n=wt(),s=new n.Signer,_=new n.Sha512;s.hash=_,s.reset(),s.appendData(r);try{const t=s.sign(e.lowLevelPrivateKey);return jt(t)}finally{s.delete(),_.delete();}}verifySignature(t,e,r){this.throwIfDisposed();const n=Vt(t,"utf8"),s=Vt(e,"base64");Zt(r);const _=new(wt().Verifier);try{_.reset(s);}catch(t){throw _.delete(),t}_.appendData(n);const c=_.verify(r.lowLevelPublicKey);return _.delete(),c}signThenEncrypt(t,e,r){this.throwIfDisposed();const n=Vt(t,"utf8");Wt(e);const s=_e(r);$t(s);const _=wt(),c=new _.RecipientCipher,a=new _.Aes256Gcm;c.encryptionCipher=a,c.random=this.random,s.forEach(({identifier:t},e)=>{c.addKeyRecipient(t,s[e].lowLevelPublicKey);});const i=c.customParams();try{const t=this.calculateSignature(n,e);i.addData(ne,t),i.addData(se,e.identifier),c.startEncryption();const r=c.packMessageInfo(),s=c.processEncryption(n),_=c.finishEncryption();return Gt.concat([r,s,_])}finally{c.delete(),a.delete(),i.delete();}}decryptThenVerify(t,e,r){this.throwIfDisposed();const n=Vt(t,"base64"),s=_e(r);$t(s),Wt(e);const _=new(wt().RecipientCipher);let c;_.random=this.random;try{_.startDecryptionWithKey(e.identifier,e.lowLevelPrivateKey,new Uint8Array(0));const t=_.processDecryption(n),r=_.finishDecryption();c=Gt.concat([t,r]);}catch(t){throw _.delete(),t}const a=_.customParams();let i;if(1===s.length)i=s[0];else{let t;try{t=a.findData(se);}catch(t){throw _.delete(),a.delete(),t}for(let e=0;e<s.length;e+=1)if(0===Gt.compare(t,s[e].identifier)){i=s[e];break}if(!i)throw _.delete(),a.delete(),new Error("Signer not found")}try{const t=a.findData(ne);if(!this.verifySignature(c,t,i))throw new Error("Invalid signature");return c}finally{_.delete(),a.delete();}}getRandomBytes(t){this.throwIfDisposed();const e=this.random.random(t);return jt(e)}signThenEncryptDetached(t,e,r){this.throwIfDisposed();const n=Vt(t,"utf8");Wt(e);const s=_e(r);$t(s);const _=wt(),c=new _.RecipientCipher,a=new _.Aes256Gcm;c.encryptionCipher=a,c.random=this.random,s.forEach(({identifier:t},e)=>{c.addKeyRecipient(t,s[e].lowLevelPublicKey);});const i=c.customParams();try{const t=this.calculateSignature(n,e);i.addData(ne,t),i.addData(se,e.identifier),c.startEncryption();const r=c.packMessageInfo(),s=c.processEncryption(n),_=c.finishEncryption();return {encryptedData:Gt.concat([s,_]),metadata:jt(r)}}finally{c.delete(),a.delete(),i.delete();}}decryptThenVerifyDetached(t,e,r,n){this.throwIfDisposed();const s=Vt(t,"base64"),_=Vt(e,"base64");Wt(r);const c=_e(n);$t(c);const a=new(wt().RecipientCipher);let i;a.random=this.random;try{a.startDecryptionWithKey(r.identifier,r.lowLevelPrivateKey,_);const t=a.processDecryption(s),e=a.finishDecryption();i=Gt.concat([t,e]);}catch(t){throw a.delete(),t}const o=a.customParams();let l;if(1===c.length)l=c[0];else{let t;try{t=o.findData(se);}catch(t){throw a.delete(),o.delete(),t}for(let e=0;e<c.length;e+=1)if(0===Gt.compare(t,c[e].identifier)){l=c[e];break}if(!l)throw a.delete(),o.delete(),new Error("Signer not found")}try{const t=o.findData(ne);if(!this.verifySignature(i,t,l))throw new Error("Invalid signature");return i}finally{a.delete(),o.delete();}}createStreamCipher(t,e){return this.throwIfDisposed(),new ie(t,e)}createStreamDecipher(t){return this.throwIfDisposed(),new oe(t)}createStreamSigner(){return this.throwIfDisposed(),new le}createStreamVerifier(t){return this.throwIfDisposed(),new ue(t)}generateGroupSession(t){this.throwIfDisposed();const e=Vt(t,"utf8");this.validateGroupId(e);const r=function(t){const e=new(wt().GroupSessionTicket);e.rng=qt();try{return e.setupTicketAsNew(t),e.getTicketMessage()}finally{e.delete();}}(ee(e)),n=r.serialize();return r.delete(),re([n])}importGroupSession(t){if(this.throwIfDisposed(),!Array.isArray(t))throw new TypeError("Epoch messages must be an array.");if(0===t.length)throw new Error("Epoch messages must not be empty.");return re(t.map(t=>Vt(t,"base64")))}calculateGroupSessionId(t){this.throwIfDisposed();const e=Vt(t,"utf8");return this.validateGroupId(e),jt(ee(e)).toString("hex")}validateGroupId(t){if(t.byteLength<fe)throw new Error(`The given group Id is too short. Must be at least ${fe} bytes.`)}createHash(t,e){const r=new e,n=r.hash(t);return r.delete(),n}calculateKeypairIdentifier(t,e){return e?this.createHash(t,wt().Sha256):this.createHash(t,wt().Sha512).slice(0,8)}throwIfDisposed(){if(this._isDisposed)throw new Error("Cannot use an instance of `VirgilCrypto` class after the `dispose` method has been called.")}}

            /**
             * @hidden
             */
            function processFile({ file, chunkSize, signal, onChunkCallback, onFinishCallback, onErrorCallback, }) {
                const reader = new FileReader();
                const dataSize = file.size;
                let offset = 0;
                let endOffset = Math.min(offset + chunkSize, dataSize);
                if (signal) {
                    const onAbort = () => {
                        reader.abort();
                        onErrorCallback(new AbortError());
                    };
                    if (signal.aborted)
                        return onAbort();
                    else
                        signal.addEventListener('abort', onAbort);
                }
                reader.onload = () => {
                    if (!reader.result)
                        throw new Error('reader.result is null');
                    try {
                        onChunkCallback(reader.result, endOffset);
                    }
                    catch (err) {
                        return onErrorCallback(err);
                    }
                    offset = endOffset;
                    endOffset = Math.min(offset + chunkSize, dataSize);
                    if (offset === dataSize) {
                        try {
                            onFinishCallback();
                        }
                        catch (err) {
                            onErrorCallback(err);
                        }
                    }
                    else {
                        reader.readAsArrayBuffer(file.slice(offset, endOffset));
                    }
                };
                reader.onerror = () => onErrorCallback(reader.error);
                reader.readAsArrayBuffer(file.slice(offset, endOffset));
            }

            /**
             * @hidden
             */
            // eslint-disable-next-line @typescript-eslint/no-explicit-any
            const isFile$1 = (val) => {
                return val instanceof File;
            };

            class EThree extends AbstractEThree {
                /**
                 * @hidden
                 * @param identity - Identity of the current user.
                 */
                constructor(identity, options) {
                    super(EThree.prepareConstructorParams(identity, options));
                    /**
                     * @hidden
                     */
                    this.toData = (value) => {
                        if (value instanceof ArrayBuffer) {
                            return new Uint8Array(value);
                        }
                        return value;
                    };
                }
                /**
                 * Initialize a new instance of EThree which tied to specific user.
                 * @param getToken - Function that receive JWT.
                 */
                static initialize(getToken, options = {}) {
                    return __awaiter$3(this, void 0, void 0, function* () {
                        const modulesToLoad = [];
                        if (!gt()) {
                            modulesToLoad.push(initFoundation().then(Et));
                        }
                        if (!h$1()) {
                            modulesToLoad.push(initPythia().then(c$2));
                        }
                        yield Promise.all(modulesToLoad);
                        if (typeof getToken !== 'function') {
                            throw new TypeError(`EThree.initialize expects a function that returns Virgil JWT, got ${typeof getToken}`);
                        }
                        const opts = Object.assign({ accessTokenProvider: new CachingJwtProvider(getToken) }, options);
                        const token = yield opts.accessTokenProvider.getToken({
                            service: 'cards',
                            operation: '',
                        });
                        const identity = token.identity();
                        return new EThree(identity, opts);
                    });
                }
                /**
                 * Signs and encrypts File or Blob for recipient public key or `LookupResult` dictionary for multiple
                 * recipients. If there is no recipient and the message is encrypted for the current user, omit the
                 * public key parameter. You can define chunk size and a callback, that will be invoked on each chunk.
                 *
                 * The file will be read twice during this method execution:
                 * 1. To calculate the signature of the plaintext file.
                 * 2. To encrypt the file with encoded signature.
                 */
                encryptFile(file, recipients, options = {}) {
                    return __awaiter$3(this, void 0, void 0, function* () {
                        const chunkSize = options.chunkSize ? options.chunkSize : 64 * 1024;
                        if (!Number.isInteger(chunkSize))
                            throw TypeError('chunkSize should be an integer value');
                        const fileSize = file.size;
                        const privateKey = yield this.keyLoader.loadLocalPrivateKey();
                        if (!privateKey)
                            throw new RegisterRequiredError();
                        const publicKeys = this.getPublicKeysForEncryption(privateKey, recipients);
                        if (!publicKeys) {
                            throw new TypeError('Could not get public keys from the second argument.\n' +
                                'Make sure you pass the resolved value of "EThree.findUsers" or "EThree.lookupPublicKeys" methods ' +
                                'when encrypting for other users, or nothing when encrypting for the current user only.');
                        }
                        const streamSigner = this.virgilCrypto.createStreamSigner();
                        const signaturePromise = new Promise((resolve, reject) => {
                            const onChunk = (chunk, offset) => {
                                if (options.onProgress) {
                                    options.onProgress({
                                        state: VIRGIL_STREAM_SIGNING_STATE,
                                        bytesProcessed: offset,
                                        fileSize: fileSize,
                                    });
                                }
                                streamSigner.update(this.toData(chunk));
                            };
                            const onFinishCallback = () => resolve(streamSigner.sign(privateKey));
                            // eslint-disable-next-line @typescript-eslint/no-explicit-any
                            const onErrorCallback = (err) => {
                                streamSigner.dispose();
                                reject(err);
                            };
                            processFile({
                                file,
                                chunkSize,
                                onFinishCallback,
                                onErrorCallback,
                                onChunkCallback: onChunk,
                                signal: options.signal,
                            });
                        });
                        const streamCipher = this.virgilCrypto.createStreamCipher(publicKeys, yield signaturePromise);
                        const encryptedChunksPromise = new Promise((resolve, reject) => {
                            const encryptedChunks = [];
                            encryptedChunks.push(streamCipher.start());
                            const onChunkCallback = (chunk, offset) => {
                                encryptedChunks.push(streamCipher.update(this.toData(chunk)));
                                if (options.onProgress) {
                                    options.onProgress({
                                        state: VIRGIL_STREAM_ENCRYPTING_STATE,
                                        bytesProcessed: offset,
                                        fileSize: fileSize,
                                    });
                                }
                            };
                            const onFinishCallback = () => {
                                encryptedChunks.push(streamCipher.final());
                                resolve(encryptedChunks);
                            };
                            // eslint-disable-next-line @typescript-eslint/no-explicit-any
                            const onErrorCallback = (err) => {
                                reject(err);
                                streamCipher.dispose();
                            };
                            processFile({
                                file,
                                chunkSize,
                                onChunkCallback,
                                onFinishCallback,
                                onErrorCallback,
                                signal: options.signal,
                            });
                        });
                        const encryptedChunks = yield encryptedChunksPromise;
                        if (isFile$1(file))
                            return new File(encryptedChunks, file.name, { type: file.type });
                        return new Blob(encryptedChunks, { type: file.type });
                    });
                }
                /**
                 * Decrypts and verifies integrity of File or Blob for recipient public key. If there is no recipient
                 * and the message is encrypted for the current user, omit the public key parameter. You can define
                 * chunk size and a callback, that will be invoked on each chunk.
                 *
                 * The file will be read twice during this method execution:
                 * 1. To decrypt encrypted file.
                 * 2. To verify the validity of the signature over the decrypted file for the public key.
                 */
                decryptFile(file, senderCardOrPublicKey, options = {}) {
                    return __awaiter$3(this, void 0, void 0, function* () {
                        const fileSize = file.size;
                        const chunkSize = options.chunkSize ? options.chunkSize : 64 * 1024;
                        if (!Number.isInteger(chunkSize))
                            throw TypeError('chunkSize should be an integer value');
                        const privateKey = (yield this.keyLoader.loadLocalPrivateKey());
                        if (!privateKey)
                            throw new RegisterRequiredError();
                        const publicKey = this.getPublicKeyForVerification(privateKey, senderCardOrPublicKey, options.encryptedOn);
                        if (!publicKey) {
                            throw new TypeError('Could not get public key from the second argument.' +
                                'Expected a Virgil Card or a Public Key object. Got ' +
                                typeof senderCardOrPublicKey);
                        }
                        const streamDecipher = this.virgilCrypto.createStreamDecipher(privateKey);
                        const decryptedChunksPromise = new Promise((resolve, reject) => {
                            const decryptedChunks = [];
                            const onChunkCallback = (chunk, offset) => {
                                decryptedChunks.push(streamDecipher.update(this.toData(chunk)));
                                if (options.onProgress) {
                                    options.onProgress({
                                        state: VIRGIL_STREAM_DECRYPTING_STATE,
                                        bytesProcessed: offset,
                                        fileSize: fileSize,
                                    });
                                }
                            };
                            const onFinishCallback = () => {
                                decryptedChunks.push(streamDecipher.final(false));
                                const signature = streamDecipher.getSignature();
                                streamDecipher.dispose();
                                if (!signature)
                                    throw new IntegrityCheckFailedError('Signature not present.');
                                resolve({ decryptedChunks, signature });
                            };
                            const onErrorCallback = (err) => {
                                streamDecipher.dispose();
                                reject(err);
                            };
                            processFile({
                                file,
                                chunkSize,
                                onChunkCallback,
                                onFinishCallback,
                                onErrorCallback,
                                signal: options.signal,
                            });
                        });
                        const { decryptedChunks, signature } = yield decryptedChunksPromise;
                        const streamVerifier = this.virgilCrypto.createStreamVerifier(signature);
                        let decryptedFile;
                        if (isFile$1(file))
                            decryptedFile = new File(decryptedChunks, file.name, { type: file.type });
                        decryptedFile = new Blob(decryptedChunks, { type: file.type });
                        const decryptedFileSize = decryptedFile.size;
                        const verifyPromise = new Promise((resolve, reject) => {
                            const onChunkCallback = (chunk, offset) => {
                                streamVerifier.update(this.toData(chunk));
                                if (options.onProgress) {
                                    options.onProgress({
                                        state: VIRGIL_STREAM_VERIFYING_STATE,
                                        bytesProcessed: offset,
                                        fileSize: decryptedFileSize,
                                    });
                                }
                            };
                            const onFinishCallback = () => resolve(streamVerifier.verify(publicKey));
                            const onErrorCallback = (err) => {
                                streamVerifier.dispose();
                                reject(err);
                            };
                            processFile({
                                file: decryptedFile,
                                chunkSize,
                                onChunkCallback,
                                onFinishCallback,
                                onErrorCallback,
                                signal: options.signal,
                            });
                        });
                        const isVerified = yield verifyPromise;
                        if (!isVerified) {
                            throw new IntegrityCheckFailedError('Signature verification has failed.');
                        }
                        return decryptedFile;
                    });
                }
                /**
                 * @hidden
                 */
                static prepareConstructorParams(identity, options) {
                    const opts = Object.assign({ apiUrl: DEFAULT_API_URL, storageName: DEFAULT_STORAGE_NAME, groupStorageName: DEFAULT_GROUP_STORAGE_NAME, useSha256Identifiers: false }, options);
                    const accessTokenProvider = opts.accessTokenProvider;
                    const keyEntryStorage = opts.keyEntryStorage || new KeyEntryStorage(opts.storageName);
                    const virgilCrypto = new pe({ useSha256Identifiers: opts.useSha256Identifiers });
                    const cardCrypto = new e$3(virgilCrypto);
                    const brainKeyCrypto = new R$1();
                    const cardVerifier = new VirgilCardVerifier(cardCrypto, {
                        verifySelfSignature: opts.apiUrl === DEFAULT_API_URL,
                        verifyVirgilSignature: opts.apiUrl === DEFAULT_API_URL,
                    });
                    const keyLoader = new PrivateKeyLoader(identity, {
                        accessTokenProvider,
                        virgilCrypto,
                        brainKeyCrypto,
                        keyEntryStorage,
                        apiUrl: opts.apiUrl,
                    });
                    const cardManager = new CardManager({
                        cardCrypto,
                        cardVerifier,
                        accessTokenProvider,
                        retryOnUnauthorized: true,
                        apiUrl: opts.apiUrl,
                        productInfo: {
                            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                            product: "e3kit",
                            // eslint-disable-next-line @typescript-eslint/no-non-null-assertion
                            version: "0.7.1",
                        },
                    });
                    const groupStorageLeveldown = levelJs(opts.groupStorageName);
                    return {
                        identity,
                        virgilCrypto,
                        cardManager,
                        accessTokenProvider,
                        keyEntryStorage,
                        keyLoader,
                        groupStorageLeveldown,
                    };
                }
                /**
                 * @hidden
                 */
                isPublicKey(publicKey) {
                    return publicKey instanceof ae;
                }
            }

            exports.AbortError = AbortError;
            exports.EThree = EThree;
            exports.GroupError = GroupError;
            exports.IdentityAlreadyExistsError = IdentityAlreadyExistsError;
            exports.IntegrityCheckFailedError = IntegrityCheckFailedError;
            exports.LookupError = LookupError;
            exports.LookupNotFoundError = LookupNotFoundError;
            exports.MissingPrivateKeyError = MissingPrivateKeyError;
            exports.MultipleCardsError = MultipleCardsError;
            exports.PrivateKeyAlreadyExistsError = PrivateKeyAlreadyExistsError;
            exports.PrivateKeyNoBackupError = PrivateKeyNoBackupError;
            exports.RegisterRequiredError = RegisterRequiredError;
            exports.SdkError = SdkError;
            exports.VIRGIL_STREAM_DECRYPTING_STATE = VIRGIL_STREAM_DECRYPTING_STATE;
            exports.VIRGIL_STREAM_ENCRYPTING_STATE = VIRGIL_STREAM_ENCRYPTING_STATE;
            exports.VIRGIL_STREAM_SIGNING_STATE = VIRGIL_STREAM_SIGNING_STATE;
            exports.VIRGIL_STREAM_VERIFYING_STATE = VIRGIL_STREAM_VERIFYING_STATE;
            exports.WrongKeyknoxPasswordError = WrongKeyknoxPasswordError;

            Object.defineProperty(exports, '__esModule', { value: true });

})));
